Class: Google::Apis::AndroidpublisherV3::ApksAddExternallyHostedResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response for creating a new externally hosted APK.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApksAddExternallyHostedResponse

Returns a new instance of ApksAddExternallyHostedResponse.



537
538
539
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#externally_hosted_apkGoogle::Apis::AndroidpublisherV3::ExternallyHostedApk

Defines an APK available for this application that is hosted externally and not uploaded to Google Play. This function is only available to organizations using Managed Play whose application is configured to restrict distribution to the organizations. Corresponds to the JSON property externallyHostedApk



535
536
537
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 535

def externally_hosted_apk
  @externally_hosted_apk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



542
543
544
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 542

def update!(**args)
  @externally_hosted_apk = args[:externally_hosted_apk] if args.key?(:externally_hosted_apk)
end