Class: Google::Apis::AndroidpublisherV3::AppRecoveryAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information about an app recovery action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppRecoveryAction

Returns a new instance of AppRecoveryAction.



686
687
688
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_recovery_idFixnum

ID corresponding to the app recovery action. Corresponds to the JSON property appRecoveryId

Returns:

  • (Fixnum)


642
643
644
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 642

def app_recovery_id
  @app_recovery_id
end

#cancel_timeString

Timestamp of when the app recovery action is canceled by the developer. Only set if the recovery action has been canceled. Corresponds to the JSON property cancelTime

Returns:

  • (String)


648
649
650
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 648

def cancel_time
  @cancel_time
end

#create_timeString

Timestamp of when the app recovery action is created by the developer. It is always set after creation of the recovery action. Corresponds to the JSON property createTime

Returns:

  • (String)


654
655
656
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 654

def create_time
  @create_time
end

#deploy_timeString

Timestamp of when the app recovery action is deployed to the users. Only set if the recovery action has been deployed. Corresponds to the JSON property deployTime

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 660

def deploy_time
  @deploy_time
end

#last_update_timeString

Timestamp of when the developer last updated recovery action. In case the action is cancelled, it corresponds to cancellation time. It is always set after creation of the recovery action. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


667
668
669
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 667

def last_update_time
  @last_update_time
end

#remote_in_app_update_dataGoogle::Apis::AndroidpublisherV3::RemoteInAppUpdateData

Data related to Remote In-App Update action such as recovered user count, affected user count etc. Corresponds to the JSON property remoteInAppUpdateData



673
674
675
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 673

def remote_in_app_update_data
  @remote_in_app_update_data
end

#statusString

The status of the recovery action. Corresponds to the JSON property status

Returns:

  • (String)


678
679
680
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 678

def status
  @status
end

#targetingGoogle::Apis::AndroidpublisherV3::Targeting

Targeting details for a recovery action such as regions, android sdk levels, app versions etc. Corresponds to the JSON property targeting



684
685
686
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 684

def targeting
  @targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



691
692
693
694
695
696
697
698
699
700
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 691

def update!(**args)
  @app_recovery_id = args[:app_recovery_id] if args.key?(:app_recovery_id)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @remote_in_app_update_data = args[:remote_in_app_update_data] if args.key?(:remote_in_app_update_data)
  @status = args[:status] if args.key?(:status)
  @targeting = args[:targeting] if args.key?(:targeting)
end