Class: Google::Apis::AndroidpublisherV3::BasePlan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single base plan for a subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BasePlan

Returns a new instance of BasePlan.



1216
1217
1218
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewing_base_plan_typeGoogle::Apis::AndroidpublisherV3::AutoRenewingBasePlanType

Represents a base plan that automatically renews at the end of its subscription period. Corresponds to the JSON property autoRenewingBasePlanType



1169
1170
1171
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1169

def auto_renewing_base_plan_type
  @auto_renewing_base_plan_type
end

#base_plan_idString

Required. Immutable. The unique identifier of this base plan. Must be unique within the subscription, and conform with RFC-1034. That is, this ID can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-), and be at most 63 characters. Corresponds to the JSON property basePlanId

Returns:

  • (String)


1177
1178
1179
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1177

def base_plan_id
  @base_plan_id
end

#installments_base_plan_typeGoogle::Apis::AndroidpublisherV3::InstallmentsBasePlanType

Represents an installments base plan where a user commits to a specified number of payments. Corresponds to the JSON property installmentsBasePlanType



1183
1184
1185
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1183

def installments_base_plan_type
  @installments_base_plan_type
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

List of up to 20 custom tags specified for this base plan, and returned to the app through the billing library. Subscription offers for this base plan will also receive these offer tags in the billing library. Corresponds to the JSON property offerTags



1190
1191
1192
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1190

def offer_tags
  @offer_tags
end

#other_regions_configGoogle::Apis::AndroidpublisherV3::OtherRegionsBasePlanConfig

Pricing information for any new locations Play may launch in. Corresponds to the JSON property otherRegionsConfig



1195
1196
1197
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1195

def other_regions_config
  @other_regions_config
end

#prepaid_base_plan_typeGoogle::Apis::AndroidpublisherV3::PrepaidBasePlanType

Represents a base plan that does not automatically renew at the end of the base plan, and must be manually renewed by the user. Corresponds to the JSON property prepaidBasePlanType



1201
1202
1203
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1201

def prepaid_base_plan_type
  @prepaid_base_plan_type
end

#regional_configsArray<Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig>

Region-specific information for this base plan. Corresponds to the JSON property regionalConfigs



1206
1207
1208
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1206

def regional_configs
  @regional_configs
end

#stateString

Output only. The state of the base plan, i.e. whether it's active. Draft and inactive base plans can be activated or deleted. Active base plans can be made inactive. Inactive base plans can be canceled. This field cannot be changed by updating the resource. Use the dedicated endpoints instead. Corresponds to the JSON property state

Returns:

  • (String)


1214
1215
1216
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1214

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1221

def update!(**args)
  @auto_renewing_base_plan_type = args[:auto_renewing_base_plan_type] if args.key?(:auto_renewing_base_plan_type)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @installments_base_plan_type = args[:installments_base_plan_type] if args.key?(:installments_base_plan_type)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config)
  @prepaid_base_plan_type = args[:prepaid_base_plan_type] if args.key?(:prepaid_base_plan_type)
  @regional_configs = args[:regional_configs] if args.key?(:regional_configs)
  @state = args[:state] if args.key?(:state)
end