Class: Google::Apis::AndroidpublisherV3::BatchDeletePurchaseOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for BatchDeletePurchaseOption.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchDeletePurchaseOptionsRequest

Returns a new instance of BatchDeletePurchaseOptionsRequest.



1265
1266
1267
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requestsArray<Google::Apis::AndroidpublisherV3::DeletePurchaseOptionRequest>

Required. A list of delete requests of up to 100 elements. All requests must delete purchase options from different one-time products. Corresponds to the JSON property requests



1263
1264
1265
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1263

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1270
1271
1272
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1270

def update!(**args)
  @requests = args[:requests] if args.key?(:requests)
end