Class: Google::Apis::AndroidpublisherV3::BatchGetOneTimeProductOffersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BatchGetOneTimeProductOffersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for the BatchGetOneTimeProductOffers endpoint.
Instance Attribute Summary collapse
-
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The list of updated one-time product offers, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchGetOneTimeProductOffersResponse
constructor
A new instance of BatchGetOneTimeProductOffersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchGetOneTimeProductOffersResponse
Returns a new instance of BatchGetOneTimeProductOffersResponse.
1138 1139 1140 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The list of updated one-time product offers, in the same order as the request.
Corresponds to the JSON property oneTimeProductOffers
1136 1137 1138 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1136 def one_time_product_offers @one_time_product_offers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1143 1144 1145 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1143 def update!(**args) @one_time_product_offers = args[:one_time_product_offers] if args.key?(:one_time_product_offers) end |