Class: Google::Apis::AndroidpublisherV3::BatchGetOneTimeProductsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BatchGetOneTimeProductsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for the BatchGetOneTimeProducts endpoint.
Instance Attribute Summary collapse
-
#one_time_products ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProduct>
The list of requested one-time products, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchGetOneTimeProductsResponse
constructor
A new instance of BatchGetOneTimeProductsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchGetOneTimeProductsResponse
Returns a new instance of BatchGetOneTimeProductsResponse.
1138 1139 1140 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#one_time_products ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProduct>
The list of requested one-time products, in the same order as the request.
Corresponds to the JSON property oneTimeProducts
1136 1137 1138 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1136 def one_time_products @one_time_products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1143 1144 1145 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1143 def update!(**args) @one_time_products = args[:one_time_products] if args.key?(:one_time_products) end |