Class: Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductOfferStatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductOfferStatesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for BatchUpdateOneTimeProductOfferStates.
Instance Attribute Summary collapse
-
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The updated one-time product offers list, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateOneTimeProductOfferStatesResponse
constructor
A new instance of BatchUpdateOneTimeProductOfferStatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateOneTimeProductOfferStatesResponse
Returns a new instance of BatchUpdateOneTimeProductOfferStatesResponse.
1353 1354 1355 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The updated one-time product offers list, in the same order as the request.
Corresponds to the JSON property oneTimeProductOffers
1351 1352 1353 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1351 def one_time_product_offers @one_time_product_offers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1358 1359 1360 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1358 def update!(**args) @one_time_product_offers = args[:one_time_product_offers] if args.key?(:one_time_product_offers) end |