Class: Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductOffersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductOffersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for BatchUpdateOneTimeProductOffers.
Instance Attribute Summary collapse
-
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The list of updated one-time product offers, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateOneTimeProductOffersResponse
constructor
A new instance of BatchUpdateOneTimeProductOffersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateOneTimeProductOffersResponse
Returns a new instance of BatchUpdateOneTimeProductOffersResponse.
1392 1393 1394 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The list of updated one-time product offers, in the same order as the request.
Corresponds to the JSON property oneTimeProductOffers
1390 1391 1392 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1390 def one_time_product_offers @one_time_product_offers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1397 1398 1399 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1397 def update!(**args) @one_time_product_offers = args[:one_time_product_offers] if args.key?(:one_time_product_offers) end |