Class: Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for BatchUpdateOneTimeProduct.
Instance Attribute Summary collapse
-
#one_time_products ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProduct>
The list of updated one-time products list, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateOneTimeProductsResponse
constructor
A new instance of BatchUpdateOneTimeProductsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateOneTimeProductsResponse
Returns a new instance of BatchUpdateOneTimeProductsResponse.
1412 1413 1414 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#one_time_products ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProduct>
The list of updated one-time products list, in the same order as the request.
Corresponds to the JSON property oneTimeProducts
1410 1411 1412 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1410 def one_time_products @one_time_products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1417 1418 1419 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1417 def update!(**args) @one_time_products = args[:one_time_products] if args.key?(:one_time_products) end |