Class: Google::Apis::AndroidpublisherV3::Bundle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information about an app bundle. The resource for BundlesService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Bundle

Returns a new instance of Bundle.



1601
1602
1603
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sha1String

A sha1 hash of the upload payload, encoded as a hex string and matching the output of the sha1sum command. Corresponds to the JSON property sha1

Returns:

  • (String)


1587
1588
1589
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1587

def sha1
  @sha1
end

#sha256String

A sha256 hash of the upload payload, encoded as a hex string and matching the output of the sha256sum command. Corresponds to the JSON property sha256

Returns:

  • (String)


1593
1594
1595
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1593

def sha256
  @sha256
end

#version_codeFixnum

The version code of the Android App Bundle, as specified in the Android App Bundle's base module APK manifest file. Corresponds to the JSON property versionCode

Returns:

  • (Fixnum)


1599
1600
1601
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1599

def version_code
  @version_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1606
1607
1608
1609
1610
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1606

def update!(**args)
  @sha1 = args[:sha1] if args.key?(:sha1)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @version_code = args[:version_code] if args.key?(:version_code)
end