Class: Google::Apis::AndroidpublisherV3::CatalogAppView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

LINT.IfChange A view of a Google Play app within the Catalog Export for app stores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CatalogAppView

Returns a new instance of CatalogAppView.



2227
2228
2229
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_version_namesArray<String>

Active versions of the app mapped from android:versionName manifest attributes. Corresponds to the JSON property activeVersionNames

Returns:

  • (Array<String>)


2100
2101
2102
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2100

def active_version_names
  @active_version_names
end

#app_categoryString

The category of the app. Corresponds to the JSON property appCategory

Returns:

  • (String)


2105
2106
2107
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2105

def app_category
  @app_category
end

#app_contact_informationGoogle::Apis::AndroidpublisherV3::AppContactInformation

Contact information for the app. Corresponds to the JSON property appContactInformation



2110
2111
2112
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2110

def app_contact_information
  @app_contact_information
end

#app_subcategoryString

The subcategory of the app e.g. "GAME_ACTION". Corresponds to the JSON property appSubcategory

Returns:

  • (String)


2115
2116
2117
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2115

def app_subcategory
  @app_subcategory
end

#delivery_tokenString

The token used for delivery of the app with the Google Play Inline Install API. Corresponds to the JSON property deliveryToken

Returns:

  • (String)


2120
2121
2122
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2120

def delivery_token
  @delivery_token
end

#developer_detailsGoogle::Apis::AndroidpublisherV3::DeveloperDetails

The developer details of a Google Play app. Corresponds to the JSON property developerDetails



2125
2126
2127
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2125

def developer_details
  @developer_details
end

#device_compatibility_requirementsArray<Google::Apis::AndroidpublisherV3::DeviceCompatibilityRequirements>

The app may specify multiple sets of device compatibility requirements, and a device is considered compatible with the app if it satisfies at least one of DeviceCompatibilityRequirements. Corresponds to the JSON property deviceCompatibilityRequirements



2132
2133
2134
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2132

def device_compatibility_requirements
  @device_compatibility_requirements
end

#excluded_devices_by_identifierArray<Google::Apis::AndroidpublisherV3::DeviceIdentifier>

List of devices excluded from the app's distribution even if they are otherwise compatible with the requirements from device_compatibility_requirements. These are OR-ed, i.e. a device is excluded if it matches any of the identifiers. Corresponds to the JSON property excludedDevicesByIdentifier



2140
2141
2142
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2140

def excluded_devices_by_identifier
  @excluded_devices_by_identifier
end

#excluded_devices_by_selectorArray<Google::Apis::AndroidpublisherV3::CatalogDeviceSelector>

List of devices excluded from the app's distribution even if they are otherwise compatible with the requirements from device_compatibility_requirements. A device is excluded if it matches any of given the selectors. Corresponds to the JSON property excludedDevicesBySelector



2148
2149
2150
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2148

def excluded_devices_by_selector
  @excluded_devices_by_selector
end

#first_release_dateGoogle::Apis::AndroidpublisherV3::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property firstReleaseDate



2160
2161
2162
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2160

def first_release_date
  @first_release_date
end

#has_in_app_adsBoolean Also known as: has_in_app_ads?

Whether the app has ads. Corresponds to the JSON property hasInAppAds

Returns:

  • (Boolean)


2165
2166
2167
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2165

def has_in_app_ads
  @has_in_app_ads
end

#has_in_app_purchasesBoolean Also known as: has_in_app_purchases?

Whether the app has in-app purchases through Google Play. Corresponds to the JSON property hasInAppPurchases

Returns:

  • (Boolean)


2171
2172
2173
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2171

def has_in_app_purchases
  @has_in_app_purchases
end

#iarc_certificate_idString

The IARC certificate ID for the app. Corresponds to the JSON property iarcCertificateId

Returns:

  • (String)


2177
2178
2179
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2177

def iarc_certificate_id
  @iarc_certificate_id
end

#is_adult_only_audienceBoolean Also known as: is_adult_only_audience?

Whether the app is targeted to an adult-only (18+) audience. Corresponds to the JSON property isAdultOnlyAudience

Returns:

  • (Boolean)


2182
2183
2184
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2182

def is_adult_only_audience
  @is_adult_only_audience
end

#last_publish_timeString

The timestamp when the app was last published. Corresponds to the JSON property lastPublishTime

Returns:

  • (String)


2188
2189
2190
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2188

def last_publish_time
  @last_publish_time
end

#localized_store_listingsGoogle::Apis::AndroidpublisherV3::LocalizedStoreListings

The localized store listings of an app. Corresponds to the JSON property localizedStoreListings



2193
2194
2195
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2193

def localized_store_listings
  @localized_store_listings
end

#package_nameString

The package name of the app. Corresponds to the JSON property packageName

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2198

def package_name
  @package_name
end

#permissionsArray<Google::Apis::AndroidpublisherV3::CatalogPermission>

Required permissions declared by the app which apply for all Android SDK versions. Corresponds to the JSON property permissions



2204
2205
2206
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2204

def permissions
  @permissions
end

#permissions_sdk23Array<Google::Apis::AndroidpublisherV3::CatalogPermission>

Required permissions declared by the app which apply for Android SDK versions SDK 23 and above. Corresponds to the JSON property permissionsSdk23



2210
2211
2212
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2210

def permissions_sdk23
  @permissions_sdk23
end

#price_in_the_united_statesGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property priceInTheUnitedStates



2215
2216
2217
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2215

def price_in_the_united_states
  @price_in_the_united_states
end

#privacy_policy_urlString

The URL of the app's privacy policy. Corresponds to the JSON property privacyPolicyUrl

Returns:

  • (String)


2220
2221
2222
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2220

def privacy_policy_url
  @privacy_policy_url
end

#sale_price_in_the_united_statesGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property salePriceInTheUnitedStates



2225
2226
2227
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2225

def sale_price_in_the_united_states
  @sale_price_in_the_united_states
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2232

def update!(**args)
  @active_version_names = args[:active_version_names] if args.key?(:active_version_names)
  @app_category = args[:app_category] if args.key?(:app_category)
  @app_contact_information = args[:app_contact_information] if args.key?(:app_contact_information)
  @app_subcategory = args[:app_subcategory] if args.key?(:app_subcategory)
  @delivery_token = args[:delivery_token] if args.key?(:delivery_token)
  @developer_details = args[:developer_details] if args.key?(:developer_details)
  @device_compatibility_requirements = args[:device_compatibility_requirements] if args.key?(:device_compatibility_requirements)
  @excluded_devices_by_identifier = args[:excluded_devices_by_identifier] if args.key?(:excluded_devices_by_identifier)
  @excluded_devices_by_selector = args[:excluded_devices_by_selector] if args.key?(:excluded_devices_by_selector)
  @first_release_date = args[:first_release_date] if args.key?(:first_release_date)
  @has_in_app_ads = args[:has_in_app_ads] if args.key?(:has_in_app_ads)
  @has_in_app_purchases = args[:has_in_app_purchases] if args.key?(:has_in_app_purchases)
  @iarc_certificate_id = args[:iarc_certificate_id] if args.key?(:iarc_certificate_id)
  @is_adult_only_audience = args[:is_adult_only_audience] if args.key?(:is_adult_only_audience)
  @last_publish_time = args[:last_publish_time] if args.key?(:last_publish_time)
  @localized_store_listings = args[:localized_store_listings] if args.key?(:localized_store_listings)
  @package_name = args[:package_name] if args.key?(:package_name)
  @permissions = args[:permissions] if args.key?(:permissions)
  @permissions_sdk23 = args[:permissions_sdk23] if args.key?(:permissions_sdk23)
  @price_in_the_united_states = args[:price_in_the_united_states] if args.key?(:price_in_the_united_states)
  @privacy_policy_url = args[:privacy_policy_url] if args.key?(:privacy_policy_url)
  @sale_price_in_the_united_states = args[:sale_price_in_the_united_states] if args.key?(:sale_price_in_the_united_states)
end