Class: Google::Apis::AndroidpublisherV3::CoarseLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Coarse Geographic location details for where the consumption happened.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CoarseLocation

Returns a new instance of CoarseLocation.



2467
2468
2469
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#administrative_areaString

Optional. Highest administrative subdivision which is used for postal addresses of a country or region. For example, this can be a state, a province, an oblast, or a prefecture. For Spain, this is the province and not the autonomous community (for example, "Barcelona" and not "Catalonia"). Many countries don't use an administrative area in postal addresses. For example, in Switzerland, this should be left unpopulated. Corresponds to the JSON property administrativeArea

Returns:

  • (String)


2444
2445
2446
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2444

def administrative_area
  @administrative_area
end

#localityString

Optional. Generally refers to the city or town portion of the address. Examples: US city, IT comune, UK post town. In regions of the world where localities are not well defined or do not fit into this structure well, leave locality empty. Corresponds to the JSON property locality

Returns:

  • (String)


2452
2453
2454
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2452

def locality
  @locality
end

#region_codeString

Required. CLDR region code of the country/region of the address. This value is never inferred and you must ensure the value is correct. Example: "CH" for Switzerland. Corresponds to the JSON property regionCode

Returns:

  • (String)


2459
2460
2461
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2459

def region_code
  @region_code
end

#sublocalityString

Optional. Sublocality of the address. For example, this can be a neighborhood, borough, or district. For most addresses, you can omit this. Corresponds to the JSON property sublocality

Returns:

  • (String)


2465
2466
2467
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2465

def sublocality
  @sublocality
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2472
2473
2474
2475
2476
2477
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2472

def update!(**args)
  @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
  @locality = args[:locality] if args.key?(:locality)
  @region_code = args[:region_code] if args.key?(:region_code)
  @sublocality = args[:sublocality] if args.key?(:sublocality)
end