Class: Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

List of events, each representing an instance where the user consumed or used the purchased item or service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumptionUsageEvent

Returns a new instance of ConsumptionUsageEvent.



2573
2574
2575
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumption_item_descriptionString

Optional. Free form text that allows developers to provide more info on the item consumed. Maximum length is 5000 characters. Corresponds to the JSON property consumptionItemDescription

Returns:

  • (String)


2539
2540
2541
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2539

def consumption_item_description
  @consumption_item_description
end

#consumption_timeString

Optional. Time when the user consumed, used, downloaded, opened, or streamed the content. Corresponds to the JSON property consumptionTime

Returns:

  • (String)


2545
2546
2547
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2545

def consumption_time
  @consumption_time
end

#ip_addressString

Optional. The IP address from which the consumption occurred. Corresponds to the JSON property ipAddress

Returns:

  • (String)


2550
2551
2552
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2550

def ip_address
  @ip_address
end

#locationGoogle::Apis::AndroidpublisherV3::CoarseLocation

Coarse Geographic location details for where the consumption happened. Corresponds to the JSON property location



2555
2556
2557
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2555

def location
  @location
end

#obfuscated_account_idString

Optional. Obfuscated string that is uniquely associated with the purchaser's user account in the app. https://developer.android.com/reference/com/android/ billingclient/api/BillingFlowParams.Builder#setObfuscatedAccountId(java.lang. String) Corresponds to the JSON property obfuscatedAccountId

Returns:

  • (String)


2563
2564
2565
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2563

def 
  @obfuscated_account_id
end

#obfuscated_profile_idString

Optional. Obfuscated string that is uniquely associated with the purchaser's user profile in the app. https://developer.android.com/reference/com/android/ billingclient/api/BillingFlowParams.Builder#setObfuscatedProfileId(java.lang. String) Corresponds to the JSON property obfuscatedProfileId

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2571

def obfuscated_profile_id
  @obfuscated_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2578
2579
2580
2581
2582
2583
2584
2585
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2578

def update!(**args)
  @consumption_item_description = args[:consumption_item_description] if args.key?(:consumption_item_description)
  @consumption_time = args[:consumption_time] if args.key?(:consumption_time)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @location = args[:location] if args.key?(:location)
  @obfuscated_account_id = args[:obfuscated_account_id] if args.key?(:obfuscated_account_id)
  @obfuscated_profile_id = args[:obfuscated_profile_id] if args.key?(:obfuscated_profile_id)
end