Class: Google::Apis::AndroidpublisherV3::ConvertedOtherRegionsPrice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Converted other regions prices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConvertedOtherRegionsPrice

Returns a new instance of ConvertedOtherRegionsPrice.



2580
2581
2582
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eur_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property eurPrice



2573
2574
2575
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2573

def eur_price
  @eur_price
end

#usd_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property usdPrice



2578
2579
2580
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2578

def usd_price
  @usd_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2585
2586
2587
2588
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2585

def update!(**args)
  @eur_price = args[:eur_price] if args.key?(:eur_price)
  @usd_price = args[:usd_price] if args.key?(:usd_price)
end