Class: Google::Apis::AndroidpublisherV3::ConvertedRegionPrice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A converted region price.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConvertedRegionPrice

Returns a new instance of ConvertedRegionPrice.



2693
2694
2695
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property price



2681
2682
2683
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2681

def price
  @price
end

#region_codeString

The region code of the region. Corresponds to the JSON property regionCode

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2686

def region_code
  @region_code
end

#tax_amountGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property taxAmount



2691
2692
2693
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2691

def tax_amount
  @tax_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2698
2699
2700
2701
2702
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2698

def update!(**args)
  @price = args[:price] if args.key?(:price)
  @region_code = args[:region_code] if args.key?(:region_code)
  @tax_amount = args[:tax_amount] if args.key?(:tax_amount)
end