Class: Google::Apis::AndroidpublisherV3::DeletePurchaseOptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::DeletePurchaseOptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for deleting a purchase option.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#latency_tolerance ⇒ String
Optional.
-
#package_name ⇒ String
Required.
-
#product_id ⇒ String
Required.
-
#purchase_option_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeletePurchaseOptionRequest
constructor
A new instance of DeletePurchaseOptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeletePurchaseOptionRequest
Returns a new instance of DeletePurchaseOptionRequest.
3129 3130 3131 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. This field has no effect for purchase options with no offers under
them. For purchase options with associated offers: * If force is set to
false (default), an error will be returned. * If force is set to true, any
associated offers under the purchase option will be deleted.
Corresponds to the JSON property force
3105 3106 3107 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3105 def force @force end |
#latency_tolerance ⇒ String
Optional. The latency tolerance for the propagation of this product update.
Defaults to latency-sensitive.
Corresponds to the JSON property latencyTolerance
3112 3113 3114 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3112 def latency_tolerance @latency_tolerance end |
#package_name ⇒ String
Required. The parent app (package name) of the purchase option to delete.
Corresponds to the JSON property packageName
3117 3118 3119 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3117 def package_name @package_name end |
#product_id ⇒ String
Required. The parent one-time product (ID) of the purchase option to delete.
Corresponds to the JSON property productId
3122 3123 3124 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3122 def product_id @product_id end |
#purchase_option_id ⇒ String
Required. The purchase option ID of the purchase option to delete.
Corresponds to the JSON property purchaseOptionId
3127 3128 3129 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3127 def purchase_option_id @purchase_option_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3134 def update!(**args) @force = args[:force] if args.key?(:force) @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance) @package_name = args[:package_name] if args.key?(:package_name) @product_id = args[:product_id] if args.key?(:product_id) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) end |