Class: Google::Apis::AndroidpublisherV3::DeviceCompatibilityRequirements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Defines a set of device compatibility requirements for the app. A device must satisfy all of the requirements in a set to be considered compatible with the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceCompatibilityRequirements

Returns a new instance of DeviceCompatibilityRequirements.



3446
3447
3448
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compatible_screensArray<Google::Apis::AndroidpublisherV3::CompatibleScreen>

Compatible screens as listed in the compatible-screens Manifest tag. Corresponds to the JSON property compatibleScreens



3383
3384
3385
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3383

def compatible_screens
  @compatible_screens
end

#gl_es_versionFixnum

Required version of OpenGL ES. Corresponds to the JSON property glEsVersion

Returns:

  • (Fixnum)


3388
3389
3390
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3388

def gl_es_version
  @gl_es_version
end

#is_screen_requiredBoolean Also known as: is_screen_required?

Specifies if the app requires a screen. Corresponds to the JSON property isScreenRequired

Returns:

  • (Boolean)


3393
3394
3395
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3393

def is_screen_required
  @is_screen_required
end

#native_platformsArray<String>

List of required ABIs (Application Binary Interface), e.g. armeabi or x86. Corresponds to the JSON property nativePlatforms

Returns:

  • (Array<String>)


3399
3400
3401
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3399

def native_platforms
  @native_platforms
end

#required_software_librariesArray<String>

List of required libraries as declared in the uses-library manifest tag. Corresponds to the JSON property requiredSoftwareLibraries

Returns:

  • (Array<String>)


3404
3405
3406
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3404

def required_software_libraries
  @required_software_libraries
end

#required_system_featuresArray<String>

The system features that the app requires. A device must have all of the system features to be considered compatible with the app. Corresponds to the JSON property requiredSystemFeatures

Returns:

  • (Array<String>)


3410
3411
3412
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3410

def required_system_features
  @required_system_features
end

#requires_smallest_width_dpFixnum

Specifies the minimum smallest width required of the screen. Corresponds to the JSON property requiresSmallestWidthDp

Returns:

  • (Fixnum)


3415
3416
3417
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3415

def requires_smallest_width_dp
  @requires_smallest_width_dp
end

#sdk_versionGoogle::Apis::AndroidpublisherV3::CatalogSdkVersion

Defines a range of SDK versions. A device is considered compatible uf its\ SDK version falls within the min_sdk_version and max_sdk_version range. Corresponds to the JSON property sdkVersion



3421
3422
3423
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3421

def sdk_version
  @sdk_version
end

#supported_gl_texturesArray<String>

Supported gl textures as specified by the supported-gl-texture Manifest tag. Corresponds to the JSON property supportedGlTextures

Returns:

  • (Array<String>)


3426
3427
3428
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3426

def supported_gl_textures
  @supported_gl_textures
end

#supported_screensArray<String>

Compatible screens as listed in the supports-screens Manifest tag. Corresponds to the JSON property supportedScreens

Returns:

  • (Array<String>)


3431
3432
3433
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3431

def supported_screens
  @supported_screens
end

#use32_bit_abiString

Value of android:use32BitAbi flag retrieved from the Manifest. Corresponds to the JSON property use32BitAbi

Returns:

  • (String)


3436
3437
3438
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3436

def use32_bit_abi
  @use32_bit_abi
end

#uses_configurationsArray<Google::Apis::AndroidpublisherV3::UsesConfiguration>

Lists all configurations marked as required by use of the uses-configuration manifest tag. Each instance of this proto represents a single uses- configuration entry. See http://developer.android.com/guide/topics/manifest/ uses-configuration-element.html Corresponds to the JSON property usesConfigurations



3444
3445
3446
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3444

def uses_configurations
  @uses_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3451

def update!(**args)
  @compatible_screens = args[:compatible_screens] if args.key?(:compatible_screens)
  @gl_es_version = args[:gl_es_version] if args.key?(:gl_es_version)
  @is_screen_required = args[:is_screen_required] if args.key?(:is_screen_required)
  @native_platforms = args[:native_platforms] if args.key?(:native_platforms)
  @required_software_libraries = args[:required_software_libraries] if args.key?(:required_software_libraries)
  @required_system_features = args[:required_system_features] if args.key?(:required_system_features)
  @requires_smallest_width_dp = args[:requires_smallest_width_dp] if args.key?(:requires_smallest_width_dp)
  @sdk_version = args[:sdk_version] if args.key?(:sdk_version)
  @supported_gl_textures = args[:supported_gl_textures] if args.key?(:supported_gl_textures)
  @supported_screens = args[:supported_screens] if args.key?(:supported_screens)
  @use32_bit_abi = args[:use32_bit_abi] if args.key?(:use32_bit_abi)
  @uses_configurations = args[:uses_configurations] if args.key?(:uses_configurations)
end