Class: Google::Apis::AndroidpublisherV3::DeviceSelector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Selector for a device group. A selector consists of a set of conditions on the device that should all match (logical AND) to determine a device group eligibility. For instance, if a selector specifies RAM conditions, device model inclusion and device model exclusion, a device is considered to match if: device matches RAM conditions AND device matches one of the included device models AND device doesn't match excluded device models

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceSelector

Returns a new instance of DeviceSelector.



2814
2815
2816
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_ramGoogle::Apis::AndroidpublisherV3::DeviceRam

Conditions about a device's RAM capabilities. Corresponds to the JSON property deviceRam



2783
2784
2785
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2783

def device_ram
  @device_ram
end

#excluded_device_idsArray<Google::Apis::AndroidpublisherV3::DeviceId>

Device models excluded by this selector, even if they match all other conditions. Corresponds to the JSON property excludedDeviceIds



2789
2790
2791
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2789

def excluded_device_ids
  @excluded_device_ids
end

#forbidden_system_featuresArray<Google::Apis::AndroidpublisherV3::SystemFeature>

A device that has any of these system features is excluded by this selector, even if it matches all other conditions. Corresponds to the JSON property forbiddenSystemFeatures



2795
2796
2797
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2795

def forbidden_system_features
  @forbidden_system_features
end

#included_device_idsArray<Google::Apis::AndroidpublisherV3::DeviceId>

Device models included by this selector. Corresponds to the JSON property includedDeviceIds



2800
2801
2802
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2800

def included_device_ids
  @included_device_ids
end

#required_system_featuresArray<Google::Apis::AndroidpublisherV3::SystemFeature>

A device needs to have all these system features to be included by the selector. Corresponds to the JSON property requiredSystemFeatures



2806
2807
2808
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2806

def required_system_features
  @required_system_features
end

#system_on_chipsArray<Google::Apis::AndroidpublisherV3::SystemOnChip>

Optional. The SoCs included by this selector. Only works for Android S+ devices. Corresponds to the JSON property systemOnChips



2812
2813
2814
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2812

def system_on_chips
  @system_on_chips
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2819
2820
2821
2822
2823
2824
2825
2826
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2819

def update!(**args)
  @device_ram = args[:device_ram] if args.key?(:device_ram)
  @excluded_device_ids = args[:excluded_device_ids] if args.key?(:excluded_device_ids)
  @forbidden_system_features = args[:forbidden_system_features] if args.key?(:forbidden_system_features)
  @included_device_ids = args[:included_device_ids] if args.key?(:included_device_ids)
  @required_system_features = args[:required_system_features] if args.key?(:required_system_features)
  @system_on_chips = args[:system_on_chips] if args.key?(:system_on_chips)
end