Class: Google::Apis::AndroidpublisherV3::EnrollAppRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request to enroll an app into Play App Signing using a self-hosted Cloud KMS key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnrollAppRequest

Returns a new instance of EnrollAppRequest.



3903
3904
3905
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enroll_existing_appGoogle::Apis::AndroidpublisherV3::EnrollExistingApp

Enroll an existing app into Play signing. Corresponds to the JSON property enrollExistingApp



3890
3891
3892
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3890

def enroll_existing_app
  @enroll_existing_app
end

#enroll_new_appGoogle::Apis::AndroidpublisherV3::EnrollNewApp

Enroll a new app into Play signing. Corresponds to the JSON property enrollNewApp



3895
3896
3897
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3895

def enroll_new_app
  @enroll_new_app
end

#pem_upload_certificateString

The certificate associated with the upload key, in PEM format. Corresponds to the JSON property pemUploadCertificate NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3901
3902
3903
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3901

def pem_upload_certificate
  @pem_upload_certificate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3908
3909
3910
3911
3912
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3908

def update!(**args)
  @enroll_existing_app = args[:enroll_existing_app] if args.key?(:enroll_existing_app)
  @enroll_new_app = args[:enroll_new_app] if args.key?(:enroll_new_app)
  @pem_upload_certificate = args[:pem_upload_certificate] if args.key?(:pem_upload_certificate)
end