Class: Google::Apis::AndroidpublisherV3::EnrollNewApp
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::EnrollNewApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Enroll a new app into Play signing.
Instance Attribute Summary collapse
-
#cloud_kms_key_and_cert ⇒ Google::Apis::AndroidpublisherV3::CloudKmsKeyAndCert
Cloud KMS key and the certificate associated with the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnrollNewApp
constructor
A new instance of EnrollNewApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnrollNewApp
Returns a new instance of EnrollNewApp.
3968 3969 3970 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_kms_key_and_cert ⇒ Google::Apis::AndroidpublisherV3::CloudKmsKeyAndCert
Cloud KMS key and the certificate associated with the key.
Corresponds to the JSON property cloudKmsKeyAndCert
3966 3967 3968 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3966 def cloud_kms_key_and_cert @cloud_kms_key_and_cert end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3973 3974 3975 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3973 def update!(**args) @cloud_kms_key_and_cert = args[:cloud_kms_key_and_cert] if args.key?(:cloud_kms_key_and_cert) end |