Class: Google::Apis::AndroidpublisherV3::ExternalAccountIdentifiers
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ExternalAccountIdentifiers
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
User account identifier in the third-party service.
Instance Attribute Summary collapse
-
#external_account_id ⇒ String
User account identifier in the third-party service.
-
#obfuscated_external_account_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's account in your app.
-
#obfuscated_external_profile_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's profile in your app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalAccountIdentifiers
constructor
A new instance of ExternalAccountIdentifiers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalAccountIdentifiers
Returns a new instance of ExternalAccountIdentifiers.
3398 3399 3400 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_account_id ⇒ String
User account identifier in the third-party service. Only present if account
linking happened as part of the subscription purchase flow.
Corresponds to the JSON property externalAccountId
3379 3380 3381 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3379 def external_account_id @external_account_id end |
#obfuscated_external_account_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's
account in your app. Present for the following purchases: * If account linking
happened as part of the subscription purchase flow. * It was specified using
https://developer.android.com/reference/com/android/billingclient/api/
BillingFlowParams.Builder#setobfuscatedaccountid when the purchase was made.
Corresponds to the JSON property obfuscatedExternalAccountId
3388 3389 3390 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3388 def @obfuscated_external_account_id end |
#obfuscated_external_profile_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's
profile in your app. Only present if specified using https://developer.android.
com/reference/com/android/billingclient/api/BillingFlowParams.Builder#
setobfuscatedprofileid when the purchase was made.
Corresponds to the JSON property obfuscatedExternalProfileId
3396 3397 3398 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3396 def @obfuscated_external_profile_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3403 3404 3405 3406 3407 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3403 def update!(**args) @external_account_id = args[:external_account_id] if args.key?(:external_account_id) @obfuscated_external_account_id = args[:obfuscated_external_account_id] if args.key?(:obfuscated_external_account_id) @obfuscated_external_profile_id = args[:obfuscated_external_profile_id] if args.key?(:obfuscated_external_profile_id) end |