Class: Google::Apis::AndroidpublisherV3::GeneratedAssetPackSlice
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::GeneratedAssetPackSlice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Download metadata for an asset pack slice.
Instance Attribute Summary collapse
-
#download_id ⇒ String
Download ID, which uniquely identifies the APK to download.
-
#module_name ⇒ String
Name of the module that this asset slice belongs to.
-
#slice_id ⇒ String
Asset slice ID.
-
#version ⇒ Fixnum
Asset module version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GeneratedAssetPackSlice
constructor
A new instance of GeneratedAssetPackSlice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GeneratedAssetPackSlice
Returns a new instance of GeneratedAssetPackSlice.
3569 3570 3571 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3569 def initialize(**args) update!(**args) end |
Instance Attribute Details
#download_id ⇒ String
Download ID, which uniquely identifies the APK to download. Should be supplied
to generatedapks.download method.
Corresponds to the JSON property downloadId
3552 3553 3554 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3552 def download_id @download_id end |
#module_name ⇒ String
Name of the module that this asset slice belongs to.
Corresponds to the JSON property moduleName
3557 3558 3559 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3557 def module_name @module_name end |
#slice_id ⇒ String
Asset slice ID.
Corresponds to the JSON property sliceId
3562 3563 3564 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3562 def slice_id @slice_id end |
#version ⇒ Fixnum
Asset module version.
Corresponds to the JSON property version
3567 3568 3569 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3567 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3574 3575 3576 3577 3578 3579 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3574 def update!(**args) @download_id = args[:download_id] if args.key?(:download_id) @module_name = args[:module_name] if args.key?(:module_name) @slice_id = args[:slice_id] if args.key?(:slice_id) @version = args[:version] if args.key?(:version) end |