Class: Google::Apis::AndroidpublisherV3::Grant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

An access grant resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Grant

Returns a new instance of Grant.



4183
4184
4185
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_level_permissionsArray<String>

The permissions granted to the user for this app. Corresponds to the JSON property appLevelPermissions

Returns:

  • (Array<String>)


4169
4170
4171
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4169

def app_level_permissions
  @app_level_permissions
end

#nameString

Required. Resource name for this grant, following the pattern "developers/ developer/users/email/grants/package_name". If this grant is for a draft app, the app ID will be used in this resource name instead of the package name. Corresponds to the JSON property name

Returns:

  • (String)


4176
4177
4178
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4176

def name
  @name
end

#package_nameString

Immutable. The package name of the app. This will be empty for draft apps. Corresponds to the JSON property packageName

Returns:

  • (String)


4181
4182
4183
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4181

def package_name
  @package_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4188
4189
4190
4191
4192
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4188

def update!(**args)
  @app_level_permissions = args[:app_level_permissions] if args.key?(:app_level_permissions)
  @name = args[:name] if args.key?(:name)
  @package_name = args[:package_name] if args.key?(:package_name)
end