Class: Google::Apis::AndroidpublisherV3::Image
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Image
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An uploaded image. The resource for ImagesService.
Instance Attribute Summary collapse
-
#ai_generated_state ⇒ String
Optional.
-
#id ⇒ String
A unique id representing this image.
-
#sha1 ⇒ String
A sha1 hash of the image.
-
#sha256 ⇒ String
A sha256 hash of the image.
-
#url ⇒ String
A URL that will serve a preview of the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
4718 4719 4720 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_generated_state ⇒ String
Optional. Whether the image was generated by AI. Attested by the developer.
Corresponds to the JSON property aiGeneratedState
4696 4697 4698 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4696 def ai_generated_state @ai_generated_state end |
#id ⇒ String
A unique id representing this image.
Corresponds to the JSON property id
4701 4702 4703 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4701 def id @id end |
#sha1 ⇒ String
A sha1 hash of the image.
Corresponds to the JSON property sha1
4706 4707 4708 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4706 def sha1 @sha1 end |
#sha256 ⇒ String
A sha256 hash of the image.
Corresponds to the JSON property sha256
4711 4712 4713 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4711 def sha256 @sha256 end |
#url ⇒ String
A URL that will serve a preview of the image.
Corresponds to the JSON property url
4716 4717 4718 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4716 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4723 4724 4725 4726 4727 4728 4729 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4723 def update!(**args) @ai_generated_state = args[:ai_generated_state] if args.key?(:ai_generated_state) @id = args[:id] if args.key?(:id) @sha1 = args[:sha1] if args.key?(:sha1) @sha256 = args[:sha256] if args.key?(:sha256) @url = args[:url] if args.key?(:url) end |