Class: Google::Apis::AndroidpublisherV3::InAppProduct
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::InAppProduct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An in-app product. The resource for InappproductsService.
Instance Attribute Summary collapse
-
#default_language ⇒ String
Default language of the localized data, as defined by BCP-47.
-
#default_price ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e.
-
#grace_period ⇒ String
Grace period of the subscription, specified in ISO 8601 format.
-
#listings ⇒ Hash<String,Google::Apis::AndroidpublisherV3::InAppProductListing>
List of localized title and description data.
-
#managed_product_taxes_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::ManagedProductTaxAndComplianceSettings
Details about taxation and legal compliance for managed products.
-
#package_name ⇒ String
Package name of the parent app.
-
#prices ⇒ Hash<String,Google::Apis::AndroidpublisherV3::Price>
Prices per buyer region.
-
#purchase_type ⇒ String
The type of the product, e.g.
-
#sku ⇒ String
Stock-keeping-unit (SKU) of the product, unique within an app.
-
#status ⇒ String
The status of the product, e.g.
-
#subscription_period ⇒ String
Subscription period, specified in ISO 8601 format.
-
#subscription_taxes_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
Details about taxation, Google Play policy, and legal compliance for subscription products.
-
#trial_period ⇒ String
Trial period, specified in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InAppProduct
constructor
A new instance of InAppProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InAppProduct
Returns a new instance of InAppProduct.
4392 4393 4394 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_language ⇒ String
Default language of the localized data, as defined by BCP-47. e.g. "en-US".
Corresponds to the JSON property defaultLanguage
4321 4322 4323 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4321 def default_language @default_language end |
#default_price ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e. currency and units.
Corresponds to the JSON property defaultPrice
4326 4327 4328 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4326 def default_price @default_price end |
#grace_period ⇒ String
Grace period of the subscription, specified in ISO 8601 format. Allows
developers to give their subscribers a grace period when the payment for the
new recurrence period is declined. Acceptable values are P0D (zero days), P3D (
three days), P7D (seven days), P14D (14 days), and P30D (30 days).
Corresponds to the JSON property gracePeriod
4334 4335 4336 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4334 def grace_period @grace_period end |
#listings ⇒ Hash<String,Google::Apis::AndroidpublisherV3::InAppProductListing>
List of localized title and description data. Map key is the language of the
localized data, as defined by BCP-47, e.g. "en-US".
Corresponds to the JSON property listings
4340 4341 4342 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4340 def listings @listings end |
#managed_product_taxes_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::ManagedProductTaxAndComplianceSettings
Details about taxation and legal compliance for managed products.
Corresponds to the JSON property managedProductTaxesAndComplianceSettings
4345 4346 4347 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4345 def managed_product_taxes_and_compliance_settings @managed_product_taxes_and_compliance_settings end |
#package_name ⇒ String
Package name of the parent app.
Corresponds to the JSON property packageName
4350 4351 4352 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4350 def package_name @package_name end |
#prices ⇒ Hash<String,Google::Apis::AndroidpublisherV3::Price>
Prices per buyer region. None of these can be zero, as in-app products are
never free. Map key is region code, as defined by ISO 3166-2.
Corresponds to the JSON property prices
4356 4357 4358 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4356 def prices @prices end |
#purchase_type ⇒ String
The type of the product, e.g. a recurring subscription.
Corresponds to the JSON property purchaseType
4361 4362 4363 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4361 def purchase_type @purchase_type end |
#sku ⇒ String
Stock-keeping-unit (SKU) of the product, unique within an app.
Corresponds to the JSON property sku
4366 4367 4368 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4366 def sku @sku end |
#status ⇒ String
The status of the product, e.g. whether it's active.
Corresponds to the JSON property status
4371 4372 4373 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4371 def status @status end |
#subscription_period ⇒ String
Subscription period, specified in ISO 8601 format. Acceptable values are P1W (
one week), P1M (one month), P3M (three months), P6M (six months), and P1Y (one
year).
Corresponds to the JSON property subscriptionPeriod
4378 4379 4380 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4378 def subscription_period @subscription_period end |
#subscription_taxes_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
Details about taxation, Google Play policy, and legal compliance for
subscription products.
Corresponds to the JSON property subscriptionTaxesAndComplianceSettings
4384 4385 4386 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4384 def subscription_taxes_and_compliance_settings @subscription_taxes_and_compliance_settings end |
#trial_period ⇒ String
Trial period, specified in ISO 8601 format. Acceptable values are anything
between P7D (seven days) and P999D (999 days).
Corresponds to the JSON property trialPeriod
4390 4391 4392 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4390 def trial_period @trial_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4397 def update!(**args) @default_language = args[:default_language] if args.key?(:default_language) @default_price = args[:default_price] if args.key?(:default_price) @grace_period = args[:grace_period] if args.key?(:grace_period) @listings = args[:listings] if args.key?(:listings) @managed_product_taxes_and_compliance_settings = args[:managed_product_taxes_and_compliance_settings] if args.key?(:managed_product_taxes_and_compliance_settings) @package_name = args[:package_name] if args.key?(:package_name) @prices = args[:prices] if args.key?(:prices) @purchase_type = args[:purchase_type] if args.key?(:purchase_type) @sku = args[:sku] if args.key?(:sku) @status = args[:status] if args.key?(:status) @subscription_period = args[:subscription_period] if args.key?(:subscription_period) @subscription_taxes_and_compliance_settings = args[:subscription_taxes_and_compliance_settings] if args.key?(:subscription_taxes_and_compliance_settings) @trial_period = args[:trial_period] if args.key?(:trial_period) end |