Class: Google::Apis::AndroidpublisherV3::InappproductsBatchGetResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::InappproductsBatchGetResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for BatchGetSubscriptions endpoint.
Instance Attribute Summary collapse
-
#inappproduct ⇒ Array<Google::Apis::AndroidpublisherV3::InAppProduct>
The list of requested in-app products, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InappproductsBatchGetResponse
constructor
A new instance of InappproductsBatchGetResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InappproductsBatchGetResponse
Returns a new instance of InappproductsBatchGetResponse.
4129 4130 4131 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inappproduct ⇒ Array<Google::Apis::AndroidpublisherV3::InAppProduct>
The list of requested in-app products, in the same order as the request.
Corresponds to the JSON property inappproduct
4127 4128 4129 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4127 def inappproduct @inappproduct end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4134 4135 4136 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4134 def update!(**args) @inappproduct = args[:inappproduct] if args.key?(:inappproduct) end |