Class: Google::Apis::AndroidpublisherV3::InappproductsListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response listing all in-app products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InappproductsListResponse

Returns a new instance of InappproductsListResponse.



5281
5282
5283
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inappproductArray<Google::Apis::AndroidpublisherV3::InAppProduct>

All in-app products. Corresponds to the JSON property inappproduct



5255
5256
5257
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5255

def inappproduct
  @inappproduct
end

#kindString

The kind of this response ("androidpublisher#inappproductsListResponse"). Corresponds to the JSON property kind

Returns:

  • (String)


5260
5261
5262
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5260

def kind
  @kind
end

#page_infoGoogle::Apis::AndroidpublisherV3::PageInfo

Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. Corresponds to the JSON property pageInfo



5267
5268
5269
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5267

def page_info
  @page_info
end

#token_paginationGoogle::Apis::AndroidpublisherV3::TokenPagination

Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page. Corresponds to the JSON property tokenPagination



5279
5280
5281
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5279

def token_pagination
  @token_pagination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5286
5287
5288
5289
5290
5291
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5286

def update!(**args)
  @inappproduct = args[:inappproduct] if args.key?(:inappproduct)
  @kind = args[:kind] if args.key?(:kind)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
end