Class: Google::Apis::AndroidpublisherV3::IntroductoryPriceInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::IntroductoryPriceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Contains the introductory price information for a subscription.
Instance Attribute Summary collapse
-
#introductory_price_amount_micros ⇒ Fixnum
Introductory price of the subscription, not including tax.
-
#introductory_price_currency_code ⇒ String
ISO 4217 currency code for the introductory subscription price.
-
#introductory_price_cycles ⇒ Fixnum
The number of billing period to offer introductory pricing.
-
#introductory_price_period ⇒ String
Introductory price period, specified in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntroductoryPriceInfo
constructor
A new instance of IntroductoryPriceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntroductoryPriceInfo
Returns a new instance of IntroductoryPriceInfo.
4504 4505 4506 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#introductory_price_amount_micros ⇒ Fixnum
Introductory price of the subscription, not including tax. The currency is the
same as price_currency_code. Price is expressed in micro-units, where 1,000,
000 micro-units represents one unit of the currency. For example, if the
subscription price is €1.99, price_amount_micros is 1990000.
Corresponds to the JSON property introductoryPriceAmountMicros
4483 4484 4485 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4483 def introductory_price_amount_micros @introductory_price_amount_micros end |
#introductory_price_currency_code ⇒ String
ISO 4217 currency code for the introductory subscription price. For example,
if the price is specified in British pounds sterling, price_currency_code is "
GBP".
Corresponds to the JSON property introductoryPriceCurrencyCode
4490 4491 4492 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4490 def introductory_price_currency_code @introductory_price_currency_code end |
#introductory_price_cycles ⇒ Fixnum
The number of billing period to offer introductory pricing.
Corresponds to the JSON property introductoryPriceCycles
4495 4496 4497 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4495 def introductory_price_cycles @introductory_price_cycles end |
#introductory_price_period ⇒ String
Introductory price period, specified in ISO 8601 format. Common values are (
but not limited to) "P1W" (one week), "P1M" (one month), "P3M" (three months),
"P6M" (six months), and "P1Y" (one year).
Corresponds to the JSON property introductoryPricePeriod
4502 4503 4504 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4502 def introductory_price_period @introductory_price_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4509 4510 4511 4512 4513 4514 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4509 def update!(**args) @introductory_price_amount_micros = args[:introductory_price_amount_micros] if args.key?(:introductory_price_amount_micros) @introductory_price_currency_code = args[:introductory_price_currency_code] if args.key?(:introductory_price_currency_code) @introductory_price_cycles = args[:introductory_price_cycles] if args.key?(:introductory_price_cycles) @introductory_price_period = args[:introductory_price_period] if args.key?(:introductory_price_period) end |