Class: Google::Apis::AndroidpublisherV3::ListReleaseSummariesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response listing all releases for a given track that are either ready to be sent for review, in review, approved, not approved or available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListReleaseSummariesResponse

Returns a new instance of ListReleaseSummariesResponse.



4763
4764
4765
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#releasesArray<Google::Apis::AndroidpublisherV3::ReleaseSummary>

List of releases for this track. A maximum of 20 releases can be returned. Corresponds to the JSON property releases



4761
4762
4763
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4761

def releases
  @releases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4768
4769
4770
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4768

def update!(**args)
  @releases = args[:releases] if args.key?(:releases)
end