Class: Google::Apis::AndroidpublisherV3::LocalizedStoreListing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A localized store listings of the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalizedStoreListing

Returns a new instance of LocalizedStoreListing.



6043
6044
6045
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_nameString

The name of the app in this localization. Corresponds to the JSON property appName

Returns:

  • (String)


5996
5997
5998
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5996

def app_name
  @app_name
end

#feature_graphicGoogle::Apis::AndroidpublisherV3::ImageAsset

An image asset. Corresponds to the JSON property featureGraphic



6001
6002
6003
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6001

def feature_graphic
  @feature_graphic
end

#full_descriptionString

A longer description of the app in this localization. Corresponds to the JSON property fullDescription

Returns:

  • (String)


6006
6007
6008
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6006

def full_description
  @full_description
end

#iconGoogle::Apis::AndroidpublisherV3::ImageAsset

An image asset. Corresponds to the JSON property icon



6011
6012
6013
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6011

def icon
  @icon
end

#language_codeString

The BCP-47 language code for this localization. Corresponds to the JSON property languageCode

Returns:

  • (String)


6016
6017
6018
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6016

def language_code
  @language_code
end

#phone_screenshotsGoogle::Apis::AndroidpublisherV3::ScreenshotSet

A set of screenshots. Corresponds to the JSON property phoneScreenshots



6021
6022
6023
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6021

def phone_screenshots
  @phone_screenshots
end

#short_descriptionString

A short description of the app in this localization. Corresponds to the JSON property shortDescription

Returns:

  • (String)


6026
6027
6028
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6026

def short_description
  @short_description
end

#tablet_regular_screenshotsGoogle::Apis::AndroidpublisherV3::ScreenshotSet

A set of screenshots. Corresponds to the JSON property tabletRegularScreenshots



6031
6032
6033
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6031

def tablet_regular_screenshots
  @tablet_regular_screenshots
end

#tablet_small_screenshotsGoogle::Apis::AndroidpublisherV3::ScreenshotSet

A set of screenshots. Corresponds to the JSON property tabletSmallScreenshots



6036
6037
6038
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6036

def tablet_small_screenshots
  @tablet_small_screenshots
end

#videoGoogle::Apis::AndroidpublisherV3::VideoAsset

A video asset. Corresponds to the JSON property video



6041
6042
6043
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6041

def video
  @video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
6059
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6048

def update!(**args)
  @app_name = args[:app_name] if args.key?(:app_name)
  @feature_graphic = args[:feature_graphic] if args.key?(:feature_graphic)
  @full_description = args[:full_description] if args.key?(:full_description)
  @icon = args[:icon] if args.key?(:icon)
  @language_code = args[:language_code] if args.key?(:language_code)
  @phone_screenshots = args[:phone_screenshots] if args.key?(:phone_screenshots)
  @short_description = args[:short_description] if args.key?(:short_description)
  @tablet_regular_screenshots = args[:tablet_regular_screenshots] if args.key?(:tablet_regular_screenshots)
  @tablet_small_screenshots = args[:tablet_small_screenshots] if args.key?(:tablet_small_screenshots)
  @video = args[:video] if args.key?(:video)
end