Class: Google::Apis::AndroidpublisherV3::MigrateBasePlanPricesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for MigrateBasePlanPrices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrateBasePlanPricesRequest

Returns a new instance of MigrateBasePlanPricesRequest.



6027
6028
6029
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

Required. The unique base plan ID of the base plan to update prices on. Corresponds to the JSON property basePlanId

Returns:

  • (String)


5997
5998
5999
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5997

def base_plan_id
  @base_plan_id
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


6003
6004
6005
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6003

def latency_tolerance
  @latency_tolerance
end

#package_nameString

Required. Package name of the parent app. Must be equal to the package_name field on the Subscription resource. Corresponds to the JSON property packageName

Returns:

  • (String)


6009
6010
6011
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6009

def package_name
  @package_name
end

#product_idString

Required. The ID of the subscription to update. Must be equal to the product_id field on the Subscription resource. Corresponds to the JSON property productId

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6015

def product_id
  @product_id
end

#regional_price_migrationsArray<Google::Apis::AndroidpublisherV3::RegionalPriceMigrationConfig>

Required. The regional prices to update. Corresponds to the JSON property regionalPriceMigrations



6020
6021
6022
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6020

def regional_price_migrations
  @regional_price_migrations
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



6025
6026
6027
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6025

def regions_version
  @regions_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6032
6033
6034
6035
6036
6037
6038
6039
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6032

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @package_name = args[:package_name] if args.key?(:package_name)
  @product_id = args[:product_id] if args.key?(:product_id)
  @regional_price_migrations = args[:regional_price_migrations] if args.key?(:regional_price_migrations)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
end