Class: Google::Apis::AndroidpublisherV3::ModuleMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ModuleMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Metadata of a module.
Instance Attribute Summary collapse
-
#delivery_type ⇒ String
Indicates the delivery type (e.g. on-demand) of the module.
-
#dependencies ⇒ Array<String>
Names of the modules that this module directly depends on.
-
#module_type ⇒ String
Indicates the type of this feature module.
-
#name ⇒ String
Module name.
-
#targeting ⇒ Google::Apis::AndroidpublisherV3::ModuleTargeting
Targeting on the module level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ModuleMetadata
constructor
A new instance of ModuleMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ModuleMetadata
Returns a new instance of ModuleMetadata.
5465 5466 5467 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delivery_type ⇒ String
Indicates the delivery type (e.g. on-demand) of the module.
Corresponds to the JSON property deliveryType
5442 5443 5444 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5442 def delivery_type @delivery_type end |
#dependencies ⇒ Array<String>
Names of the modules that this module directly depends on. Each module
implicitly depends on the base module.
Corresponds to the JSON property dependencies
5448 5449 5450 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5448 def dependencies @dependencies end |
#module_type ⇒ String
Indicates the type of this feature module.
Corresponds to the JSON property moduleType
5453 5454 5455 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5453 def module_type @module_type end |
#name ⇒ String
Module name.
Corresponds to the JSON property name
5458 5459 5460 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5458 def name @name end |
#targeting ⇒ Google::Apis::AndroidpublisherV3::ModuleTargeting
Targeting on the module level.
Corresponds to the JSON property targeting
5463 5464 5465 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5463 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5470 5471 5472 5473 5474 5475 5476 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5470 def update!(**args) @delivery_type = args[:delivery_type] if args.key?(:delivery_type) @dependencies = args[:dependencies] if args.key?(:dependencies) @module_type = args[:module_type] if args.key?(:module_type) @name = args[:name] if args.key?(:name) @targeting = args[:targeting] if args.key?(:targeting) end |