Class: Google::Apis::AndroidpublisherV3::MultiAbiTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Targeting based on multiple abis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiAbiTargeting

Returns a new instance of MultiAbiTargeting.



5229
5230
5231
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::AndroidpublisherV3::MultiAbi>

Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits. Corresponds to the JSON property alternatives



5222
5223
5224
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5222

def alternatives
  @alternatives
end

#valueArray<Google::Apis::AndroidpublisherV3::MultiAbi>

Value of a multi abi. Corresponds to the JSON property value



5227
5228
5229
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5227

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5234
5235
5236
5237
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5234

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @value = args[:value] if args.key?(:value)
end