Class: Google::Apis::AndroidpublisherV3::NestedPolicyResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::NestedPolicyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An individual nested response to a policy question about an app. Nested responses are like regular responses but without groups.
Instance Attribute Summary collapse
-
#boolean_response ⇒ Google::Apis::AndroidpublisherV3::PolicyBooleanResponse
Responses that will only ever be a boolean.
-
#document_response ⇒ Google::Apis::AndroidpublisherV3::PolicyDocumentResponse
An uploaded document.
-
#multiple_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse
Any response where multiple options can be chosen from several possibilities.
-
#question_id ⇒ String
Required.
-
#single_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicySingleChoiceResponse
Any response where a single option is chosen from several possibilities.
-
#string_response ⇒ Google::Apis::AndroidpublisherV3::PolicyStringResponse
Any response best encoded as a string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NestedPolicyResponse
constructor
A new instance of NestedPolicyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NestedPolicyResponse
Returns a new instance of NestedPolicyResponse.
6426 6427 6428 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_response ⇒ Google::Apis::AndroidpublisherV3::PolicyBooleanResponse
Responses that will only ever be a boolean.
Corresponds to the JSON property booleanResponse
6398 6399 6400 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6398 def boolean_response @boolean_response end |
#document_response ⇒ Google::Apis::AndroidpublisherV3::PolicyDocumentResponse
An uploaded document. Must be a single logical document (e.g. a financial
license).
Corresponds to the JSON property documentResponse
6404 6405 6406 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6404 def document_response @document_response end |
#multiple_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse
Any response where multiple options can be chosen from several possibilities.
Corresponds to the JSON property multipleChoiceResponse
6409 6410 6411 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6409 def multiple_choice_response @multiple_choice_response end |
#question_id ⇒ String
Required. ID of the question being answered.
Corresponds to the JSON property questionId
6414 6415 6416 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6414 def question_id @question_id end |
#single_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicySingleChoiceResponse
Any response where a single option is chosen from several possibilities.
Corresponds to the JSON property singleChoiceResponse
6419 6420 6421 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6419 def single_choice_response @single_choice_response end |
#string_response ⇒ Google::Apis::AndroidpublisherV3::PolicyStringResponse
Any response best encoded as a string. Includes URLs and multiline text fields.
Corresponds to the JSON property stringResponse
6424 6425 6426 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6424 def string_response @string_response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6431 def update!(**args) @boolean_response = args[:boolean_response] if args.key?(:boolean_response) @document_response = args[:document_response] if args.key?(:document_response) @multiple_choice_response = args[:multiple_choice_response] if args.key?(:multiple_choice_response) @question_id = args[:question_id] if args.key?(:question_id) @single_choice_response = args[:single_choice_response] if args.key?(:single_choice_response) @string_response = args[:string_response] if args.key?(:string_response) end |