Class: Google::Apis::AndroidpublisherV3::OneTimeProductBuyPurchaseOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A purchase option that can be bought.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductBuyPurchaseOption

Returns a new instance of OneTimeProductBuyPurchaseOption.



5476
5477
5478
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#legacy_compatibleBoolean Also known as: legacy_compatible?

Optional. Whether this purchase option will be available in legacy PBL flows that do not support one-time products model. Up to one "buy" purchase option can be marked as backwards compatible. Corresponds to the JSON property legacyCompatible

Returns:

  • (Boolean)


5466
5467
5468
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5466

def legacy_compatible
  @legacy_compatible
end

#multi_quantity_enabledBoolean Also known as: multi_quantity_enabled?

Optional. Whether this purchase option allows multi-quantity. Multi-quantity allows buyer to purchase more than one item in a single checkout. Corresponds to the JSON property multiQuantityEnabled

Returns:

  • (Boolean)


5473
5474
5475
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5473

def multi_quantity_enabled
  @multi_quantity_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5481
5482
5483
5484
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5481

def update!(**args)
  @legacy_compatible = args[:legacy_compatible] if args.key?(:legacy_compatible)
  @multi_quantity_enabled = args[:multi_quantity_enabled] if args.key?(:multi_quantity_enabled)
end