Class: Google::Apis::AndroidpublisherV3::OneTimeProductListing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Regional store listing for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductListing

Returns a new instance of OneTimeProductListing.



5579
5580
5581
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of this product in the language of this listing. The maximum length is 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


5566
5567
5568
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5566

def description
  @description
end

#language_codeString

Required. The language of this listing, as defined by BCP-47, e.g., "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


5571
5572
5573
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5571

def language_code
  @language_code
end

#titleString

Required. The title of this product in the language of this listing. The maximum length is 55 characters. Corresponds to the JSON property title

Returns:

  • (String)


5577
5578
5579
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5577

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5584
5585
5586
5587
5588
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5584

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @language_code = args[:language_code] if args.key?(:language_code)
  @title = args[:title] if args.key?(:title)
end