Class: Google::Apis::AndroidpublisherV3::OneTimeProductOffer
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single offer for a one-time product.
Instance Attribute Summary collapse
-
#discounted_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer
Configuration specific to discounted offers.
-
#offer_id ⇒ String
Required.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional.
-
#package_name ⇒ String
Required.
-
#pre_order_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer
Configuration specific to pre-order offers.
-
#product_id ⇒ String
Required.
-
#purchase_option_id ⇒ String
Required.
-
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>
Set of regional pricing and availability information for this offer.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductOffer
constructor
A new instance of OneTimeProductOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductOffer
Returns a new instance of OneTimeProductOffer.
6853 6854 6855 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discounted_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer
Configuration specific to discounted offers.
Corresponds to the JSON property discountedOffer
6799 6800 6801 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6799 def discounted_offer @discounted_offer end |
#offer_id ⇒ String
Required. Immutable. The ID of this product offer. Must be unique within the
purchase option. It must start with a number or lower-case letter, and can
only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The
maximum length is 63 characters.
Corresponds to the JSON property offerId
6807 6808 6809 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6807 def offer_id @offer_id end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional. List of up to 20 custom tags specified for this offer, and returned
to the app through the billing library.
Corresponds to the JSON property offerTags
6813 6814 6815 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6813 def @offer_tags end |
#package_name ⇒ String
Required. Immutable. The package name of the app the parent product belongs to.
Corresponds to the JSON property packageName
6818 6819 6820 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6818 def package_name @package_name end |
#pre_order_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer
Configuration specific to pre-order offers.
Corresponds to the JSON property preOrderOffer
6823 6824 6825 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6823 def pre_order_offer @pre_order_offer end |
#product_id ⇒ String
Required. Immutable. The ID of the parent product this offer belongs to.
Corresponds to the JSON property productId
6828 6829 6830 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6828 def product_id @product_id end |
#purchase_option_id ⇒ String
Required. Immutable. The ID of the purchase option to which this offer is an
extension.
Corresponds to the JSON property purchaseOptionId
6834 6835 6836 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6834 def purchase_option_id @purchase_option_id end |
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>
Set of regional pricing and availability information for this offer. Must not
have duplicate entries with the same region_code.
Corresponds to the JSON property regionalPricingAndAvailabilityConfigs
6840 6841 6842 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6840 def regional_pricing_and_availability_configs @regional_pricing_and_availability_configs end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
6845 6846 6847 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6845 def regions_version @regions_version end |
#state ⇒ String
Output only. The current state of this offer. This field cannot be changed by
updating the resource. Use the dedicated endpoints instead.
Corresponds to the JSON property state
6851 6852 6853 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6851 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6858 def update!(**args) @discounted_offer = args[:discounted_offer] if args.key?(:discounted_offer) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @package_name = args[:package_name] if args.key?(:package_name) @pre_order_offer = args[:pre_order_offer] if args.key?(:pre_order_offer) @product_id = args[:product_id] if args.key?(:product_id) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs) @regions_version = args[:regions_version] if args.key?(:regions_version) @state = args[:state] if args.key?(:state) end |