Class: Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Regional pricing and availability configuration for a one-time product offer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductOfferRegionalPricingAndAvailabilityConfig

Returns a new instance of OneTimeProductOfferRegionalPricingAndAvailabilityConfig.



6921
6922
6923
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_discountGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property absoluteDiscount



6892
6893
6894
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6892

def absolute_discount
  @absolute_discount
end

#availabilityString

Required. The availability for this region. Corresponds to the JSON property availability

Returns:

  • (String)


6897
6898
6899
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6897

def availability
  @availability
end

#no_overrideGoogle::Apis::AndroidpublisherV3::OneTimeProductOfferNoPriceOverrideOptions

Options for one-time product offers without a regional price override. Corresponds to the JSON property noOverride



6902
6903
6904
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6902

def no_override
  @no_override
end

#region_codeString

Required. Region code this configuration applies to, as defined by ISO 3166-2, e.g., "US". Corresponds to the JSON property regionCode

Returns:

  • (String)


6908
6909
6910
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6908

def region_code
  @region_code
end

#relative_discountFloat

The fraction of the purchase option price that the user pays for this offer. For example, if the purchase option price for this region is $12, then a 50% discount would correspond to a price of $6. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in this region. Corresponds to the JSON property relativeDiscount

Returns:

  • (Float)


6919
6920
6921
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6919

def relative_discount
  @relative_discount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6926
6927
6928
6929
6930
6931
6932
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6926

def update!(**args)
  @absolute_discount = args[:absolute_discount] if args.key?(:absolute_discount)
  @availability = args[:availability] if args.key?(:availability)
  @no_override = args[:no_override] if args.key?(:no_override)
  @region_code = args[:region_code] if args.key?(:region_code)
  @relative_discount = args[:relative_discount] if args.key?(:relative_discount)
end