Class: Google::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A purchase option that can be rented.
Instance Attribute Summary collapse
-
#expiration_period ⇒ String
Optional.
-
#rental_period ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductRentPurchaseOption
constructor
A new instance of OneTimeProductRentPurchaseOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductRentPurchaseOption
Returns a new instance of OneTimeProductRentPurchaseOption.
7124 7125 7126 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_period ⇒ String
Optional. The amount of time the user has after starting consuming the
entitlement before it is revoked. Specified in ISO 8601 format.
Corresponds to the JSON property expirationPeriod
7116 7117 7118 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7116 def expiration_period @expiration_period end |
#rental_period ⇒ String
Required. The amount of time a user has the entitlement for. Starts at
purchase flow completion. Specified in ISO 8601 format.
Corresponds to the JSON property rentalPeriod
7122 7123 7124 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7122 def rental_period @rental_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7129 7130 7131 7132 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7129 def update!(**args) @expiration_period = args[:expiration_period] if args.key?(:expiration_period) @rental_period = args[:rental_period] if args.key?(:rental_period) end |