Class: Google::Apis::AndroidpublisherV3::Order

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The Order resource encapsulates comprehensive information about a transaction made on Google Play. It includes a variety of attributes that provide details about the order itself, the products purchased, and the history of events related to the order. The Orders APIs provide real-time access to your order data within the Google Play ecosystem. You can retrieve detailed information and metadata for both one-time and recurring orders, including transaction details like charges, taxes, and refunds, as well as metadata such as pricing phases for subscriptions. The Orders APIs let you automate tasks related to order management, reducing the need for manual checks via the Play Developer Console. The following are some of the use cases for this API: + Real-time order data retrieval - Get order details and metadata immediately after a purchase using an order ID. + Order update synchronization - Periodically sync order updates to maintain an up-to-date record of order information. Note: + The Orders API calls count towards your Play Developer API quota, which defaults to 200K daily, and may be insufficient to sync extensive order histories. + A maximum of 1000 orders can be retrieved per call. Using larger page sizes is recommended to minimize quota usage. Check your quota in the Cloud Console and request more if required.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Order

Returns a new instance of Order.



7317
7318
7319
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buyer_addressGoogle::Apis::AndroidpublisherV3::BuyerAddress

Address information for the customer, for use in tax computation. Corresponds to the JSON property buyerAddress



7249
7250
7251
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7249

def buyer_address
  @buyer_address
end

#create_timeString

The time when the order was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7254
7255
7256
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7254

def create_time
  @create_time
end

#developer_revenue_in_buyer_currencyGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property developerRevenueInBuyerCurrency



7259
7260
7261
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7259

def developer_revenue_in_buyer_currency
  @developer_revenue_in_buyer_currency
end

#last_event_timeString

The time of the last event that occurred on the order. Corresponds to the JSON property lastEventTime

Returns:

  • (String)


7264
7265
7266
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7264

def last_event_time
  @last_event_time
end

#line_itemsArray<Google::Apis::AndroidpublisherV3::LineItem>

The individual line items making up this order. Corresponds to the JSON property lineItems



7269
7270
7271
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7269

def line_items
  @line_items
end

#order_detailsGoogle::Apis::AndroidpublisherV3::OrderDetails

Detailed information about the order at creation time. Corresponds to the JSON property orderDetails



7274
7275
7276
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7274

def order_details
  @order_details
end

#order_historyGoogle::Apis::AndroidpublisherV3::OrderHistory

Details about events which modified the order. Corresponds to the JSON property orderHistory



7279
7280
7281
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7279

def order_history
  @order_history
end

#order_idString

The order ID. Corresponds to the JSON property orderId

Returns:

  • (String)


7284
7285
7286
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7284

def order_id
  @order_id
end

#points_detailsGoogle::Apis::AndroidpublisherV3::PointsDetails

Details relating to any Play Points applied to an order. Corresponds to the JSON property pointsDetails



7289
7290
7291
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7289

def points_details
  @points_details
end

#purchase_tokenString

The token provided to the user's device when the subscription or item was purchased. Corresponds to the JSON property purchaseToken

Returns:

  • (String)


7295
7296
7297
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7295

def purchase_token
  @purchase_token
end

#sales_channelString

The originating sales channel of the order. Corresponds to the JSON property salesChannel

Returns:

  • (String)


7300
7301
7302
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7300

def sales_channel
  @sales_channel
end

#stateString

The state of the order. Corresponds to the JSON property state

Returns:

  • (String)


7305
7306
7307
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7305

def state
  @state
end

#taxGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property tax



7310
7311
7312
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7310

def tax
  @tax
end

#totalGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property total



7315
7316
7317
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7315

def total
  @total
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7322
7323
7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7322

def update!(**args)
  @buyer_address = args[:buyer_address] if args.key?(:buyer_address)
  @create_time = args[:create_time] if args.key?(:create_time)
  @developer_revenue_in_buyer_currency = args[:developer_revenue_in_buyer_currency] if args.key?(:developer_revenue_in_buyer_currency)
  @last_event_time = args[:last_event_time] if args.key?(:last_event_time)
  @line_items = args[:line_items] if args.key?(:line_items)
  @order_details = args[:order_details] if args.key?(:order_details)
  @order_history = args[:order_history] if args.key?(:order_history)
  @order_id = args[:order_id] if args.key?(:order_id)
  @points_details = args[:points_details] if args.key?(:points_details)
  @purchase_token = args[:purchase_token] if args.key?(:purchase_token)
  @sales_channel = args[:sales_channel] if args.key?(:sales_channel)
  @state = args[:state] if args.key?(:state)
  @tax = args[:tax] if args.key?(:tax)
  @total = args[:total] if args.key?(:total)
end