Class: Google::Apis::AndroidpublisherV3::OrderDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OrderDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Detailed information about the order at creation time.
Instance Attribute Summary collapse
-
#tax_inclusive ⇒ Boolean
(also: #tax_inclusive?)
Indicates whether the listed price was tax inclusive or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrderDetails
constructor
A new instance of OrderDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrderDetails
Returns a new instance of OrderDetails.
6052 6053 6054 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tax_inclusive ⇒ Boolean Also known as: tax_inclusive?
Indicates whether the listed price was tax inclusive or not.
Corresponds to the JSON property taxInclusive
6049 6050 6051 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6049 def tax_inclusive @tax_inclusive end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6057 6058 6059 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6057 def update!(**args) @tax_inclusive = args[:tax_inclusive] if args.key?(:tax_inclusive) end |