Class: Google::Apis::AndroidpublisherV3::OrderHistory
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OrderHistory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about events which modified the order.
Instance Attribute Summary collapse
-
#cancellation_event ⇒ Google::Apis::AndroidpublisherV3::CancellationEvent
Details of when the order was canceled.
-
#partial_refund_events ⇒ Array<Google::Apis::AndroidpublisherV3::PartialRefundEvent>
Details of the partial refund events for this order.
-
#processed_event ⇒ Google::Apis::AndroidpublisherV3::ProcessedEvent
Details of when the order was processed.
-
#refund_event ⇒ Google::Apis::AndroidpublisherV3::RefundEvent
Details of when the order was fully refunded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrderHistory
constructor
A new instance of OrderHistory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrderHistory
Returns a new instance of OrderHistory.
6145 6146 6147 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancellation_event ⇒ Google::Apis::AndroidpublisherV3::CancellationEvent
Details of when the order was canceled.
Corresponds to the JSON property cancellationEvent
6128 6129 6130 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6128 def cancellation_event @cancellation_event end |
#partial_refund_events ⇒ Array<Google::Apis::AndroidpublisherV3::PartialRefundEvent>
Details of the partial refund events for this order.
Corresponds to the JSON property partialRefundEvents
6133 6134 6135 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6133 def partial_refund_events @partial_refund_events end |
#processed_event ⇒ Google::Apis::AndroidpublisherV3::ProcessedEvent
Details of when the order was processed.
Corresponds to the JSON property processedEvent
6138 6139 6140 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6138 def processed_event @processed_event end |
#refund_event ⇒ Google::Apis::AndroidpublisherV3::RefundEvent
Details of when the order was fully refunded.
Corresponds to the JSON property refundEvent
6143 6144 6145 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6143 def refund_event @refund_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6150 6151 6152 6153 6154 6155 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6150 def update!(**args) @cancellation_event = args[:cancellation_event] if args.key?(:cancellation_event) @partial_refund_events = args[:partial_refund_events] if args.key?(:partial_refund_events) @processed_event = args[:processed_event] if args.key?(:processed_event) @refund_event = args[:refund_event] if args.key?(:refund_event) end |