Class: Google::Apis::AndroidpublisherV3::OrdersReviewRefundRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request for the orders.reviewrefund API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrdersReviewRefundRequest

Returns a new instance of OrdersReviewRefundRequest.



7434
7435
7436
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumption_percentage_milliunitsFixnum

Optional. Percentage of the In-App purchase the customer consumed, in milliunits. Minimum: 0 Maximum: 100,000. For paid apps, this can be omitted. Example : 45200 represents 45.2%. Corresponds to the JSON property consumptionPercentageMilliunits

Returns:

  • (Fixnum)


7406
7407
7408
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7406

def consumption_percentage_milliunits
  @consumption_percentage_milliunits
end

#consumption_usage_eventsArray<Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent>

Optional. List of events, each representing an instance where the user consumed or used the purchased item or service. Lists with over 1000 items will be rejected. Corresponds to the JSON property consumptionUsageEvents



7413
7414
7415
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7413

def consumption_usage_events
  @consumption_usage_events
end

#pending_refund_tokenString

Required. The pending refund token included in the pending refund review notification. Corresponds to the JSON property pendingRefundToken

Returns:

  • (String)


7419
7420
7421
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7419

def pending_refund_token
  @pending_refund_token
end

#refund_preferenceString

Required. Indicates your preference, based on your operational logic, as to whether the Play Store should grant the refund. Corresponds to the JSON property refundPreference

Returns:

  • (String)


7425
7426
7427
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7425

def refund_preference
  @refund_preference
end

#sample_content_providedBoolean Also known as: sample_content_provided?

Required. Indicates whether you provided a free sample, trial, or information about the functionality prior to the purchase. Corresponds to the JSON property sampleContentProvided

Returns:

  • (Boolean)


7431
7432
7433
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7431

def sample_content_provided
  @sample_content_provided
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7439
7440
7441
7442
7443
7444
7445
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7439

def update!(**args)
  @consumption_percentage_milliunits = args[:consumption_percentage_milliunits] if args.key?(:consumption_percentage_milliunits)
  @consumption_usage_events = args[:consumption_usage_events] if args.key?(:consumption_usage_events)
  @pending_refund_token = args[:pending_refund_token] if args.key?(:pending_refund_token)
  @refund_preference = args[:refund_preference] if args.key?(:refund_preference)
  @sample_content_provided = args[:sample_content_provided] if args.key?(:sample_content_provided)
end