Class: Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for any new locations Play may launch in specified on a subscription offer.
Instance Attribute Summary collapse
-
#other_regions_new_subscriber_availability ⇒ Boolean
(also: #other_regions_new_subscriber_availability?)
Whether the subscription offer in any new locations Play may launch in the future.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OtherRegionsSubscriptionOfferConfig
constructor
A new instance of OtherRegionsSubscriptionOfferConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OtherRegionsSubscriptionOfferConfig
Returns a new instance of OtherRegionsSubscriptionOfferConfig.
6708 6709 6710 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#other_regions_new_subscriber_availability ⇒ Boolean Also known as: other_regions_new_subscriber_availability?
Whether the subscription offer in any new locations Play may launch in the
future. If not specified, this will default to false.
Corresponds to the JSON property otherRegionsNewSubscriberAvailability
6705 6706 6707 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6705 def other_regions_new_subscriber_availability @other_regions_new_subscriber_availability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6713 6714 6715 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6713 def update!(**args) @other_regions_new_subscriber_availability = args[:other_regions_new_subscriber_availability] if args.key?(:other_regions_new_subscriber_availability) end |