Class: Google::Apis::AndroidpublisherV3::PartialRefund

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A partial refund of a transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartialRefund

Returns a new instance of PartialRefund.



7695
7696
7697
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#refund_idString

Required. A unique id distinguishing this partial refund. If the refund is successful, subsequent refunds with the same id will fail. Must be unique across refunds for one individual transaction. Corresponds to the JSON property refundId

Returns:

  • (String)


7688
7689
7690
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7688

def refund_id
  @refund_id
end

#refund_pre_tax_amountGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property refundPreTaxAmount



7693
7694
7695
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7693

def refund_pre_tax_amount
  @refund_pre_tax_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7700
7701
7702
7703
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7700

def update!(**args)
  @refund_id = args[:refund_id] if args.key?(:refund_id)
  @refund_pre_tax_amount = args[:refund_pre_tax_amount] if args.key?(:refund_pre_tax_amount)
end