Class: Google::Apis::AndroidpublisherV3::PreorderOfferDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Offer details information related to a preorder line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreorderOfferDetails

Returns a new instance of PreorderOfferDetails.



7880
7881
7882
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preorder_release_timeString

The time when a preordered item is released for a preorder purchase. Corresponds to the JSON property preorderReleaseTime

Returns:

  • (String)


7878
7879
7880
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7878

def preorder_release_time
  @preorder_release_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7885
7886
7887
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7885

def update!(**args)
  @preorder_release_time = args[:preorder_release_time] if args.key?(:preorder_release_time)
end