Class: Google::Apis::AndroidpublisherV3::PrepaidBasePlanType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Represents a base plan that does not automatically renew at the end of the base plan, and must be manually renewed by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrepaidBasePlanType

Returns a new instance of PrepaidBasePlanType.



7908
7909
7910
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_period_durationString

Required. Immutable. Subscription period, specified in ISO 8601 format. For a list of acceptable billing periods, refer to the help center. The duration is immutable after the base plan is created. Corresponds to the JSON property billingPeriodDuration

Returns:

  • (String)


7900
7901
7902
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7900

def billing_period_duration
  @billing_period_duration
end

#time_extensionString

Whether users should be able to extend this prepaid base plan in Google Play surfaces. Defaults to TIME_EXTENSION_ACTIVE if not specified. Corresponds to the JSON property timeExtension

Returns:

  • (String)


7906
7907
7908
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7906

def time_extension
  @time_extension
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7913
7914
7915
7916
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7913

def update!(**args)
  @billing_period_duration = args[:billing_period_duration] if args.key?(:billing_period_duration)
  @time_extension = args[:time_extension] if args.key?(:time_extension)
end