Class: Google::Apis::AndroidpublisherV3::Price
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Price
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Definition of a price, i.e. currency and units.
Instance Attribute Summary collapse
-
#currency ⇒ String
3 letter Currency code, as defined by ISO 4217.
-
#price_micros ⇒ String
Price in 1/million of the currency base unit, represented as a string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Price
constructor
A new instance of Price.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Price
Returns a new instance of Price.
6625 6626 6627 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency ⇒ String
3 letter Currency code, as defined by ISO 4217. See java/com/google/common/
money/CurrencyCode.java
Corresponds to the JSON property currency
6618 6619 6620 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6618 def currency @currency end |
#price_micros ⇒ String
Price in 1/million of the currency base unit, represented as a string.
Corresponds to the JSON property priceMicros
6623 6624 6625 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6623 def price_micros @price_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6630 6631 6632 6633 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6630 def update!(**args) @currency = args[:currency] if args.key?(:currency) @price_micros = args[:price_micros] if args.key?(:price_micros) end |