Class: Google::Apis::AndroidpublisherV3::ProductOfferDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Offer details information related to a purchase line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductOfferDetails

Returns a new instance of ProductOfferDetails.



8271
8272
8273
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumption_stateString

Output only. The consumption state of the purchase. Corresponds to the JSON property consumptionState

Returns:

  • (String)


8227
8228
8229
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8227

def consumption_state
  @consumption_state
end

#offer_idString

The offer ID. Only present for offers. Corresponds to the JSON property offerId

Returns:

  • (String)


8232
8233
8234
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8232

def offer_id
  @offer_id
end

#offer_tagsArray<String>

The latest offer tags associated with the offer. It includes tags inherited from the purchase option. Corresponds to the JSON property offerTags

Returns:

  • (Array<String>)


8238
8239
8240
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8238

def offer_tags
  @offer_tags
end

#offer_tokenString

The per-transaction offer token used to make this purchase line item. Corresponds to the JSON property offerToken

Returns:

  • (String)


8243
8244
8245
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8243

def offer_token
  @offer_token
end

#preorder_offer_detailsGoogle::Apis::AndroidpublisherV3::PreorderOfferDetails

Offer details information related to a preorder line item. Corresponds to the JSON property preorderOfferDetails



8248
8249
8250
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8248

def preorder_offer_details
  @preorder_offer_details
end

#purchase_option_idString

The purchase option ID. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


8253
8254
8255
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8253

def purchase_option_id
  @purchase_option_id
end

#quantityFixnum

The quantity associated with the purchase of the inapp product. Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


8258
8259
8260
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8258

def quantity
  @quantity
end

#refundable_quantityFixnum

The quantity eligible for refund, i.e. quantity that hasn't been refunded. The value reflects quantity-based partial refunds and full refunds. Corresponds to the JSON property refundableQuantity

Returns:

  • (Fixnum)


8264
8265
8266
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8264

def refundable_quantity
  @refundable_quantity
end

#rent_offer_detailsGoogle::Apis::AndroidpublisherV3::RentOfferDetails

Offer details information related to a rental line item. Corresponds to the JSON property rentOfferDetails



8269
8270
8271
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8269

def rent_offer_details
  @rent_offer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
8286
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8276

def update!(**args)
  @consumption_state = args[:consumption_state] if args.key?(:consumption_state)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @offer_token = args[:offer_token] if args.key?(:offer_token)
  @preorder_offer_details = args[:preorder_offer_details] if args.key?(:preorder_offer_details)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @quantity = args[:quantity] if args.key?(:quantity)
  @refundable_quantity = args[:refundable_quantity] if args.key?(:refundable_quantity)
  @rent_offer_details = args[:rent_offer_details] if args.key?(:rent_offer_details)
end