Class: Google::Apis::AndroidpublisherV3::ProductPurchase
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ProductPurchase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A ProductPurchase resource indicates the status of a user's inapp product purchase.
Instance Attribute Summary collapse
-
#acknowledgement_state ⇒ Fixnum
The acknowledgement state of the inapp product.
-
#consumption_state ⇒ Fixnum
The consumption state of the inapp product.
-
#developer_payload ⇒ String
A developer-specified string that contains supplemental information about an order.
-
#kind ⇒ String
This kind represents an inappPurchase object in the androidpublisher service.
-
#obfuscated_external_account_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's account in your app.
-
#obfuscated_external_profile_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's profile in your app.
-
#order_id ⇒ String
The order id associated with the purchase of the inapp product.
-
#product_id ⇒ String
The inapp product SKU.
-
#purchase_state ⇒ Fixnum
The purchase state of the order.
-
#purchase_time_millis ⇒ Fixnum
The time the product was purchased, in milliseconds since the epoch (Jan 1, 1970).
-
#purchase_token ⇒ String
The purchase token generated to identify this purchase.
-
#purchase_type ⇒ Fixnum
The type of purchase of the inapp product.
-
#quantity ⇒ Fixnum
The quantity associated with the purchase of the inapp product.
-
#refundable_quantity ⇒ Fixnum
The quantity eligible for refund, i.e.
-
#region_code ⇒ String
ISO 3166-1 alpha-2 billing region code of the user at the time the product was granted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductPurchase
constructor
A new instance of ProductPurchase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductPurchase
Returns a new instance of ProductPurchase.
8208 8209 8210 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acknowledgement_state ⇒ Fixnum
The acknowledgement state of the inapp product. Possible values are: 0. Yet to
be acknowledged 1. Acknowledged
Corresponds to the JSON property acknowledgementState
8119 8120 8121 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8119 def acknowledgement_state @acknowledgement_state end |
#consumption_state ⇒ Fixnum
The consumption state of the inapp product. Possible values are: 0. Yet to be
consumed 1. Consumed
Corresponds to the JSON property consumptionState
8125 8126 8127 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8125 def consumption_state @consumption_state end |
#developer_payload ⇒ String
A developer-specified string that contains supplemental information about an
order.
Corresponds to the JSON property developerPayload
8131 8132 8133 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8131 def developer_payload @developer_payload end |
#kind ⇒ String
This kind represents an inappPurchase object in the androidpublisher service.
Corresponds to the JSON property kind
8136 8137 8138 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8136 def kind @kind end |
#obfuscated_external_account_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's
account in your app. Only present if specified using https://developer.android.
com/reference/com/android/billingclient/api/BillingFlowParams.Builder#
setobfuscatedaccountid when the purchase was made.
Corresponds to the JSON property obfuscatedExternalAccountId
8144 8145 8146 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8144 def @obfuscated_external_account_id end |
#obfuscated_external_profile_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's
profile in your app. Only present if specified using https://developer.android.
com/reference/com/android/billingclient/api/BillingFlowParams.Builder#
setobfuscatedprofileid when the purchase was made.
Corresponds to the JSON property obfuscatedExternalProfileId
8152 8153 8154 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8152 def @obfuscated_external_profile_id end |
#order_id ⇒ String
The order id associated with the purchase of the inapp product.
Corresponds to the JSON property orderId
8157 8158 8159 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8157 def order_id @order_id end |
#product_id ⇒ String
The inapp product SKU. May not be present.
Corresponds to the JSON property productId
8162 8163 8164 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8162 def product_id @product_id end |
#purchase_state ⇒ Fixnum
The purchase state of the order. Possible values are: 0. Purchased 1. Canceled
- Pending
Corresponds to the JSON property
purchaseState
8168 8169 8170 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8168 def purchase_state @purchase_state end |
#purchase_time_millis ⇒ Fixnum
The time the product was purchased, in milliseconds since the epoch (Jan 1,
1970).
Corresponds to the JSON property purchaseTimeMillis
8174 8175 8176 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8174 def purchase_time_millis @purchase_time_millis end |
#purchase_token ⇒ String
The purchase token generated to identify this purchase. May not be present.
Corresponds to the JSON property purchaseToken
8179 8180 8181 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8179 def purchase_token @purchase_token end |
#purchase_type ⇒ Fixnum
The type of purchase of the inapp product. This field is only set if this
purchase was not made using the standard in-app billing flow. Possible values
are: 0. Test (i.e. purchased from a license testing account) 1. Promo (i.e.
purchased using a promo code). Does not include Play Points purchases. 2.
Rewarded (i.e. from watching a video ad instead of paying)
Corresponds to the JSON property purchaseType
8188 8189 8190 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8188 def purchase_type @purchase_type end |
#quantity ⇒ Fixnum
The quantity associated with the purchase of the inapp product. If not present,
the quantity is 1.
Corresponds to the JSON property quantity
8194 8195 8196 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8194 def quantity @quantity end |
#refundable_quantity ⇒ Fixnum
The quantity eligible for refund, i.e. quantity that hasn't been refunded. The
value reflects quantity-based partial refunds and full refunds.
Corresponds to the JSON property refundableQuantity
8200 8201 8202 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8200 def refundable_quantity @refundable_quantity end |
#region_code ⇒ String
ISO 3166-1 alpha-2 billing region code of the user at the time the product was
granted.
Corresponds to the JSON property regionCode
8206 8207 8208 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8206 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8213 8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 8224 8225 8226 8227 8228 8229 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8213 def update!(**args) @acknowledgement_state = args[:acknowledgement_state] if args.key?(:acknowledgement_state) @consumption_state = args[:consumption_state] if args.key?(:consumption_state) @developer_payload = args[:developer_payload] if args.key?(:developer_payload) @kind = args[:kind] if args.key?(:kind) @obfuscated_external_account_id = args[:obfuscated_external_account_id] if args.key?(:obfuscated_external_account_id) @obfuscated_external_profile_id = args[:obfuscated_external_profile_id] if args.key?(:obfuscated_external_profile_id) @order_id = args[:order_id] if args.key?(:order_id) @product_id = args[:product_id] if args.key?(:product_id) @purchase_state = args[:purchase_state] if args.key?(:purchase_state) @purchase_time_millis = args[:purchase_time_millis] if args.key?(:purchase_time_millis) @purchase_token = args[:purchase_token] if args.key?(:purchase_token) @purchase_type = args[:purchase_type] if args.key?(:purchase_type) @quantity = args[:quantity] if args.key?(:quantity) @refundable_quantity = args[:refundable_quantity] if args.key?(:refundable_quantity) @region_code = args[:region_code] if args.key?(:region_code) end |