Class: Google::Apis::AndroidpublisherV3::PurchaseOptionTaxAndComplianceSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about taxation, Google Play policy and legal compliance for one-time product purchase options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PurchaseOptionTaxAndComplianceSettings

Returns a new instance of PurchaseOptionTaxAndComplianceSettings.



7015
7016
7017
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#withdrawal_right_typeString

Optional. Digital content or service classification for products distributed to users in eligible regions. If unset, it defaults to WITHDRAWAL_RIGHT_DIGITAL_CONTENT. Refer to the Help Center article for more information. Corresponds to the JSON property withdrawalRightType

Returns:

  • (String)


7013
7014
7015
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7013

def withdrawal_right_type
  @withdrawal_right_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7020
7021
7022
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7020

def update!(**args)
  @withdrawal_right_type = args[:withdrawal_right_type] if args.key?(:withdrawal_right_type)
end