Class: Google::Apis::AndroidpublisherV3::RecentAppView
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RecentAppView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Metadata about a recently updated app.
Instance Attribute Summary collapse
-
#app_view ⇒ Google::Apis::AndroidpublisherV3::CatalogAppView
LINT.IfChange A view of a Google Play app within the Catalog Export for app stores.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecentAppView
constructor
A new instance of RecentAppView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecentAppView
Returns a new instance of RecentAppView.
8462 8463 8464 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_view ⇒ Google::Apis::AndroidpublisherV3::CatalogAppView
LINT.IfChange A view of a Google Play app within the Catalog Export for app
stores.
Corresponds to the JSON property appView
8460 8461 8462 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8460 def app_view @app_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8467 8468 8469 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8467 def update!(**args) @app_view = args[:app_view] if args.key?(:app_view) end |