Class: Google::Apis::AndroidpublisherV3::RecurringExternalTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecurringExternalTransaction

Returns a new instance of RecurringExternalTransaction.



8541
8542
8543
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_subscriptionGoogle::Apis::AndroidpublisherV3::ExternalSubscription

Details of an external subscription. Corresponds to the JSON property externalSubscription



8512
8513
8514
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8512

def external_subscription
  @external_subscription
end

#external_transaction_tokenString

Input only. Provided during the call to Create. Retrieved from the client when the alternative billing flow is launched. Required only for the initial purchase. Corresponds to the JSON property externalTransactionToken

Returns:

  • (String)


8519
8520
8521
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8519

def external_transaction_token
  @external_transaction_token
end

#initial_external_transaction_idString

The external transaction id of the first transaction of this recurring series of transactions. For example, for a subscription this would be the transaction id of the first payment. Required when creating recurring external transactions. Corresponds to the JSON property initialExternalTransactionId

Returns:

  • (String)


8527
8528
8529
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8527

def initial_external_transaction_id
  @initial_external_transaction_id
end

#migrated_transaction_programString

Input only. Provided during the call to Create. Must only be used when migrating a subscription from manual monthly reporting to automated reporting. Corresponds to the JSON property migratedTransactionProgram

Returns:

  • (String)


8533
8534
8535
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8533

def migrated_transaction_program
  @migrated_transaction_program
end

#other_recurring_productGoogle::Apis::AndroidpublisherV3::OtherRecurringProduct

Details of a recurring external transaction product which doesn't belong to any other more specific category. Corresponds to the JSON property otherRecurringProduct



8539
8540
8541
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8539

def other_recurring_product
  @other_recurring_product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8546
8547
8548
8549
8550
8551
8552
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8546

def update!(**args)
  @external_subscription = args[:external_subscription] if args.key?(:external_subscription)
  @external_transaction_token = args[:external_transaction_token] if args.key?(:external_transaction_token)
  @initial_external_transaction_id = args[:initial_external_transaction_id] if args.key?(:initial_external_transaction_id)
  @migrated_transaction_program = args[:migrated_transaction_program] if args.key?(:migrated_transaction_program)
  @other_recurring_product = args[:other_recurring_product] if args.key?(:other_recurring_product)
end