Class: Google::Apis::AndroidpublisherV3::RefundDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RefundDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details for a partial or full refund.
Instance Attribute Summary collapse
-
#tax ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#total ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RefundDetails
constructor
A new instance of RefundDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RefundDetails
Returns a new instance of RefundDetails.
8569 8570 8571 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8569 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tax ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property tax
8562 8563 8564 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8562 def tax @tax end |
#total ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property total
8567 8568 8569 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8567 def total @total end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8574 8575 8576 8577 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8574 def update!(**args) @tax = args[:tax] if args.key?(:tax) @total = args[:total] if args.key?(:total) end |