Class: Google::Apis::AndroidpublisherV3::RefundExternalTransactionRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RefundExternalTransactionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A request to refund an existing external transaction.
Instance Attribute Summary collapse
-
#full_refund ⇒ Google::Apis::AndroidpublisherV3::FullRefund
A full refund of the remaining amount of a transaction.
-
#partial_refund ⇒ Google::Apis::AndroidpublisherV3::PartialRefund
A partial refund of a transaction.
-
#refund_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RefundExternalTransactionRequest
constructor
A new instance of RefundExternalTransactionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RefundExternalTransactionRequest
Returns a new instance of RefundExternalTransactionRequest.
7171 7172 7173 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_refund ⇒ Google::Apis::AndroidpublisherV3::FullRefund
A full refund of the remaining amount of a transaction.
Corresponds to the JSON property fullRefund
7159 7160 7161 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7159 def full_refund @full_refund end |
#partial_refund ⇒ Google::Apis::AndroidpublisherV3::PartialRefund
A partial refund of a transaction.
Corresponds to the JSON property partialRefund
7164 7165 7166 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7164 def partial_refund @partial_refund end |
#refund_time ⇒ String
Required. The time that the transaction was refunded.
Corresponds to the JSON property refundTime
7169 7170 7171 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7169 def refund_time @refund_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7176 7177 7178 7179 7180 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7176 def update!(**args) @full_refund = args[:full_refund] if args.key?(:full_refund) @partial_refund = args[:partial_refund] if args.key?(:partial_refund) @refund_time = args[:refund_time] if args.key?(:refund_time) end |