Class: Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Specified details about taxation in a given geographical region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalTaxRateInfo

Returns a new instance of RegionalTaxRateInfo.



9083
9084
9085
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligible_for_streaming_service_tax_rateBoolean Also known as: eligible_for_streaming_service_tax_rate?

You must tell us if your app contains streaming products to correctly charge US state and local sales tax. Field only supported in the United States. Corresponds to the JSON property eligibleForStreamingServiceTaxRate

Returns:

  • (Boolean)


9065
9066
9067
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9065

def eligible_for_streaming_service_tax_rate
  @eligible_for_streaming_service_tax_rate
end

#streaming_tax_typeString

To collect communications or amusement taxes in the United States, choose the appropriate tax category. Learn more. Corresponds to the JSON property streamingTaxType

Returns:

  • (String)


9073
9074
9075
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9073

def streaming_tax_type
  @streaming_tax_type
end

#tax_tierString

Tax tier to specify reduced tax rate. Developers who sell digital news, magazines, newspapers, books, or audiobooks in various regions may be eligible for reduced tax rates. Learn more. Corresponds to the JSON property taxTier

Returns:

  • (String)


9081
9082
9083
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9081

def tax_tier
  @tax_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9088
9089
9090
9091
9092
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9088

def update!(**args)
  @eligible_for_streaming_service_tax_rate = args[:eligible_for_streaming_service_tax_rate] if args.key?(:eligible_for_streaming_service_tax_rate)
  @streaming_tax_type = args[:streaming_tax_type] if args.key?(:streaming_tax_type)
  @tax_tier = args[:tax_tier] if args.key?(:tax_tier)
end