Class: Google::Apis::AndroidpublisherV3::RegionsVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The version of the available regions being used for the specified resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionsVersion

Returns a new instance of RegionsVersion.



9133
9134
9135
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#versionString

Required. A string representing the version of available regions being used for the specified resource. Regional prices and latest supported version for the resource have to be specified according to the information published in this article. Each time the supported locations substantially change, the version will be incremented. Using this field will ensure that creating and updating the resource with an older region's version and set of regional prices and currencies will succeed even though a new version is available. Corresponds to the JSON property version

Returns:

  • (String)


9131
9132
9133
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9131

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9138
9139
9140
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9138

def update!(**args)
  @version = args[:version] if args.key?(:version)
end