Class: Google::Apis::AndroidpublisherV3::RemoteInAppUpdateData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Data related to Remote In-App Update action such as recovered user count, affected user count etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteInAppUpdateData

Returns a new instance of RemoteInAppUpdateData.



7612
7613
7614
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#remote_app_update_data_per_bundleArray<Google::Apis::AndroidpublisherV3::RemoteInAppUpdateDataPerBundle>

Data related to the recovery action at bundle level. Corresponds to the JSON property remoteAppUpdateDataPerBundle



7610
7611
7612
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7610

def remote_app_update_data_per_bundle
  @remote_app_update_data_per_bundle
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7617
7618
7619
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7617

def update!(**args)
  @remote_app_update_data_per_bundle = args[:remote_app_update_data_per_bundle] if args.key?(:remote_app_update_data_per_bundle)
end