Class: Google::Apis::AndroidpublisherV3::RemoteInAppUpdateDataPerBundle
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RemoteInAppUpdateDataPerBundle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Data related to the recovery action at bundle level.
Instance Attribute Summary collapse
-
#recovered_device_count ⇒ Fixnum
Total number of devices which have been rescued.
-
#total_device_count ⇒ Fixnum
Total number of devices affected by this recovery action associated with bundle of the app.
-
#version_code ⇒ Fixnum
Version Code corresponding to the target bundle.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteInAppUpdateDataPerBundle
constructor
A new instance of RemoteInAppUpdateDataPerBundle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteInAppUpdateDataPerBundle
Returns a new instance of RemoteInAppUpdateDataPerBundle.
9241 9242 9243 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recovered_device_count ⇒ Fixnum
Total number of devices which have been rescued.
Corresponds to the JSON property recoveredDeviceCount
9228 9229 9230 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9228 def recovered_device_count @recovered_device_count end |
#total_device_count ⇒ Fixnum
Total number of devices affected by this recovery action associated with
bundle of the app.
Corresponds to the JSON property totalDeviceCount
9234 9235 9236 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9234 def total_device_count @total_device_count end |
#version_code ⇒ Fixnum
Version Code corresponding to the target bundle.
Corresponds to the JSON property versionCode
9239 9240 9241 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9239 def version_code @version_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9246 9247 9248 9249 9250 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9246 def update!(**args) @recovered_device_count = args[:recovered_device_count] if args.key?(:recovered_device_count) @total_device_count = args[:total_device_count] if args.key?(:total_device_count) @version_code = args[:version_code] if args.key?(:version_code) end |