Class: Google::Apis::AndroidpublisherV3::Review
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Review
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An Android app review.
Instance Attribute Summary collapse
-
#author_name ⇒ String
The name of the user who wrote the review.
-
#comments ⇒ Array<Google::Apis::AndroidpublisherV3::Comment>
A repeated field containing comments for the review.
-
#review_id ⇒ String
Unique identifier for this review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Review
constructor
A new instance of Review.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Review
Returns a new instance of Review.
7657 7658 7659 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author_name ⇒ String
The name of the user who wrote the review.
Corresponds to the JSON property authorName
7645 7646 7647 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7645 def @author_name end |
#comments ⇒ Array<Google::Apis::AndroidpublisherV3::Comment>
A repeated field containing comments for the review.
Corresponds to the JSON property comments
7650 7651 7652 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7650 def comments @comments end |
#review_id ⇒ String
Unique identifier for this review.
Corresponds to the JSON property reviewId
7655 7656 7657 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7655 def review_id @review_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7662 7663 7664 7665 7666 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7662 def update!(**args) @author_name = args[:author_name] if args.key?(:author_name) @comments = args[:comments] if args.key?(:comments) @review_id = args[:review_id] if args.key?(:review_id) end |