Class: Google::Apis::AndroidpublisherV3::RotatedCloudKmsKey
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RotatedCloudKmsKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Message representing rotated Cloud KMS key. Consists of the Cloud KMS key and its associated proof of rotation.
Instance Attribute Summary collapse
-
#cloud_kms_key_and_cert ⇒ Google::Apis::AndroidpublisherV3::CloudKmsKeyAndCert
Cloud KMS key and the certificate associated with the key.
-
#signing_certificate_lineage ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotatedCloudKmsKey
constructor
A new instance of RotatedCloudKmsKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotatedCloudKmsKey
Returns a new instance of RotatedCloudKmsKey.
9646 9647 9648 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_kms_key_and_cert ⇒ Google::Apis::AndroidpublisherV3::CloudKmsKeyAndCert
Cloud KMS key and the certificate associated with the key.
Corresponds to the JSON property cloudKmsKeyAndCert
9637 9638 9639 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9637 def cloud_kms_key_and_cert @cloud_kms_key_and_cert end |
#signing_certificate_lineage ⇒ String
Required. Proof-of-rotation. See creating signing certificate lineages.
Corresponds to the JSON property signingCertificateLineage
NOTE: Values are automatically base64 encoded/decoded in the client library.
9644 9645 9646 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9644 def signing_certificate_lineage @signing_certificate_lineage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9651 9652 9653 9654 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9651 def update!(**args) @cloud_kms_key_and_cert = args[:cloud_kms_key_and_cert] if args.key?(:cloud_kms_key_and_cert) @signing_certificate_lineage = args[:signing_certificate_lineage] if args.key?(:signing_certificate_lineage) end |