Class: Google::Apis::AndroidpublisherV3::SdkVersionTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SdkVersionTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Targeting based on sdk version.
Instance Attribute Summary collapse
-
#alternatives ⇒ Array<Google::Apis::AndroidpublisherV3::SdkVersion>
Targeting of other sibling directories that were in the Bundle.
-
#value ⇒ Array<Google::Apis::AndroidpublisherV3::SdkVersion>
Value of an sdk version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SdkVersionTargeting
constructor
A new instance of SdkVersionTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SdkVersionTargeting
Returns a new instance of SdkVersionTargeting.
9546 9547 9548 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternatives ⇒ Array<Google::Apis::AndroidpublisherV3::SdkVersion>
Targeting of other sibling directories that were in the Bundle. For main
splits this is targeting of other main splits.
Corresponds to the JSON property alternatives
9539 9540 9541 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9539 def alternatives @alternatives end |
#value ⇒ Array<Google::Apis::AndroidpublisherV3::SdkVersion>
Value of an sdk version.
Corresponds to the JSON property value
9544 9545 9546 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9544 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9551 9552 9553 9554 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9551 def update!(**args) @alternatives = args[:alternatives] if args.key?(:alternatives) @value = args[:value] if args.key?(:value) end |