Class: Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information associated with purchases made with 'Subscribe with Google'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscribeWithGoogleInfo

Returns a new instance of SubscribeWithGoogleInfo.



9716
9717
9718
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_addressString

The email address of the user when the subscription was purchased. Corresponds to the JSON property emailAddress

Returns:

  • (String)


9694
9695
9696
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9694

def email_address
  @email_address
end

#family_nameString

The family name of the user when the subscription was purchased. Corresponds to the JSON property familyName

Returns:

  • (String)


9699
9700
9701
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9699

def family_name
  @family_name
end

#given_nameString

The given name of the user when the subscription was purchased. Corresponds to the JSON property givenName

Returns:

  • (String)


9704
9705
9706
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9704

def given_name
  @given_name
end

#profile_idString

The Google profile id of the user when the subscription was purchased. Corresponds to the JSON property profileId

Returns:

  • (String)


9709
9710
9711
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9709

def profile_id
  @profile_id
end

#profile_nameString

The profile name of the user when the subscription was purchased. Corresponds to the JSON property profileName

Returns:

  • (String)


9714
9715
9716
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9714

def profile_name
  @profile_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9721
9722
9723
9724
9725
9726
9727
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9721

def update!(**args)
  @email_address = args[:email_address] if args.key?(:email_address)
  @family_name = args[:family_name] if args.key?(:family_name)
  @given_name = args[:given_name] if args.key?(:given_name)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
  @profile_name = args[:profile_name] if args.key?(:profile_name)
end