Class: Google::Apis::AndroidpublisherV3::Subscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single subscription for an app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subscription

Returns a new instance of Subscription.



10030
10031
10032
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archivedBoolean Also known as: archived?

Output only. Deprecated: subscription archiving is not supported. Corresponds to the JSON property archived

Returns:

  • (Boolean)


9989
9990
9991
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9989

def archived
  @archived
end

#base_plansArray<Google::Apis::AndroidpublisherV3::BasePlan>

The set of base plans for this subscription. Represents the prices and duration of the subscription if no other offers apply. Corresponds to the JSON property basePlans



9996
9997
9998
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9996

def base_plans
  @base_plans
end

#listingsArray<Google::Apis::AndroidpublisherV3::SubscriptionListing>

Required. List of localized listings for this subscription. Must contain at least an entry for the default language of the parent app. Corresponds to the JSON property listings



10002
10003
10004
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10002

def listings
  @listings
end

#package_nameString

Immutable. Package name of the parent app. Corresponds to the JSON property packageName

Returns:

  • (String)


10007
10008
10009
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10007

def package_name
  @package_name
end

#product_idString

Immutable. Unique product ID of the product. Unique within the parent app. Product IDs must be composed of lower-case letters (a-z), numbers (0-9), underscores (_) and dots (.). It must start with a lower-case letter or number, and be between 1 and 40 (inclusive) characters in length. Corresponds to the JSON property productId

Returns:

  • (String)


10015
10016
10017
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10015

def product_id
  @product_id
end

#restricted_payment_countriesGoogle::Apis::AndroidpublisherV3::RestrictedPaymentCountries

Countries where the purchase of this product is restricted to payment methods registered in the same country. If empty, no payment location restrictions are imposed. Corresponds to the JSON property restrictedPaymentCountries



10022
10023
10024
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10022

def restricted_payment_countries
  @restricted_payment_countries
end

#tax_and_compliance_settingsGoogle::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings

Details about taxation, Google Play policy, and legal compliance for subscription products. Corresponds to the JSON property taxAndComplianceSettings



10028
10029
10030
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10028

def tax_and_compliance_settings
  @tax_and_compliance_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10035
10036
10037
10038
10039
10040
10041
10042
10043
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10035

def update!(**args)
  @archived = args[:archived] if args.key?(:archived)
  @base_plans = args[:base_plans] if args.key?(:base_plans)
  @listings = args[:listings] if args.key?(:listings)
  @package_name = args[:package_name] if args.key?(:package_name)
  @product_id = args[:product_id] if args.key?(:product_id)
  @restricted_payment_countries = args[:restricted_payment_countries] if args.key?(:restricted_payment_countries)
  @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings)
end