Class: Google::Apis::AndroidpublisherV3::SubscriptionOffer
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single, temporary offer
Instance Attribute Summary collapse
-
#base_plan_id ⇒ String
Required.
-
#offer_id ⇒ String
Required.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
List of up to 20 custom tags specified for this offer, and returned to the app through the billing library.
-
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig
Configuration for any new locations Play may launch in specified on a subscription offer.
-
#package_name ⇒ String
Required.
-
#phases ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase>
Required.
-
#product_id ⇒ String
Required.
-
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig>
Required.
-
#state ⇒ String
Output only.
-
#targeting ⇒ Google::Apis::AndroidpublisherV3::SubscriptionOfferTargeting
Defines the rule a user needs to satisfy to receive this offer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionOffer
constructor
A new instance of SubscriptionOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionOffer
Returns a new instance of SubscriptionOffer.
10275 10276 10277 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_plan_id ⇒ String
Required. Immutable. The ID of the base plan to which this offer is an
extension.
Corresponds to the JSON property basePlanId
10219 10220 10221 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10219 def base_plan_id @base_plan_id end |
#offer_id ⇒ String
Required. Immutable. Unique ID of this subscription offer. Must be unique
within the base plan.
Corresponds to the JSON property offerId
10225 10226 10227 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10225 def offer_id @offer_id end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
List of up to 20 custom tags specified for this offer, and returned to the app
through the billing library.
Corresponds to the JSON property offerTags
10231 10232 10233 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10231 def @offer_tags end |
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig
Configuration for any new locations Play may launch in specified on a
subscription offer.
Corresponds to the JSON property otherRegionsConfig
10237 10238 10239 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10237 def other_regions_config @other_regions_config end |
#package_name ⇒ String
Required. Immutable. The package name of the app the parent subscription
belongs to.
Corresponds to the JSON property packageName
10243 10244 10245 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10243 def package_name @package_name end |
#phases ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase>
Required. The phases of this subscription offer. Must contain at least one and
at most two entries. Users will always receive all these phases in the
specified order.
Corresponds to the JSON property phases
10250 10251 10252 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10250 def phases @phases end |
#product_id ⇒ String
Required. Immutable. The ID of the parent subscription this offer belongs to.
Corresponds to the JSON property productId
10255 10256 10257 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10255 def product_id @product_id end |
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig>
Required. The region-specific configuration of this offer. Must contain at
least one entry.
Corresponds to the JSON property regionalConfigs
10261 10262 10263 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10261 def regional_configs @regional_configs end |
#state ⇒ String
Output only. The current state of this offer. Can be changed using Activate
and Deactivate actions. NB: the base plan state supersedes this state, so an
active offer may not be available if the base plan is not active.
Corresponds to the JSON property state
10268 10269 10270 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10268 def state @state end |
#targeting ⇒ Google::Apis::AndroidpublisherV3::SubscriptionOfferTargeting
Defines the rule a user needs to satisfy to receive this offer.
Corresponds to the JSON property targeting
10273 10274 10275 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10273 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10280 def update!(**args) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config) @package_name = args[:package_name] if args.key?(:package_name) @phases = args[:phases] if args.key?(:phases) @product_id = args[:product_id] if args.key?(:product_id) @regional_configs = args[:regional_configs] if args.key?(:regional_configs) @state = args[:state] if args.key?(:state) @targeting = args[:targeting] if args.key?(:targeting) end |