Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Item-level info for a subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionPurchaseLineItem

Returns a new instance of SubscriptionPurchaseLineItem.



10424
10425
10426
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewing_planGoogle::Apis::AndroidpublisherV3::AutoRenewingPlan

Information related to an auto renewing plan. Corresponds to the JSON property autoRenewingPlan



10369
10370
10371
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10369

def auto_renewing_plan
  @auto_renewing_plan
end

#deferred_item_removalGoogle::Apis::AndroidpublisherV3::DeferredItemRemoval

Information related to deferred item replacement. Corresponds to the JSON property deferredItemRemoval



10374
10375
10376
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10374

def deferred_item_removal
  @deferred_item_removal
end

#deferred_item_replacementGoogle::Apis::AndroidpublisherV3::DeferredItemReplacement

Information related to deferred item replacement. Corresponds to the JSON property deferredItemReplacement



10379
10380
10381
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10379

def deferred_item_replacement
  @deferred_item_replacement
end

#expiry_timeString

Time at which the subscription expired or will expire unless the access is extended (ex. renews). Corresponds to the JSON property expiryTime

Returns:

  • (String)


10385
10386
10387
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10385

def expiry_time
  @expiry_time
end

#item_replacementGoogle::Apis::AndroidpublisherV3::ItemReplacement

Details about a subscription line item that is being replaced. Corresponds to the JSON property itemReplacement



10390
10391
10392
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10390

def item_replacement
  @item_replacement
end

#latest_successful_order_idString

The order id of the latest successful order associated with this item. Not present if the item is not owned by the user yet (e.g. the item being deferred replaced to). Corresponds to the JSON property latestSuccessfulOrderId

Returns:

  • (String)


10397
10398
10399
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10397

def latest_successful_order_id
  @latest_successful_order_id
end

#offer_detailsGoogle::Apis::AndroidpublisherV3::OfferDetails

Offer details information related to a purchase line item. Corresponds to the JSON property offerDetails



10402
10403
10404
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10402

def offer_details
  @offer_details
end

#offer_phaseGoogle::Apis::AndroidpublisherV3::OfferPhase

Offer phase details. Corresponds to the JSON property offerPhase



10407
10408
10409
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10407

def offer_phase
  @offer_phase
end

#prepaid_planGoogle::Apis::AndroidpublisherV3::PrepaidPlan

Information related to a prepaid plan. Corresponds to the JSON property prepaidPlan



10412
10413
10414
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10412

def prepaid_plan
  @prepaid_plan
end

#product_idString

The purchased product ID (for example, 'monthly001'). Corresponds to the JSON property productId

Returns:

  • (String)


10417
10418
10419
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10417

def product_id
  @product_id
end

#signup_promotionGoogle::Apis::AndroidpublisherV3::SignupPromotion

The promotion applied on this item when purchased. Corresponds to the JSON property signupPromotion



10422
10423
10424
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10422

def 
  @signup_promotion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10429
10430
10431
10432
10433
10434
10435
10436
10437
10438
10439
10440
10441
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10429

def update!(**args)
  @auto_renewing_plan = args[:auto_renewing_plan] if args.key?(:auto_renewing_plan)
  @deferred_item_removal = args[:deferred_item_removal] if args.key?(:deferred_item_removal)
  @deferred_item_replacement = args[:deferred_item_replacement] if args.key?(:deferred_item_replacement)
  @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
  @item_replacement = args[:item_replacement] if args.key?(:item_replacement)
  @latest_successful_order_id = args[:latest_successful_order_id] if args.key?(:latest_successful_order_id)
  @offer_details = args[:offer_details] if args.key?(:offer_details)
  @offer_phase = args[:offer_phase] if args.key?(:offer_phase)
  @prepaid_plan = args[:prepaid_plan] if args.key?(:prepaid_plan)
  @product_id = args[:product_id] if args.key?(:product_id)
  @signup_promotion = args[:signup_promotion] if args.key?(:signup_promotion)
end