Class: Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about taxation, Google Play policy, and legal compliance for subscription products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings

Returns a new instance of SubscriptionTaxAndComplianceSettings.



10669
10670
10671
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eea_withdrawal_right_typeString

Digital content or service classification for products distributed to users in the European Economic Area (EEA). The withdrawal regime under EEA consumer laws depends on this classification. Refer to the Help Center article for more information. Corresponds to the JSON property eeaWithdrawalRightType

Returns:

  • (String)


10640
10641
10642
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10640

def eea_withdrawal_right_type
  @eea_withdrawal_right_type
end

#is_tokenized_digital_assetBoolean Also known as: is_tokenized_digital_asset?

Whether this subscription is declared as a product representing a tokenized digital asset. Corresponds to the JSON property isTokenizedDigitalAsset

Returns:

  • (Boolean)


10646
10647
10648
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10646

def is_tokenized_digital_asset
  @is_tokenized_digital_asset
end

#product_tax_category_codeString

Product tax category code to assign to the subscription. Product tax category determines the transaction tax rates applied to the subscription. Refer to the Help Center article for more information. Corresponds to the JSON property productTaxCategoryCode

Returns:

  • (String)


10655
10656
10657
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10655

def product_tax_category_code
  @product_tax_category_code
end

#regional_product_age_rating_infosArray<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>

Regional age rating information. Currently this field is only supported for region code US. Corresponds to the JSON property regionalProductAgeRatingInfos



10661
10662
10663
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10661

def regional_product_age_rating_infos
  @regional_product_age_rating_infos
end

#tax_rate_info_by_region_codeHash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>

A mapping from region code to tax rate details. The keys are region codes as defined by Unicode's "CLDR". Corresponds to the JSON property taxRateInfoByRegionCode



10667
10668
10669
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10667

def tax_rate_info_by_region_code
  @tax_rate_info_by_region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10674
10675
10676
10677
10678
10679
10680
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10674

def update!(**args)
  @eea_withdrawal_right_type = args[:eea_withdrawal_right_type] if args.key?(:eea_withdrawal_right_type)
  @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset)
  @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code)
  @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos)
  @tax_rate_info_by_region_code = args[:tax_rate_info_by_region_code] if args.key?(:tax_rate_info_by_region_code)
end