Class: Google::Apis::AndroidpublisherV3::Targeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Targeting details for a recovery action such as regions, android sdk levels, app versions etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Targeting

Returns a new instance of Targeting.



10576
10577
10578
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_usersGoogle::Apis::AndroidpublisherV3::AllUsers

Object representation to describe all set of users. Corresponds to the JSON property allUsers



10554
10555
10556
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10554

def all_users
  @all_users
end

#android_sdksGoogle::Apis::AndroidpublisherV3::AndroidSdks

Android api level targeting data for app recovery action targeting. Corresponds to the JSON property androidSdks



10559
10560
10561
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10559

def android_sdks
  @android_sdks
end

#regionsGoogle::Apis::AndroidpublisherV3::Regions

Region targeting data for app recovery action targeting. Corresponds to the JSON property regions



10564
10565
10566
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10564

def regions
  @regions
end

#version_listGoogle::Apis::AndroidpublisherV3::AppVersionList

Data format for a list of app versions. Corresponds to the JSON property versionList



10569
10570
10571
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10569

def version_list
  @version_list
end

#version_rangeGoogle::Apis::AndroidpublisherV3::AppVersionRange

Data format for a continuous range of app versions. Corresponds to the JSON property versionRange



10574
10575
10576
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10574

def version_range
  @version_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10581
10582
10583
10584
10585
10586
10587
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10581

def update!(**args)
  @all_users = args[:all_users] if args.key?(:all_users)
  @android_sdks = args[:android_sdks] if args.key?(:android_sdks)
  @regions = args[:regions] if args.key?(:regions)
  @version_list = args[:version_list] if args.key?(:version_list)
  @version_range = args[:version_range] if args.key?(:version_range)
end