Class: Google::Apis::AndroidpublisherV3::TargetingRuleScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Defines the scope of subscriptions which a targeting rule can match to target offers to users based on past or current entitlement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingRuleScope

Returns a new instance of TargetingRuleScope.



9463
9464
9465
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#any_subscription_in_appGoogle::Apis::AndroidpublisherV3::TargetingRuleScopeAnySubscriptionInApp

Represents the targeting rule scope corresponding to any subscription in the parent app. Corresponds to the JSON property anySubscriptionInApp



9449
9450
9451
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9449

def any_subscription_in_app
  @any_subscription_in_app
end

#specific_subscription_in_appString

The scope of the current targeting rule is the subscription with the specified subscription ID. Must be a subscription within the same parent app. Corresponds to the JSON property specificSubscriptionInApp

Returns:

  • (String)


9455
9456
9457
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9455

def specific_subscription_in_app
  @specific_subscription_in_app
end

#this_subscriptionGoogle::Apis::AndroidpublisherV3::TargetingRuleScopeThisSubscription

Represents the targeting rule scope corresponding to the subscriptions in which this offer is defined. Corresponds to the JSON property thisSubscription



9461
9462
9463
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9461

def this_subscription
  @this_subscription
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9468
9469
9470
9471
9472
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9468

def update!(**args)
  @any_subscription_in_app = args[:any_subscription_in_app] if args.key?(:any_subscription_in_app)
  @specific_subscription_in_app = args[:specific_subscription_in_app] if args.key?(:specific_subscription_in_app)
  @this_subscription = args[:this_subscription] if args.key?(:this_subscription)
end