Class: Google::Apis::AndroidpublisherV3::TargetingUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::TargetingUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Update type for targeting. Note it is always a subset Targeting.
Instance Attribute Summary collapse
-
#all_users ⇒ Google::Apis::AndroidpublisherV3::AllUsers
Object representation to describe all set of users.
-
#android_sdks ⇒ Google::Apis::AndroidpublisherV3::AndroidSdks
Android api level targeting data for app recovery action targeting.
-
#regions ⇒ Google::Apis::AndroidpublisherV3::Regions
Region targeting data for app recovery action targeting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetingUpdate
constructor
A new instance of TargetingUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetingUpdate
Returns a new instance of TargetingUpdate.
10955 10956 10957 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_users ⇒ Google::Apis::AndroidpublisherV3::AllUsers
Object representation to describe all set of users.
Corresponds to the JSON property allUsers
10943 10944 10945 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10943 def all_users @all_users end |
#android_sdks ⇒ Google::Apis::AndroidpublisherV3::AndroidSdks
Android api level targeting data for app recovery action targeting.
Corresponds to the JSON property androidSdks
10948 10949 10950 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10948 def android_sdks @android_sdks end |
#regions ⇒ Google::Apis::AndroidpublisherV3::Regions
Region targeting data for app recovery action targeting.
Corresponds to the JSON property regions
10953 10954 10955 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10953 def regions @regions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10960 10961 10962 10963 10964 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10960 def update!(**args) @all_users = args[:all_users] if args.key?(:all_users) @android_sdks = args[:android_sdks] if args.key?(:android_sdks) @regions = args[:regions] if args.key?(:regions) end |