Class: Google::Apis::AndroidpublisherV3::Timestamp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Timestamp

Returns a new instance of Timestamp.



11082
11083
11084
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Non-negative fractions of a second at nanosecond resolution. Must be from 0 to 999,999,999 inclusive. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


11075
11076
11077
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11075

def nanos
  @nanos
end

#secondsFixnum

Represents seconds of UTC time since Unix epoch. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


11080
11081
11082
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11080

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11087
11088
11089
11090
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11087

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end