Class: Google::Apis::AndroidpublisherV3::TokenPagination
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::TokenPagination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Tokens to pass to the standard list field 'page_token'.
-
#previous_page_token ⇒ String
Corresponds to the JSON property
previousPageToken.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TokenPagination
constructor
A new instance of TokenPagination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TokenPagination
Returns a new instance of TokenPagination.
11115 11116 11117 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Tokens to pass to the standard list field 'page_token'. Whenever available,
tokens are preferred over manipulating start_index.
Corresponds to the JSON property nextPageToken
11108 11109 11110 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11108 def next_page_token @next_page_token end |
#previous_page_token ⇒ String
Corresponds to the JSON property previousPageToken
11113 11114 11115 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11113 def previous_page_token @previous_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11120 11121 11122 11123 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11120 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @previous_page_token = args[:previous_page_token] if args.key?(:previous_page_token) end |