Class: Google::Apis::AndroidpublisherV3::Track

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A track configuration. The resource for TracksService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Track

Returns a new instance of Track.



9800
9801
9802
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#releasesArray<Google::Apis::AndroidpublisherV3::TrackRelease>

In a read request, represents all active releases in the track. In an update request, represents desired changes. Corresponds to the JSON property releases



9790
9791
9792
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9790

def releases
  @releases
end

#trackString

Identifier of the track. Form factor tracks have a special prefix as an identifier, for example wear:production, automotive:production. More on track name Corresponds to the JSON property track

Returns:

  • (String)


9798
9799
9800
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9798

def track
  @track
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9805
9806
9807
9808
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9805

def update!(**args)
  @releases = args[:releases] if args.key?(:releases)
  @track = args[:track] if args.key?(:track)
end