Class: Google::Apis::AndroidpublisherV3::TrackConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configurations of the new track.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackConfig

Returns a new instance of TrackConfig.



9747
9748
9749
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#form_factorString

Required. Form factor of the new track. Defaults to the default track. Corresponds to the JSON property formFactor

Returns:

  • (String)


9729
9730
9731
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9729

def form_factor
  @form_factor
end

#trackString

Required. Identifier of the new track. For default tracks, this field consists of the track alias only. Form factor tracks have a special prefix as an identifier, for example wear:production, automotive:production. This prefix must match the value of the form_factor field, if it is not a default track. More on track name Corresponds to the JSON property track

Returns:

  • (String)


9739
9740
9741
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9739

def track
  @track
end

#typeString

Required. Type of the new track. Currently, the only supported value is closedTesting. Corresponds to the JSON property type

Returns:

  • (String)


9745
9746
9747
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9745

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9752
9753
9754
9755
9756
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9752

def update!(**args)
  @form_factor = args[:form_factor] if args.key?(:form_factor)
  @track = args[:track] if args.key?(:track)
  @type = args[:type] if args.key?(:type)
end