Class: Google::Apis::AndroidpublisherV3::TrackTargetedCountry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Representation of a single country where the contents of a track can be made available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackTargetedCountry

Returns a new instance of TrackTargetedCountry.



10316
10317
10318
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

The country that can be targeted, as a two-letter CLDR code. Corresponds to the JSON property countryCode

Returns:

  • (String)


10314
10315
10316
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10314

def country_code
  @country_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10321
10322
10323
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10321

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
end