Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductOfferRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for UpdateOneTimeProductOffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateOneTimeProductOfferRequest

Returns a new instance of UpdateOneTimeProductOfferRequest.



10499
10500
10501
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. If set to true, and the offer with the given package_name, product_id, purchase_option_id and offer_id doesn't exist, an offer will be created. If a new offer is created, the update_mask is ignored. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


10475
10476
10477
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10475

def allow_missing
  @allow_missing
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this offer update. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


10482
10483
10484
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10482

def latency_tolerance
  @latency_tolerance
end

#one_time_product_offerGoogle::Apis::AndroidpublisherV3::OneTimeProductOffer

A single offer for a one-time product. Corresponds to the JSON property oneTimeProductOffer



10487
10488
10489
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10487

def one_time_product_offer
  @one_time_product_offer
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



10492
10493
10494
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10492

def regions_version
  @regions_version
end

#update_maskString

Required. The list of fields to be updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


10497
10498
10499
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10497

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10504
10505
10506
10507
10508
10509
10510
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10504

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @one_time_product_offer = args[:one_time_product_offer] if args.key?(:one_time_product_offer)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end