Class: Google::Apis::AndroidpublisherV3::UpdateSubscriptionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for UpdateSubscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateSubscriptionRequest

Returns a new instance of UpdateSubscriptionRequest.



11709
11710
11711
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. If set to true, and the subscription with the given package_name and product_id doesn't exist, the subscription will be created. If a new subscription is created, update_mask is ignored. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


11685
11686
11687
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11685

def allow_missing
  @allow_missing
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


11692
11693
11694
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11692

def latency_tolerance
  @latency_tolerance
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



11697
11698
11699
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11697

def regions_version
  @regions_version
end

#subscriptionGoogle::Apis::AndroidpublisherV3::Subscription

A single subscription for an app. Corresponds to the JSON property subscription



11702
11703
11704
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11702

def subscription
  @subscription
end

#update_maskString

Required. The list of fields to be updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


11707
11708
11709
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11707

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11714
11715
11716
11717
11718
11719
11720
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11714

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @subscription = args[:subscription] if args.key?(:subscription)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end