Class: Google::Apis::AndroidpublisherV3::UpgradeTargetingRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Represents a targeting rule of the form: User currently has scope [with billing period billing_period].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeTargetingRule

Returns a new instance of UpgradeTargetingRule.



11496
11497
11498
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_period_durationString

The specific billing period duration, specified in ISO 8601 format, that a user must be currently subscribed to to be eligible for this rule. If not specified, users subscribed to any billing period are matched. Corresponds to the JSON property billingPeriodDuration

Returns:

  • (String)


11481
11482
11483
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11481

def billing_period_duration
  @billing_period_duration
end

#once_per_userBoolean Also known as: once_per_user?

Limit this offer to only once per user. If set to true, a user can never be eligible for this offer again if they ever subscribed to this offer. Corresponds to the JSON property oncePerUser

Returns:

  • (Boolean)


11487
11488
11489
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11487

def once_per_user
  @once_per_user
end

#scopeGoogle::Apis::AndroidpublisherV3::TargetingRuleScope

Defines the scope of subscriptions which a targeting rule can match to target offers to users based on past or current entitlement. Corresponds to the JSON property scope



11494
11495
11496
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11494

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11501
11502
11503
11504
11505
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11501

def update!(**args)
  @billing_period_duration = args[:billing_period_duration] if args.key?(:billing_period_duration)
  @once_per_user = args[:once_per_user] if args.key?(:once_per_user)
  @scope = args[:scope] if args.key?(:scope)
end