Class: Google::Apis::AndroidpublisherV3::UsesConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Represents all configurations marked as required by use of the uses- configuration manifest tag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsesConfiguration

Returns a new instance of UsesConfiguration.



12133
12134
12135
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_keyboard_typeString

The type of keyboard required. Corresponds to the JSON property requiredKeyboardType

Returns:

  • (String)


12109
12110
12111
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12109

def required_keyboard_type
  @required_keyboard_type
end

#required_navigation_typeString

The navigation device required. Corresponds to the JSON property requiredNavigationType

Returns:

  • (String)


12114
12115
12116
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12114

def required_navigation_type
  @required_navigation_type
end

#required_touchscreen_typeString

The type of touchscreen required. Corresponds to the JSON property requiredTouchscreenType

Returns:

  • (String)


12119
12120
12121
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12119

def required_touchscreen_type
  @required_touchscreen_type
end

#requires_five_way_navigationBoolean Also known as: requires_five_way_navigation?

Whether or not the application requires a five-way navigation control. Corresponds to the JSON property requiresFiveWayNavigation

Returns:

  • (Boolean)


12124
12125
12126
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12124

def requires_five_way_navigation
  @requires_five_way_navigation
end

#requires_hardware_keyboardBoolean Also known as: requires_hardware_keyboard?

Whether or not the application requires a hardware keyboard. Corresponds to the JSON property requiresHardwareKeyboard

Returns:

  • (Boolean)


12130
12131
12132
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12130

def requires_hardware_keyboard
  @requires_hardware_keyboard
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12138
12139
12140
12141
12142
12143
12144
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12138

def update!(**args)
  @required_keyboard_type = args[:required_keyboard_type] if args.key?(:required_keyboard_type)
  @required_navigation_type = args[:required_navigation_type] if args.key?(:required_navigation_type)
  @required_touchscreen_type = args[:required_touchscreen_type] if args.key?(:required_touchscreen_type)
  @requires_five_way_navigation = args[:requires_five_way_navigation] if args.key?(:requires_five_way_navigation)
  @requires_hardware_keyboard = args[:requires_hardware_keyboard] if args.key?(:requires_hardware_keyboard)
end