Class: Google::Apis::AndroidpublisherV3::Variant
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Variant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
APK that is suitable for inclusion in a system image. The resource of SystemApksService.
Instance Attribute Summary collapse
-
#device_spec ⇒ Google::Apis::AndroidpublisherV3::DeviceSpec
The device spec used to generate a system APK.
-
#options ⇒ Google::Apis::AndroidpublisherV3::SystemApkOptions
Options for system APKs.
-
#variant_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Variant
constructor
A new instance of Variant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Variant
Returns a new instance of Variant.
12211 12212 12213 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_spec ⇒ Google::Apis::AndroidpublisherV3::DeviceSpec
The device spec used to generate a system APK.
Corresponds to the JSON property deviceSpec
12199 12200 12201 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12199 def device_spec @device_spec end |
#options ⇒ Google::Apis::AndroidpublisherV3::SystemApkOptions
Options for system APKs.
Corresponds to the JSON property options
12204 12205 12206 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12204 def @options end |
#variant_id ⇒ Fixnum
Output only. The ID of a previously created system APK variant.
Corresponds to the JSON property variantId
12209 12210 12211 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12209 def variant_id @variant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12216 12217 12218 12219 12220 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12216 def update!(**args) @device_spec = args[:device_spec] if args.key?(:device_spec) @options = args[:options] if args.key?(:options) @variant_id = args[:variant_id] if args.key?(:variant_id) end |