Class: Google::Apis::AndroidpublisherV3::VoidedPurchase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A VoidedPurchase resource indicates a purchase that was either canceled/ refunded/charged-back.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VoidedPurchase

Returns a new instance of VoidedPurchase.



10739
10740
10741
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

This kind represents a voided purchase object in the androidpublisher service. Corresponds to the JSON property kind

Returns:

  • (String)


10692
10693
10694
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10692

def kind
  @kind
end

#order_idString

The order id which uniquely identifies a one-time purchase, subscription purchase, or subscription renewal. Corresponds to the JSON property orderId

Returns:

  • (String)


10698
10699
10700
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10698

def order_id
  @order_id
end

#purchase_time_millisFixnum

The time at which the purchase was made, in milliseconds since the epoch (Jan 1, 1970). Corresponds to the JSON property purchaseTimeMillis

Returns:

  • (Fixnum)


10704
10705
10706
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10704

def purchase_time_millis
  @purchase_time_millis
end

#purchase_tokenString

The token which uniquely identifies a one-time purchase or subscription. To uniquely identify subscription renewals use order_id (available starting from version 3 of the API). Corresponds to the JSON property purchaseToken

Returns:

  • (String)


10711
10712
10713
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10711

def purchase_token
  @purchase_token
end

#voided_quantityFixnum

The voided quantity as the result of a quantity-based partial refund. Voided purchases of quantity-based partial refunds may only be returned when includeQuantityBasedPartialRefund is set to true. Corresponds to the JSON property voidedQuantity

Returns:

  • (Fixnum)


10718
10719
10720
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10718

def voided_quantity
  @voided_quantity
end

#voided_reasonFixnum

The reason why the purchase was voided, possible values are: 0. Other 1. Remorse 2. Not_received 3. Defective 4. Accidental_purchase 5. Fraud 6. Friendly_fraud 7. Chargeback 8. Unacknowledged_purchase Corresponds to the JSON property voidedReason

Returns:

  • (Fixnum)


10725
10726
10727
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10725

def voided_reason
  @voided_reason
end

#voided_sourceFixnum

The initiator of voided purchase, possible values are: 0. User 1. Developer 2. Google Corresponds to the JSON property voidedSource

Returns:

  • (Fixnum)


10731
10732
10733
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10731

def voided_source
  @voided_source
end

#voided_time_millisFixnum

The time at which the purchase was canceled/refunded/charged-back, in milliseconds since the epoch (Jan 1, 1970). Corresponds to the JSON property voidedTimeMillis

Returns:

  • (Fixnum)


10737
10738
10739
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10737

def voided_time_millis
  @voided_time_millis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10744
10745
10746
10747
10748
10749
10750
10751
10752
10753
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10744

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @order_id = args[:order_id] if args.key?(:order_id)
  @purchase_time_millis = args[:purchase_time_millis] if args.key?(:purchase_time_millis)
  @purchase_token = args[:purchase_token] if args.key?(:purchase_token)
  @voided_quantity = args[:voided_quantity] if args.key?(:voided_quantity)
  @voided_reason = args[:voided_reason] if args.key?(:voided_reason)
  @voided_source = args[:voided_source] if args.key?(:voided_source)
  @voided_time_millis = args[:voided_time_millis] if args.key?(:voided_time_millis)
end