Class: Google::Apis::AndroidpublisherV3::AppStoreAppActiveApkSet
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::AppStoreAppActiveApkSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An installable set of active APKs. A set of APKs might only contain 1 APK if the app in question publishes using APKs. If the app uses app bundles (or a similar technology), this set should contain all APKs (even optional ones) that might be installed for this app. A set of APKs should be installable together. If certain APKs are exclusive to one another and cannot be installed together, then a separate AppStoreAppActiveApkSet should be created.
Instance Attribute Summary collapse
-
#base_apk_id ⇒ String
Required.
-
#split_apk_id ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppStoreAppActiveApkSet
constructor
A new instance of AppStoreAppActiveApkSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppStoreAppActiveApkSet
Returns a new instance of AppStoreAppActiveApkSet.
725 726 727 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_apk_id ⇒ String
Required. The ID for the main base application module. Example: base.apk or
app.apk.
Corresponds to the JSON property baseApkId
716 717 718 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 716 def base_apk_id @base_apk_id end |
#split_apk_id ⇒ Array<String>
Optional. IDs for split modules that might be installed in combination with
the base APK. Can be empty if app bundles (or a similar technology) are not
used. Example: config.en.apk.
Corresponds to the JSON property splitApkId
723 724 725 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 723 def split_apk_id @split_apk_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
730 731 732 733 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 730 def update!(**args) @base_apk_id = args[:base_apk_id] if args.key?(:base_apk_id) @split_apk_id = args[:split_apk_id] if args.key?(:split_apk_id) end |