Class: Google::Apis::AndroidpublisherV3::AutoRenewingPlan
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::AutoRenewingPlan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Information related to an auto renewing plan.
Instance Attribute Summary collapse
-
#auto_renew_enabled ⇒ Boolean
(also: #auto_renew_enabled?)
If the subscription is currently set to auto-renew, e.g.
-
#installment_details ⇒ Google::Apis::AndroidpublisherV3::InstallmentPlan
Information to a installment plan.
-
#price_change_details ⇒ Google::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails
Price change related information of a subscription item.
-
#price_step_up_consent_details ⇒ Google::Apis::AndroidpublisherV3::PriceStepUpConsentDetails
Information related to a price step-up that requires user consent.
-
#recurring_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoRenewingPlan
constructor
A new instance of AutoRenewingPlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoRenewingPlan
Returns a new instance of AutoRenewingPlan.
937 938 939 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renew_enabled ⇒ Boolean Also known as: auto_renew_enabled?
If the subscription is currently set to auto-renew, e.g. the user has not
canceled the subscription
Corresponds to the JSON property autoRenewEnabled
914 915 916 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 914 def auto_renew_enabled @auto_renew_enabled end |
#installment_details ⇒ Google::Apis::AndroidpublisherV3::InstallmentPlan
Information to a installment plan.
Corresponds to the JSON property installmentDetails
920 921 922 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 920 def installment_details @installment_details end |
#price_change_details ⇒ Google::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails
Price change related information of a subscription item.
Corresponds to the JSON property priceChangeDetails
925 926 927 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 925 def price_change_details @price_change_details end |
#price_step_up_consent_details ⇒ Google::Apis::AndroidpublisherV3::PriceStepUpConsentDetails
Information related to a price step-up that requires user consent.
Corresponds to the JSON property priceStepUpConsentDetails
930 931 932 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 930 def @price_step_up_consent_details end |
#recurring_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property recurringPrice
935 936 937 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 935 def recurring_price @recurring_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
942 943 944 945 946 947 948 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 942 def update!(**args) @auto_renew_enabled = args[:auto_renew_enabled] if args.key?(:auto_renew_enabled) @installment_details = args[:installment_details] if args.key?(:installment_details) @price_change_details = args[:price_change_details] if args.key?(:price_change_details) @price_step_up_consent_details = args[:price_step_up_consent_details] if args.key?(:price_step_up_consent_details) @recurring_price = args[:recurring_price] if args.key?(:recurring_price) end |