Class: Google::Apis::AndroidpublisherV3::AutoRenewingPlan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information related to an auto renewing plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoRenewingPlan

Returns a new instance of AutoRenewingPlan.



918
919
920
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renew_enabledBoolean Also known as: auto_renew_enabled?

If the subscription is currently set to auto-renew, e.g. the user has not canceled the subscription Corresponds to the JSON property autoRenewEnabled

Returns:

  • (Boolean)


895
896
897
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 895

def auto_renew_enabled
  @auto_renew_enabled
end

#installment_detailsGoogle::Apis::AndroidpublisherV3::InstallmentPlan

Information to a installment plan. Corresponds to the JSON property installmentDetails



901
902
903
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 901

def installment_details
  @installment_details
end

#price_change_detailsGoogle::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails

Price change related information of a subscription item. Corresponds to the JSON property priceChangeDetails



906
907
908
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 906

def price_change_details
  @price_change_details
end

Information related to a price step-up that requires user consent. Corresponds to the JSON property priceStepUpConsentDetails



911
912
913
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 911

def price_step_up_consent_details
  @price_step_up_consent_details
end

#recurring_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property recurringPrice



916
917
918
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 916

def recurring_price
  @recurring_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



923
924
925
926
927
928
929
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 923

def update!(**args)
  @auto_renew_enabled = args[:auto_renew_enabled] if args.key?(:auto_renew_enabled)
  @installment_details = args[:installment_details] if args.key?(:installment_details)
  @price_change_details = args[:price_change_details] if args.key?(:price_change_details)
  @price_step_up_consent_details = args[:price_step_up_consent_details] if args.key?(:price_step_up_consent_details)
  @recurring_price = args[:recurring_price] if args.key?(:recurring_price)
end