Class: Google::Apis::AndroidpublisherV3::BasePlan
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BasePlan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single base plan for a subscription.
Instance Attribute Summary collapse
-
#auto_renewing_base_plan_type ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingBasePlanType
Represents a base plan that automatically renews at the end of its subscription period.
-
#base_plan_id ⇒ String
Required.
-
#installments_base_plan_type ⇒ Google::Apis::AndroidpublisherV3::InstallmentsBasePlanType
Represents an installments base plan where a user commits to a specified number of payments.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
List of up to 20 custom tags specified for this base plan, and returned to the app through the billing library.
-
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsBasePlanConfig
Pricing information for any new locations Play may launch in.
-
#prepaid_base_plan_type ⇒ Google::Apis::AndroidpublisherV3::PrepaidBasePlanType
Represents a base plan that does not automatically renew at the end of the base plan, and must be manually renewed by the user.
-
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig>
Region-specific information for this base plan.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasePlan
constructor
A new instance of BasePlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BasePlan
Returns a new instance of BasePlan.
1000 1001 1002 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renewing_base_plan_type ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingBasePlanType
Represents a base plan that automatically renews at the end of its
subscription period.
Corresponds to the JSON property autoRenewingBasePlanType
953 954 955 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 953 def auto_renewing_base_plan_type @auto_renewing_base_plan_type end |
#base_plan_id ⇒ String
Required. Immutable. The unique identifier of this base plan. Must be unique
within the subscription, and conform with RFC-1034. That is, this ID can only
contain lower-case letters (a-z), numbers (0-9), and hyphens (-), and be at
most 63 characters.
Corresponds to the JSON property basePlanId
961 962 963 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 961 def base_plan_id @base_plan_id end |
#installments_base_plan_type ⇒ Google::Apis::AndroidpublisherV3::InstallmentsBasePlanType
Represents an installments base plan where a user commits to a specified
number of payments.
Corresponds to the JSON property installmentsBasePlanType
967 968 969 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 967 def installments_base_plan_type @installments_base_plan_type end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
List of up to 20 custom tags specified for this base plan, and returned to the
app through the billing library. Subscription offers for this base plan will
also receive these offer tags in the billing library.
Corresponds to the JSON property offerTags
974 975 976 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 974 def @offer_tags end |
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsBasePlanConfig
Pricing information for any new locations Play may launch in.
Corresponds to the JSON property otherRegionsConfig
979 980 981 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 979 def other_regions_config @other_regions_config end |
#prepaid_base_plan_type ⇒ Google::Apis::AndroidpublisherV3::PrepaidBasePlanType
Represents a base plan that does not automatically renew at the end of the
base plan, and must be manually renewed by the user.
Corresponds to the JSON property prepaidBasePlanType
985 986 987 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 985 def prepaid_base_plan_type @prepaid_base_plan_type end |
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig>
Region-specific information for this base plan.
Corresponds to the JSON property regionalConfigs
990 991 992 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 990 def regional_configs @regional_configs end |
#state ⇒ String
Output only. The state of the base plan, i.e. whether it's active. Draft and
inactive base plans can be activated or deleted. Active base plans can be made
inactive. Inactive base plans can be canceled. This field cannot be changed by
updating the resource. Use the dedicated endpoints instead.
Corresponds to the JSON property state
998 999 1000 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 998 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1005 def update!(**args) @auto_renewing_base_plan_type = args[:auto_renewing_base_plan_type] if args.key?(:auto_renewing_base_plan_type) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @installments_base_plan_type = args[:installments_base_plan_type] if args.key?(:installments_base_plan_type) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config) @prepaid_base_plan_type = args[:prepaid_base_plan_type] if args.key?(:prepaid_base_plan_type) @regional_configs = args[:regional_configs] if args.key?(:regional_configs) @state = args[:state] if args.key?(:state) end |