Class: Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductOfferStatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BatchUpdateOneTimeProductOfferStatesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response message for BatchUpdateOneTimeProductOfferStates.
Instance Attribute Summary collapse
-
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The updated one-time product offers list, in the same order as the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateOneTimeProductOfferStatesResponse
constructor
A new instance of BatchUpdateOneTimeProductOfferStatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateOneTimeProductOfferStatesResponse
Returns a new instance of BatchUpdateOneTimeProductOfferStatesResponse.
1334 1335 1336 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#one_time_product_offers ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOffer>
The updated one-time product offers list, in the same order as the request.
Corresponds to the JSON property oneTimeProductOffers
1332 1333 1334 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1332 def one_time_product_offers @one_time_product_offers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1339 1340 1341 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1339 def update!(**args) @one_time_product_offers = args[:one_time_product_offers] if args.key?(:one_time_product_offers) end |