Class: Google::Apis::AndroidpublisherV3::BuyerAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Address information for the customer, for use in tax computation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuyerAddress

Returns a new instance of BuyerAddress.



1844
1845
1846
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buyer_countryString

Two letter country code based on ISO-3166-1 Alpha-2 (UN country codes). Corresponds to the JSON property buyerCountry

Returns:

  • (String)


1830
1831
1832
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1830

def buyer_country
  @buyer_country
end

#buyer_postcodeString

Postal code of an address. When Google is the Merchant of Record for the order, this information is not included. Corresponds to the JSON property buyerPostcode

Returns:

  • (String)


1836
1837
1838
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1836

def buyer_postcode
  @buyer_postcode
end

#buyer_stateString

Top-level administrative subdivision of the buyer address country. When Google is the Merchant of Record for the order, this information is not included. Corresponds to the JSON property buyerState

Returns:

  • (String)


1842
1843
1844
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1842

def buyer_state
  @buyer_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1849
1850
1851
1852
1853
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1849

def update!(**args)
  @buyer_country = args[:buyer_country] if args.key?(:buyer_country)
  @buyer_postcode = args[:buyer_postcode] if args.key?(:buyer_postcode)
  @buyer_state = args[:buyer_state] if args.key?(:buyer_state)
end