Class: Google::Apis::AndroidpublisherV3::BuyerAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Address information for the customer, for use in tax computation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuyerAddress

Returns a new instance of BuyerAddress.



1678
1679
1680
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buyer_countryString

Two letter country code based on ISO-3166-1 Alpha-2 (UN country codes). Corresponds to the JSON property buyerCountry

Returns:

  • (String)


1664
1665
1666
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1664

def buyer_country
  @buyer_country
end

#buyer_postcodeString

Postal code of an address. When Google is the Merchant of Record for the order, this information is not included. Corresponds to the JSON property buyerPostcode

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1670

def buyer_postcode
  @buyer_postcode
end

#buyer_stateString

Top-level administrative subdivision of the buyer address country. When Google is the Merchant of Record for the order, this information is not included. Corresponds to the JSON property buyerState

Returns:

  • (String)


1676
1677
1678
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1676

def buyer_state
  @buyer_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1683
1684
1685
1686
1687
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1683

def update!(**args)
  @buyer_country = args[:buyer_country] if args.key?(:buyer_country)
  @buyer_postcode = args[:buyer_postcode] if args.key?(:buyer_postcode)
  @buyer_state = args[:buyer_state] if args.key?(:buyer_state)
end