Class: Google::Apis::AndroidpublisherV3::BuyerAddress
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::BuyerAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Address information for the customer, for use in tax computation.
Instance Attribute Summary collapse
-
#buyer_country ⇒ String
Two letter country code based on ISO-3166-1 Alpha-2 (UN country codes).
-
#buyer_postcode ⇒ String
Postal code of an address.
-
#buyer_state ⇒ String
Top-level administrative subdivision of the buyer address country.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuyerAddress
constructor
A new instance of BuyerAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuyerAddress
Returns a new instance of BuyerAddress.
1659 1660 1661 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buyer_country ⇒ String
Two letter country code based on ISO-3166-1 Alpha-2 (UN country codes).
Corresponds to the JSON property buyerCountry
1645 1646 1647 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1645 def buyer_country @buyer_country end |
#buyer_postcode ⇒ String
Postal code of an address. When Google is the Merchant of Record for the order,
this information is not included.
Corresponds to the JSON property buyerPostcode
1651 1652 1653 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1651 def buyer_postcode @buyer_postcode end |
#buyer_state ⇒ String
Top-level administrative subdivision of the buyer address country. When Google
is the Merchant of Record for the order, this information is not included.
Corresponds to the JSON property buyerState
1657 1658 1659 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1657 def buyer_state @buyer_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1664 1665 1666 1667 1668 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1664 def update!(**args) @buyer_country = args[:buyer_country] if args.key?(:buyer_country) @buyer_postcode = args[:buyer_postcode] if args.key?(:buyer_postcode) @buyer_state = args[:buyer_state] if args.key?(:buyer_state) end |