Class: Google::Apis::AndroidpublisherV3::CancelSurveyResult
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::CancelSurveyResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Result of the cancel survey when the subscription was canceled by the user.
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason the user selected in the cancel survey.
-
#reason_user_input ⇒ String
Only set for CANCEL_SURVEY_REASON_OTHERS.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CancelSurveyResult
constructor
A new instance of CancelSurveyResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CancelSurveyResult
Returns a new instance of CancelSurveyResult.
1807 1808 1809 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
The reason the user selected in the cancel survey.
Corresponds to the JSON property reason
1799 1800 1801 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1799 def reason @reason end |
#reason_user_input ⇒ String
Only set for CANCEL_SURVEY_REASON_OTHERS. This is the user's freeform response
to the survey.
Corresponds to the JSON property reasonUserInput
1805 1806 1807 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1805 def reason_user_input @reason_user_input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1812 1813 1814 1815 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1812 def update!(**args) @reason = args[:reason] if args.key?(:reason) @reason_user_input = args[:reason_user_input] if args.key?(:reason_user_input) end |