Class: Google::Apis::AndroidpublisherV3::CancelSurveyResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Result of the cancel survey when the subscription was canceled by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CancelSurveyResult

Returns a new instance of CancelSurveyResult.



1788
1789
1790
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

The reason the user selected in the cancel survey. Corresponds to the JSON property reason

Returns:

  • (String)


1780
1781
1782
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1780

def reason
  @reason
end

#reason_user_inputString

Only set for CANCEL_SURVEY_REASON_OTHERS. This is the user's freeform response to the survey. Corresponds to the JSON property reasonUserInput

Returns:

  • (String)


1786
1787
1788
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1786

def reason_user_input
  @reason_user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1793
1794
1795
1796
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 1793

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
  @reason_user_input = args[:reason_user_input] if args.key?(:reason_user_input)
end