Class: Google::Apis::AndroidpublisherV3::CatalogDeviceSelector
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::CatalogDeviceSelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Defines a device selector for a device. A device is considered matched if it matches any of given the selectors.
Instance Attribute Summary collapse
-
#device_type_selector ⇒ String
The device type selector.
-
#ram_selector ⇒ Google::Apis::AndroidpublisherV3::RamSelector
Defines a RAM selector for a device.
-
#soc_selectors ⇒ Array<Google::Apis::AndroidpublisherV3::SocSelector>
The SOC selectors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CatalogDeviceSelector
constructor
A new instance of CatalogDeviceSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CatalogDeviceSelector
Returns a new instance of CatalogDeviceSelector.
2279 2280 2281 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_type_selector ⇒ String
The device type selector.
Corresponds to the JSON property deviceTypeSelector
2266 2267 2268 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2266 def device_type_selector @device_type_selector end |
#ram_selector ⇒ Google::Apis::AndroidpublisherV3::RamSelector
Defines a RAM selector for a device.
Corresponds to the JSON property ramSelector
2271 2272 2273 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2271 def ram_selector @ram_selector end |
#soc_selectors ⇒ Array<Google::Apis::AndroidpublisherV3::SocSelector>
The SOC selectors. A device matches the device selector if it matches any of
the SOC selectors.
Corresponds to the JSON property socSelectors
2277 2278 2279 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2277 def soc_selectors @soc_selectors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2284 2285 2286 2287 2288 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2284 def update!(**args) @device_type_selector = args[:device_type_selector] if args.key?(:device_type_selector) @ram_selector = args[:ram_selector] if args.key?(:ram_selector) @soc_selectors = args[:soc_selectors] if args.key?(:soc_selectors) end |