Class: Google::Apis::AndroidpublisherV3::CloudKmsKey
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::CloudKmsKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Reference to a private key hosted in developer-managed Google Cloud KMS.
Instance Attribute Summary collapse
-
#crypto_key_version_resource ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudKmsKey
constructor
A new instance of CloudKmsKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudKmsKey
Returns a new instance of CloudKmsKey.
2395 2396 2397 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crypto_key_version_resource ⇒ String
Required. Resource identifier of the private key hosted in Google Cloud KMS.
The Google Play service account must be granted Decrypt and Sign permissions
on this resource. Format: projects//locations//keyRings//cryptoKeys//
cryptoKeyVersions/
Corresponds to the JSON property cryptoKeyVersionResource
2393 2394 2395 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2393 def crypto_key_version_resource @crypto_key_version_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2400 2401 2402 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2400 def update!(**args) @crypto_key_version_resource = args[:crypto_key_version_resource] if args.key?(:crypto_key_version_resource) end |