Class: Google::Apis::AndroidpublisherV3::CoarseLocation
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::CoarseLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Coarse Geographic location details for where the consumption happened.
Instance Attribute Summary collapse
-
#administrative_area ⇒ String
Optional.
-
#locality ⇒ String
Optional.
-
#region_code ⇒ String
Required.
-
#sublocality ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CoarseLocation
constructor
A new instance of CoarseLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CoarseLocation
Returns a new instance of CoarseLocation.
2384 2385 2386 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#administrative_area ⇒ String
Optional. Highest administrative subdivision which is used for postal
addresses of a country or region. For example, this can be a state, a province,
an oblast, or a prefecture. For Spain, this is the province and not the
autonomous community (for example, "Barcelona" and not "Catalonia"). Many
countries don't use an administrative area in postal addresses. For example,
in Switzerland, this should be left unpopulated.
Corresponds to the JSON property administrativeArea
2361 2362 2363 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2361 def administrative_area @administrative_area end |
#locality ⇒ String
Optional. Generally refers to the city or town portion of the address.
Examples: US city, IT comune, UK post town. In regions of the world where
localities are not well defined or do not fit into this structure well, leave
locality empty.
Corresponds to the JSON property locality
2369 2370 2371 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2369 def locality @locality end |
#region_code ⇒ String
Required. CLDR region code of the country/region
of the address. This value is never inferred and you must ensure the value is
correct. Example: "CH" for Switzerland.
Corresponds to the JSON property regionCode
2376 2377 2378 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2376 def region_code @region_code end |
#sublocality ⇒ String
Optional. Sublocality of the address. For example, this can be a neighborhood,
borough, or district. For most addresses, you can omit this.
Corresponds to the JSON property sublocality
2382 2383 2384 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2382 def sublocality @sublocality end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2389 2390 2391 2392 2393 2394 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2389 def update!(**args) @administrative_area = args[:administrative_area] if args.key?(:administrative_area) @locality = args[:locality] if args.key?(:locality) @region_code = args[:region_code] if args.key?(:region_code) @sublocality = args[:sublocality] if args.key?(:sublocality) end |