Class: Google::Apis::AndroidpublisherV3::CoarseLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Coarse Geographic location details for where the consumption happened.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CoarseLocation

Returns a new instance of CoarseLocation.



2095
2096
2097
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#administrative_areaString

Optional. Highest administrative subdivision which is used for postal addresses of a country or region. For example, this can be a state, a province, an oblast, or a prefecture. For Spain, this is the province and not the autonomous community (for example, "Barcelona" and not "Catalonia"). Many countries don't use an administrative area in postal addresses. For example, in Switzerland, this should be left unpopulated. Corresponds to the JSON property administrativeArea

Returns:

  • (String)


2072
2073
2074
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2072

def administrative_area
  @administrative_area
end

#localityString

Optional. Generally refers to the city or town portion of the address. Examples: US city, IT comune, UK post town. In regions of the world where localities are not well defined or do not fit into this structure well, leave locality empty. Corresponds to the JSON property locality

Returns:

  • (String)


2080
2081
2082
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2080

def locality
  @locality
end

#region_codeString

Required. CLDR region code of the country/region of the address. This value is never inferred and you must ensure the value is correct. Example: "CH" for Switzerland. Corresponds to the JSON property regionCode

Returns:

  • (String)


2087
2088
2089
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2087

def region_code
  @region_code
end

#sublocalityString

Optional. Sublocality of the address. For example, this can be a neighborhood, borough, or district. For most addresses, you can omit this. Corresponds to the JSON property sublocality

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2093

def sublocality
  @sublocality
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2100
2101
2102
2103
2104
2105
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2100

def update!(**args)
  @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
  @locality = args[:locality] if args.key?(:locality)
  @region_code = args[:region_code] if args.key?(:region_code)
  @sublocality = args[:sublocality] if args.key?(:sublocality)
end