Class: Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

List of events, each representing an instance where the user consumed or used the purchased item or service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumptionUsageEvent

Returns a new instance of ConsumptionUsageEvent.



2490
2491
2492
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumption_item_descriptionString

Optional. Free form text that allows developers to provide more info on the item consumed. Maximum length is 5000 characters. Corresponds to the JSON property consumptionItemDescription

Returns:

  • (String)


2456
2457
2458
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2456

def consumption_item_description
  @consumption_item_description
end

#consumption_timeString

Optional. Time when the user consumed, used, downloaded, opened, or streamed the content. Corresponds to the JSON property consumptionTime

Returns:

  • (String)


2462
2463
2464
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2462

def consumption_time
  @consumption_time
end

#ip_addressString

Optional. The IP address from which the consumption occurred. Corresponds to the JSON property ipAddress

Returns:

  • (String)


2467
2468
2469
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2467

def ip_address
  @ip_address
end

#locationGoogle::Apis::AndroidpublisherV3::CoarseLocation

Coarse Geographic location details for where the consumption happened. Corresponds to the JSON property location



2472
2473
2474
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2472

def location
  @location
end

#obfuscated_account_idString

Optional. Obfuscated string that is uniquely associated with the purchaser's user account in the app. https://developer.android.com/reference/com/android/ billingclient/api/BillingFlowParams.Builder#setObfuscatedAccountId(java.lang. String) Corresponds to the JSON property obfuscatedAccountId

Returns:

  • (String)


2480
2481
2482
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2480

def 
  @obfuscated_account_id
end

#obfuscated_profile_idString

Optional. Obfuscated string that is uniquely associated with the purchaser's user profile in the app. https://developer.android.com/reference/com/android/ billingclient/api/BillingFlowParams.Builder#setObfuscatedProfileId(java.lang. String) Corresponds to the JSON property obfuscatedProfileId

Returns:

  • (String)


2488
2489
2490
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2488

def obfuscated_profile_id
  @obfuscated_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2495
2496
2497
2498
2499
2500
2501
2502
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2495

def update!(**args)
  @consumption_item_description = args[:consumption_item_description] if args.key?(:consumption_item_description)
  @consumption_time = args[:consumption_time] if args.key?(:consumption_time)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @location = args[:location] if args.key?(:location)
  @obfuscated_account_id = args[:obfuscated_account_id] if args.key?(:obfuscated_account_id)
  @obfuscated_profile_id = args[:obfuscated_profile_id] if args.key?(:obfuscated_profile_id)
end