Class: Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
List of events, each representing an instance where the user consumed or used the purchased item or service.
Instance Attribute Summary collapse
-
#consumption_item_description ⇒ String
Optional.
-
#consumption_time ⇒ String
Optional.
-
#ip_address ⇒ String
Optional.
-
#location ⇒ Google::Apis::AndroidpublisherV3::CoarseLocation
Coarse Geographic location details for where the consumption happened.
-
#obfuscated_account_id ⇒ String
Optional.
-
#obfuscated_profile_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumptionUsageEvent
constructor
A new instance of ConsumptionUsageEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumptionUsageEvent
Returns a new instance of ConsumptionUsageEvent.
2176 2177 2178 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumption_item_description ⇒ String
Optional. Free form text that allows developers to provide more info on the
item consumed. Maximum length is 5000 characters.
Corresponds to the JSON property consumptionItemDescription
2142 2143 2144 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2142 def consumption_item_description @consumption_item_description end |
#consumption_time ⇒ String
Optional. Time when the user consumed, used, downloaded, opened, or streamed
the content.
Corresponds to the JSON property consumptionTime
2148 2149 2150 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2148 def consumption_time @consumption_time end |
#ip_address ⇒ String
Optional. The IP address from which the consumption occurred.
Corresponds to the JSON property ipAddress
2153 2154 2155 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2153 def ip_address @ip_address end |
#location ⇒ Google::Apis::AndroidpublisherV3::CoarseLocation
Coarse Geographic location details for where the consumption happened.
Corresponds to the JSON property location
2158 2159 2160 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2158 def location @location end |
#obfuscated_account_id ⇒ String
Optional. Obfuscated string that is uniquely associated with the purchaser's
user account in the app. https://developer.android.com/reference/com/android/
billingclient/api/BillingFlowParams.Builder#setObfuscatedAccountId(java.lang.
String)
Corresponds to the JSON property obfuscatedAccountId
2166 2167 2168 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2166 def @obfuscated_account_id end |
#obfuscated_profile_id ⇒ String
Optional. Obfuscated string that is uniquely associated with the purchaser's
user profile in the app. https://developer.android.com/reference/com/android/
billingclient/api/BillingFlowParams.Builder#setObfuscatedProfileId(java.lang.
String)
Corresponds to the JSON property obfuscatedProfileId
2174 2175 2176 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2174 def @obfuscated_profile_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2181 2182 2183 2184 2185 2186 2187 2188 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2181 def update!(**args) @consumption_item_description = args[:consumption_item_description] if args.key?(:consumption_item_description) @consumption_time = args[:consumption_time] if args.key?(:consumption_time) @ip_address = args[:ip_address] if args.key?(:ip_address) @location = args[:location] if args.key?(:location) @obfuscated_account_id = args[:obfuscated_account_id] if args.key?(:obfuscated_account_id) @obfuscated_profile_id = args[:obfuscated_profile_id] if args.key?(:obfuscated_profile_id) end |