Class: Google::Apis::AndroidpublisherV3::ConvertRegionPricesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ConvertRegionPricesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for ConvertRegionPrices.
Instance Attribute Summary collapse
-
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#product_tax_category_code ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConvertRegionPricesRequest
constructor
A new instance of ConvertRegionPricesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConvertRegionPricesRequest
Returns a new instance of ConvertRegionPricesRequest.
2524 2525 2526 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property price
2512 2513 2514 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2512 def price @price end |
#product_tax_category_code ⇒ String
Optional. Product tax category code in context. Product tax category
determines the transaction tax rates applied to the product that will be
factored into the price calculation. If not set, tax rates for the default
product tax category will be used. Refer to the Help Center article for more
information.
Corresponds to the JSON property productTaxCategoryCode
2522 2523 2524 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2522 def product_tax_category_code @product_tax_category_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2529 2530 2531 2532 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2529 def update!(**args) @price = args[:price] if args.key?(:price) @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code) end |