Class: Google::Apis::AndroidpublisherV3::ConvertRegionPricesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for ConvertRegionPrices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConvertRegionPricesRequest

Returns a new instance of ConvertRegionPricesRequest.



2210
2211
2212
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property price



2198
2199
2200
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2198

def price
  @price
end

#product_tax_category_codeString

Optional. Product tax category code in context. Product tax category determines the transaction tax rates applied to the product that will be factored into the price calculation. If not set, tax rates for the default product tax category will be used. Refer to the Help Center article for more information. Corresponds to the JSON property productTaxCategoryCode

Returns:

  • (String)


2208
2209
2210
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2208

def product_tax_category_code
  @product_tax_category_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2215
2216
2217
2218
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2215

def update!(**args)
  @price = args[:price] if args.key?(:price)
  @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code)
end