Class: Google::Apis::AndroidpublisherV3::DeferralContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Deferral context of the purchases.subscriptionsv2.defer API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeferralContext

Returns a new instance of DeferralContext.



2297
2298
2299
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#defer_durationString

Required. The duration by which all subscription items should be deferred. Corresponds to the JSON property deferDuration

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2280

def defer_duration
  @defer_duration
end

#etagString

Required. The API will fail if the etag does not match the latest etag for this subscription. The etag is retrieved from purchases.subscriptionsv2.get: https://developers.google.com/android-publisher/api-ref/rest/v3/purchases. subscriptionsv2/get Corresponds to the JSON property etag

Returns:

  • (String)


2288
2289
2290
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2288

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

If set to "true", the request is a dry run to validate the effect of Defer, the subscription would not be impacted. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2294
2295
2296
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2294

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2302
2303
2304
2305
2306
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2302

def update!(**args)
  @defer_duration = args[:defer_duration] if args.key?(:defer_duration)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end