Class: Google::Apis::AndroidpublisherV3::DeletePurchaseOptionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for deleting a purchase option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeletePurchaseOptionRequest

Returns a new instance of DeletePurchaseOptionRequest.



2470
2471
2472
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. This field has no effect for purchase options with no offers under them. For purchase options with associated offers: * If force is set to false (default), an error will be returned. * If force is set to true, any associated offers under the purchase option will be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


2446
2447
2448
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2446

def force
  @force
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


2453
2454
2455
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2453

def latency_tolerance
  @latency_tolerance
end

#package_nameString

Required. The parent app (package name) of the purchase option to delete. Corresponds to the JSON property packageName

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2458

def package_name
  @package_name
end

#product_idString

Required. The parent one-time product (ID) of the purchase option to delete. Corresponds to the JSON property productId

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2463

def product_id
  @product_id
end

#purchase_option_idString

Required. The purchase option ID of the purchase option to delete. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


2468
2469
2470
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2468

def purchase_option_id
  @purchase_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2475
2476
2477
2478
2479
2480
2481
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2475

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @package_name = args[:package_name] if args.key?(:package_name)
  @product_id = args[:product_id] if args.key?(:product_id)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
end