Class: Google::Apis::AndroidpublisherV3::DeveloperComment
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::DeveloperComment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Developer entry from conversation between user and developer.
Instance Attribute Summary collapse
-
#last_modified ⇒ Google::Apis::AndroidpublisherV3::Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#text ⇒ String
The content of the comment, i.e.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeveloperComment
constructor
A new instance of DeveloperComment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeveloperComment
Returns a new instance of DeveloperComment.
3307 3308 3309 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_modified ⇒ Google::Apis::AndroidpublisherV3::Timestamp
A Timestamp represents a point in time independent of any time zone or local
calendar, encoded as a count of seconds and fractions of seconds at nanosecond
resolution. The count is relative to an epoch at UTC midnight on January 1,
1970.
Corresponds to the JSON property lastModified
3300 3301 3302 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3300 def last_modified @last_modified end |
#text ⇒ String
The content of the comment, i.e. reply body.
Corresponds to the JSON property text
3305 3306 3307 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3305 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3312 3313 3314 3315 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3312 def update!(**args) @last_modified = args[:last_modified] if args.key?(:last_modified) @text = args[:text] if args.key?(:text) end |