Class: Google::Apis::AndroidpublisherV3::DeveloperComment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Developer entry from conversation between user and developer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperComment

Returns a new instance of DeveloperComment.



2910
2911
2912
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_modifiedGoogle::Apis::AndroidpublisherV3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970. Corresponds to the JSON property lastModified



2903
2904
2905
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2903

def last_modified
  @last_modified
end

#textString

The content of the comment, i.e. reply body. Corresponds to the JSON property text

Returns:

  • (String)


2908
2909
2910
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2908

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2915
2916
2917
2918
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2915

def update!(**args)
  @last_modified = args[:last_modified] if args.key?(:last_modified)
  @text = args[:text] if args.key?(:text)
end