Class: Google::Apis::AndroidpublisherV3::DeviceCompatibilityRequirements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Defines a set of device compatibility requirements for the app. A device must satisfy all of the requirements in a set to be considered compatible with the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceCompatibilityRequirements

Returns a new instance of DeviceCompatibilityRequirements.



3363
3364
3365
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compatible_screensArray<Google::Apis::AndroidpublisherV3::CompatibleScreen>

Compatible screens as listed in the compatible-screens Manifest tag. Corresponds to the JSON property compatibleScreens



3300
3301
3302
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3300

def compatible_screens
  @compatible_screens
end

#gl_es_versionFixnum

Required version of OpenGL ES. Corresponds to the JSON property glEsVersion

Returns:

  • (Fixnum)


3305
3306
3307
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3305

def gl_es_version
  @gl_es_version
end

#is_screen_requiredBoolean Also known as: is_screen_required?

Specifies if the app requires a screen. Corresponds to the JSON property isScreenRequired

Returns:

  • (Boolean)


3310
3311
3312
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3310

def is_screen_required
  @is_screen_required
end

#native_platformsArray<String>

List of required ABIs (Application Binary Interface), e.g. armeabi or x86. Corresponds to the JSON property nativePlatforms

Returns:

  • (Array<String>)


3316
3317
3318
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3316

def native_platforms
  @native_platforms
end

#required_software_librariesArray<String>

List of required libraries as declared in the uses-library manifest tag. Corresponds to the JSON property requiredSoftwareLibraries

Returns:

  • (Array<String>)


3321
3322
3323
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3321

def required_software_libraries
  @required_software_libraries
end

#required_system_featuresArray<String>

The system features that the app requires. A device must have all of the system features to be considered compatible with the app. Corresponds to the JSON property requiredSystemFeatures

Returns:

  • (Array<String>)


3327
3328
3329
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3327

def required_system_features
  @required_system_features
end

#requires_smallest_width_dpFixnum

Specifies the minimum smallest width required of the screen. Corresponds to the JSON property requiresSmallestWidthDp

Returns:

  • (Fixnum)


3332
3333
3334
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3332

def requires_smallest_width_dp
  @requires_smallest_width_dp
end

#sdk_versionGoogle::Apis::AndroidpublisherV3::CatalogSdkVersion

Defines a range of SDK versions. A device is considered compatible uf its\ SDK version falls within the min_sdk_version and max_sdk_version range. Corresponds to the JSON property sdkVersion



3338
3339
3340
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3338

def sdk_version
  @sdk_version
end

#supported_gl_texturesArray<String>

Supported gl textures as specified by the supported-gl-texture Manifest tag. Corresponds to the JSON property supportedGlTextures

Returns:

  • (Array<String>)


3343
3344
3345
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3343

def supported_gl_textures
  @supported_gl_textures
end

#supported_screensArray<String>

Compatible screens as listed in the supports-screens Manifest tag. Corresponds to the JSON property supportedScreens

Returns:

  • (Array<String>)


3348
3349
3350
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3348

def supported_screens
  @supported_screens
end

#use32_bit_abiString

Value of android:use32BitAbi flag retrieved from the Manifest. Corresponds to the JSON property use32BitAbi

Returns:

  • (String)


3353
3354
3355
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3353

def use32_bit_abi
  @use32_bit_abi
end

#uses_configurationsArray<Google::Apis::AndroidpublisherV3::UsesConfiguration>

Lists all configurations marked as required by use of the uses-configuration manifest tag. Each instance of this proto represents a single uses- configuration entry. See http://developer.android.com/guide/topics/manifest/ uses-configuration-element.html Corresponds to the JSON property usesConfigurations



3361
3362
3363
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3361

def uses_configurations
  @uses_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3368

def update!(**args)
  @compatible_screens = args[:compatible_screens] if args.key?(:compatible_screens)
  @gl_es_version = args[:gl_es_version] if args.key?(:gl_es_version)
  @is_screen_required = args[:is_screen_required] if args.key?(:is_screen_required)
  @native_platforms = args[:native_platforms] if args.key?(:native_platforms)
  @required_software_libraries = args[:required_software_libraries] if args.key?(:required_software_libraries)
  @required_system_features = args[:required_system_features] if args.key?(:required_system_features)
  @requires_smallest_width_dp = args[:requires_smallest_width_dp] if args.key?(:requires_smallest_width_dp)
  @sdk_version = args[:sdk_version] if args.key?(:sdk_version)
  @supported_gl_textures = args[:supported_gl_textures] if args.key?(:supported_gl_textures)
  @supported_screens = args[:supported_screens] if args.key?(:supported_screens)
  @use32_bit_abi = args[:use32_bit_abi] if args.key?(:use32_bit_abi)
  @uses_configurations = args[:uses_configurations] if args.key?(:uses_configurations)
end