Class: Google::Apis::AndroidpublisherV3::DeviceGroup
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::DeviceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A group of devices. A group is defined by a set of device selectors. A device belongs to the group if it matches any selector (logical OR).
Instance Attribute Summary collapse
-
#device_selectors ⇒ Array<Google::Apis::AndroidpublisherV3::DeviceSelector>
Device selectors for this group.
-
#name ⇒ String
The name of the group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceGroup
constructor
A new instance of DeviceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceGroup
Returns a new instance of DeviceGroup.
2650 2651 2652 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_selectors ⇒ Array<Google::Apis::AndroidpublisherV3::DeviceSelector>
Device selectors for this group. A device matching any of the selectors is
included in this group.
Corresponds to the JSON property deviceSelectors
2643 2644 2645 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2643 def device_selectors @device_selectors end |
#name ⇒ String
The name of the group.
Corresponds to the JSON property name
2648 2649 2650 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2648 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2655 2656 2657 2658 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2655 def update!(**args) @device_selectors = args[:device_selectors] if args.key?(:device_selectors) @name = args[:name] if args.key?(:name) end |