Class: Google::Apis::AndroidpublisherV3::DeviceTierConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::DeviceTierConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration describing device targeting criteria for the content of an app.
Instance Attribute Summary collapse
-
#device_groups ⇒ Array<Google::Apis::AndroidpublisherV3::DeviceGroup>
Definition of device groups for the app.
-
#device_tier_config_id ⇒ Fixnum
Output only.
-
#device_tier_set ⇒ Google::Apis::AndroidpublisherV3::DeviceTierSet
A set of device tiers.
-
#user_country_sets ⇒ Array<Google::Apis::AndroidpublisherV3::UserCountrySet>
Definition of user country sets for the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceTierConfig
constructor
A new instance of DeviceTierConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceTierConfig
Returns a new instance of DeviceTierConfig.
3288 3289 3290 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_groups ⇒ Array<Google::Apis::AndroidpublisherV3::DeviceGroup>
Definition of device groups for the app.
Corresponds to the JSON property deviceGroups
3267 3268 3269 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3267 def device_groups @device_groups end |
#device_tier_config_id ⇒ Fixnum
Output only. The device tier config ID.
Corresponds to the JSON property deviceTierConfigId
3272 3273 3274 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3272 def device_tier_config_id @device_tier_config_id end |
#device_tier_set ⇒ Google::Apis::AndroidpublisherV3::DeviceTierSet
A set of device tiers. A tier set determines what variation of app content
gets served to a specific device, for device-targeted content. You should
assign a priority level to each tier, which determines the ordering by which
they are evaluated by Play. See the documentation of DeviceTier.level for more
details.
Corresponds to the JSON property deviceTierSet
3281 3282 3283 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3281 def device_tier_set @device_tier_set end |
#user_country_sets ⇒ Array<Google::Apis::AndroidpublisherV3::UserCountrySet>
Definition of user country sets for the app.
Corresponds to the JSON property userCountrySets
3286 3287 3288 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3286 def user_country_sets @user_country_sets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3293 3294 3295 3296 3297 3298 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3293 def update!(**args) @device_groups = args[:device_groups] if args.key?(:device_groups) @device_tier_config_id = args[:device_tier_config_id] if args.key?(:device_tier_config_id) @device_tier_set = args[:device_tier_set] if args.key?(:device_tier_set) @user_country_sets = args[:user_country_sets] if args.key?(:user_country_sets) end |