Class: Google::Apis::AndroidpublisherV3::DeviceTierConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration describing device targeting criteria for the content of an app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceTierConfig

Returns a new instance of DeviceTierConfig.



2943
2944
2945
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_groupsArray<Google::Apis::AndroidpublisherV3::DeviceGroup>

Definition of device groups for the app. Corresponds to the JSON property deviceGroups



2922
2923
2924
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2922

def device_groups
  @device_groups
end

#device_tier_config_idFixnum

Output only. The device tier config ID. Corresponds to the JSON property deviceTierConfigId

Returns:

  • (Fixnum)


2927
2928
2929
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2927

def device_tier_config_id
  @device_tier_config_id
end

#device_tier_setGoogle::Apis::AndroidpublisherV3::DeviceTierSet

A set of device tiers. A tier set determines what variation of app content gets served to a specific device, for device-targeted content. You should assign a priority level to each tier, which determines the ordering by which they are evaluated by Play. See the documentation of DeviceTier.level for more details. Corresponds to the JSON property deviceTierSet



2936
2937
2938
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2936

def device_tier_set
  @device_tier_set
end

#user_country_setsArray<Google::Apis::AndroidpublisherV3::UserCountrySet>

Definition of user country sets for the app. Corresponds to the JSON property userCountrySets



2941
2942
2943
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2941

def user_country_sets
  @user_country_sets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2948
2949
2950
2951
2952
2953
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 2948

def update!(**args)
  @device_groups = args[:device_groups] if args.key?(:device_groups)
  @device_tier_config_id = args[:device_tier_config_id] if args.key?(:device_tier_config_id)
  @device_tier_set = args[:device_tier_set] if args.key?(:device_tier_set)
  @user_country_sets = args[:user_country_sets] if args.key?(:user_country_sets)
end