Class: Google::Apis::AndroidpublisherV3::DeviceTierSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A set of device tiers. A tier set determines what variation of app content gets served to a specific device, for device-targeted content. You should assign a priority level to each tier, which determines the ordering by which they are evaluated by Play. See the documentation of DeviceTier.level for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceTierSet

Returns a new instance of DeviceTierSet.



3314
3315
3316
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_tiersArray<Google::Apis::AndroidpublisherV3::DeviceTier>

Device tiers belonging to the set. Corresponds to the JSON property deviceTiers



3312
3313
3314
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3312

def device_tiers
  @device_tiers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3319
3320
3321
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3319

def update!(**args)
  @device_tiers = args[:device_tiers] if args.key?(:device_tiers)
end