Class: Google::Apis::AndroidpublisherV3::ExternalAccountIds

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

User account identifier in your app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalAccountIds

Returns a new instance of ExternalAccountIds.



3099
3100
3101
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#obfuscated_account_idString

Optional. Specifies an optional obfuscated string that is uniquely associated with the purchaser's user account in your app. If you pass this value, Google Play can use it to detect irregular activity. Do not use this field to store any Personally Identifiable Information (PII) such as emails in cleartext. Attempting to store PII in this field will result in purchases being blocked. Google Play recommends that you use either encryption or a one-way hash to generate an obfuscated identifier to send to Google Play. This identifier is limited to 64 characters. This field can only be set for resubscription purchases. See https://developer.android.com/reference/com/android/ billingclient/api/BillingFlowParams.Builder#setobfuscatedaccountid to set this field for purchases made using the standard in-app billing flow. Corresponds to the JSON property obfuscatedAccountId

Returns:

  • (String)


3082
3083
3084
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3082

def 
  @obfuscated_account_id
end

#obfuscated_profile_idString

Optional. Specifies an optional obfuscated string that is uniquely associated with the purchaser's user profile in your app. If you pass this value, Google Play can use it to detect irregular activity. Do not use this field to store any Personally Identifiable Information (PII) such as emails in cleartext. Attempting to store PII in this field will result in purchases being blocked. Google Play recommends that you use either encryption or a one-way hash to generate an obfuscated identifier to send to Google Play. This identifier is limited to 64 characters. This field can only be set for resubscription purchases. See https://developer.android.com/reference/com/android/ billingclient/api/BillingFlowParams.Builder#setobfuscatedprofileid to set this field for purchases made using the standard in-app billing flow. Corresponds to the JSON property obfuscatedProfileId

Returns:

  • (String)


3097
3098
3099
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3097

def obfuscated_profile_id
  @obfuscated_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3104
3105
3106
3107
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3104

def update!(**args)
  @obfuscated_account_id = args[:obfuscated_account_id] if args.key?(:obfuscated_account_id)
  @obfuscated_profile_id = args[:obfuscated_profile_id] if args.key?(:obfuscated_profile_id)
end