Class: Google::Apis::AndroidpublisherV3::ExternalOfferDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Reporting details unique to the external offers program.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalOfferDetails

Returns a new instance of ExternalOfferDetails.



3961
3962
3963
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_download_event_external_transaction_idString

Optional. The external transaction id associated with the app download event through an external link. Required when reporting transactions made in externally installed apps. Corresponds to the JSON property appDownloadEventExternalTransactionId

Returns:

  • (String)


3939
3940
3941
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3939

def app_download_event_external_transaction_id
  @app_download_event_external_transaction_id
end

#installed_app_categoryString

Optional. The category of the downloaded app though this transaction. This must match the category provided in Play Console during the external app verification process. Only required for app downloads. Corresponds to the JSON property installedAppCategory

Returns:

  • (String)


3946
3947
3948
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3946

def installed_app_category
  @installed_app_category
end

#installed_app_packageString

Optional. The package name of the app downloaded through this transaction. Required when link_type is LINK_TO_APP_DOWNLOAD. Corresponds to the JSON property installedAppPackage

Returns:

  • (String)


3952
3953
3954
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3952

def installed_app_package
  @installed_app_package
end

Optional. The type of content being reported by this transaction. Required when reporting app downloads or purchased digital content offers made in app installed through Google Play. Corresponds to the JSON property linkType

Returns:

  • (String)


3959
3960
3961
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3959

def link_type
  @link_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3966
3967
3968
3969
3970
3971
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3966

def update!(**args)
  @app_download_event_external_transaction_id = args[:app_download_event_external_transaction_id] if args.key?(:app_download_event_external_transaction_id)
  @installed_app_category = args[:installed_app_category] if args.key?(:installed_app_category)
  @installed_app_package = args[:installed_app_package] if args.key?(:installed_app_package)
  @link_type = args[:link_type] if args.key?(:link_type)
end