Class: Google::Apis::AndroidpublisherV3::ExternalOfferDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ExternalOfferDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Reporting details unique to the external offers program.
Instance Attribute Summary collapse
-
#app_download_event_external_transaction_id ⇒ String
Optional.
-
#installed_app_category ⇒ String
Optional.
-
#installed_app_package ⇒ String
Optional.
-
#link_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalOfferDetails
constructor
A new instance of ExternalOfferDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalOfferDetails
Returns a new instance of ExternalOfferDetails.
3141 3142 3143 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_download_event_external_transaction_id ⇒ String
Optional. The external transaction id associated with the app download event
through an external link. Required when reporting transactions made in
externally installed apps.
Corresponds to the JSON property appDownloadEventExternalTransactionId
3119 3120 3121 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3119 def app_download_event_external_transaction_id @app_download_event_external_transaction_id end |
#installed_app_category ⇒ String
Optional. The category of the downloaded app though this transaction. This
must match the category provided in Play Console during the external app
verification process. Only required for app downloads.
Corresponds to the JSON property installedAppCategory
3126 3127 3128 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3126 def installed_app_category @installed_app_category end |
#installed_app_package ⇒ String
Optional. The package name of the app downloaded through this transaction.
Required when link_type is LINK_TO_APP_DOWNLOAD.
Corresponds to the JSON property installedAppPackage
3132 3133 3134 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3132 def installed_app_package @installed_app_package end |
#link_type ⇒ String
Optional. The type of content being reported by this transaction. Required
when reporting app downloads or purchased digital content offers made in app
installed through Google Play.
Corresponds to the JSON property linkType
3139 3140 3141 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3139 def link_type @link_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3146 3147 3148 3149 3150 3151 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3146 def update!(**args) @app_download_event_external_transaction_id = args[:app_download_event_external_transaction_id] if args.key?(:app_download_event_external_transaction_id) @installed_app_category = args[:installed_app_category] if args.key?(:installed_app_category) @installed_app_package = args[:installed_app_package] if args.key?(:installed_app_package) @link_type = args[:link_type] if args.key?(:link_type) end |