Class: Google::Apis::AndroidpublisherV3::ExternalTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The details of an external transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalTransaction

Returns a new instance of ExternalTransaction.



3609
3610
3611
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when this transaction was created. This is the time when Google was notified of the transaction. Corresponds to the JSON property createTime

Returns:

  • (String)


3526
3527
3528
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3526

def create_time
  @create_time
end

#current_pre_tax_amountGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property currentPreTaxAmount



3531
3532
3533
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3531

def current_pre_tax_amount
  @current_pre_tax_amount
end

#current_tax_amountGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property currentTaxAmount



3536
3537
3538
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3536

def current_tax_amount
  @current_tax_amount
end

#external_offer_detailsGoogle::Apis::AndroidpublisherV3::ExternalOfferDetails

Reporting details unique to the external offers program. Corresponds to the JSON property externalOfferDetails



3541
3542
3543
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3541

def external_offer_details
  @external_offer_details
end

#external_transaction_idString

Output only. The id of this transaction. All transaction ids under the same package name must be unique. Set when creating the external transaction. Corresponds to the JSON property externalTransactionId

Returns:

  • (String)


3547
3548
3549
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3547

def external_transaction_id
  @external_transaction_id
end

#one_time_transactionGoogle::Apis::AndroidpublisherV3::OneTimeExternalTransaction

Represents a one-time transaction. Corresponds to the JSON property oneTimeTransaction



3552
3553
3554
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3552

def one_time_transaction
  @one_time_transaction
end

#original_pre_tax_amountGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property originalPreTaxAmount



3557
3558
3559
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3557

def original_pre_tax_amount
  @original_pre_tax_amount
end

#original_tax_amountGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property originalTaxAmount



3562
3563
3564
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3562

def original_tax_amount
  @original_tax_amount
end

#package_nameString

Output only. The resource name of the external transaction. The package name of the application the inapp products were sold (for example, 'com.some.app'). Corresponds to the JSON property packageName

Returns:

  • (String)


3568
3569
3570
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3568

def package_name
  @package_name
end

#recurring_transactionGoogle::Apis::AndroidpublisherV3::RecurringExternalTransaction

Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder). Corresponds to the JSON property recurringTransaction



3575
3576
3577
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3575

def recurring_transaction
  @recurring_transaction
end

#test_purchaseGoogle::Apis::AndroidpublisherV3::ExternalTransactionTestPurchase

Represents a transaction performed using a test account. These transactions will not be charged by Google. Corresponds to the JSON property testPurchase



3581
3582
3583
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3581

def test_purchase
  @test_purchase
end

#transaction_program_codeFixnum

Optional. The transaction program code, used to help determine service fee for eligible apps participating in partner programs. Developers participating in the Play Media Experience Program (https://play.google.com/console/about/ programs/mediaprogram/) must provide the program code when reporting alternative billing transactions. If you are an eligible developer, please contact your BDM for more information on how to set this field. Note: this field can not be used for external offers transactions. Corresponds to the JSON property transactionProgramCode

Returns:

  • (Fixnum)


3592
3593
3594
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3592

def transaction_program_code
  @transaction_program_code
end

#transaction_stateString

Output only. The current state of the transaction. Corresponds to the JSON property transactionState

Returns:

  • (String)


3597
3598
3599
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3597

def transaction_state
  @transaction_state
end

#transaction_timeString

Required. The time when the transaction was completed. Corresponds to the JSON property transactionTime

Returns:

  • (String)


3602
3603
3604
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3602

def transaction_time
  @transaction_time
end

#user_tax_addressGoogle::Apis::AndroidpublisherV3::ExternalTransactionAddress

User's address for the external transaction. Corresponds to the JSON property userTaxAddress



3607
3608
3609
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3607

def user_tax_address
  @user_tax_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3614

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_pre_tax_amount = args[:current_pre_tax_amount] if args.key?(:current_pre_tax_amount)
  @current_tax_amount = args[:current_tax_amount] if args.key?(:current_tax_amount)
  @external_offer_details = args[:external_offer_details] if args.key?(:external_offer_details)
  @external_transaction_id = args[:external_transaction_id] if args.key?(:external_transaction_id)
  @one_time_transaction = args[:one_time_transaction] if args.key?(:one_time_transaction)
  @original_pre_tax_amount = args[:original_pre_tax_amount] if args.key?(:original_pre_tax_amount)
  @original_tax_amount = args[:original_tax_amount] if args.key?(:original_tax_amount)
  @package_name = args[:package_name] if args.key?(:package_name)
  @recurring_transaction = args[:recurring_transaction] if args.key?(:recurring_transaction)
  @test_purchase = args[:test_purchase] if args.key?(:test_purchase)
  @transaction_program_code = args[:transaction_program_code] if args.key?(:transaction_program_code)
  @transaction_state = args[:transaction_state] if args.key?(:transaction_state)
  @transaction_time = args[:transaction_time] if args.key?(:transaction_time)
  @user_tax_address = args[:user_tax_address] if args.key?(:user_tax_address)
end