Class: Google::Apis::AndroidpublisherV3::ExternalTransaction
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ExternalTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
The details of an external transaction.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#current_pre_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e.
-
#current_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e.
-
#external_offer_details ⇒ Google::Apis::AndroidpublisherV3::ExternalOfferDetails
Reporting details unique to the external offers program.
-
#external_transaction_id ⇒ String
Output only.
-
#one_time_transaction ⇒ Google::Apis::AndroidpublisherV3::OneTimeExternalTransaction
Represents a one-time transaction.
-
#original_pre_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e.
-
#original_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e.
-
#package_name ⇒ String
Output only.
-
#recurring_transaction ⇒ Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
Represents a transaction that is part of a recurring series of payments.
-
#test_purchase ⇒ Google::Apis::AndroidpublisherV3::ExternalTransactionTestPurchase
Represents a transaction performed using a test account.
-
#transaction_program_code ⇒ Fixnum
Optional.
-
#transaction_state ⇒ String
Output only.
-
#transaction_time ⇒ String
Required.
-
#user_tax_address ⇒ Google::Apis::AndroidpublisherV3::ExternalTransactionAddress
User's address for the external transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalTransaction
constructor
A new instance of ExternalTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalTransaction
Returns a new instance of ExternalTransaction.
3264 3265 3266 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when this transaction was created. This is the time when
Google was notified of the transaction.
Corresponds to the JSON property createTime
3181 3182 3183 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3181 def create_time @create_time end |
#current_pre_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e. currency and units.
Corresponds to the JSON property currentPreTaxAmount
3186 3187 3188 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3186 def current_pre_tax_amount @current_pre_tax_amount end |
#current_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e. currency and units.
Corresponds to the JSON property currentTaxAmount
3191 3192 3193 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3191 def current_tax_amount @current_tax_amount end |
#external_offer_details ⇒ Google::Apis::AndroidpublisherV3::ExternalOfferDetails
Reporting details unique to the external offers program.
Corresponds to the JSON property externalOfferDetails
3196 3197 3198 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3196 def external_offer_details @external_offer_details end |
#external_transaction_id ⇒ String
Output only. The id of this transaction. All transaction ids under the same
package name must be unique. Set when creating the external transaction.
Corresponds to the JSON property externalTransactionId
3202 3203 3204 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3202 def external_transaction_id @external_transaction_id end |
#one_time_transaction ⇒ Google::Apis::AndroidpublisherV3::OneTimeExternalTransaction
Represents a one-time transaction.
Corresponds to the JSON property oneTimeTransaction
3207 3208 3209 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3207 def one_time_transaction @one_time_transaction end |
#original_pre_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e. currency and units.
Corresponds to the JSON property originalPreTaxAmount
3212 3213 3214 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3212 def original_pre_tax_amount @original_pre_tax_amount end |
#original_tax_amount ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e. currency and units.
Corresponds to the JSON property originalTaxAmount
3217 3218 3219 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3217 def original_tax_amount @original_tax_amount end |
#package_name ⇒ String
Output only. The resource name of the external transaction. The package name
of the application the inapp products were sold (for example, 'com.some.app').
Corresponds to the JSON property packageName
3223 3224 3225 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3223 def package_name @package_name end |
#recurring_transaction ⇒ Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
Represents a transaction that is part of a recurring series of payments. This
can be a subscription or a one-time product with multiple payments (such as
preorder).
Corresponds to the JSON property recurringTransaction
3230 3231 3232 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3230 def recurring_transaction @recurring_transaction end |
#test_purchase ⇒ Google::Apis::AndroidpublisherV3::ExternalTransactionTestPurchase
Represents a transaction performed using a test account. These transactions
will not be charged by Google.
Corresponds to the JSON property testPurchase
3236 3237 3238 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3236 def test_purchase @test_purchase end |
#transaction_program_code ⇒ Fixnum
Optional. The transaction program code, used to help determine service fee for
eligible apps participating in partner programs. Developers participating in
the Play Media Experience Program (https://play.google.com/console/about/
programs/mediaprogram/) must provide the program code when reporting
alternative billing transactions. If you are an eligible developer, please
contact your BDM for more information on how to set this field. Note: this
field can not be used for external offers transactions.
Corresponds to the JSON property transactionProgramCode
3247 3248 3249 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3247 def transaction_program_code @transaction_program_code end |
#transaction_state ⇒ String
Output only. The current state of the transaction.
Corresponds to the JSON property transactionState
3252 3253 3254 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3252 def transaction_state @transaction_state end |
#transaction_time ⇒ String
Required. The time when the transaction was completed.
Corresponds to the JSON property transactionTime
3257 3258 3259 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3257 def transaction_time @transaction_time end |
#user_tax_address ⇒ Google::Apis::AndroidpublisherV3::ExternalTransactionAddress
User's address for the external transaction.
Corresponds to the JSON property userTaxAddress
3262 3263 3264 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3262 def user_tax_address @user_tax_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3269 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @current_pre_tax_amount = args[:current_pre_tax_amount] if args.key?(:current_pre_tax_amount) @current_tax_amount = args[:current_tax_amount] if args.key?(:current_tax_amount) @external_offer_details = args[:external_offer_details] if args.key?(:external_offer_details) @external_transaction_id = args[:external_transaction_id] if args.key?(:external_transaction_id) @one_time_transaction = args[:one_time_transaction] if args.key?(:one_time_transaction) @original_pre_tax_amount = args[:original_pre_tax_amount] if args.key?(:original_pre_tax_amount) @original_tax_amount = args[:original_tax_amount] if args.key?(:original_tax_amount) @package_name = args[:package_name] if args.key?(:package_name) @recurring_transaction = args[:recurring_transaction] if args.key?(:recurring_transaction) @test_purchase = args[:test_purchase] if args.key?(:test_purchase) @transaction_program_code = args[:transaction_program_code] if args.key?(:transaction_program_code) @transaction_state = args[:transaction_state] if args.key?(:transaction_state) @transaction_time = args[:transaction_time] if args.key?(:transaction_time) @user_tax_address = args[:user_tax_address] if args.key?(:user_tax_address) end |