Class: Google::Apis::AndroidpublisherV3::ExternallyHostedApk
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ExternallyHostedApk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Defines an APK available for this application that is hosted externally and not uploaded to Google Play. This function is only available to organizations using Managed Play whose application is configured to restrict distribution to the organizations.
Instance Attribute Summary collapse
-
#application_label ⇒ String
The application label.
-
#certificate_base64s ⇒ Array<String>
A certificate (or array of certificates if a certificate-chain is used) used to sign this APK, represented as a base64 encoded byte array.
-
#externally_hosted_url ⇒ String
The URL at which the APK is hosted.
-
#file_sha1_base64 ⇒ String
The sha1 checksum of this APK, represented as a base64 encoded byte array.
-
#file_sha256_base64 ⇒ String
The sha256 checksum of this APK, represented as a base64 encoded byte array.
-
#file_size ⇒ Fixnum
The file size in bytes of this APK.
-
#icon_base64 ⇒ String
The icon image from the APK, as a base64 encoded byte array.
-
#maximum_sdk ⇒ Fixnum
The maximum SDK supported by this APK (optional).
-
#minimum_sdk ⇒ Fixnum
The minimum SDK targeted by this APK.
-
#native_codes ⇒ Array<String>
The native code environments supported by this APK (optional).
-
#package_name ⇒ String
The package name.
-
#uses_features ⇒ Array<String>
The features required by this APK (optional).
-
#uses_permissions ⇒ Array<Google::Apis::AndroidpublisherV3::UsesPermission>
The permissions requested by this APK.
-
#version_code ⇒ Fixnum
The version code of this APK.
-
#version_name ⇒ String
The version name of this APK.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternallyHostedApk
constructor
A new instance of ExternallyHostedApk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternallyHostedApk
Returns a new instance of ExternallyHostedApk.
4418 4419 4420 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_label ⇒ String
The application label.
Corresponds to the JSON property applicationLabel
4345 4346 4347 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4345 def application_label @application_label end |
#certificate_base64s ⇒ Array<String>
A certificate (or array of certificates if a certificate-chain is used) used
to sign this APK, represented as a base64 encoded byte array.
Corresponds to the JSON property certificateBase64s
4351 4352 4353 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4351 def certificate_base64s @certificate_base64s end |
#externally_hosted_url ⇒ String
The URL at which the APK is hosted. This must be an https URL.
Corresponds to the JSON property externallyHostedUrl
4356 4357 4358 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4356 def externally_hosted_url @externally_hosted_url end |
#file_sha1_base64 ⇒ String
The sha1 checksum of this APK, represented as a base64 encoded byte array.
Corresponds to the JSON property fileSha1Base64
4361 4362 4363 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4361 def file_sha1_base64 @file_sha1_base64 end |
#file_sha256_base64 ⇒ String
The sha256 checksum of this APK, represented as a base64 encoded byte array.
Corresponds to the JSON property fileSha256Base64
4366 4367 4368 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4366 def file_sha256_base64 @file_sha256_base64 end |
#file_size ⇒ Fixnum
The file size in bytes of this APK.
Corresponds to the JSON property fileSize
4371 4372 4373 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4371 def file_size @file_size end |
#icon_base64 ⇒ String
The icon image from the APK, as a base64 encoded byte array.
Corresponds to the JSON property iconBase64
4376 4377 4378 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4376 def icon_base64 @icon_base64 end |
#maximum_sdk ⇒ Fixnum
The maximum SDK supported by this APK (optional).
Corresponds to the JSON property maximumSdk
4381 4382 4383 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4381 def maximum_sdk @maximum_sdk end |
#minimum_sdk ⇒ Fixnum
The minimum SDK targeted by this APK.
Corresponds to the JSON property minimumSdk
4386 4387 4388 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4386 def minimum_sdk @minimum_sdk end |
#native_codes ⇒ Array<String>
The native code environments supported by this APK (optional).
Corresponds to the JSON property nativeCodes
4391 4392 4393 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4391 def native_codes @native_codes end |
#package_name ⇒ String
The package name.
Corresponds to the JSON property packageName
4396 4397 4398 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4396 def package_name @package_name end |
#uses_features ⇒ Array<String>
The features required by this APK (optional).
Corresponds to the JSON property usesFeatures
4401 4402 4403 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4401 def uses_features @uses_features end |
#uses_permissions ⇒ Array<Google::Apis::AndroidpublisherV3::UsesPermission>
The permissions requested by this APK.
Corresponds to the JSON property usesPermissions
4406 4407 4408 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4406 def @uses_permissions end |
#version_code ⇒ Fixnum
The version code of this APK.
Corresponds to the JSON property versionCode
4411 4412 4413 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4411 def version_code @version_code end |
#version_name ⇒ String
The version name of this APK.
Corresponds to the JSON property versionName
4416 4417 4418 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4416 def version_name @version_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4423 def update!(**args) @application_label = args[:application_label] if args.key?(:application_label) @certificate_base64s = args[:certificate_base64s] if args.key?(:certificate_base64s) @externally_hosted_url = args[:externally_hosted_url] if args.key?(:externally_hosted_url) @file_sha1_base64 = args[:file_sha1_base64] if args.key?(:file_sha1_base64) @file_sha256_base64 = args[:file_sha256_base64] if args.key?(:file_sha256_base64) @file_size = args[:file_size] if args.key?(:file_size) @icon_base64 = args[:icon_base64] if args.key?(:icon_base64) @maximum_sdk = args[:maximum_sdk] if args.key?(:maximum_sdk) @minimum_sdk = args[:minimum_sdk] if args.key?(:minimum_sdk) @native_codes = args[:native_codes] if args.key?(:native_codes) @package_name = args[:package_name] if args.key?(:package_name) @uses_features = args[:uses_features] if args.key?(:uses_features) @uses_permissions = args[:uses_permissions] if args.key?(:uses_permissions) @version_code = args[:version_code] if args.key?(:version_code) @version_name = args[:version_name] if args.key?(:version_name) end |