Class: Google::Apis::AndroidpublisherV3::ExternallyHostedApk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Defines an APK available for this application that is hosted externally and not uploaded to Google Play. This function is only available to organizations using Managed Play whose application is configured to restrict distribution to the organizations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternallyHostedApk

Returns a new instance of ExternallyHostedApk.



3419
3420
3421
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_labelString

The application label. Corresponds to the JSON property applicationLabel

Returns:

  • (String)


3346
3347
3348
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3346

def application_label
  @application_label
end

#certificate_base64sArray<String>

A certificate (or array of certificates if a certificate-chain is used) used to sign this APK, represented as a base64 encoded byte array. Corresponds to the JSON property certificateBase64s

Returns:

  • (Array<String>)


3352
3353
3354
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3352

def certificate_base64s
  @certificate_base64s
end

#externally_hosted_urlString

The URL at which the APK is hosted. This must be an https URL. Corresponds to the JSON property externallyHostedUrl

Returns:

  • (String)


3357
3358
3359
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3357

def externally_hosted_url
  @externally_hosted_url
end

#file_sha1_base64String

The sha1 checksum of this APK, represented as a base64 encoded byte array. Corresponds to the JSON property fileSha1Base64

Returns:

  • (String)


3362
3363
3364
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3362

def file_sha1_base64
  @file_sha1_base64
end

#file_sha256_base64String

The sha256 checksum of this APK, represented as a base64 encoded byte array. Corresponds to the JSON property fileSha256Base64

Returns:

  • (String)


3367
3368
3369
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3367

def file_sha256_base64
  @file_sha256_base64
end

#file_sizeFixnum

The file size in bytes of this APK. Corresponds to the JSON property fileSize

Returns:

  • (Fixnum)


3372
3373
3374
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3372

def file_size
  @file_size
end

#icon_base64String

The icon image from the APK, as a base64 encoded byte array. Corresponds to the JSON property iconBase64

Returns:

  • (String)


3377
3378
3379
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3377

def icon_base64
  @icon_base64
end

#maximum_sdkFixnum

The maximum SDK supported by this APK (optional). Corresponds to the JSON property maximumSdk

Returns:

  • (Fixnum)


3382
3383
3384
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3382

def maximum_sdk
  @maximum_sdk
end

#minimum_sdkFixnum

The minimum SDK targeted by this APK. Corresponds to the JSON property minimumSdk

Returns:

  • (Fixnum)


3387
3388
3389
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3387

def minimum_sdk
  @minimum_sdk
end

#native_codesArray<String>

The native code environments supported by this APK (optional). Corresponds to the JSON property nativeCodes

Returns:

  • (Array<String>)


3392
3393
3394
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3392

def native_codes
  @native_codes
end

#package_nameString

The package name. Corresponds to the JSON property packageName

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3397

def package_name
  @package_name
end

#uses_featuresArray<String>

The features required by this APK (optional). Corresponds to the JSON property usesFeatures

Returns:

  • (Array<String>)


3402
3403
3404
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3402

def uses_features
  @uses_features
end

#uses_permissionsArray<Google::Apis::AndroidpublisherV3::UsesPermission>

The permissions requested by this APK. Corresponds to the JSON property usesPermissions



3407
3408
3409
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3407

def uses_permissions
  @uses_permissions
end

#version_codeFixnum

The version code of this APK. Corresponds to the JSON property versionCode

Returns:

  • (Fixnum)


3412
3413
3414
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3412

def version_code
  @version_code
end

#version_nameString

The version name of this APK. Corresponds to the JSON property versionName

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3417

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
3440
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3424

def update!(**args)
  @application_label = args[:application_label] if args.key?(:application_label)
  @certificate_base64s = args[:certificate_base64s] if args.key?(:certificate_base64s)
  @externally_hosted_url = args[:externally_hosted_url] if args.key?(:externally_hosted_url)
  @file_sha1_base64 = args[:file_sha1_base64] if args.key?(:file_sha1_base64)
  @file_sha256_base64 = args[:file_sha256_base64] if args.key?(:file_sha256_base64)
  @file_size = args[:file_size] if args.key?(:file_size)
  @icon_base64 = args[:icon_base64] if args.key?(:icon_base64)
  @maximum_sdk = args[:maximum_sdk] if args.key?(:maximum_sdk)
  @minimum_sdk = args[:minimum_sdk] if args.key?(:minimum_sdk)
  @native_codes = args[:native_codes] if args.key?(:native_codes)
  @package_name = args[:package_name] if args.key?(:package_name)
  @uses_features = args[:uses_features] if args.key?(:uses_features)
  @uses_permissions = args[:uses_permissions] if args.key?(:uses_permissions)
  @version_code = args[:version_code] if args.key?(:version_code)
  @version_name = args[:version_name] if args.key?(:version_name)
end