Class: Google::Apis::AndroidpublisherV3::GeneratedRecoveryApk
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::GeneratedRecoveryApk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Download metadata for an app recovery module.
Instance Attribute Summary collapse
-
#download_id ⇒ String
Download ID, which uniquely identifies the APK to download.
-
#module_name ⇒ String
Name of the module which recovery apk belongs to.
-
#recovery_id ⇒ Fixnum
ID of the recovery action.
-
#recovery_status ⇒ String
The status of the recovery action corresponding to the recovery apk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GeneratedRecoveryApk
constructor
A new instance of GeneratedRecoveryApk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GeneratedRecoveryApk
Returns a new instance of GeneratedRecoveryApk.
4645 4646 4647 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#download_id ⇒ String
Download ID, which uniquely identifies the APK to download. Should be supplied
to generatedapks.download method.
Corresponds to the JSON property downloadId
4628 4629 4630 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4628 def download_id @download_id end |
#module_name ⇒ String
Name of the module which recovery apk belongs to.
Corresponds to the JSON property moduleName
4633 4634 4635 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4633 def module_name @module_name end |
#recovery_id ⇒ Fixnum
ID of the recovery action.
Corresponds to the JSON property recoveryId
4638 4639 4640 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4638 def recovery_id @recovery_id end |
#recovery_status ⇒ String
The status of the recovery action corresponding to the recovery apk.
Corresponds to the JSON property recoveryStatus
4643 4644 4645 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4643 def recovery_status @recovery_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4650 4651 4652 4653 4654 4655 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4650 def update!(**args) @download_id = args[:download_id] if args.key?(:download_id) @module_name = args[:module_name] if args.key?(:module_name) @recovery_id = args[:recovery_id] if args.key?(:recovery_id) @recovery_status = args[:recovery_status] if args.key?(:recovery_status) end |