Class: Google::Apis::AndroidpublisherV3::GeneratedRecoveryApk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Download metadata for an app recovery module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedRecoveryApk

Returns a new instance of GeneratedRecoveryApk.



4466
4467
4468
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#download_idString

Download ID, which uniquely identifies the APK to download. Should be supplied to generatedapks.download method. Corresponds to the JSON property downloadId

Returns:

  • (String)


4449
4450
4451
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4449

def download_id
  @download_id
end

#module_nameString

Name of the module which recovery apk belongs to. Corresponds to the JSON property moduleName

Returns:

  • (String)


4454
4455
4456
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4454

def module_name
  @module_name
end

#recovery_idFixnum

ID of the recovery action. Corresponds to the JSON property recoveryId

Returns:

  • (Fixnum)


4459
4460
4461
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4459

def recovery_id
  @recovery_id
end

#recovery_statusString

The status of the recovery action corresponding to the recovery apk. Corresponds to the JSON property recoveryStatus

Returns:

  • (String)


4464
4465
4466
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4464

def recovery_status
  @recovery_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4471
4472
4473
4474
4475
4476
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4471

def update!(**args)
  @download_id = args[:download_id] if args.key?(:download_id)
  @module_name = args[:module_name] if args.key?(:module_name)
  @recovery_id = args[:recovery_id] if args.key?(:recovery_id)
  @recovery_status = args[:recovery_status] if args.key?(:recovery_status)
end