Class: Google::Apis::AndroidpublisherV3::GeneratedRecoveryApk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Download metadata for an app recovery module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedRecoveryApk

Returns a new instance of GeneratedRecoveryApk.



3991
3992
3993
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#download_idString

Download ID, which uniquely identifies the APK to download. Should be supplied to generatedapks.download method. Corresponds to the JSON property downloadId

Returns:

  • (String)


3974
3975
3976
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3974

def download_id
  @download_id
end

#module_nameString

Name of the module which recovery apk belongs to. Corresponds to the JSON property moduleName

Returns:

  • (String)


3979
3980
3981
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3979

def module_name
  @module_name
end

#recovery_idFixnum

ID of the recovery action. Corresponds to the JSON property recoveryId

Returns:

  • (Fixnum)


3984
3985
3986
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3984

def recovery_id
  @recovery_id
end

#recovery_statusString

The status of the recovery action corresponding to the recovery apk. Corresponds to the JSON property recoveryStatus

Returns:

  • (String)


3989
3990
3991
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3989

def recovery_status
  @recovery_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3996
3997
3998
3999
4000
4001
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3996

def update!(**args)
  @download_id = args[:download_id] if args.key?(:download_id)
  @module_name = args[:module_name] if args.key?(:module_name)
  @recovery_id = args[:recovery_id] if args.key?(:recovery_id)
  @recovery_status = args[:recovery_status] if args.key?(:recovery_status)
end