Class: Google::Apis::AndroidpublisherV3::GeneratedRecoveryApk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Download metadata for an app recovery module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedRecoveryApk

Returns a new instance of GeneratedRecoveryApk.



3607
3608
3609
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#download_idString

Download ID, which uniquely identifies the APK to download. Should be supplied to generatedapks.download method. Corresponds to the JSON property downloadId

Returns:

  • (String)


3590
3591
3592
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3590

def download_id
  @download_id
end

#module_nameString

Name of the module which recovery apk belongs to. Corresponds to the JSON property moduleName

Returns:

  • (String)


3595
3596
3597
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3595

def module_name
  @module_name
end

#recovery_idFixnum

ID of the recovery action. Corresponds to the JSON property recoveryId

Returns:

  • (Fixnum)


3600
3601
3602
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3600

def recovery_id
  @recovery_id
end

#recovery_statusString

The status of the recovery action corresponding to the recovery apk. Corresponds to the JSON property recoveryStatus

Returns:

  • (String)


3605
3606
3607
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3605

def recovery_status
  @recovery_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3612
3613
3614
3615
3616
3617
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3612

def update!(**args)
  @download_id = args[:download_id] if args.key?(:download_id)
  @module_name = args[:module_name] if args.key?(:module_name)
  @recovery_id = args[:recovery_id] if args.key?(:recovery_id)
  @recovery_status = args[:recovery_status] if args.key?(:recovery_status)
end