Class: Google::Apis::AndroidpublisherV3::Image
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Image
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An uploaded image. The resource for ImagesService.
Instance Attribute Summary collapse
-
#id ⇒ String
A unique id representing this image.
-
#sha1 ⇒ String
A sha1 hash of the image.
-
#sha256 ⇒ String
A sha256 hash of the image.
-
#url ⇒ String
A URL that will serve a preview of the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
3854 3855 3856 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
A unique id representing this image.
Corresponds to the JSON property id
3837 3838 3839 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3837 def id @id end |
#sha1 ⇒ String
A sha1 hash of the image.
Corresponds to the JSON property sha1
3842 3843 3844 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3842 def sha1 @sha1 end |
#sha256 ⇒ String
A sha256 hash of the image.
Corresponds to the JSON property sha256
3847 3848 3849 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3847 def sha256 @sha256 end |
#url ⇒ String
A URL that will serve a preview of the image.
Corresponds to the JSON property url
3852 3853 3854 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3852 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3859 3860 3861 3862 3863 3864 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3859 def update!(**args) @id = args[:id] if args.key?(:id) @sha1 = args[:sha1] if args.key?(:sha1) @sha256 = args[:sha256] if args.key?(:sha256) @url = args[:url] if args.key?(:url) end |