Class: Google::Apis::AndroidpublisherV3::InAppProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

An in-app product. The resource for InappproductsService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InAppProduct

Returns a new instance of InAppProduct.



4002
4003
4004
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_languageString

Default language of the localized data, as defined by BCP-47. e.g. "en-US". Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


3931
3932
3933
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3931

def default_language
  @default_language
end

#default_priceGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property defaultPrice



3936
3937
3938
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3936

def default_price
  @default_price
end

#grace_periodString

Grace period of the subscription, specified in ISO 8601 format. Allows developers to give their subscribers a grace period when the payment for the new recurrence period is declined. Acceptable values are P0D (zero days), P3D ( three days), P7D (seven days), P14D (14 days), and P30D (30 days). Corresponds to the JSON property gracePeriod

Returns:

  • (String)


3944
3945
3946
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3944

def grace_period
  @grace_period
end

#listingsHash<String,Google::Apis::AndroidpublisherV3::InAppProductListing>

List of localized title and description data. Map key is the language of the localized data, as defined by BCP-47, e.g. "en-US". Corresponds to the JSON property listings



3950
3951
3952
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3950

def listings
  @listings
end

#managed_product_taxes_and_compliance_settingsGoogle::Apis::AndroidpublisherV3::ManagedProductTaxAndComplianceSettings

Details about taxation and legal compliance for managed products. Corresponds to the JSON property managedProductTaxesAndComplianceSettings



3955
3956
3957
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3955

def managed_product_taxes_and_compliance_settings
  @managed_product_taxes_and_compliance_settings
end

#package_nameString

Package name of the parent app. Corresponds to the JSON property packageName

Returns:

  • (String)


3960
3961
3962
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3960

def package_name
  @package_name
end

#pricesHash<String,Google::Apis::AndroidpublisherV3::Price>

Prices per buyer region. None of these can be zero, as in-app products are never free. Map key is region code, as defined by ISO 3166-2. Corresponds to the JSON property prices

Returns:



3966
3967
3968
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3966

def prices
  @prices
end

#purchase_typeString

The type of the product, e.g. a recurring subscription. Corresponds to the JSON property purchaseType

Returns:

  • (String)


3971
3972
3973
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3971

def purchase_type
  @purchase_type
end

#skuString

Stock-keeping-unit (SKU) of the product, unique within an app. Corresponds to the JSON property sku

Returns:

  • (String)


3976
3977
3978
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3976

def sku
  @sku
end

#statusString

The status of the product, e.g. whether it's active. Corresponds to the JSON property status

Returns:

  • (String)


3981
3982
3983
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3981

def status
  @status
end

#subscription_periodString

Subscription period, specified in ISO 8601 format. Acceptable values are P1W ( one week), P1M (one month), P3M (three months), P6M (six months), and P1Y (one year). Corresponds to the JSON property subscriptionPeriod

Returns:

  • (String)


3988
3989
3990
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3988

def subscription_period
  @subscription_period
end

#subscription_taxes_and_compliance_settingsGoogle::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings

Details about taxation, Google Play policy, and legal compliance for subscription products. Corresponds to the JSON property subscriptionTaxesAndComplianceSettings



3994
3995
3996
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 3994

def subscription_taxes_and_compliance_settings
  @subscription_taxes_and_compliance_settings
end

#trial_periodString

Trial period, specified in ISO 8601 format. Acceptable values are anything between P7D (seven days) and P999D (999 days). Corresponds to the JSON property trialPeriod

Returns:

  • (String)


4000
4001
4002
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4000

def trial_period
  @trial_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4007

def update!(**args)
  @default_language = args[:default_language] if args.key?(:default_language)
  @default_price = args[:default_price] if args.key?(:default_price)
  @grace_period = args[:grace_period] if args.key?(:grace_period)
  @listings = args[:listings] if args.key?(:listings)
  @managed_product_taxes_and_compliance_settings = args[:managed_product_taxes_and_compliance_settings] if args.key?(:managed_product_taxes_and_compliance_settings)
  @package_name = args[:package_name] if args.key?(:package_name)
  @prices = args[:prices] if args.key?(:prices)
  @purchase_type = args[:purchase_type] if args.key?(:purchase_type)
  @sku = args[:sku] if args.key?(:sku)
  @status = args[:status] if args.key?(:status)
  @subscription_period = args[:subscription_period] if args.key?(:subscription_period)
  @subscription_taxes_and_compliance_settings = args[:subscription_taxes_and_compliance_settings] if args.key?(:subscription_taxes_and_compliance_settings)
  @trial_period = args[:trial_period] if args.key?(:trial_period)
end