Class: Google::Apis::AndroidpublisherV3::InappproductsListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response listing all in-app products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InappproductsListResponse

Returns a new instance of InappproductsListResponse.



4244
4245
4246
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inappproductArray<Google::Apis::AndroidpublisherV3::InAppProduct>

All in-app products. Corresponds to the JSON property inappproduct



4218
4219
4220
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4218

def inappproduct
  @inappproduct
end

#kindString

The kind of this response ("androidpublisher#inappproductsListResponse"). Corresponds to the JSON property kind

Returns:

  • (String)


4223
4224
4225
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4223

def kind
  @kind
end

#page_infoGoogle::Apis::AndroidpublisherV3::PageInfo

Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. Corresponds to the JSON property pageInfo



4230
4231
4232
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4230

def page_info
  @page_info
end

#token_paginationGoogle::Apis::AndroidpublisherV3::TokenPagination

Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page. Corresponds to the JSON property tokenPagination



4242
4243
4244
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4242

def token_pagination
  @token_pagination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4249
4250
4251
4252
4253
4254
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4249

def update!(**args)
  @inappproduct = args[:inappproduct] if args.key?(:inappproduct)
  @kind = args[:kind] if args.key?(:kind)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
end