Class: Google::Apis::AndroidpublisherV3::InappproductsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::InappproductsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response listing all in-app products.
Instance Attribute Summary collapse
-
#inappproduct ⇒ Array<Google::Apis::AndroidpublisherV3::InAppProduct>
All in-app products.
-
#kind ⇒ String
The kind of this response ("androidpublisher#inappproductsListResponse").
-
#page_info ⇒ Google::Apis::AndroidpublisherV3::PageInfo
Information about the current page.
-
#token_pagination ⇒ Google::Apis::AndroidpublisherV3::TokenPagination
Pagination information returned by a List operation when token pagination is enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InappproductsListResponse
constructor
A new instance of InappproductsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InappproductsListResponse
Returns a new instance of InappproductsListResponse.
4219 4220 4221 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inappproduct ⇒ Array<Google::Apis::AndroidpublisherV3::InAppProduct>
All in-app products.
Corresponds to the JSON property inappproduct
4193 4194 4195 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4193 def inappproduct @inappproduct end |
#kind ⇒ String
The kind of this response ("androidpublisher#inappproductsListResponse").
Corresponds to the JSON property kind
4198 4199 4200 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4198 def kind @kind end |
#page_info ⇒ Google::Apis::AndroidpublisherV3::PageInfo
Information about the current page. List operations that supports paging
return only one "page" of results. This protocol buffer message describes the
page that has been returned.
Corresponds to the JSON property pageInfo
4205 4206 4207 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4205 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::AndroidpublisherV3::TokenPagination
Pagination information returned by a List operation when token pagination is
enabled. List operations that supports paging return only one "page" of
results. This protocol buffer message describes the page that has been
returned. When using token pagination, clients should use the next/previous
token to get another page of the result. The presence or absence of next/
previous token indicates whether a next/previous page is available and
provides a mean of accessing this page. ListRequest.page_token should be set
to either next_page_token or previous_page_token to access another page.
Corresponds to the JSON property tokenPagination
4217 4218 4219 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4217 def token_pagination @token_pagination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4224 4225 4226 4227 4228 4229 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4224 def update!(**args) @inappproduct = args[:inappproduct] if args.key?(:inappproduct) @kind = args[:kind] if args.key?(:kind) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) end |