Class: Google::Apis::AndroidpublisherV3::InstallmentsBasePlanType
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::InstallmentsBasePlanType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Represents an installments base plan where a user commits to a specified number of payments.
Instance Attribute Summary collapse
-
#account_hold_duration ⇒ String
Optional.
-
#billing_period_duration ⇒ String
Required.
-
#committed_payments_count ⇒ Fixnum
Required.
-
#grace_period_duration ⇒ String
Grace period of the subscription, specified in ISO 8601 format.
-
#proration_mode ⇒ String
The proration mode for the base plan determines what happens when a user switches to this plan from another base plan.
-
#renewal_type ⇒ String
Required.
-
#resubscribe_state ⇒ String
Whether users should be able to resubscribe to this base plan in Google Play surfaces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstallmentsBasePlanType
constructor
A new instance of InstallmentsBasePlanType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstallmentsBasePlanType
Returns a new instance of InstallmentsBasePlanType.
4365 4366 4367 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_hold_duration ⇒ String
Optional. Custom account hold period of the subscription, specified in ISO
8601 format. Acceptable values must be in days and between P0D and P60D. An
empty field represents a recommended account hold, calculated as 60 days minus
grace period. The sum of gracePeriodDuration and accountHoldDuration must be
between P30D and P60D days, inclusive.
Corresponds to the JSON property accountHoldDuration
4321 4322 4323 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4321 def account_hold_duration @account_hold_duration end |
#billing_period_duration ⇒ String
Required. Immutable. Subscription period, specified in ISO 8601 format. For a
list of acceptable billing periods, refer to the help center. The duration is
immutable after the base plan is created.
Corresponds to the JSON property billingPeriodDuration
4328 4329 4330 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4328 def billing_period_duration @billing_period_duration end |
#committed_payments_count ⇒ Fixnum
Required. Immutable. The number of payments the user is committed to. It is
immutable after the base plan is created.
Corresponds to the JSON property committedPaymentsCount
4334 4335 4336 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4334 def committed_payments_count @committed_payments_count end |
#grace_period_duration ⇒ String
Grace period of the subscription, specified in ISO 8601 format. Acceptable
values must be in days and between P0D and the lesser of 30D and base plan
billing period. If not specified, a default value will be used based on the
billing period. The sum of gracePeriodDuration and accountHoldDuration must be
between P30D and P60D days, inclusive.
Corresponds to the JSON property gracePeriodDuration
4343 4344 4345 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4343 def grace_period_duration @grace_period_duration end |
#proration_mode ⇒ String
The proration mode for the base plan determines what happens when a user
switches to this plan from another base plan. If unspecified, defaults to
CHARGE_ON_NEXT_BILLING_DATE.
Corresponds to the JSON property prorationMode
4350 4351 4352 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4350 def proration_mode @proration_mode end |
#renewal_type ⇒ String
Required. Immutable. Installments base plan renewal type. Determines the
behavior at the end of the initial commitment. The renewal type is immutable
after the base plan is created.
Corresponds to the JSON property renewalType
4357 4358 4359 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4357 def renewal_type @renewal_type end |
#resubscribe_state ⇒ String
Whether users should be able to resubscribe to this base plan in Google Play
surfaces. Defaults to RESUBSCRIBE_STATE_ACTIVE if not specified.
Corresponds to the JSON property resubscribeState
4363 4364 4365 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4363 def resubscribe_state @resubscribe_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4370 4371 4372 4373 4374 4375 4376 4377 4378 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4370 def update!(**args) @account_hold_duration = args[:account_hold_duration] if args.key?(:account_hold_duration) @billing_period_duration = args[:billing_period_duration] if args.key?(:billing_period_duration) @committed_payments_count = args[:committed_payments_count] if args.key?(:committed_payments_count) @grace_period_duration = args[:grace_period_duration] if args.key?(:grace_period_duration) @proration_mode = args[:proration_mode] if args.key?(:proration_mode) @renewal_type = args[:renewal_type] if args.key?(:renewal_type) @resubscribe_state = args[:resubscribe_state] if args.key?(:resubscribe_state) end |