Class: Google::Apis::AndroidpublisherV3::InternalAppSharingArtifact
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::InternalAppSharingArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An artifact resource which gets created when uploading an APK or Android App Bundle through internal app sharing.
Instance Attribute Summary collapse
-
#certificate_fingerprint ⇒ String
The sha256 fingerprint of the certificate used to sign the generated artifact.
-
#download_url ⇒ String
The download URL generated for the uploaded artifact.
-
#sha256 ⇒ String
The sha256 hash of the artifact represented as a lowercase hexadecimal number, matching the output of the sha256sum command.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InternalAppSharingArtifact
constructor
A new instance of InternalAppSharingArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InternalAppSharingArtifact
Returns a new instance of InternalAppSharingArtifact.
5485 5486 5487 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_fingerprint ⇒ String
The sha256 fingerprint of the certificate used to sign the generated artifact.
Corresponds to the JSON property certificateFingerprint
5471 5472 5473 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5471 def certificate_fingerprint @certificate_fingerprint end |
#download_url ⇒ String
The download URL generated for the uploaded artifact. Users that are
authorized to download can follow the link to the Play Store app to install it.
Corresponds to the JSON property downloadUrl
5477 5478 5479 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5477 def download_url @download_url end |
#sha256 ⇒ String
The sha256 hash of the artifact represented as a lowercase hexadecimal number,
matching the output of the sha256sum command.
Corresponds to the JSON property sha256
5483 5484 5485 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5483 def sha256 @sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5490 5491 5492 5493 5494 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5490 def update!(**args) @certificate_fingerprint = args[:certificate_fingerprint] if args.key?(:certificate_fingerprint) @download_url = args[:download_url] if args.key?(:download_url) @sha256 = args[:sha256] if args.key?(:sha256) end |