Class: Google::Apis::AndroidpublisherV3::InternalAppSharingArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

An artifact resource which gets created when uploading an APK or Android App Bundle through internal app sharing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InternalAppSharingArtifact

Returns a new instance of InternalAppSharingArtifact.



5306
5307
5308
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_fingerprintString

The sha256 fingerprint of the certificate used to sign the generated artifact. Corresponds to the JSON property certificateFingerprint

Returns:

  • (String)


5292
5293
5294
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5292

def certificate_fingerprint
  @certificate_fingerprint
end

#download_urlString

The download URL generated for the uploaded artifact. Users that are authorized to download can follow the link to the Play Store app to install it. Corresponds to the JSON property downloadUrl

Returns:

  • (String)


5298
5299
5300
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5298

def download_url
  @download_url
end

#sha256String

The sha256 hash of the artifact represented as a lowercase hexadecimal number, matching the output of the sha256sum command. Corresponds to the JSON property sha256

Returns:

  • (String)


5304
5305
5306
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5304

def sha256
  @sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5311
5312
5313
5314
5315
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5311

def update!(**args)
  @certificate_fingerprint = args[:certificate_fingerprint] if args.key?(:certificate_fingerprint)
  @download_url = args[:download_url] if args.key?(:download_url)
  @sha256 = args[:sha256] if args.key?(:sha256)
end