Class: Google::Apis::AndroidpublisherV3::InternalAppSharingArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

An artifact resource which gets created when uploading an APK or Android App Bundle through internal app sharing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InternalAppSharingArtifact

Returns a new instance of InternalAppSharingArtifact.



4423
4424
4425
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_fingerprintString

The sha256 fingerprint of the certificate used to sign the generated artifact. Corresponds to the JSON property certificateFingerprint

Returns:

  • (String)


4409
4410
4411
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4409

def certificate_fingerprint
  @certificate_fingerprint
end

#download_urlString

The download URL generated for the uploaded artifact. Users that are authorized to download can follow the link to the Play Store app to install it. Corresponds to the JSON property downloadUrl

Returns:

  • (String)


4415
4416
4417
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4415

def download_url
  @download_url
end

#sha256String

The sha256 hash of the artifact represented as a lowercase hexadecimal number, matching the output of the sha256sum command. Corresponds to the JSON property sha256

Returns:

  • (String)


4421
4422
4423
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4421

def sha256
  @sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4428
4429
4430
4431
4432
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4428

def update!(**args)
  @certificate_fingerprint = args[:certificate_fingerprint] if args.key?(:certificate_fingerprint)
  @download_url = args[:download_url] if args.key?(:download_url)
  @sha256 = args[:sha256] if args.key?(:sha256)
end