Class: Google::Apis::AndroidpublisherV3::IntroductoryPriceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Contains the introductory price information for a subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntroductoryPriceInfo

Returns a new instance of IntroductoryPriceInfo.



4440
4441
4442
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#introductory_price_amount_microsFixnum

Introductory price of the subscription, not including tax. The currency is the same as price_currency_code. Price is expressed in micro-units, where 1,000, 000 micro-units represents one unit of the currency. For example, if the subscription price is €1.99, price_amount_micros is 1990000. Corresponds to the JSON property introductoryPriceAmountMicros

Returns:

  • (Fixnum)


4419
4420
4421
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4419

def introductory_price_amount_micros
  @introductory_price_amount_micros
end

#introductory_price_currency_codeString

ISO 4217 currency code for the introductory subscription price. For example, if the price is specified in British pounds sterling, price_currency_code is " GBP". Corresponds to the JSON property introductoryPriceCurrencyCode

Returns:

  • (String)


4426
4427
4428
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4426

def introductory_price_currency_code
  @introductory_price_currency_code
end

#introductory_price_cyclesFixnum

The number of billing period to offer introductory pricing. Corresponds to the JSON property introductoryPriceCycles

Returns:

  • (Fixnum)


4431
4432
4433
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4431

def introductory_price_cycles
  @introductory_price_cycles
end

#introductory_price_periodString

Introductory price period, specified in ISO 8601 format. Common values are ( but not limited to) "P1W" (one week), "P1M" (one month), "P3M" (three months), "P6M" (six months), and "P1Y" (one year). Corresponds to the JSON property introductoryPricePeriod

Returns:

  • (String)


4438
4439
4440
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4438

def introductory_price_period
  @introductory_price_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4445
4446
4447
4448
4449
4450
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4445

def update!(**args)
  @introductory_price_amount_micros = args[:introductory_price_amount_micros] if args.key?(:introductory_price_amount_micros)
  @introductory_price_currency_code = args[:introductory_price_currency_code] if args.key?(:introductory_price_currency_code)
  @introductory_price_cycles = args[:introductory_price_cycles] if args.key?(:introductory_price_cycles)
  @introductory_price_period = args[:introductory_price_period] if args.key?(:introductory_price_period)
end