Class: Google::Apis::AndroidpublisherV3::ItemReplacement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about a subscription line item that is being replaced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemReplacement

Returns a new instance of ItemReplacement.



5393
5394
5395
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

The base plan ID of the subscription line item being replaced. Corresponds to the JSON property basePlanId

Returns:

  • (String)


5376
5377
5378
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5376

def base_plan_id
  @base_plan_id
end

#offer_idString

The offer ID of the subscription line item being replaced, if applicable. Corresponds to the JSON property offerId

Returns:

  • (String)


5381
5382
5383
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5381

def offer_id
  @offer_id
end

#product_idString

The product ID of the subscription line item being replaced. Corresponds to the JSON property productId

Returns:

  • (String)


5386
5387
5388
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5386

def product_id
  @product_id
end

#replacement_modeString

The replacement mode applied during the purchase. Corresponds to the JSON property replacementMode

Returns:

  • (String)


5391
5392
5393
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5391

def replacement_mode
  @replacement_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5398
5399
5400
5401
5402
5403
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5398

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @product_id = args[:product_id] if args.key?(:product_id)
  @replacement_mode = args[:replacement_mode] if args.key?(:replacement_mode)
end