Class: Google::Apis::AndroidpublisherV3::ItemReplacement
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ItemReplacement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about a subscription line item that is being replaced.
Instance Attribute Summary collapse
-
#base_plan_id ⇒ String
The base plan ID of the subscription line item being replaced.
-
#offer_id ⇒ String
The offer ID of the subscription line item being replaced, if applicable.
-
#product_id ⇒ String
The product ID of the subscription line item being replaced.
-
#replacement_mode ⇒ String
The replacement mode applied during the purchase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ItemReplacement
constructor
A new instance of ItemReplacement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ItemReplacement
Returns a new instance of ItemReplacement.
4899 4900 4901 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_plan_id ⇒ String
The base plan ID of the subscription line item being replaced.
Corresponds to the JSON property basePlanId
4882 4883 4884 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4882 def base_plan_id @base_plan_id end |
#offer_id ⇒ String
The offer ID of the subscription line item being replaced, if applicable.
Corresponds to the JSON property offerId
4887 4888 4889 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4887 def offer_id @offer_id end |
#product_id ⇒ String
The product ID of the subscription line item being replaced.
Corresponds to the JSON property productId
4892 4893 4894 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4892 def product_id @product_id end |
#replacement_mode ⇒ String
The replacement mode applied during the purchase.
Corresponds to the JSON property replacementMode
4897 4898 4899 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4897 def replacement_mode @replacement_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4904 4905 4906 4907 4908 4909 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4904 def update!(**args) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @offer_id = args[:offer_id] if args.key?(:offer_id) @product_id = args[:product_id] if args.key?(:product_id) @replacement_mode = args[:replacement_mode] if args.key?(:replacement_mode) end |