Class: Google::Apis::AndroidpublisherV3::ItemReplacement
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ItemReplacement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about a subscription line item that is being replaced.
Instance Attribute Summary collapse
-
#base_plan_id ⇒ String
The base plan ID of the subscription line item being replaced.
-
#offer_id ⇒ String
The offer ID of the subscription line item being replaced, if applicable.
-
#product_id ⇒ String
The product ID of the subscription line item being replaced.
-
#replacement_mode ⇒ String
The replacement mode applied during the purchase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ItemReplacement
constructor
A new instance of ItemReplacement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ItemReplacement
Returns a new instance of ItemReplacement.
4554 4555 4556 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_plan_id ⇒ String
The base plan ID of the subscription line item being replaced.
Corresponds to the JSON property basePlanId
4537 4538 4539 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4537 def base_plan_id @base_plan_id end |
#offer_id ⇒ String
The offer ID of the subscription line item being replaced, if applicable.
Corresponds to the JSON property offerId
4542 4543 4544 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4542 def offer_id @offer_id end |
#product_id ⇒ String
The product ID of the subscription line item being replaced.
Corresponds to the JSON property productId
4547 4548 4549 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4547 def product_id @product_id end |
#replacement_mode ⇒ String
The replacement mode applied during the purchase.
Corresponds to the JSON property replacementMode
4552 4553 4554 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4552 def replacement_mode @replacement_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4559 4560 4561 4562 4563 4564 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4559 def update!(**args) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @offer_id = args[:offer_id] if args.key?(:offer_id) @product_id = args[:product_id] if args.key?(:product_id) @replacement_mode = args[:replacement_mode] if args.key?(:replacement_mode) end |