Class: Google::Apis::AndroidpublisherV3::ItemReplacement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about a subscription line item that is being replaced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemReplacement

Returns a new instance of ItemReplacement.



4534
4535
4536
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

The base plan ID of the subscription line item being replaced. Corresponds to the JSON property basePlanId

Returns:

  • (String)


4517
4518
4519
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4517

def base_plan_id
  @base_plan_id
end

#offer_idString

The offer ID of the subscription line item being replaced, if applicable. Corresponds to the JSON property offerId

Returns:

  • (String)


4522
4523
4524
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4522

def offer_id
  @offer_id
end

#product_idString

The product ID of the subscription line item being replaced. Corresponds to the JSON property productId

Returns:

  • (String)


4527
4528
4529
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4527

def product_id
  @product_id
end

#replacement_modeString

The replacement mode applied during the purchase. Corresponds to the JSON property replacementMode

Returns:

  • (String)


4532
4533
4534
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4532

def replacement_mode
  @replacement_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4539
4540
4541
4542
4543
4544
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4539

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @product_id = args[:product_id] if args.key?(:product_id)
  @replacement_mode = args[:replacement_mode] if args.key?(:replacement_mode)
end