Class: Google::Apis::AndroidpublisherV3::ItemReplacement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about a subscription line item that is being replaced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemReplacement

Returns a new instance of ItemReplacement.



4515
4516
4517
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

The base plan ID of the subscription line item being replaced. Corresponds to the JSON property basePlanId

Returns:

  • (String)


4498
4499
4500
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4498

def base_plan_id
  @base_plan_id
end

#offer_idString

The offer ID of the subscription line item being replaced, if applicable. Corresponds to the JSON property offerId

Returns:

  • (String)


4503
4504
4505
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4503

def offer_id
  @offer_id
end

#product_idString

The product ID of the subscription line item being replaced. Corresponds to the JSON property productId

Returns:

  • (String)


4508
4509
4510
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4508

def product_id
  @product_id
end

#replacement_modeString

The replacement mode applied during the purchase. Corresponds to the JSON property replacementMode

Returns:

  • (String)


4513
4514
4515
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4513

def replacement_mode
  @replacement_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4520
4521
4522
4523
4524
4525
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4520

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @product_id = args[:product_id] if args.key?(:product_id)
  @replacement_mode = args[:replacement_mode] if args.key?(:replacement_mode)
end