Class: Google::Apis::AndroidpublisherV3::LineItem
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::LineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details of a line item.
Instance Attribute Summary collapse
-
#listing_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#one_time_purchase_details ⇒ Google::Apis::AndroidpublisherV3::OneTimePurchaseDetails
Details of a one-time purchase.
-
#paid_app_details ⇒ Google::Apis::AndroidpublisherV3::PaidAppDetails
Details of a paid app purchase.
-
#product_id ⇒ String
The purchased product ID or in-app SKU (for example, 'monthly001' or 'com.some. thing.inapp1').
-
#product_title ⇒ String
Developer-specified name of the product.
-
#subscription_details ⇒ Google::Apis::AndroidpublisherV3::SubscriptionDetails
Details of a subscription purchase.
-
#tax ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#total ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LineItem
constructor
A new instance of LineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LineItem
Returns a new instance of LineItem.
5008 5009 5010 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5008 def initialize(**args) update!(**args) end |
Instance Attribute Details
#listing_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property listingPrice
4969 4970 4971 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4969 def listing_price @listing_price end |
#one_time_purchase_details ⇒ Google::Apis::AndroidpublisherV3::OneTimePurchaseDetails
Details of a one-time purchase.
Corresponds to the JSON property oneTimePurchaseDetails
4974 4975 4976 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4974 def one_time_purchase_details @one_time_purchase_details end |
#paid_app_details ⇒ Google::Apis::AndroidpublisherV3::PaidAppDetails
Details of a paid app purchase.
Corresponds to the JSON property paidAppDetails
4979 4980 4981 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4979 def paid_app_details @paid_app_details end |
#product_id ⇒ String
The purchased product ID or in-app SKU (for example, 'monthly001' or 'com.some.
thing.inapp1').
Corresponds to the JSON property productId
4985 4986 4987 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4985 def product_id @product_id end |
#product_title ⇒ String
Developer-specified name of the product. Displayed in buyer's locale. Example:
coins, monthly subscription, etc.
Corresponds to the JSON property productTitle
4991 4992 4993 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4991 def product_title @product_title end |
#subscription_details ⇒ Google::Apis::AndroidpublisherV3::SubscriptionDetails
Details of a subscription purchase.
Corresponds to the JSON property subscriptionDetails
4996 4997 4998 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4996 def subscription_details @subscription_details end |
#tax ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property tax
5001 5002 5003 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5001 def tax @tax end |
#total ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property total
5006 5007 5008 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5006 def total @total end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5013 def update!(**args) @listing_price = args[:listing_price] if args.key?(:listing_price) @one_time_purchase_details = args[:one_time_purchase_details] if args.key?(:one_time_purchase_details) @paid_app_details = args[:paid_app_details] if args.key?(:paid_app_details) @product_id = args[:product_id] if args.key?(:product_id) @product_title = args[:product_title] if args.key?(:product_title) @subscription_details = args[:subscription_details] if args.key?(:subscription_details) @tax = args[:tax] if args.key?(:tax) @total = args[:total] if args.key?(:total) end |