Class: Google::Apis::AndroidpublisherV3::LineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItem

Returns a new instance of LineItem.



4599
4600
4601
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#listing_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property listingPrice



4560
4561
4562
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4560

def listing_price
  @listing_price
end

#one_time_purchase_detailsGoogle::Apis::AndroidpublisherV3::OneTimePurchaseDetails

Details of a one-time purchase. Corresponds to the JSON property oneTimePurchaseDetails



4565
4566
4567
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4565

def one_time_purchase_details
  @one_time_purchase_details
end

Details of a paid app purchase. Corresponds to the JSON property paidAppDetails



4570
4571
4572
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4570

def paid_app_details
  @paid_app_details
end

#product_idString

The purchased product ID or in-app SKU (for example, 'monthly001' or 'com.some. thing.inapp1'). Corresponds to the JSON property productId

Returns:

  • (String)


4576
4577
4578
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4576

def product_id
  @product_id
end

#product_titleString

Developer-specified name of the product. Displayed in buyer's locale. Example: coins, monthly subscription, etc. Corresponds to the JSON property productTitle

Returns:

  • (String)


4582
4583
4584
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4582

def product_title
  @product_title
end

#subscription_detailsGoogle::Apis::AndroidpublisherV3::SubscriptionDetails

Details of a subscription purchase. Corresponds to the JSON property subscriptionDetails



4587
4588
4589
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4587

def subscription_details
  @subscription_details
end

#taxGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property tax



4592
4593
4594
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4592

def tax
  @tax
end

#totalGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property total



4597
4598
4599
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4597

def total
  @total
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4604

def update!(**args)
  @listing_price = args[:listing_price] if args.key?(:listing_price)
  @one_time_purchase_details = args[:one_time_purchase_details] if args.key?(:one_time_purchase_details)
  @paid_app_details = args[:paid_app_details] if args.key?(:paid_app_details)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_title = args[:product_title] if args.key?(:product_title)
  @subscription_details = args[:subscription_details] if args.key?(:subscription_details)
  @tax = args[:tax] if args.key?(:tax)
  @total = args[:total] if args.key?(:total)
end