Class: Google::Apis::AndroidpublisherV3::ListReleaseSummariesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ListReleaseSummariesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Response listing all releases for a given track that are either ready to be sent for review, in review, approved, not approved or available.
Instance Attribute Summary collapse
-
#releases ⇒ Array<Google::Apis::AndroidpublisherV3::ReleaseSummary>
List of releases for this track.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReleaseSummariesResponse
constructor
A new instance of ListReleaseSummariesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReleaseSummariesResponse
Returns a new instance of ListReleaseSummariesResponse.
4743 4744 4745 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#releases ⇒ Array<Google::Apis::AndroidpublisherV3::ReleaseSummary>
List of releases for this track. A maximum of 20 releases can be returned.
Corresponds to the JSON property releases
4741 4742 4743 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4741 def releases @releases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4748 4749 4750 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4748 def update!(**args) @releases = args[:releases] if args.key?(:releases) end |