Class: Google::Apis::AndroidpublisherV3::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A response containing one or more users with access to an account.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to pass to subsequent calls in order to retrieve subsequent results.
-
#users ⇒ Array<Google::Apis::AndroidpublisherV3::User>
The resulting users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
5730 5731 5732 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to pass to subsequent calls in order to retrieve subsequent results.
This will not be set if there are no more results to return.
Corresponds to the JSON property nextPageToken
5723 5724 5725 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5723 def next_page_token @next_page_token end |
#users ⇒ Array<Google::Apis::AndroidpublisherV3::User>
The resulting users.
Corresponds to the JSON property users
5728 5729 5730 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5728 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5735 5736 5737 5738 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5735 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @users = args[:users] if args.key?(:users) end |