Class: Google::Apis::AndroidpublisherV3::ListUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A response containing one or more users with access to an account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUsersResponse

Returns a new instance of ListUsersResponse.



4865
4866
4867
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to pass to subsequent calls in order to retrieve subsequent results. This will not be set if there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4858
4859
4860
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4858

def next_page_token
  @next_page_token
end

#usersArray<Google::Apis::AndroidpublisherV3::User>

The resulting users. Corresponds to the JSON property users



4863
4864
4865
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4863

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4870
4871
4872
4873
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4870

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @users = args[:users] if args.key?(:users)
end