Class: Google::Apis::AndroidpublisherV3::LocalizedStoreListing
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::LocalizedStoreListing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A localized store listings of the app.
Instance Attribute Summary collapse
-
#app_name ⇒ String
The name of the app in this localization.
-
#feature_graphic ⇒ Google::Apis::AndroidpublisherV3::ImageAsset
An image asset.
-
#full_description ⇒ String
A longer description of the app in this localization.
-
#icon ⇒ Google::Apis::AndroidpublisherV3::ImageAsset
An image asset.
-
#language_code ⇒ String
The BCP-47 language code for this localization.
-
#phone_screenshots ⇒ Google::Apis::AndroidpublisherV3::ScreenshotSet
A set of screenshots.
-
#short_description ⇒ String
A short description of the app in this localization.
-
#tablet_regular_screenshots ⇒ Google::Apis::AndroidpublisherV3::ScreenshotSet
A set of screenshots.
-
#tablet_small_screenshots ⇒ Google::Apis::AndroidpublisherV3::ScreenshotSet
A set of screenshots.
-
#video ⇒ Google::Apis::AndroidpublisherV3::VideoAsset
A video asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocalizedStoreListing
constructor
A new instance of LocalizedStoreListing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocalizedStoreListing
Returns a new instance of LocalizedStoreListing.
5864 5865 5866 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_name ⇒ String
The name of the app in this localization.
Corresponds to the JSON property appName
5817 5818 5819 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5817 def app_name @app_name end |
#feature_graphic ⇒ Google::Apis::AndroidpublisherV3::ImageAsset
An image asset.
Corresponds to the JSON property featureGraphic
5822 5823 5824 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5822 def feature_graphic @feature_graphic end |
#full_description ⇒ String
A longer description of the app in this localization.
Corresponds to the JSON property fullDescription
5827 5828 5829 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5827 def full_description @full_description end |
#icon ⇒ Google::Apis::AndroidpublisherV3::ImageAsset
An image asset.
Corresponds to the JSON property icon
5832 5833 5834 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5832 def icon @icon end |
#language_code ⇒ String
The BCP-47 language code for this localization.
Corresponds to the JSON property languageCode
5837 5838 5839 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5837 def language_code @language_code end |
#phone_screenshots ⇒ Google::Apis::AndroidpublisherV3::ScreenshotSet
A set of screenshots.
Corresponds to the JSON property phoneScreenshots
5842 5843 5844 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5842 def phone_screenshots @phone_screenshots end |
#short_description ⇒ String
A short description of the app in this localization.
Corresponds to the JSON property shortDescription
5847 5848 5849 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5847 def short_description @short_description end |
#tablet_regular_screenshots ⇒ Google::Apis::AndroidpublisherV3::ScreenshotSet
A set of screenshots.
Corresponds to the JSON property tabletRegularScreenshots
5852 5853 5854 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5852 def tablet_regular_screenshots @tablet_regular_screenshots end |
#tablet_small_screenshots ⇒ Google::Apis::AndroidpublisherV3::ScreenshotSet
A set of screenshots.
Corresponds to the JSON property tabletSmallScreenshots
5857 5858 5859 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5857 def tablet_small_screenshots @tablet_small_screenshots end |
#video ⇒ Google::Apis::AndroidpublisherV3::VideoAsset
A video asset.
Corresponds to the JSON property video
5862 5863 5864 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5862 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5869 def update!(**args) @app_name = args[:app_name] if args.key?(:app_name) @feature_graphic = args[:feature_graphic] if args.key?(:feature_graphic) @full_description = args[:full_description] if args.key?(:full_description) @icon = args[:icon] if args.key?(:icon) @language_code = args[:language_code] if args.key?(:language_code) @phone_screenshots = args[:phone_screenshots] if args.key?(:phone_screenshots) @short_description = args[:short_description] if args.key?(:short_description) @tablet_regular_screenshots = args[:tablet_regular_screenshots] if args.key?(:tablet_regular_screenshots) @tablet_small_screenshots = args[:tablet_small_screenshots] if args.key?(:tablet_small_screenshots) @video = args[:video] if args.key?(:video) end |