Class: Google::Apis::AndroidpublisherV3::LocalizedStoreListings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The localized store listings of an app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalizedStoreListings

Returns a new instance of LocalizedStoreListings.



5899
5900
5901
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_language_codeString

The default language code of the app. If a localized store listing is not available for a given language, assets from the default language are used instead. Corresponds to the JSON property defaultLanguageCode

Returns:

  • (String)


5892
5893
5894
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5892

def default_language_code
  @default_language_code
end

#localized_store_listingsArray<Google::Apis::AndroidpublisherV3::LocalizedStoreListing>

Corresponds to the JSON property localizedStoreListings



5897
5898
5899
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5897

def localized_store_listings
  @localized_store_listings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5904
5905
5906
5907
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5904

def update!(**args)
  @default_language_code = args[:default_language_code] if args.key?(:default_language_code)
  @localized_store_listings = args[:localized_store_listings] if args.key?(:localized_store_listings)
end