Class: Google::Apis::AndroidpublisherV3::ManagedProductTaxAndComplianceSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ManagedProductTaxAndComplianceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about taxation and legal compliance for managed products.
Instance Attribute Summary collapse
-
#eea_withdrawal_right_type ⇒ String
Digital content or service classification for products distributed to users in the European Economic Area (EEA).
-
#is_tokenized_digital_asset ⇒ Boolean
(also: #is_tokenized_digital_asset?)
Whether this in-app product is declared as a product representing a tokenized digital asset.
-
#product_tax_category_code ⇒ String
Product tax category code to assign to the in-app product.
-
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information.
-
#tax_rate_info_by_region_code ⇒ Hash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>
A mapping from region code to tax rate details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedProductTaxAndComplianceSettings
constructor
A new instance of ManagedProductTaxAndComplianceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedProductTaxAndComplianceSettings
Returns a new instance of ManagedProductTaxAndComplianceSettings.
5356 5357 5358 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eea_withdrawal_right_type ⇒ String
Digital content or service classification for products distributed to users in
the European Economic Area (EEA). The withdrawal regime under EEA consumer
laws depends on this classification. Refer to the Help Center article for more
information.
Corresponds to the JSON property eeaWithdrawalRightType
5327 5328 5329 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5327 def eea_withdrawal_right_type @eea_withdrawal_right_type end |
#is_tokenized_digital_asset ⇒ Boolean Also known as: is_tokenized_digital_asset?
Whether this in-app product is declared as a product representing a tokenized
digital asset.
Corresponds to the JSON property isTokenizedDigitalAsset
5333 5334 5335 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5333 def is_tokenized_digital_asset @is_tokenized_digital_asset end |
#product_tax_category_code ⇒ String
Product tax category code to assign to the in-app product. Product tax
category determines the transaction tax rates applied to the product. Refer to
the Help Center article for more information.
Corresponds to the JSON property productTaxCategoryCode
5342 5343 5344 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5342 def product_tax_category_code @product_tax_category_code end |
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information. Currently this field is only supported for
region code US.
Corresponds to the JSON property regionalProductAgeRatingInfos
5348 5349 5350 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5348 def @regional_product_age_rating_infos end |
#tax_rate_info_by_region_code ⇒ Hash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>
A mapping from region code to tax rate details. The keys are region codes as
defined by Unicode's "CLDR".
Corresponds to the JSON property taxRateInfoByRegionCode
5354 5355 5356 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5354 def tax_rate_info_by_region_code @tax_rate_info_by_region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5361 5362 5363 5364 5365 5366 5367 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5361 def update!(**args) @eea_withdrawal_right_type = args[:eea_withdrawal_right_type] if args.key?(:eea_withdrawal_right_type) @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset) @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code) @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos) @tax_rate_info_by_region_code = args[:tax_rate_info_by_region_code] if args.key?(:tax_rate_info_by_region_code) end |