Class: Google::Apis::AndroidpublisherV3::MigrateBasePlanPricesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::MigrateBasePlanPricesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for MigrateBasePlanPrices.
Instance Attribute Summary collapse
-
#base_plan_id ⇒ String
Required.
-
#latency_tolerance ⇒ String
Optional.
-
#package_name ⇒ String
Required.
-
#product_id ⇒ String
Required.
-
#regional_price_migrations ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalPriceMigrationConfig>
Required.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrateBasePlanPricesRequest
constructor
A new instance of MigrateBasePlanPricesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrateBasePlanPricesRequest
Returns a new instance of MigrateBasePlanPricesRequest.
4978 4979 4980 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_plan_id ⇒ String
Required. The unique base plan ID of the base plan to update prices on.
Corresponds to the JSON property basePlanId
4948 4949 4950 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4948 def base_plan_id @base_plan_id end |
#latency_tolerance ⇒ String
Optional. The latency tolerance for the propagation of this product update.
Defaults to latency-sensitive.
Corresponds to the JSON property latencyTolerance
4954 4955 4956 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4954 def latency_tolerance @latency_tolerance end |
#package_name ⇒ String
Required. Package name of the parent app. Must be equal to the package_name
field on the Subscription resource.
Corresponds to the JSON property packageName
4960 4961 4962 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4960 def package_name @package_name end |
#product_id ⇒ String
Required. The ID of the subscription to update. Must be equal to the
product_id field on the Subscription resource.
Corresponds to the JSON property productId
4966 4967 4968 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4966 def product_id @product_id end |
#regional_price_migrations ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalPriceMigrationConfig>
Required. The regional prices to update.
Corresponds to the JSON property regionalPriceMigrations
4971 4972 4973 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4971 def regional_price_migrations @regional_price_migrations end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
4976 4977 4978 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4976 def regions_version @regions_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4983 4984 4985 4986 4987 4988 4989 4990 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 4983 def update!(**args) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance) @package_name = args[:package_name] if args.key?(:package_name) @product_id = args[:product_id] if args.key?(:product_id) @regional_price_migrations = args[:regional_price_migrations] if args.key?(:regional_price_migrations) @regions_version = args[:regions_version] if args.key?(:regions_version) end |