Class: Google::Apis::AndroidpublisherV3::ModuleMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ModuleMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Metadata of a module.
Instance Attribute Summary collapse
-
#delivery_type ⇒ String
Indicates the delivery type (e.g. on-demand) of the module.
-
#dependencies ⇒ Array<String>
Names of the modules that this module directly depends on.
-
#module_type ⇒ String
Indicates the type of this feature module.
-
#name ⇒ String
Module name.
-
#targeting ⇒ Google::Apis::AndroidpublisherV3::ModuleTargeting
Targeting on the module level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ModuleMetadata
constructor
A new instance of ModuleMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ModuleMetadata
Returns a new instance of ModuleMetadata.
5036 5037 5038 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delivery_type ⇒ String
Indicates the delivery type (e.g. on-demand) of the module.
Corresponds to the JSON property deliveryType
5013 5014 5015 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5013 def delivery_type @delivery_type end |
#dependencies ⇒ Array<String>
Names of the modules that this module directly depends on. Each module
implicitly depends on the base module.
Corresponds to the JSON property dependencies
5019 5020 5021 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5019 def dependencies @dependencies end |
#module_type ⇒ String
Indicates the type of this feature module.
Corresponds to the JSON property moduleType
5024 5025 5026 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5024 def module_type @module_type end |
#name ⇒ String
Module name.
Corresponds to the JSON property name
5029 5030 5031 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5029 def name @name end |
#targeting ⇒ Google::Apis::AndroidpublisherV3::ModuleTargeting
Targeting on the module level.
Corresponds to the JSON property targeting
5034 5035 5036 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5034 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5041 5042 5043 5044 5045 5046 5047 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5041 def update!(**args) @delivery_type = args[:delivery_type] if args.key?(:delivery_type) @dependencies = args[:dependencies] if args.key?(:dependencies) @module_type = args[:module_type] if args.key?(:module_type) @name = args[:name] if args.key?(:name) @targeting = args[:targeting] if args.key?(:targeting) end |