Class: Google::Apis::AndroidpublisherV3::MultiAbiTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Targeting based on multiple abis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiAbiTargeting

Returns a new instance of MultiAbiTargeting.



5210
5211
5212
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::AndroidpublisherV3::MultiAbi>

Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits. Corresponds to the JSON property alternatives



5203
5204
5205
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5203

def alternatives
  @alternatives
end

#valueArray<Google::Apis::AndroidpublisherV3::MultiAbi>

Value of a multi abi. Corresponds to the JSON property value



5208
5209
5210
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5208

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5215
5216
5217
5218
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5215

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @value = args[:value] if args.key?(:value)
end