Class: Google::Apis::AndroidpublisherV3::OfferPhaseDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a pricing phase for the entitlement period funded by this order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OfferPhaseDetails

Returns a new instance of OfferPhaseDetails.



5262
5263
5264
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_detailsGoogle::Apis::AndroidpublisherV3::BaseDetails

Details of a base price pricing phase. Corresponds to the JSON property baseDetails



5238
5239
5240
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5238

def base_details
  @base_details
end

#free_trial_detailsGoogle::Apis::AndroidpublisherV3::FreeTrialDetails

Details of a free trial pricing phase. Corresponds to the JSON property freeTrialDetails



5243
5244
5245
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5243

def free_trial_details
  @free_trial_details
end

#introductory_price_detailsGoogle::Apis::AndroidpublisherV3::IntroductoryPriceDetails

Details of an introductory price pricing phase. Corresponds to the JSON property introductoryPriceDetails



5248
5249
5250
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5248

def introductory_price_details
  @introductory_price_details
end

#proration_period_detailsGoogle::Apis::AndroidpublisherV3::ProrationPeriodDetails

Details of a proration period. A proration period can be a period calculated during a plan change to cover existing entitlements (For more information, see Allow users to upgrade, downgrade, or change their subscription, or a prorated period to align add-on renewal dates with the base (For more information, see Rules applicable for items in the purchase). Corresponds to the JSON property prorationPeriodDetails



5260
5261
5262
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5260

def proration_period_details
  @proration_period_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5267
5268
5269
5270
5271
5272
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5267

def update!(**args)
  @base_details = args[:base_details] if args.key?(:base_details)
  @free_trial_details = args[:free_trial_details] if args.key?(:free_trial_details)
  @introductory_price_details = args[:introductory_price_details] if args.key?(:introductory_price_details)
  @proration_period_details = args[:proration_period_details] if args.key?(:proration_period_details)
end