Class: Google::Apis::AndroidpublisherV3::OneTimeProduct
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProduct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single one-time product for an app.
Instance Attribute Summary collapse
-
#listings ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductListing>
Required.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional.
-
#package_name ⇒ String
Required.
-
#product_id ⇒ String
Required.
-
#purchase_options ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption>
Required.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#restricted_payment_countries ⇒ Google::Apis::AndroidpublisherV3::RestrictedPaymentCountries
Countries where the purchase of this product is restricted to payment methods registered in the same country.
-
#tax_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductTaxAndComplianceSettings
Details about taxation, Google Play policy and legal compliance for one-time products.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProduct
constructor
A new instance of OneTimeProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProduct
Returns a new instance of OneTimeProduct.
5880 5881 5882 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#listings ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductListing>
Required. Set of localized title and description data. Must not have duplicate
entries with the same language_code.
Corresponds to the JSON property listings
5835 5836 5837 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5835 def listings @listings end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional. List of up to 20 custom tags specified for this one-time product,
and returned to the app through the billing library. Purchase options and
offers for this product will also receive these tags in the billing library.
Corresponds to the JSON property offerTags
5842 5843 5844 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5842 def @offer_tags end |
#package_name ⇒ String
Required. Immutable. Package name of the parent app.
Corresponds to the JSON property packageName
5847 5848 5849 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5847 def package_name @package_name end |
#product_id ⇒ String
Required. Immutable. Unique product ID of the product. Unique within the
parent app. Product IDs must start with a number or lowercase letter, and can
contain numbers (0-9), lowercase letters (a-z), underscores (_), and periods (.
).
Corresponds to the JSON property productId
5855 5856 5857 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5855 def product_id @product_id end |
#purchase_options ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption>
Required. The set of purchase options for this one-time product.
Corresponds to the JSON property purchaseOptions
5860 5861 5862 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5860 def @purchase_options end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
5865 5866 5867 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5865 def regions_version @regions_version end |
#restricted_payment_countries ⇒ Google::Apis::AndroidpublisherV3::RestrictedPaymentCountries
Countries where the purchase of this product is restricted to payment methods
registered in the same country. If empty, no payment location restrictions are
imposed.
Corresponds to the JSON property restrictedPaymentCountries
5872 5873 5874 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5872 def restricted_payment_countries @restricted_payment_countries end |
#tax_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductTaxAndComplianceSettings
Details about taxation, Google Play policy and legal compliance for one-time
products.
Corresponds to the JSON property taxAndComplianceSettings
5878 5879 5880 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5878 def tax_and_compliance_settings @tax_and_compliance_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5885 5886 5887 5888 5889 5890 5891 5892 5893 5894 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5885 def update!(**args) @listings = args[:listings] if args.key?(:listings) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @package_name = args[:package_name] if args.key?(:package_name) @product_id = args[:product_id] if args.key?(:product_id) @purchase_options = args[:purchase_options] if args.key?(:purchase_options) @regions_version = args[:regions_version] if args.key?(:regions_version) @restricted_payment_countries = args[:restricted_payment_countries] if args.key?(:restricted_payment_countries) @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings) end |