Class: Google::Apis::AndroidpublisherV3::OneTimeProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single one-time product for an app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProduct

Returns a new instance of OneTimeProduct.



5420
5421
5422
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#listingsArray<Google::Apis::AndroidpublisherV3::OneTimeProductListing>

Required. Set of localized title and description data. Must not have duplicate entries with the same language_code. Corresponds to the JSON property listings



5375
5376
5377
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5375

def listings
  @listings
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

Optional. List of up to 20 custom tags specified for this one-time product, and returned to the app through the billing library. Purchase options and offers for this product will also receive these tags in the billing library. Corresponds to the JSON property offerTags



5382
5383
5384
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5382

def offer_tags
  @offer_tags
end

#package_nameString

Required. Immutable. Package name of the parent app. Corresponds to the JSON property packageName

Returns:

  • (String)


5387
5388
5389
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5387

def package_name
  @package_name
end

#product_idString

Required. Immutable. Unique product ID of the product. Unique within the parent app. Product IDs must start with a number or lowercase letter, and can contain numbers (0-9), lowercase letters (a-z), underscores (_), and periods (. ). Corresponds to the JSON property productId

Returns:

  • (String)


5395
5396
5397
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5395

def product_id
  @product_id
end

#purchase_optionsArray<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption>

Required. The set of purchase options for this one-time product. Corresponds to the JSON property purchaseOptions



5400
5401
5402
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5400

def purchase_options
  @purchase_options
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



5405
5406
5407
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5405

def regions_version
  @regions_version
end

#restricted_payment_countriesGoogle::Apis::AndroidpublisherV3::RestrictedPaymentCountries

Countries where the purchase of this product is restricted to payment methods registered in the same country. If empty, no payment location restrictions are imposed. Corresponds to the JSON property restrictedPaymentCountries



5412
5413
5414
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5412

def restricted_payment_countries
  @restricted_payment_countries
end

#tax_and_compliance_settingsGoogle::Apis::AndroidpublisherV3::OneTimeProductTaxAndComplianceSettings

Details about taxation, Google Play policy and legal compliance for one-time products. Corresponds to the JSON property taxAndComplianceSettings



5418
5419
5420
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5418

def tax_and_compliance_settings
  @tax_and_compliance_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5425

def update!(**args)
  @listings = args[:listings] if args.key?(:listings)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @package_name = args[:package_name] if args.key?(:package_name)
  @product_id = args[:product_id] if args.key?(:product_id)
  @purchase_options = args[:purchase_options] if args.key?(:purchase_options)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @restricted_payment_countries = args[:restricted_payment_countries] if args.key?(:restricted_payment_countries)
  @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings)
end