Class: Google::Apis::AndroidpublisherV3::OneTimeProductBuyPurchaseOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A purchase option that can be bought.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductBuyPurchaseOption

Returns a new instance of OneTimeProductBuyPurchaseOption.



5417
5418
5419
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#legacy_compatibleBoolean Also known as: legacy_compatible?

Optional. Whether this purchase option will be available in legacy PBL flows that do not support one-time products model. Up to one "buy" purchase option can be marked as backwards compatible. Corresponds to the JSON property legacyCompatible

Returns:

  • (Boolean)


5407
5408
5409
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5407

def legacy_compatible
  @legacy_compatible
end

#multi_quantity_enabledBoolean Also known as: multi_quantity_enabled?

Optional. Whether this purchase option allows multi-quantity. Multi-quantity allows buyer to purchase more than one item in a single checkout. Corresponds to the JSON property multiQuantityEnabled

Returns:

  • (Boolean)


5414
5415
5416
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5414

def multi_quantity_enabled
  @multi_quantity_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5422
5423
5424
5425
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5422

def update!(**args)
  @legacy_compatible = args[:legacy_compatible] if args.key?(:legacy_compatible)
  @multi_quantity_enabled = args[:multi_quantity_enabled] if args.key?(:multi_quantity_enabled)
end