Class: Google::Apis::AndroidpublisherV3::OneTimeProductListing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Regional store listing for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductListing

Returns a new instance of OneTimeProductListing.



5521
5522
5523
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of this product in the language of this listing. The maximum length is 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


5508
5509
5510
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5508

def description
  @description
end

#language_codeString

Required. The language of this listing, as defined by BCP-47, e.g., "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


5513
5514
5515
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5513

def language_code
  @language_code
end

#titleString

Required. The title of this product in the language of this listing. The maximum length is 55 characters. Corresponds to the JSON property title

Returns:

  • (String)


5519
5520
5521
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5519

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5526
5527
5528
5529
5530
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5526

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @language_code = args[:language_code] if args.key?(:language_code)
  @title = args[:title] if args.key?(:title)
end