Class: Google::Apis::AndroidpublisherV3::OneTimeProductListing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Regional store listing for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductListing

Returns a new instance of OneTimeProductListing.



5482
5483
5484
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of this product in the language of this listing. The maximum length is 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


5469
5470
5471
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5469

def description
  @description
end

#language_codeString

Required. The language of this listing, as defined by BCP-47, e.g., "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


5474
5475
5476
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5474

def language_code
  @language_code
end

#titleString

Required. The title of this product in the language of this listing. The maximum length is 55 characters. Corresponds to the JSON property title

Returns:

  • (String)


5480
5481
5482
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5480

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5487
5488
5489
5490
5491
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5487

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @language_code = args[:language_code] if args.key?(:language_code)
  @title = args[:title] if args.key?(:title)
end