Class: Google::Apis::AndroidpublisherV3::OneTimeProductOffer
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single offer for a one-time product.
Instance Attribute Summary collapse
-
#discounted_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer
Configuration specific to discounted offers.
-
#offer_id ⇒ String
Required.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional.
-
#package_name ⇒ String
Required.
-
#pre_order_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer
Configuration specific to pre-order offers.
-
#product_id ⇒ String
Required.
-
#purchase_option_id ⇒ String
Required.
-
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>
Set of regional pricing and availability information for this offer.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductOffer
constructor
A new instance of OneTimeProductOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductOffer
Returns a new instance of OneTimeProductOffer.
6674 6675 6676 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discounted_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer
Configuration specific to discounted offers.
Corresponds to the JSON property discountedOffer
6620 6621 6622 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6620 def discounted_offer @discounted_offer end |
#offer_id ⇒ String
Required. Immutable. The ID of this product offer. Must be unique within the
purchase option. It must start with a number or lower-case letter, and can
only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The
maximum length is 63 characters.
Corresponds to the JSON property offerId
6628 6629 6630 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6628 def offer_id @offer_id end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional. List of up to 20 custom tags specified for this offer, and returned
to the app through the billing library.
Corresponds to the JSON property offerTags
6634 6635 6636 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6634 def @offer_tags end |
#package_name ⇒ String
Required. Immutable. The package name of the app the parent product belongs to.
Corresponds to the JSON property packageName
6639 6640 6641 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6639 def package_name @package_name end |
#pre_order_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer
Configuration specific to pre-order offers.
Corresponds to the JSON property preOrderOffer
6644 6645 6646 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6644 def pre_order_offer @pre_order_offer end |
#product_id ⇒ String
Required. Immutable. The ID of the parent product this offer belongs to.
Corresponds to the JSON property productId
6649 6650 6651 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6649 def product_id @product_id end |
#purchase_option_id ⇒ String
Required. Immutable. The ID of the purchase option to which this offer is an
extension.
Corresponds to the JSON property purchaseOptionId
6655 6656 6657 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6655 def purchase_option_id @purchase_option_id end |
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>
Set of regional pricing and availability information for this offer. Must not
have duplicate entries with the same region_code.
Corresponds to the JSON property regionalPricingAndAvailabilityConfigs
6661 6662 6663 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6661 def regional_pricing_and_availability_configs @regional_pricing_and_availability_configs end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
6666 6667 6668 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6666 def regions_version @regions_version end |
#state ⇒ String
Output only. The current state of this offer. This field cannot be changed by
updating the resource. Use the dedicated endpoints instead.
Corresponds to the JSON property state
6672 6673 6674 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6672 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6679 def update!(**args) @discounted_offer = args[:discounted_offer] if args.key?(:discounted_offer) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @package_name = args[:package_name] if args.key?(:package_name) @pre_order_offer = args[:pre_order_offer] if args.key?(:pre_order_offer) @product_id = args[:product_id] if args.key?(:product_id) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs) @regions_version = args[:regions_version] if args.key?(:regions_version) @state = args[:state] if args.key?(:state) end |