Class: Google::Apis::AndroidpublisherV3::OneTimeProductOffer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single offer for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductOffer

Returns a new instance of OneTimeProductOffer.



5614
5615
5616
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discounted_offerGoogle::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer

Configuration specific to discounted offers. Corresponds to the JSON property discountedOffer



5560
5561
5562
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5560

def discounted_offer
  @discounted_offer
end

#offer_idString

Required. Immutable. The ID of this product offer. Must be unique within the purchase option. It must start with a number or lower-case letter, and can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The maximum length is 63 characters. Corresponds to the JSON property offerId

Returns:

  • (String)


5568
5569
5570
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5568

def offer_id
  @offer_id
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

Optional. List of up to 20 custom tags specified for this offer, and returned to the app through the billing library. Corresponds to the JSON property offerTags



5574
5575
5576
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5574

def offer_tags
  @offer_tags
end

#package_nameString

Required. Immutable. The package name of the app the parent product belongs to. Corresponds to the JSON property packageName

Returns:

  • (String)


5579
5580
5581
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5579

def package_name
  @package_name
end

#pre_order_offerGoogle::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer

Configuration specific to pre-order offers. Corresponds to the JSON property preOrderOffer



5584
5585
5586
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5584

def pre_order_offer
  @pre_order_offer
end

#product_idString

Required. Immutable. The ID of the parent product this offer belongs to. Corresponds to the JSON property productId

Returns:

  • (String)


5589
5590
5591
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5589

def product_id
  @product_id
end

#purchase_option_idString

Required. Immutable. The ID of the purchase option to which this offer is an extension. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


5595
5596
5597
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5595

def purchase_option_id
  @purchase_option_id
end

#regional_pricing_and_availability_configsArray<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>

Set of regional pricing and availability information for this offer. Must not have duplicate entries with the same region_code. Corresponds to the JSON property regionalPricingAndAvailabilityConfigs



5601
5602
5603
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5601

def regional_pricing_and_availability_configs
  @regional_pricing_and_availability_configs
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



5606
5607
5608
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5606

def regions_version
  @regions_version
end

#stateString

Output only. The current state of this offer. This field cannot be changed by updating the resource. Use the dedicated endpoints instead. Corresponds to the JSON property state

Returns:

  • (String)


5612
5613
5614
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5612

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5619

def update!(**args)
  @discounted_offer = args[:discounted_offer] if args.key?(:discounted_offer)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @package_name = args[:package_name] if args.key?(:package_name)
  @pre_order_offer = args[:pre_order_offer] if args.key?(:pre_order_offer)
  @product_id = args[:product_id] if args.key?(:product_id)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @state = args[:state] if args.key?(:state)
end