Class: Google::Apis::AndroidpublisherV3::OneTimeProductOffer
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single offer for a one-time product.
Instance Attribute Summary collapse
-
#discounted_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer
Configuration specific to discounted offers.
-
#offer_id ⇒ String
Required.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional.
-
#package_name ⇒ String
Required.
-
#pre_order_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer
Configuration specific to pre-order offers.
-
#product_id ⇒ String
Required.
-
#purchase_option_id ⇒ String
Required.
-
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>
Set of regional pricing and availability information for this offer.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductOffer
constructor
A new instance of OneTimeProductOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductOffer
Returns a new instance of OneTimeProductOffer.
5594 5595 5596 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discounted_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer
Configuration specific to discounted offers.
Corresponds to the JSON property discountedOffer
5540 5541 5542 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5540 def discounted_offer @discounted_offer end |
#offer_id ⇒ String
Required. Immutable. The ID of this product offer. Must be unique within the
purchase option. It must start with a number or lower-case letter, and can
only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The
maximum length is 63 characters.
Corresponds to the JSON property offerId
5548 5549 5550 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5548 def offer_id @offer_id end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional. List of up to 20 custom tags specified for this offer, and returned
to the app through the billing library.
Corresponds to the JSON property offerTags
5554 5555 5556 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5554 def @offer_tags end |
#package_name ⇒ String
Required. Immutable. The package name of the app the parent product belongs to.
Corresponds to the JSON property packageName
5559 5560 5561 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5559 def package_name @package_name end |
#pre_order_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer
Configuration specific to pre-order offers.
Corresponds to the JSON property preOrderOffer
5564 5565 5566 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5564 def pre_order_offer @pre_order_offer end |
#product_id ⇒ String
Required. Immutable. The ID of the parent product this offer belongs to.
Corresponds to the JSON property productId
5569 5570 5571 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5569 def product_id @product_id end |
#purchase_option_id ⇒ String
Required. Immutable. The ID of the purchase option to which this offer is an
extension.
Corresponds to the JSON property purchaseOptionId
5575 5576 5577 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5575 def purchase_option_id @purchase_option_id end |
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>
Set of regional pricing and availability information for this offer. Must not
have duplicate entries with the same region_code.
Corresponds to the JSON property regionalPricingAndAvailabilityConfigs
5581 5582 5583 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5581 def regional_pricing_and_availability_configs @regional_pricing_and_availability_configs end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
5586 5587 5588 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5586 def regions_version @regions_version end |
#state ⇒ String
Output only. The current state of this offer. This field cannot be changed by
updating the resource. Use the dedicated endpoints instead.
Corresponds to the JSON property state
5592 5593 5594 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5592 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5599 5600 5601 5602 5603 5604 5605 5606 5607 5608 5609 5610 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5599 def update!(**args) @discounted_offer = args[:discounted_offer] if args.key?(:discounted_offer) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @package_name = args[:package_name] if args.key?(:package_name) @pre_order_offer = args[:pre_order_offer] if args.key?(:pre_order_offer) @product_id = args[:product_id] if args.key?(:product_id) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs) @regions_version = args[:regions_version] if args.key?(:regions_version) @state = args[:state] if args.key?(:state) end |