Class: Google::Apis::AndroidpublisherV3::OneTimeProductOffer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single offer for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductOffer

Returns a new instance of OneTimeProductOffer.



5555
5556
5557
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discounted_offerGoogle::Apis::AndroidpublisherV3::OneTimeProductDiscountedOffer

Configuration specific to discounted offers. Corresponds to the JSON property discountedOffer



5501
5502
5503
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5501

def discounted_offer
  @discounted_offer
end

#offer_idString

Required. Immutable. The ID of this product offer. Must be unique within the purchase option. It must start with a number or lower-case letter, and can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The maximum length is 63 characters. Corresponds to the JSON property offerId

Returns:

  • (String)


5509
5510
5511
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5509

def offer_id
  @offer_id
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

Optional. List of up to 20 custom tags specified for this offer, and returned to the app through the billing library. Corresponds to the JSON property offerTags



5515
5516
5517
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5515

def offer_tags
  @offer_tags
end

#package_nameString

Required. Immutable. The package name of the app the parent product belongs to. Corresponds to the JSON property packageName

Returns:

  • (String)


5520
5521
5522
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5520

def package_name
  @package_name
end

#pre_order_offerGoogle::Apis::AndroidpublisherV3::OneTimeProductPreOrderOffer

Configuration specific to pre-order offers. Corresponds to the JSON property preOrderOffer



5525
5526
5527
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5525

def pre_order_offer
  @pre_order_offer
end

#product_idString

Required. Immutable. The ID of the parent product this offer belongs to. Corresponds to the JSON property productId

Returns:

  • (String)


5530
5531
5532
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5530

def product_id
  @product_id
end

#purchase_option_idString

Required. Immutable. The ID of the purchase option to which this offer is an extension. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


5536
5537
5538
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5536

def purchase_option_id
  @purchase_option_id
end

#regional_pricing_and_availability_configsArray<Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig>

Set of regional pricing and availability information for this offer. Must not have duplicate entries with the same region_code. Corresponds to the JSON property regionalPricingAndAvailabilityConfigs



5542
5543
5544
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5542

def regional_pricing_and_availability_configs
  @regional_pricing_and_availability_configs
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



5547
5548
5549
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5547

def regions_version
  @regions_version
end

#stateString

Output only. The current state of this offer. This field cannot be changed by updating the resource. Use the dedicated endpoints instead. Corresponds to the JSON property state

Returns:

  • (String)


5553
5554
5555
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5553

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5560
5561
5562
5563
5564
5565
5566
5567
5568
5569
5570
5571
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5560

def update!(**args)
  @discounted_offer = args[:discounted_offer] if args.key?(:discounted_offer)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @package_name = args[:package_name] if args.key?(:package_name)
  @pre_order_offer = args[:pre_order_offer] if args.key?(:pre_order_offer)
  @product_id = args[:product_id] if args.key?(:product_id)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @state = args[:state] if args.key?(:state)
end