Class: Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Regional pricing and availability configuration for a one-time product offer.
Instance Attribute Summary collapse
-
#absolute_discount ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#availability ⇒ String
Required.
-
#no_override ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductOfferNoPriceOverrideOptions
Options for one-time product offers without a regional price override.
-
#region_code ⇒ String
Required.
-
#relative_discount ⇒ Float
The fraction of the purchase option price that the user pays for this offer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductOfferRegionalPricingAndAvailabilityConfig
constructor
A new instance of OneTimeProductOfferRegionalPricingAndAvailabilityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductOfferRegionalPricingAndAvailabilityConfig
Returns a new instance of OneTimeProductOfferRegionalPricingAndAvailabilityConfig.
6742 6743 6744 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#absolute_discount ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property absoluteDiscount
6713 6714 6715 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6713 def absolute_discount @absolute_discount end |
#availability ⇒ String
Required. The availability for this region.
Corresponds to the JSON property availability
6718 6719 6720 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6718 def availability @availability end |
#no_override ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductOfferNoPriceOverrideOptions
Options for one-time product offers without a regional price override.
Corresponds to the JSON property noOverride
6723 6724 6725 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6723 def no_override @no_override end |
#region_code ⇒ String
Required. Region code this configuration applies to, as defined by ISO 3166-2,
e.g., "US".
Corresponds to the JSON property regionCode
6729 6730 6731 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6729 def region_code @region_code end |
#relative_discount ⇒ Float
The fraction of the purchase option price that the user pays for this offer.
For example, if the purchase option price for this region is $12, then a 50%
discount would correspond to a price of $6. The discount must be specified as
a fraction strictly larger than 0 and strictly smaller than 1. The resulting
price will be rounded to the nearest billable unit (e.g. cents for USD). The
relative discount is considered invalid if the discounted price ends up being
smaller than the minimum price allowed in this region.
Corresponds to the JSON property relativeDiscount
6740 6741 6742 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6740 def relative_discount @relative_discount end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6747 6748 6749 6750 6751 6752 6753 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6747 def update!(**args) @absolute_discount = args[:absolute_discount] if args.key?(:absolute_discount) @availability = args[:availability] if args.key?(:availability) @no_override = args[:no_override] if args.key?(:no_override) @region_code = args[:region_code] if args.key?(:region_code) @relative_discount = args[:relative_discount] if args.key?(:relative_discount) end |