Class: Google::Apis::AndroidpublisherV3::OneTimeProductOfferRegionalPricingAndAvailabilityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Regional pricing and availability configuration for a one-time product offer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductOfferRegionalPricingAndAvailabilityConfig

Returns a new instance of OneTimeProductOfferRegionalPricingAndAvailabilityConfig.



5662
5663
5664
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_discountGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property absoluteDiscount



5633
5634
5635
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5633

def absolute_discount
  @absolute_discount
end

#availabilityString

Required. The availability for this region. Corresponds to the JSON property availability

Returns:

  • (String)


5638
5639
5640
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5638

def availability
  @availability
end

#no_overrideGoogle::Apis::AndroidpublisherV3::OneTimeProductOfferNoPriceOverrideOptions

Options for one-time product offers without a regional price override. Corresponds to the JSON property noOverride



5643
5644
5645
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5643

def no_override
  @no_override
end

#region_codeString

Required. Region code this configuration applies to, as defined by ISO 3166-2, e.g., "US". Corresponds to the JSON property regionCode

Returns:

  • (String)


5649
5650
5651
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5649

def region_code
  @region_code
end

#relative_discountFloat

The fraction of the purchase option price that the user pays for this offer. For example, if the purchase option price for this region is $12, then a 50% discount would correspond to a price of $6. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in this region. Corresponds to the JSON property relativeDiscount

Returns:

  • (Float)


5660
5661
5662
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5660

def relative_discount
  @relative_discount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5667
5668
5669
5670
5671
5672
5673
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5667

def update!(**args)
  @absolute_discount = args[:absolute_discount] if args.key?(:absolute_discount)
  @availability = args[:availability] if args.key?(:availability)
  @no_override = args[:no_override] if args.key?(:no_override)
  @region_code = args[:region_code] if args.key?(:region_code)
  @relative_discount = args[:relative_discount] if args.key?(:relative_discount)
end