Class: Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single purchase option for a one-time product.
Instance Attribute Summary collapse
-
#buy_option ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductBuyPurchaseOption
A purchase option that can be bought.
-
#new_regions_config ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig
Pricing information for any new regions Play may launch in the future.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional.
-
#purchase_option_id ⇒ String
Required.
-
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>
Regional pricing and availability information for this purchase option.
-
#rent_option ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption
A purchase option that can be rented.
-
#state ⇒ String
Output only.
-
#tax_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::PurchaseOptionTaxAndComplianceSettings
Details about taxation, Google Play policy and legal compliance for one-time product purchase options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductPurchaseOption
constructor
A new instance of OneTimeProductPurchaseOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductPurchaseOption
Returns a new instance of OneTimeProductPurchaseOption.
6847 6848 6849 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buy_option ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductBuyPurchaseOption
A purchase option that can be bought.
Corresponds to the JSON property buyOption
6802 6803 6804 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6802 def buy_option @buy_option end |
#new_regions_config ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig
Pricing information for any new regions Play may launch in the future.
Corresponds to the JSON property newRegionsConfig
6807 6808 6809 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6807 def new_regions_config @new_regions_config end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
Optional. List of up to 20 custom tags specified for this purchase option, and
returned to the app through the billing library. Offers for this purchase
option will also receive these tags in the billing library.
Corresponds to the JSON property offerTags
6814 6815 6816 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6814 def @offer_tags end |
#purchase_option_id ⇒ String
Required. Immutable. The unique identifier of this purchase option. Must be
unique within the one-time product. It must start with a number or lower-case
letter, and can only contain lower-case letters (a-z), numbers (0-9), and
hyphens (-). The maximum length is 63 characters.
Corresponds to the JSON property purchaseOptionId
6822 6823 6824 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6822 def purchase_option_id @purchase_option_id end |
#regional_pricing_and_availability_configs ⇒ Array<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>
Regional pricing and availability information for this purchase option.
Corresponds to the JSON property regionalPricingAndAvailabilityConfigs
6827 6828 6829 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6827 def regional_pricing_and_availability_configs @regional_pricing_and_availability_configs end |
#rent_option ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption
A purchase option that can be rented.
Corresponds to the JSON property rentOption
6832 6833 6834 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6832 def rent_option @rent_option end |
#state ⇒ String
Output only. The state of the purchase option, i.e., whether it's active. This
field cannot be changed by updating the resource. Use the dedicated endpoints
instead.
Corresponds to the JSON property state
6839 6840 6841 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6839 def state @state end |
#tax_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::PurchaseOptionTaxAndComplianceSettings
Details about taxation, Google Play policy and legal compliance for one-time
product purchase options.
Corresponds to the JSON property taxAndComplianceSettings
6845 6846 6847 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6845 def tax_and_compliance_settings @tax_and_compliance_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6852 def update!(**args) @buy_option = args[:buy_option] if args.key?(:buy_option) @new_regions_config = args[:new_regions_config] if args.key?(:new_regions_config) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs) @rent_option = args[:rent_option] if args.key?(:rent_option) @state = args[:state] if args.key?(:state) @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings) end |