Class: Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single purchase option for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductPurchaseOption

Returns a new instance of OneTimeProductPurchaseOption.



6227
6228
6229
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buy_optionGoogle::Apis::AndroidpublisherV3::OneTimeProductBuyPurchaseOption

A purchase option that can be bought. Corresponds to the JSON property buyOption



6182
6183
6184
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6182

def buy_option
  @buy_option
end

#new_regions_configGoogle::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig

Pricing information for any new regions Play may launch in the future. Corresponds to the JSON property newRegionsConfig



6187
6188
6189
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6187

def new_regions_config
  @new_regions_config
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

Optional. List of up to 20 custom tags specified for this purchase option, and returned to the app through the billing library. Offers for this purchase option will also receive these tags in the billing library. Corresponds to the JSON property offerTags



6194
6195
6196
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6194

def offer_tags
  @offer_tags
end

#purchase_option_idString

Required. Immutable. The unique identifier of this purchase option. Must be unique within the one-time product. It must start with a number or lower-case letter, and can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The maximum length is 63 characters. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


6202
6203
6204
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6202

def purchase_option_id
  @purchase_option_id
end

#regional_pricing_and_availability_configsArray<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>

Regional pricing and availability information for this purchase option. Corresponds to the JSON property regionalPricingAndAvailabilityConfigs



6207
6208
6209
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6207

def regional_pricing_and_availability_configs
  @regional_pricing_and_availability_configs
end

#rent_optionGoogle::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption

A purchase option that can be rented. Corresponds to the JSON property rentOption



6212
6213
6214
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6212

def rent_option
  @rent_option
end

#stateString

Output only. The state of the purchase option, i.e., whether it's active. This field cannot be changed by updating the resource. Use the dedicated endpoints instead. Corresponds to the JSON property state

Returns:

  • (String)


6219
6220
6221
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6219

def state
  @state
end

#tax_and_compliance_settingsGoogle::Apis::AndroidpublisherV3::PurchaseOptionTaxAndComplianceSettings

Details about taxation, Google Play policy and legal compliance for one-time product purchase options. Corresponds to the JSON property taxAndComplianceSettings



6225
6226
6227
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6225

def tax_and_compliance_settings
  @tax_and_compliance_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6232

def update!(**args)
  @buy_option = args[:buy_option] if args.key?(:buy_option)
  @new_regions_config = args[:new_regions_config] if args.key?(:new_regions_config)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs)
  @rent_option = args[:rent_option] if args.key?(:rent_option)
  @state = args[:state] if args.key?(:state)
  @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings)
end