Class: Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single purchase option for a one-time product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductPurchaseOption

Returns a new instance of OneTimeProductPurchaseOption.



5831
5832
5833
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buy_optionGoogle::Apis::AndroidpublisherV3::OneTimeProductBuyPurchaseOption

A purchase option that can be bought. Corresponds to the JSON property buyOption



5786
5787
5788
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5786

def buy_option
  @buy_option
end

#new_regions_configGoogle::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig

Pricing information for any new regions Play may launch in the future. Corresponds to the JSON property newRegionsConfig



5791
5792
5793
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5791

def new_regions_config
  @new_regions_config
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

Optional. List of up to 20 custom tags specified for this purchase option, and returned to the app through the billing library. Offers for this purchase option will also receive these tags in the billing library. Corresponds to the JSON property offerTags



5798
5799
5800
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5798

def offer_tags
  @offer_tags
end

#purchase_option_idString

Required. Immutable. The unique identifier of this purchase option. Must be unique within the one-time product. It must start with a number or lower-case letter, and can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The maximum length is 63 characters. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


5806
5807
5808
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5806

def purchase_option_id
  @purchase_option_id
end

#regional_pricing_and_availability_configsArray<Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>

Regional pricing and availability information for this purchase option. Corresponds to the JSON property regionalPricingAndAvailabilityConfigs



5811
5812
5813
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5811

def regional_pricing_and_availability_configs
  @regional_pricing_and_availability_configs
end

#rent_optionGoogle::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption

A purchase option that can be rented. Corresponds to the JSON property rentOption



5816
5817
5818
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5816

def rent_option
  @rent_option
end

#stateString

Output only. The state of the purchase option, i.e., whether it's active. This field cannot be changed by updating the resource. Use the dedicated endpoints instead. Corresponds to the JSON property state

Returns:

  • (String)


5823
5824
5825
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5823

def state
  @state
end

#tax_and_compliance_settingsGoogle::Apis::AndroidpublisherV3::PurchaseOptionTaxAndComplianceSettings

Details about taxation, Google Play policy and legal compliance for one-time product purchase options. Corresponds to the JSON property taxAndComplianceSettings



5829
5830
5831
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5829

def tax_and_compliance_settings
  @tax_and_compliance_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5836

def update!(**args)
  @buy_option = args[:buy_option] if args.key?(:buy_option)
  @new_regions_config = args[:new_regions_config] if args.key?(:new_regions_config)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @regional_pricing_and_availability_configs = args[:regional_pricing_and_availability_configs] if args.key?(:regional_pricing_and_availability_configs)
  @rent_option = args[:rent_option] if args.key?(:rent_option)
  @state = args[:state] if args.key?(:state)
  @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings)
end