Class: Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Pricing information for any new regions Play may launch in the future.
Instance Attribute Summary collapse
-
#availability ⇒ String
Required.
-
#eur_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#usd_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductPurchaseOptionNewRegionsConfig
constructor
A new instance of OneTimeProductPurchaseOptionNewRegionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductPurchaseOptionNewRegionsConfig
Returns a new instance of OneTimeProductPurchaseOptionNewRegionsConfig.
5869 5870 5871 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability ⇒ String
Required. The regional availability for the new regions config. When set to
AVAILABLE, the pricing information will be used for any new regions Play may
launch in the future.
Corresponds to the JSON property availability
5857 5858 5859 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5857 def availability @availability end |
#eur_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property eurPrice
5862 5863 5864 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5862 def eur_price @eur_price end |
#usd_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property usdPrice
5867 5868 5869 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5867 def usd_price @usd_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5874 5875 5876 5877 5878 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5874 def update!(**args) @availability = args[:availability] if args.key?(:availability) @eur_price = args[:eur_price] if args.key?(:eur_price) @usd_price = args[:usd_price] if args.key?(:usd_price) end |