Class: Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Pricing information for any new regions Play may launch in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductPurchaseOptionNewRegionsConfig

Returns a new instance of OneTimeProductPurchaseOptionNewRegionsConfig.



5863
5864
5865
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilityString

Required. The regional availability for the new regions config. When set to AVAILABLE, the pricing information will be used for any new regions Play may launch in the future. Corresponds to the JSON property availability

Returns:

  • (String)


5851
5852
5853
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5851

def availability
  @availability
end

#eur_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property eurPrice



5856
5857
5858
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5856

def eur_price
  @eur_price
end

#usd_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property usdPrice



5861
5862
5863
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5861

def usd_price
  @usd_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5868
5869
5870
5871
5872
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5868

def update!(**args)
  @availability = args[:availability] if args.key?(:availability)
  @eur_price = args[:eur_price] if args.key?(:eur_price)
  @usd_price = args[:usd_price] if args.key?(:usd_price)
end