Class: Google::Apis::AndroidpublisherV3::OneTimeProductPurchaseOptionNewRegionsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Pricing information for any new regions Play may launch in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductPurchaseOptionNewRegionsConfig

Returns a new instance of OneTimeProductPurchaseOptionNewRegionsConfig.



5766
5767
5768
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilityString

Required. The regional availability for the new regions config. When set to AVAILABLE, the pricing information will be used for any new regions Play may launch in the future. Corresponds to the JSON property availability

Returns:

  • (String)


5754
5755
5756
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5754

def availability
  @availability
end

#eur_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property eurPrice



5759
5760
5761
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5759

def eur_price
  @eur_price
end

#usd_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property usdPrice



5764
5765
5766
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5764

def usd_price
  @usd_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5771
5772
5773
5774
5775
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5771

def update!(**args)
  @availability = args[:availability] if args.key?(:availability)
  @eur_price = args[:eur_price] if args.key?(:eur_price)
  @usd_price = args[:usd_price] if args.key?(:usd_price)
end