Class: Google::Apis::AndroidpublisherV3::OneTimeProductRentPurchaseOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A purchase option that can be rented.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimeProductRentPurchaseOption

Returns a new instance of OneTimeProductRentPurchaseOption.



5885
5886
5887
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expiration_periodString

Optional. The amount of time the user has after starting consuming the entitlement before it is revoked. Specified in ISO 8601 format. Corresponds to the JSON property expirationPeriod

Returns:

  • (String)


5877
5878
5879
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5877

def expiration_period
  @expiration_period
end

#rental_periodString

Required. The amount of time a user has the entitlement for. Starts at purchase flow completion. Specified in ISO 8601 format. Corresponds to the JSON property rentalPeriod

Returns:

  • (String)


5883
5884
5885
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5883

def rental_period
  @rental_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5890
5891
5892
5893
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5890

def update!(**args)
  @expiration_period = args[:expiration_period] if args.key?(:expiration_period)
  @rental_period = args[:rental_period] if args.key?(:rental_period)
end