Class: Google::Apis::AndroidpublisherV3::OneTimeProductTaxAndComplianceSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OneTimeProductTaxAndComplianceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about taxation, Google Play policy and legal compliance for one-time products.
Instance Attribute Summary collapse
-
#is_tokenized_digital_asset ⇒ Boolean
(also: #is_tokenized_digital_asset?)
Whether this one-time product is declared as a product representing a tokenized digital asset.
-
#product_tax_category_code ⇒ String
Product tax category code to assign to the one-time product.
-
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information.
-
#regional_tax_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalTaxConfig>
Regional tax configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeProductTaxAndComplianceSettings
constructor
A new instance of OneTimeProductTaxAndComplianceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeProductTaxAndComplianceSettings
Returns a new instance of OneTimeProductTaxAndComplianceSettings.
5907 5908 5909 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_tokenized_digital_asset ⇒ Boolean Also known as: is_tokenized_digital_asset?
Whether this one-time product is declared as a product representing a
tokenized digital asset.
Corresponds to the JSON property isTokenizedDigitalAsset
5885 5886 5887 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5885 def is_tokenized_digital_asset @is_tokenized_digital_asset end |
#product_tax_category_code ⇒ String
Product tax category code to assign to the one-time product. Product tax
category determines the transaction tax rates applied to the product. Refer to
the Help Center article for more information.
Corresponds to the JSON property productTaxCategoryCode
5894 5895 5896 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5894 def product_tax_category_code @product_tax_category_code end |
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information. Currently this field is only supported for
region code US.
Corresponds to the JSON property regionalProductAgeRatingInfos
5900 5901 5902 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5900 def @regional_product_age_rating_infos end |
#regional_tax_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalTaxConfig>
Regional tax configuration.
Corresponds to the JSON property regionalTaxConfigs
5905 5906 5907 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5905 def regional_tax_configs @regional_tax_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5912 5913 5914 5915 5916 5917 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5912 def update!(**args) @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset) @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code) @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos) @regional_tax_configs = args[:regional_tax_configs] if args.key?(:regional_tax_configs) end |