Class: Google::Apis::AndroidpublisherV3::OneTimePurchaseDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a one-time purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OneTimePurchaseDetails

Returns a new instance of OneTimePurchaseDetails.



5952
5953
5954
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#offer_idString

The offer ID of the one-time purchase offer. Corresponds to the JSON property offerId

Returns:

  • (String)


5927
5928
5929
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5927

def offer_id
  @offer_id
end

#preorder_detailsGoogle::Apis::AndroidpublisherV3::PreorderDetails

Details of a pre-order purchase. Corresponds to the JSON property preorderDetails



5932
5933
5934
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5932

def preorder_details
  @preorder_details
end

#purchase_option_idString

ID of the purchase option. This field is set for both purchase options and variant offers. For purchase options, this ID identifies the purchase option itself. For variant offers, this ID refers to the associated purchase option, and in conjunction with offer_id it identifies the variant offer. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


5940
5941
5942
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5940

def purchase_option_id
  @purchase_option_id
end

#quantityFixnum

The number of items purchased (for multi-quantity item purchases). Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


5945
5946
5947
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5945

def quantity
  @quantity
end

#rental_detailsGoogle::Apis::AndroidpublisherV3::RentalDetails

Details of a rental purchase. Corresponds to the JSON property rentalDetails



5950
5951
5952
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5950

def rental_details
  @rental_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5957
5958
5959
5960
5961
5962
5963
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 5957

def update!(**args)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @preorder_details = args[:preorder_details] if args.key?(:preorder_details)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @quantity = args[:quantity] if args.key?(:quantity)
  @rental_details = args[:rental_details] if args.key?(:rental_details)
end