Class: Google::Apis::AndroidpublisherV3::OrderHistory
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OrderHistory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about events which modified the order.
Instance Attribute Summary collapse
-
#cancellation_event ⇒ Google::Apis::AndroidpublisherV3::CancellationEvent
Details of when the order was canceled.
-
#partial_refund_events ⇒ Array<Google::Apis::AndroidpublisherV3::PartialRefundEvent>
Details of the partial refund events for this order.
-
#processed_event ⇒ Google::Apis::AndroidpublisherV3::ProcessedEvent
Details of when the order was processed.
-
#refund_event ⇒ Google::Apis::AndroidpublisherV3::RefundEvent
Details of when the order was fully refunded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrderHistory
constructor
A new instance of OrderHistory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrderHistory
Returns a new instance of OrderHistory.
6125 6126 6127 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancellation_event ⇒ Google::Apis::AndroidpublisherV3::CancellationEvent
Details of when the order was canceled.
Corresponds to the JSON property cancellationEvent
6108 6109 6110 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6108 def cancellation_event @cancellation_event end |
#partial_refund_events ⇒ Array<Google::Apis::AndroidpublisherV3::PartialRefundEvent>
Details of the partial refund events for this order.
Corresponds to the JSON property partialRefundEvents
6113 6114 6115 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6113 def partial_refund_events @partial_refund_events end |
#processed_event ⇒ Google::Apis::AndroidpublisherV3::ProcessedEvent
Details of when the order was processed.
Corresponds to the JSON property processedEvent
6118 6119 6120 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6118 def processed_event @processed_event end |
#refund_event ⇒ Google::Apis::AndroidpublisherV3::RefundEvent
Details of when the order was fully refunded.
Corresponds to the JSON property refundEvent
6123 6124 6125 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6123 def refund_event @refund_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6130 6131 6132 6133 6134 6135 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6130 def update!(**args) @cancellation_event = args[:cancellation_event] if args.key?(:cancellation_event) @partial_refund_events = args[:partial_refund_events] if args.key?(:partial_refund_events) @processed_event = args[:processed_event] if args.key?(:processed_event) @refund_event = args[:refund_event] if args.key?(:refund_event) end |