Class: Google::Apis::AndroidpublisherV3::OrdersReviewRefundRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OrdersReviewRefundRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request for the orders.reviewrefund API.
Instance Attribute Summary collapse
-
#consumption_percentage_milliunits ⇒ Fixnum
Optional.
-
#consumption_usage_events ⇒ Array<Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent>
Optional.
-
#pending_refund_token ⇒ String
Required.
-
#refund_preference ⇒ String
Required.
-
#sample_content_provided ⇒ Boolean
(also: #sample_content_provided?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrdersReviewRefundRequest
constructor
A new instance of OrdersReviewRefundRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrdersReviewRefundRequest
Returns a new instance of OrdersReviewRefundRequest.
7255 7256 7257 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumption_percentage_milliunits ⇒ Fixnum
Optional. Percentage of the In-App purchase the customer consumed, in
milliunits. Minimum: 0 Maximum: 100,000. For paid apps, this can be omitted.
Example : 45200 represents 45.2%.
Corresponds to the JSON property consumptionPercentageMilliunits
7227 7228 7229 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7227 def consumption_percentage_milliunits @consumption_percentage_milliunits end |
#consumption_usage_events ⇒ Array<Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent>
Optional. List of events, each representing an instance where the user
consumed or used the purchased item or service. Lists with over 1000 items
will be rejected.
Corresponds to the JSON property consumptionUsageEvents
7234 7235 7236 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7234 def consumption_usage_events @consumption_usage_events end |
#pending_refund_token ⇒ String
Required. The pending refund token included in the pending refund review
notification.
Corresponds to the JSON property pendingRefundToken
7240 7241 7242 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7240 def pending_refund_token @pending_refund_token end |
#refund_preference ⇒ String
Required. Indicates your preference, based on your operational logic, as to
whether the Play Store should grant the refund.
Corresponds to the JSON property refundPreference
7246 7247 7248 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7246 def refund_preference @refund_preference end |
#sample_content_provided ⇒ Boolean Also known as: sample_content_provided?
Required. Indicates whether you provided a free sample, trial, or information
about the functionality prior to the purchase.
Corresponds to the JSON property sampleContentProvided
7252 7253 7254 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7252 def sample_content_provided @sample_content_provided end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7260 7261 7262 7263 7264 7265 7266 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7260 def update!(**args) @consumption_percentage_milliunits = args[:consumption_percentage_milliunits] if args.key?(:consumption_percentage_milliunits) @consumption_usage_events = args[:consumption_usage_events] if args.key?(:consumption_usage_events) @pending_refund_token = args[:pending_refund_token] if args.key?(:pending_refund_token) @refund_preference = args[:refund_preference] if args.key?(:refund_preference) @sample_content_provided = args[:sample_content_provided] if args.key?(:sample_content_provided) end |