Class: Google::Apis::AndroidpublisherV3::OrdersReviewRefundRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request for the orders.reviewrefund API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrdersReviewRefundRequest

Returns a new instance of OrdersReviewRefundRequest.



6635
6636
6637
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumption_percentage_milliunitsFixnum

Optional. Percentage of the In-App purchase the customer consumed, in milliunits. Minimum: 0 Maximum: 100,000. For paid apps, this can be omitted. Example : 45200 represents 45.2%. Corresponds to the JSON property consumptionPercentageMilliunits

Returns:

  • (Fixnum)


6607
6608
6609
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6607

def consumption_percentage_milliunits
  @consumption_percentage_milliunits
end

#consumption_usage_eventsArray<Google::Apis::AndroidpublisherV3::ConsumptionUsageEvent>

Optional. List of events, each representing an instance where the user consumed or used the purchased item or service. Lists with over 1000 items will be rejected. Corresponds to the JSON property consumptionUsageEvents



6614
6615
6616
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6614

def consumption_usage_events
  @consumption_usage_events
end

#pending_refund_tokenString

Required. The pending refund token included in the pending refund review notification. Corresponds to the JSON property pendingRefundToken

Returns:

  • (String)


6620
6621
6622
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6620

def pending_refund_token
  @pending_refund_token
end

#refund_preferenceString

Required. Indicates your preference, based on your operational logic, as to whether the Play Store should grant the refund. Corresponds to the JSON property refundPreference

Returns:

  • (String)


6626
6627
6628
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6626

def refund_preference
  @refund_preference
end

#sample_content_providedBoolean Also known as: sample_content_provided?

Required. Indicates whether you provided a free sample, trial, or information about the functionality prior to the purchase. Corresponds to the JSON property sampleContentProvided

Returns:

  • (Boolean)


6632
6633
6634
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6632

def sample_content_provided
  @sample_content_provided
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6640
6641
6642
6643
6644
6645
6646
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6640

def update!(**args)
  @consumption_percentage_milliunits = args[:consumption_percentage_milliunits] if args.key?(:consumption_percentage_milliunits)
  @consumption_usage_events = args[:consumption_usage_events] if args.key?(:consumption_usage_events)
  @pending_refund_token = args[:pending_refund_token] if args.key?(:pending_refund_token)
  @refund_preference = args[:refund_preference] if args.key?(:refund_preference)
  @sample_content_provided = args[:sample_content_provided] if args.key?(:sample_content_provided)
end