Class: Google::Apis::AndroidpublisherV3::OtherRegionsBasePlanConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OtherRegionsBasePlanConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Pricing information for any new locations Play may launch in.
Instance Attribute Summary collapse
-
#eur_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#new_subscriber_availability ⇒ Boolean
(also: #new_subscriber_availability?)
Whether the base plan is available for new subscribers in any new locations Play may launch in.
-
#usd_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OtherRegionsBasePlanConfig
constructor
A new instance of OtherRegionsBasePlanConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OtherRegionsBasePlanConfig
Returns a new instance of OtherRegionsBasePlanConfig.
6173 6174 6175 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eur_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property eurPrice
6159 6160 6161 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6159 def eur_price @eur_price end |
#new_subscriber_availability ⇒ Boolean Also known as: new_subscriber_availability?
Whether the base plan is available for new subscribers in any new locations
Play may launch in. If not specified, this will default to false.
Corresponds to the JSON property newSubscriberAvailability
6165 6166 6167 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6165 def new_subscriber_availability @new_subscriber_availability end |
#usd_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property usdPrice
6171 6172 6173 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6171 def usd_price @usd_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6178 6179 6180 6181 6182 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6178 def update!(**args) @eur_price = args[:eur_price] if args.key?(:eur_price) @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability) @usd_price = args[:usd_price] if args.key?(:usd_price) end |