Class: Google::Apis::AndroidpublisherV3::OtherRegionsBasePlanConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Pricing information for any new locations Play may launch in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OtherRegionsBasePlanConfig

Returns a new instance of OtherRegionsBasePlanConfig.



6134
6135
6136
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eur_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property eurPrice



6120
6121
6122
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6120

def eur_price
  @eur_price
end

#new_subscriber_availabilityBoolean Also known as: new_subscriber_availability?

Whether the base plan is available for new subscribers in any new locations Play may launch in. If not specified, this will default to false. Corresponds to the JSON property newSubscriberAvailability

Returns:

  • (Boolean)


6126
6127
6128
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6126

def new_subscriber_availability
  @new_subscriber_availability
end

#usd_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property usdPrice



6132
6133
6134
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6132

def usd_price
  @usd_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6139
6140
6141
6142
6143
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6139

def update!(**args)
  @eur_price = args[:eur_price] if args.key?(:eur_price)
  @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability)
  @usd_price = args[:usd_price] if args.key?(:usd_price)
end