Class: Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration for any new locations Play may launch in for a single offer phase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OtherRegionsSubscriptionOfferPhaseConfig

Returns a new instance of OtherRegionsSubscriptionOfferPhaseConfig.



7372
7373
7374
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_discountsGoogle::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhasePrices

Pricing information for any new locations Play may launch in. Corresponds to the JSON property absoluteDiscounts



7346
7347
7348
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7346

def absolute_discounts
  @absolute_discounts
end

#freeGoogle::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseFreePriceOverride

Represents the free price override configuration for any new locations Play may launch for a single offer phase. Corresponds to the JSON property free



7352
7353
7354
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7352

def free
  @free
end

#other_regions_pricesGoogle::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhasePrices

Pricing information for any new locations Play may launch in. Corresponds to the JSON property otherRegionsPrices



7357
7358
7359
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7357

def other_regions_prices
  @other_regions_prices
end

#relative_discountFloat

The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase. For example, if the base plan price for this region is $12 for a period of 1 year, then a 50% discount for a phase of a duration of 3 months would correspond to a price of $1.50. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in any new locations Play may launch in. Corresponds to the JSON property relativeDiscount

Returns:

  • (Float)


7370
7371
7372
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7370

def relative_discount
  @relative_discount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7377
7378
7379
7380
7381
7382
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7377

def update!(**args)
  @absolute_discounts = args[:absolute_discounts] if args.key?(:absolute_discounts)
  @free = args[:free] if args.key?(:free)
  @other_regions_prices = args[:other_regions_prices] if args.key?(:other_regions_prices)
  @relative_discount = args[:relative_discount] if args.key?(:relative_discount)
end