Class: Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for any new locations Play may launch in for a single offer phase.
Instance Attribute Summary collapse
-
#absolute_discounts ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhasePrices
Pricing information for any new locations Play may launch in.
-
#free ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseFreePriceOverride
Represents the free price override configuration for any new locations Play may launch for a single offer phase.
-
#other_regions_prices ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhasePrices
Pricing information for any new locations Play may launch in.
-
#relative_discount ⇒ Float
The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OtherRegionsSubscriptionOfferPhaseConfig
constructor
A new instance of OtherRegionsSubscriptionOfferPhaseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OtherRegionsSubscriptionOfferPhaseConfig
Returns a new instance of OtherRegionsSubscriptionOfferPhaseConfig.
6305 6306 6307 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#absolute_discounts ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhasePrices
Pricing information for any new locations Play may launch in.
Corresponds to the JSON property absoluteDiscounts
6279 6280 6281 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6279 def absolute_discounts @absolute_discounts end |
#free ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseFreePriceOverride
Represents the free price override configuration for any new locations Play
may launch for a single offer phase.
Corresponds to the JSON property free
6285 6286 6287 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6285 def free @free end |
#other_regions_prices ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhasePrices
Pricing information for any new locations Play may launch in.
Corresponds to the JSON property otherRegionsPrices
6290 6291 6292 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6290 def other_regions_prices @other_regions_prices end |
#relative_discount ⇒ Float
The fraction of the base plan price prorated over the phase duration that the
user pays for this offer phase. For example, if the base plan price for this
region is $12 for a period of 1 year, then a 50% discount for a phase of a
duration of 3 months would correspond to a price of $1.50. The discount must
be specified as a fraction strictly larger than 0 and strictly smaller than 1.
The resulting price will be rounded to the nearest billable unit (e.g. cents
for USD). The relative discount is considered invalid if the discounted price
ends up being smaller than the minimum price allowed in any new locations Play
may launch in.
Corresponds to the JSON property relativeDiscount
6303 6304 6305 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6303 def relative_discount @relative_discount end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6310 6311 6312 6313 6314 6315 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6310 def update!(**args) @absolute_discounts = args[:absolute_discounts] if args.key?(:absolute_discounts) @free = args[:free] if args.key?(:free) @other_regions_prices = args[:other_regions_prices] if args.key?(:other_regions_prices) @relative_discount = args[:relative_discount] if args.key?(:relative_discount) end |