Class: Google::Apis::AndroidpublisherV3::OutOfAppPurchaseContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information specific to an out of app purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OutOfAppPurchaseContext

Returns a new instance of OutOfAppPurchaseContext.



6330
6331
6332
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expired_external_account_identifiersGoogle::Apis::AndroidpublisherV3::ExternalAccountIdentifiers

User account identifier in the third-party service. Corresponds to the JSON property expiredExternalAccountIdentifiers



6320
6321
6322
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6320

def 
  @expired_external_account_identifiers
end

#expired_purchase_tokenString

The purchase token of the last expired subscription. This purchase token must only be used to help identify the user if the link between the purchaseToken and user is stored in your database. This cannot be used to call the Google Developer API if it has been more than 60 days since expiry. Corresponds to the JSON property expiredPurchaseToken

Returns:

  • (String)


6328
6329
6330
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6328

def expired_purchase_token
  @expired_purchase_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6335
6336
6337
6338
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6335

def update!(**args)
  @expired_external_account_identifiers = args[:expired_external_account_identifiers] if args.key?(:expired_external_account_identifiers)
  @expired_purchase_token = args[:expired_purchase_token] if args.key?(:expired_purchase_token)
end