Class: Google::Apis::AndroidpublisherV3::PageInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned.
Instance Attribute Summary collapse
-
#result_per_page ⇒ Fixnum
Maximum number of results returned in one page.
-
#start_index ⇒ Fixnum
Index of the first result returned in the current page.
-
#total_results ⇒ Fixnum
Total number of results available on the backend ! The total number of results in the result set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PageInfo
constructor
A new instance of PageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PageInfo
Returns a new instance of PageInfo.
7475 7476 7477 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7475 def initialize(**args) update!(**args) end |
Instance Attribute Details
#result_per_page ⇒ Fixnum
Maximum number of results returned in one page. ! The number of results
included in the API response.
Corresponds to the JSON property resultPerPage
7462 7463 7464 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7462 def result_per_page @result_per_page end |
#start_index ⇒ Fixnum
Index of the first result returned in the current page.
Corresponds to the JSON property startIndex
7467 7468 7469 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7467 def start_index @start_index end |
#total_results ⇒ Fixnum
Total number of results available on the backend ! The total number of results
in the result set.
Corresponds to the JSON property totalResults
7473 7474 7475 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7473 def total_results @total_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7480 7481 7482 7483 7484 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7480 def update!(**args) @result_per_page = args[:result_per_page] if args.key?(:result_per_page) @start_index = args[:start_index] if args.key?(:start_index) @total_results = args[:total_results] if args.key?(:total_results) end |