Class: Google::Apis::AndroidpublisherV3::PageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PageInfo

Returns a new instance of PageInfo.



6344
6345
6346
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#result_per_pageFixnum

Maximum number of results returned in one page. ! The number of results included in the API response. Corresponds to the JSON property resultPerPage

Returns:

  • (Fixnum)


6331
6332
6333
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6331

def result_per_page
  @result_per_page
end

#start_indexFixnum

Index of the first result returned in the current page. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


6336
6337
6338
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6336

def start_index
  @start_index
end

#total_resultsFixnum

Total number of results available on the backend ! The total number of results in the result set. Corresponds to the JSON property totalResults

Returns:

  • (Fixnum)


6342
6343
6344
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6342

def total_results
  @total_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6349
6350
6351
6352
6353
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6349

def update!(**args)
  @result_per_page = args[:result_per_page] if args.key?(:result_per_page)
  @start_index = args[:start_index] if args.key?(:start_index)
  @total_results = args[:total_results] if args.key?(:total_results)
end