Class: Google::Apis::AndroidpublisherV3::PartialRefund

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A partial refund of a transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartialRefund

Returns a new instance of PartialRefund.



6405
6406
6407
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#refund_idString

Required. A unique id distinguishing this partial refund. If the refund is successful, subsequent refunds with the same id will fail. Must be unique across refunds for one individual transaction. Corresponds to the JSON property refundId

Returns:

  • (String)


6398
6399
6400
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6398

def refund_id
  @refund_id
end

#refund_pre_tax_amountGoogle::Apis::AndroidpublisherV3::Price

Definition of a price, i.e. currency and units. Corresponds to the JSON property refundPreTaxAmount



6403
6404
6405
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6403

def refund_pre_tax_amount
  @refund_pre_tax_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6410
6411
6412
6413
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6410

def update!(**args)
  @refund_id = args[:refund_id] if args.key?(:refund_id)
  @refund_pre_tax_amount = args[:refund_pre_tax_amount] if args.key?(:refund_pre_tax_amount)
end