Class: Google::Apis::AndroidpublisherV3::PointsDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PointsDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details relating to any Play Points applied to an order.
Instance Attribute Summary collapse
-
#points_coupon_value ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#points_discount_rate_micros ⇒ Fixnum
The percentage rate which the Play Points promotion reduces the cost by.
-
#points_offer_id ⇒ String
ID unique to the play points offer in use for this order.
-
#points_spent ⇒ Fixnum
The number of Play Points applied in this order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PointsDetails
constructor
A new instance of PointsDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PointsDetails
Returns a new instance of PointsDetails.
6496 6497 6498 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#points_coupon_value ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property pointsCouponValue
6474 6475 6476 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6474 def points_coupon_value @points_coupon_value end |
#points_discount_rate_micros ⇒ Fixnum
The percentage rate which the Play Points promotion reduces the cost by. E.g.
for a 100 points for $2 coupon, this is 500,000. Since $2 has an estimate of
200 points, but the actual Points required, 100, is 50% of this, and 50% in
micros is 500,000. Between 0 and 1,000,000.
Corresponds to the JSON property pointsDiscountRateMicros
6482 6483 6484 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6482 def points_discount_rate_micros @points_discount_rate_micros end |
#points_offer_id ⇒ String
ID unique to the play points offer in use for this order.
Corresponds to the JSON property pointsOfferId
6487 6488 6489 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6487 def points_offer_id @points_offer_id end |
#points_spent ⇒ Fixnum
The number of Play Points applied in this order. E.g. for a 100 points for $2
coupon, this is 100. For coupon stacked with base offer, this is the total
points spent across both.
Corresponds to the JSON property pointsSpent
6494 6495 6496 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6494 def points_spent @points_spent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6501 6502 6503 6504 6505 6506 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6501 def update!(**args) @points_coupon_value = args[:points_coupon_value] if args.key?(:points_coupon_value) @points_discount_rate_micros = args[:points_discount_rate_micros] if args.key?(:points_discount_rate_micros) @points_offer_id = args[:points_offer_id] if args.key?(:points_offer_id) @points_spent = args[:points_spent] if args.key?(:points_spent) end |