Class: Google::Apis::AndroidpublisherV3::PointsDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details relating to any Play Points applied to an order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PointsDetails

Returns a new instance of PointsDetails.



6457
6458
6459
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#points_coupon_valueGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property pointsCouponValue



6435
6436
6437
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6435

def points_coupon_value
  @points_coupon_value
end

#points_discount_rate_microsFixnum

The percentage rate which the Play Points promotion reduces the cost by. E.g. for a 100 points for $2 coupon, this is 500,000. Since $2 has an estimate of 200 points, but the actual Points required, 100, is 50% of this, and 50% in micros is 500,000. Between 0 and 1,000,000. Corresponds to the JSON property pointsDiscountRateMicros

Returns:

  • (Fixnum)


6443
6444
6445
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6443

def points_discount_rate_micros
  @points_discount_rate_micros
end

#points_offer_idString

ID unique to the play points offer in use for this order. Corresponds to the JSON property pointsOfferId

Returns:

  • (String)


6448
6449
6450
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6448

def points_offer_id
  @points_offer_id
end

#points_spentFixnum

The number of Play Points applied in this order. E.g. for a 100 points for $2 coupon, this is 100. For coupon stacked with base offer, this is the total points spent across both. Corresponds to the JSON property pointsSpent

Returns:

  • (Fixnum)


6455
6456
6457
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6455

def points_spent
  @points_spent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6462
6463
6464
6465
6466
6467
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6462

def update!(**args)
  @points_coupon_value = args[:points_coupon_value] if args.key?(:points_coupon_value)
  @points_discount_rate_micros = args[:points_discount_rate_micros] if args.key?(:points_discount_rate_micros)
  @points_offer_id = args[:points_offer_id] if args.key?(:points_offer_id)
  @points_spent = args[:points_spent] if args.key?(:points_spent)
end