Class: Google::Apis::AndroidpublisherV3::PolicyDocumentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

An uploaded document. Must be a single logical document (e.g. a financial license).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyDocumentResponse

Returns a new instance of PolicyDocumentResponse.



7068
7069
7070
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idString

Required. ID of the uploaded document. Corresponds to the JSON property documentId

Returns:

  • (String)


7048
7049
7050
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7048

def document_id
  @document_id
end

#expiry_dateGoogle::Apis::AndroidpublisherV3::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property expiryDate



7060
7061
7062
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7060

def expiry_date
  @expiry_date
end

#non_expiringBoolean Also known as: non_expiring?

Optional. True if confirmed that the document does not have an expiry date. Corresponds to the JSON property nonExpiring

Returns:

  • (Boolean)


7065
7066
7067
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7065

def non_expiring
  @non_expiring
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7073
7074
7075
7076
7077
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7073

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @expiry_date = args[:expiry_date] if args.key?(:expiry_date)
  @non_expiring = args[:non_expiring] if args.key?(:non_expiring)
end