Class: Google::Apis::AndroidpublisherV3::PolicyResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PolicyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An individual response to a policy question about an app.
Instance Attribute Summary collapse
-
#boolean_response ⇒ Google::Apis::AndroidpublisherV3::PolicyBooleanResponse
Responses that will only ever be a boolean.
-
#document_response ⇒ Google::Apis::AndroidpublisherV3::PolicyDocumentResponse
An uploaded document.
-
#group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyGroupResponse
A repeated group of responses.
-
#keyed_group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyKeyedGroupResponse
A group of responses each identified by a distinct key within an allowed set.
-
#multiple_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse
Any response where multiple options can be chosen from several possibilities.
-
#question_id ⇒ String
Required.
-
#single_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicySingleChoiceResponse
Any response where a single option is chosen from several possibilities.
-
#string_response ⇒ Google::Apis::AndroidpublisherV3::PolicyStringResponse
Any response best encoded as a string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PolicyResponse
constructor
A new instance of PolicyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PolicyResponse
Returns a new instance of PolicyResponse.
7982 7983 7984 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_response ⇒ Google::Apis::AndroidpublisherV3::PolicyBooleanResponse
Responses that will only ever be a boolean.
Corresponds to the JSON property booleanResponse
7944 7945 7946 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7944 def boolean_response @boolean_response end |
#document_response ⇒ Google::Apis::AndroidpublisherV3::PolicyDocumentResponse
An uploaded document. Must be a single logical document (e.g. a financial
license).
Corresponds to the JSON property documentResponse
7950 7951 7952 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7950 def document_response @document_response end |
#group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyGroupResponse
A repeated group of responses.
Corresponds to the JSON property groupResponse
7955 7956 7957 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7955 def group_response @group_response end |
#keyed_group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyKeyedGroupResponse
A group of responses each identified by a distinct key within an allowed set.
Corresponds to the JSON property keyedGroupResponse
7960 7961 7962 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7960 def keyed_group_response @keyed_group_response end |
#multiple_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse
Any response where multiple options can be chosen from several possibilities.
Corresponds to the JSON property multipleChoiceResponse
7965 7966 7967 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7965 def multiple_choice_response @multiple_choice_response end |
#question_id ⇒ String
Required. ID of the question being answered.
Corresponds to the JSON property questionId
7970 7971 7972 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7970 def question_id @question_id end |
#single_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicySingleChoiceResponse
Any response where a single option is chosen from several possibilities.
Corresponds to the JSON property singleChoiceResponse
7975 7976 7977 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7975 def single_choice_response @single_choice_response end |
#string_response ⇒ Google::Apis::AndroidpublisherV3::PolicyStringResponse
Any response best encoded as a string. Includes URLs and multiline text fields.
Corresponds to the JSON property stringResponse
7980 7981 7982 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7980 def string_response @string_response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7987 def update!(**args) @boolean_response = args[:boolean_response] if args.key?(:boolean_response) @document_response = args[:document_response] if args.key?(:document_response) @group_response = args[:group_response] if args.key?(:group_response) @keyed_group_response = args[:keyed_group_response] if args.key?(:keyed_group_response) @multiple_choice_response = args[:multiple_choice_response] if args.key?(:multiple_choice_response) @question_id = args[:question_id] if args.key?(:question_id) @single_choice_response = args[:single_choice_response] if args.key?(:single_choice_response) @string_response = args[:string_response] if args.key?(:string_response) end |