Class: Google::Apis::AndroidpublisherV3::PolicyResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

An individual response to a policy question about an app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyResponse

Returns a new instance of PolicyResponse.



7803
7804
7805
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boolean_responseGoogle::Apis::AndroidpublisherV3::PolicyBooleanResponse

Responses that will only ever be a boolean. Corresponds to the JSON property booleanResponse



7765
7766
7767
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7765

def boolean_response
  @boolean_response
end

#document_responseGoogle::Apis::AndroidpublisherV3::PolicyDocumentResponse

An uploaded document. Must be a single logical document (e.g. a financial license). Corresponds to the JSON property documentResponse



7771
7772
7773
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7771

def document_response
  @document_response
end

#group_responseGoogle::Apis::AndroidpublisherV3::PolicyGroupResponse

A repeated group of responses. Corresponds to the JSON property groupResponse



7776
7777
7778
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7776

def group_response
  @group_response
end

#keyed_group_responseGoogle::Apis::AndroidpublisherV3::PolicyKeyedGroupResponse

A group of responses each identified by a distinct key within an allowed set. Corresponds to the JSON property keyedGroupResponse



7781
7782
7783
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7781

def keyed_group_response
  @keyed_group_response
end

#multiple_choice_responseGoogle::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse

Any response where multiple options can be chosen from several possibilities. Corresponds to the JSON property multipleChoiceResponse



7786
7787
7788
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7786

def multiple_choice_response
  @multiple_choice_response
end

#question_idString

Required. ID of the question being answered. Corresponds to the JSON property questionId

Returns:

  • (String)


7791
7792
7793
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7791

def question_id
  @question_id
end

#single_choice_responseGoogle::Apis::AndroidpublisherV3::PolicySingleChoiceResponse

Any response where a single option is chosen from several possibilities. Corresponds to the JSON property singleChoiceResponse



7796
7797
7798
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7796

def single_choice_response
  @single_choice_response
end

#string_responseGoogle::Apis::AndroidpublisherV3::PolicyStringResponse

Any response best encoded as a string. Includes URLs and multiline text fields. Corresponds to the JSON property stringResponse



7801
7802
7803
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7801

def string_response
  @string_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7808
7809
7810
7811
7812
7813
7814
7815
7816
7817
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7808

def update!(**args)
  @boolean_response = args[:boolean_response] if args.key?(:boolean_response)
  @document_response = args[:document_response] if args.key?(:document_response)
  @group_response = args[:group_response] if args.key?(:group_response)
  @keyed_group_response = args[:keyed_group_response] if args.key?(:keyed_group_response)
  @multiple_choice_response = args[:multiple_choice_response] if args.key?(:multiple_choice_response)
  @question_id = args[:question_id] if args.key?(:question_id)
  @single_choice_response = args[:single_choice_response] if args.key?(:single_choice_response)
  @string_response = args[:string_response] if args.key?(:string_response)
end