Class: Google::Apis::AndroidpublisherV3::PolicyResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PolicyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
An individual response to a policy question about an app.
Instance Attribute Summary collapse
-
#boolean_response ⇒ Google::Apis::AndroidpublisherV3::PolicyBooleanResponse
Responses that will only ever be a boolean.
-
#document_response ⇒ Google::Apis::AndroidpublisherV3::PolicyDocumentResponse
An uploaded document.
-
#group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyGroupResponse
A repeated group of responses.
-
#keyed_group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyKeyedGroupResponse
A group of responses each identified by a distinct key within an allowed set.
-
#multiple_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse
Any response where multiple options can be chosen from several possibilities.
-
#question_id ⇒ String
Required.
-
#single_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicySingleChoiceResponse
Any response where a single option is chosen from several possibilities.
-
#string_response ⇒ Google::Apis::AndroidpublisherV3::PolicyStringResponse
Any response best encoded as a string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PolicyResponse
constructor
A new instance of PolicyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PolicyResponse
Returns a new instance of PolicyResponse.
7183 7184 7185 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_response ⇒ Google::Apis::AndroidpublisherV3::PolicyBooleanResponse
Responses that will only ever be a boolean.
Corresponds to the JSON property booleanResponse
7145 7146 7147 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7145 def boolean_response @boolean_response end |
#document_response ⇒ Google::Apis::AndroidpublisherV3::PolicyDocumentResponse
An uploaded document. Must be a single logical document (e.g. a financial
license).
Corresponds to the JSON property documentResponse
7151 7152 7153 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7151 def document_response @document_response end |
#group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyGroupResponse
A repeated group of responses.
Corresponds to the JSON property groupResponse
7156 7157 7158 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7156 def group_response @group_response end |
#keyed_group_response ⇒ Google::Apis::AndroidpublisherV3::PolicyKeyedGroupResponse
A group of responses each identified by a distinct key within an allowed set.
Corresponds to the JSON property keyedGroupResponse
7161 7162 7163 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7161 def keyed_group_response @keyed_group_response end |
#multiple_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicyMultipleChoiceResponse
Any response where multiple options can be chosen from several possibilities.
Corresponds to the JSON property multipleChoiceResponse
7166 7167 7168 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7166 def multiple_choice_response @multiple_choice_response end |
#question_id ⇒ String
Required. ID of the question being answered.
Corresponds to the JSON property questionId
7171 7172 7173 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7171 def question_id @question_id end |
#single_choice_response ⇒ Google::Apis::AndroidpublisherV3::PolicySingleChoiceResponse
Any response where a single option is chosen from several possibilities.
Corresponds to the JSON property singleChoiceResponse
7176 7177 7178 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7176 def single_choice_response @single_choice_response end |
#string_response ⇒ Google::Apis::AndroidpublisherV3::PolicyStringResponse
Any response best encoded as a string. Includes URLs and multiline text fields.
Corresponds to the JSON property stringResponse
7181 7182 7183 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7181 def string_response @string_response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7188 7189 7190 7191 7192 7193 7194 7195 7196 7197 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7188 def update!(**args) @boolean_response = args[:boolean_response] if args.key?(:boolean_response) @document_response = args[:document_response] if args.key?(:document_response) @group_response = args[:group_response] if args.key?(:group_response) @keyed_group_response = args[:keyed_group_response] if args.key?(:keyed_group_response) @multiple_choice_response = args[:multiple_choice_response] if args.key?(:multiple_choice_response) @question_id = args[:question_id] if args.key?(:question_id) @single_choice_response = args[:single_choice_response] if args.key?(:single_choice_response) @string_response = args[:string_response] if args.key?(:string_response) end |