Class: Google::Apis::AndroidpublisherV3::PreorderOfferDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PreorderOfferDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Offer details information related to a preorder line item.
Instance Attribute Summary collapse
-
#preorder_release_time ⇒ String
The time when a preordered item is released for a preorder purchase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreorderOfferDetails
constructor
A new instance of PreorderOfferDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreorderOfferDetails
Returns a new instance of PreorderOfferDetails.
6531 6532 6533 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#preorder_release_time ⇒ String
The time when a preordered item is released for a preorder purchase.
Corresponds to the JSON property preorderReleaseTime
6529 6530 6531 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6529 def preorder_release_time @preorder_release_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6536 6537 6538 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6536 def update!(**args) @preorder_release_time = args[:preorder_release_time] if args.key?(:preorder_release_time) end |