Class: Google::Apis::AndroidpublisherV3::PreorderOfferDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PreorderOfferDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Offer details information related to a preorder line item.
Instance Attribute Summary collapse
-
#preorder_release_time ⇒ String
The time when a preordered item is released for a preorder purchase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreorderOfferDetails
constructor
A new instance of PreorderOfferDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreorderOfferDetails
Returns a new instance of PreorderOfferDetails.
6492 6493 6494 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#preorder_release_time ⇒ String
The time when a preordered item is released for a preorder purchase.
Corresponds to the JSON property preorderReleaseTime
6490 6491 6492 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6490 def preorder_release_time @preorder_release_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6497 6498 6499 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6497 def update!(**args) @preorder_release_time = args[:preorder_release_time] if args.key?(:preorder_release_time) end |