Class: Google::Apis::AndroidpublisherV3::PrepaidPlan
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PrepaidPlan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Information related to a prepaid plan.
Instance Attribute Summary collapse
-
#allow_extend_after_time ⇒ String
If present, this is the time after which top up purchases are allowed for the prepaid plan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrepaidPlan
constructor
A new instance of PrepaidPlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrepaidPlan
Returns a new instance of PrepaidPlan.
6600 6601 6602 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_extend_after_time ⇒ String
If present, this is the time after which top up purchases are allowed for the
prepaid plan. Will not be present for expired prepaid plans.
Corresponds to the JSON property allowExtendAfterTime
6598 6599 6600 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6598 def allow_extend_after_time @allow_extend_after_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6605 6606 6607 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6605 def update!(**args) @allow_extend_after_time = args[:allow_extend_after_time] if args.key?(:allow_extend_after_time) end |