Class: Google::Apis::AndroidpublisherV3::PriceStepUpConsentDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::PriceStepUpConsentDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Information related to a price step-up that requires user consent.
Instance Attribute Summary collapse
-
#consent_deadline_time ⇒ String
The deadline by which the user must provide consent.
-
#new_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PriceStepUpConsentDetails
constructor
A new instance of PriceStepUpConsentDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PriceStepUpConsentDetails
Returns a new instance of PriceStepUpConsentDetails.
7985 7986 7987 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_deadline_time ⇒ String
The deadline by which the user must provide consent. If consent is not
provided by this time, the subscription will be canceled.
Corresponds to the JSON property consentDeadlineTime
7973 7974 7975 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7973 def @consent_deadline_time end |
#new_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property newPrice
7978 7979 7980 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7978 def new_price @new_price end |
#state ⇒ String
Output only. The state of the price step-up consent.
Corresponds to the JSON property state
7983 7984 7985 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7983 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7990 7991 7992 7993 7994 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7990 def update!(**args) @consent_deadline_time = args[:consent_deadline_time] if args.key?(:consent_deadline_time) @new_price = args[:new_price] if args.key?(:new_price) @state = args[:state] if args.key?(:state) end |