Class: Google::Apis::AndroidpublisherV3::PriceStepUpConsentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information related to a price step-up that requires user consent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PriceStepUpConsentDetails

Returns a new instance of PriceStepUpConsentDetails.



6636
6637
6638
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The deadline by which the user must provide consent. If consent is not provided by this time, the subscription will be canceled. Corresponds to the JSON property consentDeadlineTime

Returns:

  • (String)


6624
6625
6626
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6624

def consent_deadline_time
  @consent_deadline_time
end

#new_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property newPrice



6629
6630
6631
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6629

def new_price
  @new_price
end

#stateString

Output only. The state of the price step-up consent. Corresponds to the JSON property state

Returns:

  • (String)


6634
6635
6636
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6634

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6641
6642
6643
6644
6645
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6641

def update!(**args)
  @consent_deadline_time = args[:consent_deadline_time] if args.key?(:consent_deadline_time)
  @new_price = args[:new_price] if args.key?(:new_price)
  @state = args[:state] if args.key?(:state)
end