Class: Google::Apis::AndroidpublisherV3::PriceStepUpConsentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information related to a price step-up that requires user consent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PriceStepUpConsentDetails

Returns a new instance of PriceStepUpConsentDetails.



6597
6598
6599
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The deadline by which the user must provide consent. If consent is not provided by this time, the subscription will be canceled. Corresponds to the JSON property consentDeadlineTime

Returns:

  • (String)


6585
6586
6587
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6585

def consent_deadline_time
  @consent_deadline_time
end

#new_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property newPrice



6590
6591
6592
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6590

def new_price
  @new_price
end

#stateString

Output only. The state of the price step-up consent. Corresponds to the JSON property state

Returns:

  • (String)


6595
6596
6597
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6595

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6602
6603
6604
6605
6606
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6602

def update!(**args)
  @consent_deadline_time = args[:consent_deadline_time] if args.key?(:consent_deadline_time)
  @new_price = args[:new_price] if args.key?(:new_price)
  @state = args[:state] if args.key?(:state)
end