Class: Google::Apis::AndroidpublisherV3::ProductLineItem
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ProductLineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Contains item-level info for a ProductPurchaseV2.
Instance Attribute Summary collapse
-
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
-
#product_offer_details ⇒ Google::Apis::AndroidpublisherV3::ProductOfferDetails
Offer details information related to a purchase line item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductLineItem
constructor
A new instance of ProductLineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductLineItem
Returns a new instance of ProductLineItem.
6681 6682 6683 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
Corresponds to the JSON property productId
6674 6675 6676 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6674 def product_id @product_id end |
#product_offer_details ⇒ Google::Apis::AndroidpublisherV3::ProductOfferDetails
Offer details information related to a purchase line item.
Corresponds to the JSON property productOfferDetails
6679 6680 6681 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6679 def product_offer_details @product_offer_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6686 6687 6688 6689 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6686 def update!(**args) @product_id = args[:product_id] if args.key?(:product_id) @product_offer_details = args[:product_offer_details] if args.key?(:product_offer_details) end |