Class: Google::Apis::AndroidpublisherV3::ProductOfferDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ProductOfferDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Offer details information related to a purchase line item.
Instance Attribute Summary collapse
-
#consumption_state ⇒ String
Output only.
-
#offer_id ⇒ String
The offer ID.
-
#offer_tags ⇒ Array<String>
The latest offer tags associated with the offer.
-
#offer_token ⇒ String
The per-transaction offer token used to make this purchase line item.
-
#preorder_offer_details ⇒ Google::Apis::AndroidpublisherV3::PreorderOfferDetails
Offer details information related to a preorder line item.
-
#purchase_option_id ⇒ String
The purchase option ID.
-
#quantity ⇒ Fixnum
The quantity associated with the purchase of the inapp product.
-
#refundable_quantity ⇒ Fixnum
The quantity eligible for refund, i.e.
-
#rent_offer_details ⇒ Google::Apis::AndroidpublisherV3::RentOfferDetails
Offer details information related to a rental line item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductOfferDetails
constructor
A new instance of ProductOfferDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductOfferDetails
Returns a new instance of ProductOfferDetails.
8092 8093 8094 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumption_state ⇒ String
Output only. The consumption state of the purchase.
Corresponds to the JSON property consumptionState
8048 8049 8050 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8048 def consumption_state @consumption_state end |
#offer_id ⇒ String
The offer ID. Only present for offers.
Corresponds to the JSON property offerId
8053 8054 8055 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8053 def offer_id @offer_id end |
#offer_tags ⇒ Array<String>
The latest offer tags associated with the offer. It includes tags inherited
from the purchase option.
Corresponds to the JSON property offerTags
8059 8060 8061 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8059 def @offer_tags end |
#offer_token ⇒ String
The per-transaction offer token used to make this purchase line item.
Corresponds to the JSON property offerToken
8064 8065 8066 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8064 def offer_token @offer_token end |
#preorder_offer_details ⇒ Google::Apis::AndroidpublisherV3::PreorderOfferDetails
Offer details information related to a preorder line item.
Corresponds to the JSON property preorderOfferDetails
8069 8070 8071 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8069 def preorder_offer_details @preorder_offer_details end |
#purchase_option_id ⇒ String
The purchase option ID.
Corresponds to the JSON property purchaseOptionId
8074 8075 8076 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8074 def purchase_option_id @purchase_option_id end |
#quantity ⇒ Fixnum
The quantity associated with the purchase of the inapp product.
Corresponds to the JSON property quantity
8079 8080 8081 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8079 def quantity @quantity end |
#refundable_quantity ⇒ Fixnum
The quantity eligible for refund, i.e. quantity that hasn't been refunded. The
value reflects quantity-based partial refunds and full refunds.
Corresponds to the JSON property refundableQuantity
8085 8086 8087 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8085 def refundable_quantity @refundable_quantity end |
#rent_offer_details ⇒ Google::Apis::AndroidpublisherV3::RentOfferDetails
Offer details information related to a rental line item.
Corresponds to the JSON property rentOfferDetails
8090 8091 8092 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8090 def rent_offer_details @rent_offer_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8097 def update!(**args) @consumption_state = args[:consumption_state] if args.key?(:consumption_state) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @offer_token = args[:offer_token] if args.key?(:offer_token) @preorder_offer_details = args[:preorder_offer_details] if args.key?(:preorder_offer_details) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) @quantity = args[:quantity] if args.key?(:quantity) @refundable_quantity = args[:refundable_quantity] if args.key?(:refundable_quantity) @rent_offer_details = args[:rent_offer_details] if args.key?(:rent_offer_details) end |