Class: Google::Apis::AndroidpublisherV3::ProductOfferDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ProductOfferDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Offer details information related to a purchase line item.
Instance Attribute Summary collapse
-
#consumption_state ⇒ String
Output only.
-
#offer_id ⇒ String
The offer ID.
-
#offer_tags ⇒ Array<String>
The latest offer tags associated with the offer.
-
#offer_token ⇒ String
The per-transaction offer token used to make this purchase line item.
-
#preorder_offer_details ⇒ Google::Apis::AndroidpublisherV3::PreorderOfferDetails
Offer details information related to a preorder line item.
-
#purchase_option_id ⇒ String
The purchase option ID.
-
#quantity ⇒ Fixnum
The quantity associated with the purchase of the inapp product.
-
#refundable_quantity ⇒ Fixnum
The quantity eligible for refund, i.e.
-
#rent_offer_details ⇒ Google::Apis::AndroidpublisherV3::RentOfferDetails
Offer details information related to a rental line item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductOfferDetails
constructor
A new instance of ProductOfferDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductOfferDetails
Returns a new instance of ProductOfferDetails.
6801 6802 6803 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumption_state ⇒ String
Output only. The consumption state of the purchase.
Corresponds to the JSON property consumptionState
6757 6758 6759 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6757 def consumption_state @consumption_state end |
#offer_id ⇒ String
The offer ID. Only present for offers.
Corresponds to the JSON property offerId
6762 6763 6764 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6762 def offer_id @offer_id end |
#offer_tags ⇒ Array<String>
The latest offer tags associated with the offer. It includes tags inherited
from the purchase option.
Corresponds to the JSON property offerTags
6768 6769 6770 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6768 def @offer_tags end |
#offer_token ⇒ String
The per-transaction offer token used to make this purchase line item.
Corresponds to the JSON property offerToken
6773 6774 6775 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6773 def offer_token @offer_token end |
#preorder_offer_details ⇒ Google::Apis::AndroidpublisherV3::PreorderOfferDetails
Offer details information related to a preorder line item.
Corresponds to the JSON property preorderOfferDetails
6778 6779 6780 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6778 def preorder_offer_details @preorder_offer_details end |
#purchase_option_id ⇒ String
The purchase option ID.
Corresponds to the JSON property purchaseOptionId
6783 6784 6785 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6783 def purchase_option_id @purchase_option_id end |
#quantity ⇒ Fixnum
The quantity associated with the purchase of the inapp product.
Corresponds to the JSON property quantity
6788 6789 6790 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6788 def quantity @quantity end |
#refundable_quantity ⇒ Fixnum
The quantity eligible for refund, i.e. quantity that hasn't been refunded. The
value reflects quantity-based partial refunds and full refunds.
Corresponds to the JSON property refundableQuantity
6794 6795 6796 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6794 def refundable_quantity @refundable_quantity end |
#rent_offer_details ⇒ Google::Apis::AndroidpublisherV3::RentOfferDetails
Offer details information related to a rental line item.
Corresponds to the JSON property rentOfferDetails
6799 6800 6801 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6799 def rent_offer_details @rent_offer_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6806 6807 6808 6809 6810 6811 6812 6813 6814 6815 6816 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6806 def update!(**args) @consumption_state = args[:consumption_state] if args.key?(:consumption_state) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @offer_token = args[:offer_token] if args.key?(:offer_token) @preorder_offer_details = args[:preorder_offer_details] if args.key?(:preorder_offer_details) @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id) @quantity = args[:quantity] if args.key?(:quantity) @refundable_quantity = args[:refundable_quantity] if args.key?(:refundable_quantity) @rent_offer_details = args[:rent_offer_details] if args.key?(:rent_offer_details) end |