Class: Google::Apis::AndroidpublisherV3::ProductOfferDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Offer details information related to a purchase line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductOfferDetails

Returns a new instance of ProductOfferDetails.



6704
6705
6706
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumption_stateString

Output only. The consumption state of the purchase. Corresponds to the JSON property consumptionState

Returns:

  • (String)


6660
6661
6662
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6660

def consumption_state
  @consumption_state
end

#offer_idString

The offer ID. Only present for offers. Corresponds to the JSON property offerId

Returns:

  • (String)


6665
6666
6667
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6665

def offer_id
  @offer_id
end

#offer_tagsArray<String>

The latest offer tags associated with the offer. It includes tags inherited from the purchase option. Corresponds to the JSON property offerTags

Returns:

  • (Array<String>)


6671
6672
6673
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6671

def offer_tags
  @offer_tags
end

#offer_tokenString

The per-transaction offer token used to make this purchase line item. Corresponds to the JSON property offerToken

Returns:

  • (String)


6676
6677
6678
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6676

def offer_token
  @offer_token
end

#preorder_offer_detailsGoogle::Apis::AndroidpublisherV3::PreorderOfferDetails

Offer details information related to a preorder line item. Corresponds to the JSON property preorderOfferDetails



6681
6682
6683
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6681

def preorder_offer_details
  @preorder_offer_details
end

#purchase_option_idString

The purchase option ID. Corresponds to the JSON property purchaseOptionId

Returns:

  • (String)


6686
6687
6688
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6686

def purchase_option_id
  @purchase_option_id
end

#quantityFixnum

The quantity associated with the purchase of the inapp product. Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


6691
6692
6693
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6691

def quantity
  @quantity
end

#refundable_quantityFixnum

The quantity eligible for refund, i.e. quantity that hasn't been refunded. The value reflects quantity-based partial refunds and full refunds. Corresponds to the JSON property refundableQuantity

Returns:

  • (Fixnum)


6697
6698
6699
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6697

def refundable_quantity
  @refundable_quantity
end

#rent_offer_detailsGoogle::Apis::AndroidpublisherV3::RentOfferDetails

Offer details information related to a rental line item. Corresponds to the JSON property rentOfferDetails



6702
6703
6704
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6702

def rent_offer_details
  @rent_offer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6709

def update!(**args)
  @consumption_state = args[:consumption_state] if args.key?(:consumption_state)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @offer_token = args[:offer_token] if args.key?(:offer_token)
  @preorder_offer_details = args[:preorder_offer_details] if args.key?(:preorder_offer_details)
  @purchase_option_id = args[:purchase_option_id] if args.key?(:purchase_option_id)
  @quantity = args[:quantity] if args.key?(:quantity)
  @refundable_quantity = args[:refundable_quantity] if args.key?(:refundable_quantity)
  @rent_offer_details = args[:rent_offer_details] if args.key?(:rent_offer_details)
end