Class: Google::Apis::AndroidpublisherV3::ProductPurchaseV2
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ProductPurchaseV2
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A ProductPurchaseV2 resource indicates the status of a user's inapp product purchase.
Instance Attribute Summary collapse
-
#acknowledgement_state ⇒ String
Output only.
-
#kind ⇒ String
This kind represents a ProductPurchaseV2 object in the androidpublisher service.
-
#obfuscated_external_account_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's account in your app.
-
#obfuscated_external_profile_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's profile in your app.
-
#order_id ⇒ String
The order id associated with the purchase of the inapp product.
-
#product_line_item ⇒ Array<Google::Apis::AndroidpublisherV3::ProductLineItem>
Contains item-level info for a ProductPurchaseV2.
-
#purchase_completion_time ⇒ String
The time when the purchase was successful, i.e., when the PurchaseState has changed to PURCHASED.
-
#purchase_state_context ⇒ Google::Apis::AndroidpublisherV3::PurchaseStateContext
Context about the purchase state.
-
#region_code ⇒ String
ISO 3166-1 alpha-2 billing region code of the user at the time the product was granted.
-
#test_purchase_context ⇒ Google::Apis::AndroidpublisherV3::TestPurchaseContext
Context about a test purchase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductPurchaseV2
constructor
A new instance of ProductPurchaseV2.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductPurchaseV2
Returns a new instance of ProductPurchaseV2.
8301 8302 8303 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acknowledgement_state ⇒ String
Output only. The acknowledgement state of the purchase.
Corresponds to the JSON property acknowledgementState
8240 8241 8242 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8240 def acknowledgement_state @acknowledgement_state end |
#kind ⇒ String
This kind represents a ProductPurchaseV2 object in the androidpublisher
service.
Corresponds to the JSON property kind
8246 8247 8248 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8246 def kind @kind end |
#obfuscated_external_account_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's
account in your app. Only present if specified using https://developer.android.
com/reference/com/android/billingclient/api/BillingFlowParams.Builder#
setobfuscatedaccountid when the purchase was made.
Corresponds to the JSON property obfuscatedExternalAccountId
8254 8255 8256 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8254 def @obfuscated_external_account_id end |
#obfuscated_external_profile_id ⇒ String
An obfuscated version of the id that is uniquely associated with the user's
profile in your app. Only present if specified using https://developer.android.
com/reference/com/android/billingclient/api/BillingFlowParams.Builder#
setobfuscatedprofileid when the purchase was made.
Corresponds to the JSON property obfuscatedExternalProfileId
8262 8263 8264 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8262 def @obfuscated_external_profile_id end |
#order_id ⇒ String
The order id associated with the purchase of the inapp product. May not be set
if there is no order associated with the purchase.
Corresponds to the JSON property orderId
8268 8269 8270 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8268 def order_id @order_id end |
#product_line_item ⇒ Array<Google::Apis::AndroidpublisherV3::ProductLineItem>
Contains item-level info for a ProductPurchaseV2.
Corresponds to the JSON property productLineItem
8273 8274 8275 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8273 def product_line_item @product_line_item end |
#purchase_completion_time ⇒ String
The time when the purchase was successful, i.e., when the PurchaseState has
changed to PURCHASED. This field will not be present until the payment is
complete. For example, if the user initiated a pending transaction (https://
developer.android.com/google/play/billing/integrate#pending), this field will
not be populated until the user successfully completes the steps required to
complete the transaction.
Corresponds to the JSON property purchaseCompletionTime
8283 8284 8285 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8283 def purchase_completion_time @purchase_completion_time end |
#purchase_state_context ⇒ Google::Apis::AndroidpublisherV3::PurchaseStateContext
Context about the purchase state.
Corresponds to the JSON property purchaseStateContext
8288 8289 8290 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8288 def purchase_state_context @purchase_state_context end |
#region_code ⇒ String
ISO 3166-1 alpha-2 billing region code of the user at the time the product was
granted.
Corresponds to the JSON property regionCode
8294 8295 8296 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8294 def region_code @region_code end |
#test_purchase_context ⇒ Google::Apis::AndroidpublisherV3::TestPurchaseContext
Context about a test purchase.
Corresponds to the JSON property testPurchaseContext
8299 8300 8301 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8299 def test_purchase_context @test_purchase_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8306 def update!(**args) @acknowledgement_state = args[:acknowledgement_state] if args.key?(:acknowledgement_state) @kind = args[:kind] if args.key?(:kind) @obfuscated_external_account_id = args[:obfuscated_external_account_id] if args.key?(:obfuscated_external_account_id) @obfuscated_external_profile_id = args[:obfuscated_external_profile_id] if args.key?(:obfuscated_external_profile_id) @order_id = args[:order_id] if args.key?(:order_id) @product_line_item = args[:product_line_item] if args.key?(:product_line_item) @purchase_completion_time = args[:purchase_completion_time] if args.key?(:purchase_completion_time) @purchase_state_context = args[:purchase_state_context] if args.key?(:purchase_state_context) @region_code = args[:region_code] if args.key?(:region_code) @test_purchase_context = args[:test_purchase_context] if args.key?(:test_purchase_context) end |