Class: Google::Apis::AndroidpublisherV3::ProductPurchaseV2

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A ProductPurchaseV2 resource indicates the status of a user's inapp product purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductPurchaseV2

Returns a new instance of ProductPurchaseV2.



7010
7011
7012
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acknowledgement_stateString

Output only. The acknowledgement state of the purchase. Corresponds to the JSON property acknowledgementState

Returns:

  • (String)


6949
6950
6951
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6949

def acknowledgement_state
  @acknowledgement_state
end

#kindString

This kind represents a ProductPurchaseV2 object in the androidpublisher service. Corresponds to the JSON property kind

Returns:

  • (String)


6955
6956
6957
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6955

def kind
  @kind
end

#obfuscated_external_account_idString

An obfuscated version of the id that is uniquely associated with the user's account in your app. Only present if specified using https://developer.android. com/reference/com/android/billingclient/api/BillingFlowParams.Builder# setobfuscatedaccountid when the purchase was made. Corresponds to the JSON property obfuscatedExternalAccountId

Returns:

  • (String)


6963
6964
6965
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6963

def 
  @obfuscated_external_account_id
end

#obfuscated_external_profile_idString

An obfuscated version of the id that is uniquely associated with the user's profile in your app. Only present if specified using https://developer.android. com/reference/com/android/billingclient/api/BillingFlowParams.Builder# setobfuscatedprofileid when the purchase was made. Corresponds to the JSON property obfuscatedExternalProfileId

Returns:

  • (String)


6971
6972
6973
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6971

def obfuscated_external_profile_id
  @obfuscated_external_profile_id
end

#order_idString

The order id associated with the purchase of the inapp product. May not be set if there is no order associated with the purchase. Corresponds to the JSON property orderId

Returns:

  • (String)


6977
6978
6979
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6977

def order_id
  @order_id
end

#product_line_itemArray<Google::Apis::AndroidpublisherV3::ProductLineItem>

Contains item-level info for a ProductPurchaseV2. Corresponds to the JSON property productLineItem



6982
6983
6984
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6982

def product_line_item
  @product_line_item
end

#purchase_completion_timeString

The time when the purchase was successful, i.e., when the PurchaseState has changed to PURCHASED. This field will not be present until the payment is complete. For example, if the user initiated a pending transaction (https:// developer.android.com/google/play/billing/integrate#pending), this field will not be populated until the user successfully completes the steps required to complete the transaction. Corresponds to the JSON property purchaseCompletionTime

Returns:

  • (String)


6992
6993
6994
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6992

def purchase_completion_time
  @purchase_completion_time
end

#purchase_state_contextGoogle::Apis::AndroidpublisherV3::PurchaseStateContext

Context about the purchase state. Corresponds to the JSON property purchaseStateContext



6997
6998
6999
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6997

def purchase_state_context
  @purchase_state_context
end

#region_codeString

ISO 3166-1 alpha-2 billing region code of the user at the time the product was granted. Corresponds to the JSON property regionCode

Returns:

  • (String)


7003
7004
7005
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7003

def region_code
  @region_code
end

#test_purchase_contextGoogle::Apis::AndroidpublisherV3::TestPurchaseContext

Context about a test purchase. Corresponds to the JSON property testPurchaseContext



7008
7009
7010
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7008

def test_purchase_context
  @test_purchase_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7015

def update!(**args)
  @acknowledgement_state = args[:acknowledgement_state] if args.key?(:acknowledgement_state)
  @kind = args[:kind] if args.key?(:kind)
  @obfuscated_external_account_id = args[:obfuscated_external_account_id] if args.key?(:obfuscated_external_account_id)
  @obfuscated_external_profile_id = args[:obfuscated_external_profile_id] if args.key?(:obfuscated_external_profile_id)
  @order_id = args[:order_id] if args.key?(:order_id)
  @product_line_item = args[:product_line_item] if args.key?(:product_line_item)
  @purchase_completion_time = args[:purchase_completion_time] if args.key?(:purchase_completion_time)
  @purchase_state_context = args[:purchase_state_context] if args.key?(:purchase_state_context)
  @region_code = args[:region_code] if args.key?(:region_code)
  @test_purchase_context = args[:test_purchase_context] if args.key?(:test_purchase_context)
end