Class: Google::Apis::AndroidpublisherV3::ProrationPeriodDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a proration period. A proration period can be a period calculated during a plan change to cover existing entitlements (For more information, see Allow users to upgrade, downgrade, or change their subscription, or a prorated period to align add-on renewal dates with the base (For more information, see Rules applicable for items in the purchase).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProrationPeriodDetails

Returns a new instance of ProrationPeriodDetails.



6971
6972
6973
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_offer_phaseString

Represent the original offer phase from the purchased the line item if the proration period contains any of them. For example, a proration period from CHARGE_FULL_PRICE plan change may merge the 1st offer phase of the subscription offer of the new product user purchased. In this case, the original offer phase will be set here. Corresponds to the JSON property originalOfferPhase

Returns:

  • (String)


6969
6970
6971
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6969

def original_offer_phase
  @original_offer_phase
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6976
6977
6978
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6976

def update!(**args)
  @original_offer_phase = args[:original_offer_phase] if args.key?(:original_offer_phase)
end