Class: Google::Apis::AndroidpublisherV3::ProrationPeriodOfferPhase
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ProrationPeriodOfferPhase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about proration period offer phase.
Instance Attribute Summary collapse
-
#original_offer_phase_type ⇒ String
The original offer phase type before the proration period.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProrationPeriodOfferPhase
constructor
A new instance of ProrationPeriodOfferPhase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProrationPeriodOfferPhase
Returns a new instance of ProrationPeriodOfferPhase.
8379 8380 8381 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#original_offer_phase_type ⇒ String
The original offer phase type before the proration period. Only set when the
proration period is updated from an existing offer phase.
Corresponds to the JSON property originalOfferPhaseType
8377 8378 8379 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8377 def original_offer_phase_type @original_offer_phase_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8384 8385 8386 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8384 def update!(**args) @original_offer_phase_type = args[:original_offer_phase_type] if args.key?(:original_offer_phase_type) end |