Class: Google::Apis::AndroidpublisherV3::ProrationPeriodOfferPhase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about proration period offer phase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProrationPeriodOfferPhase

Returns a new instance of ProrationPeriodOfferPhase.



6991
6992
6993
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_offer_phase_typeString

The original offer phase type before the proration period. Only set when the proration period is updated from an existing offer phase. Corresponds to the JSON property originalOfferPhaseType

Returns:

  • (String)


6989
6990
6991
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6989

def original_offer_phase_type
  @original_offer_phase_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6996
6997
6998
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 6996

def update!(**args)
  @original_offer_phase_type = args[:original_offer_phase_type] if args.key?(:original_offer_phase_type)
end