Class: Google::Apis::AndroidpublisherV3::RamSelector
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RamSelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Defines a RAM selector for a device.
Instance Attribute Summary collapse
-
#ram_mb_less_than_or_equal ⇒ Fixnum
This will match any device that has less than or equal ram_mb_less_than_or_equal mb of RAM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RamSelector
constructor
A new instance of RamSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RamSelector
Returns a new instance of RamSelector.
8442 8443 8444 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ram_mb_less_than_or_equal ⇒ Fixnum
This will match any device that has less than or equal
ram_mb_less_than_or_equal mb of RAM.
Corresponds to the JSON property ramMbLessThanOrEqual
8440 8441 8442 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8440 def ram_mb_less_than_or_equal @ram_mb_less_than_or_equal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8447 8448 8449 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8447 def update!(**args) @ram_mb_less_than_or_equal = args[:ram_mb_less_than_or_equal] if args.key?(:ram_mb_less_than_or_equal) end |