Class: Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder).
Instance Attribute Summary collapse
-
#external_subscription ⇒ Google::Apis::AndroidpublisherV3::ExternalSubscription
Details of an external subscription.
-
#external_transaction_token ⇒ String
Input only.
-
#initial_external_transaction_id ⇒ String
The external transaction id of the first transaction of this recurring series of transactions.
-
#migrated_transaction_program ⇒ String
Input only.
-
#other_recurring_product ⇒ Google::Apis::AndroidpublisherV3::OtherRecurringProduct
Details of a recurring external transaction product which doesn't belong to any other more specific category.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecurringExternalTransaction
constructor
A new instance of RecurringExternalTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecurringExternalTransaction
Returns a new instance of RecurringExternalTransaction.
7850 7851 7852 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_subscription ⇒ Google::Apis::AndroidpublisherV3::ExternalSubscription
Details of an external subscription.
Corresponds to the JSON property externalSubscription
7821 7822 7823 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7821 def external_subscription @external_subscription end |
#external_transaction_token ⇒ String
Input only. Provided during the call to Create. Retrieved from the client when
the alternative billing flow is launched. Required only for the initial
purchase.
Corresponds to the JSON property externalTransactionToken
7828 7829 7830 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7828 def external_transaction_token @external_transaction_token end |
#initial_external_transaction_id ⇒ String
The external transaction id of the first transaction of this recurring series
of transactions. For example, for a subscription this would be the transaction
id of the first payment. Required when creating recurring external
transactions.
Corresponds to the JSON property initialExternalTransactionId
7836 7837 7838 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7836 def initial_external_transaction_id @initial_external_transaction_id end |
#migrated_transaction_program ⇒ String
Input only. Provided during the call to Create. Must only be used when
migrating a subscription from manual monthly reporting to automated reporting.
Corresponds to the JSON property migratedTransactionProgram
7842 7843 7844 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7842 def migrated_transaction_program @migrated_transaction_program end |
#other_recurring_product ⇒ Google::Apis::AndroidpublisherV3::OtherRecurringProduct
Details of a recurring external transaction product which doesn't belong to
any other more specific category.
Corresponds to the JSON property otherRecurringProduct
7848 7849 7850 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7848 def other_recurring_product @other_recurring_product end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7855 7856 7857 7858 7859 7860 7861 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7855 def update!(**args) @external_subscription = args[:external_subscription] if args.key?(:external_subscription) @external_transaction_token = args[:external_transaction_token] if args.key?(:external_transaction_token) @initial_external_transaction_id = args[:initial_external_transaction_id] if args.key?(:initial_external_transaction_id) @migrated_transaction_program = args[:migrated_transaction_program] if args.key?(:migrated_transaction_program) @other_recurring_product = args[:other_recurring_product] if args.key?(:other_recurring_product) end |