Class: Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder).
Instance Attribute Summary collapse
-
#external_subscription ⇒ Google::Apis::AndroidpublisherV3::ExternalSubscription
Details of an external subscription.
-
#external_transaction_token ⇒ String
Input only.
-
#initial_external_transaction_id ⇒ String
The external transaction id of the first transaction of this recurring series of transactions.
-
#migrated_transaction_program ⇒ String
Input only.
-
#other_recurring_product ⇒ Google::Apis::AndroidpublisherV3::OtherRecurringProduct
Details of a recurring external transaction product which doesn't belong to any other more specific category.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecurringExternalTransaction
constructor
A new instance of RecurringExternalTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecurringExternalTransaction
Returns a new instance of RecurringExternalTransaction.
7185 7186 7187 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_subscription ⇒ Google::Apis::AndroidpublisherV3::ExternalSubscription
Details of an external subscription.
Corresponds to the JSON property externalSubscription
7156 7157 7158 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7156 def external_subscription @external_subscription end |
#external_transaction_token ⇒ String
Input only. Provided during the call to Create. Retrieved from the client when
the alternative billing flow is launched. Required only for the initial
purchase.
Corresponds to the JSON property externalTransactionToken
7163 7164 7165 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7163 def external_transaction_token @external_transaction_token end |
#initial_external_transaction_id ⇒ String
The external transaction id of the first transaction of this recurring series
of transactions. For example, for a subscription this would be the transaction
id of the first payment. Required when creating recurring external
transactions.
Corresponds to the JSON property initialExternalTransactionId
7171 7172 7173 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7171 def initial_external_transaction_id @initial_external_transaction_id end |
#migrated_transaction_program ⇒ String
Input only. Provided during the call to Create. Must only be used when
migrating a subscription from manual monthly reporting to automated reporting.
Corresponds to the JSON property migratedTransactionProgram
7177 7178 7179 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7177 def migrated_transaction_program @migrated_transaction_program end |
#other_recurring_product ⇒ Google::Apis::AndroidpublisherV3::OtherRecurringProduct
Details of a recurring external transaction product which doesn't belong to
any other more specific category.
Corresponds to the JSON property otherRecurringProduct
7183 7184 7185 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7183 def other_recurring_product @other_recurring_product end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7190 7191 7192 7193 7194 7195 7196 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7190 def update!(**args) @external_subscription = args[:external_subscription] if args.key?(:external_subscription) @external_transaction_token = args[:external_transaction_token] if args.key?(:external_transaction_token) @initial_external_transaction_id = args[:initial_external_transaction_id] if args.key?(:initial_external_transaction_id) @migrated_transaction_program = args[:migrated_transaction_program] if args.key?(:migrated_transaction_program) @other_recurring_product = args[:other_recurring_product] if args.key?(:other_recurring_product) end |