Class: Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RecurringExternalTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder).
Instance Attribute Summary collapse
-
#external_subscription ⇒ Google::Apis::AndroidpublisherV3::ExternalSubscription
Details of an external subscription.
-
#external_transaction_token ⇒ String
Input only.
-
#initial_external_transaction_id ⇒ String
The external transaction id of the first transaction of this recurring series of transactions.
-
#migrated_transaction_program ⇒ String
Input only.
-
#other_recurring_product ⇒ Google::Apis::AndroidpublisherV3::OtherRecurringProduct
Details of a recurring external transaction product which doesn't belong to any other more specific category.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecurringExternalTransaction
constructor
A new instance of RecurringExternalTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecurringExternalTransaction
Returns a new instance of RecurringExternalTransaction.
7141 7142 7143 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_subscription ⇒ Google::Apis::AndroidpublisherV3::ExternalSubscription
Details of an external subscription.
Corresponds to the JSON property externalSubscription
7112 7113 7114 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7112 def external_subscription @external_subscription end |
#external_transaction_token ⇒ String
Input only. Provided during the call to Create. Retrieved from the client when
the alternative billing flow is launched. Required only for the initial
purchase.
Corresponds to the JSON property externalTransactionToken
7119 7120 7121 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7119 def external_transaction_token @external_transaction_token end |
#initial_external_transaction_id ⇒ String
The external transaction id of the first transaction of this recurring series
of transactions. For example, for a subscription this would be the transaction
id of the first payment. Required when creating recurring external
transactions.
Corresponds to the JSON property initialExternalTransactionId
7127 7128 7129 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7127 def initial_external_transaction_id @initial_external_transaction_id end |
#migrated_transaction_program ⇒ String
Input only. Provided during the call to Create. Must only be used when
migrating a subscription from manual monthly reporting to automated reporting.
Corresponds to the JSON property migratedTransactionProgram
7133 7134 7135 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7133 def migrated_transaction_program @migrated_transaction_program end |
#other_recurring_product ⇒ Google::Apis::AndroidpublisherV3::OtherRecurringProduct
Details of a recurring external transaction product which doesn't belong to
any other more specific category.
Corresponds to the JSON property otherRecurringProduct
7139 7140 7141 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7139 def other_recurring_product @other_recurring_product end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7146 7147 7148 7149 7150 7151 7152 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7146 def update!(**args) @external_subscription = args[:external_subscription] if args.key?(:external_subscription) @external_transaction_token = args[:external_transaction_token] if args.key?(:external_transaction_token) @initial_external_transaction_id = args[:initial_external_transaction_id] if args.key?(:initial_external_transaction_id) @migrated_transaction_program = args[:migrated_transaction_program] if args.key?(:migrated_transaction_program) @other_recurring_product = args[:other_recurring_product] if args.key?(:other_recurring_product) end |