Class: Google::Apis::AndroidpublisherV3::RecurringExternalTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecurringExternalTransaction

Returns a new instance of RecurringExternalTransaction.



7121
7122
7123
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_subscriptionGoogle::Apis::AndroidpublisherV3::ExternalSubscription

Details of an external subscription. Corresponds to the JSON property externalSubscription



7092
7093
7094
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7092

def external_subscription
  @external_subscription
end

#external_transaction_tokenString

Input only. Provided during the call to Create. Retrieved from the client when the alternative billing flow is launched. Required only for the initial purchase. Corresponds to the JSON property externalTransactionToken

Returns:

  • (String)


7099
7100
7101
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7099

def external_transaction_token
  @external_transaction_token
end

#initial_external_transaction_idString

The external transaction id of the first transaction of this recurring series of transactions. For example, for a subscription this would be the transaction id of the first payment. Required when creating recurring external transactions. Corresponds to the JSON property initialExternalTransactionId

Returns:

  • (String)


7107
7108
7109
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7107

def initial_external_transaction_id
  @initial_external_transaction_id
end

#migrated_transaction_programString

Input only. Provided during the call to Create. Must only be used when migrating a subscription from manual monthly reporting to automated reporting. Corresponds to the JSON property migratedTransactionProgram

Returns:

  • (String)


7113
7114
7115
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7113

def migrated_transaction_program
  @migrated_transaction_program
end

#other_recurring_productGoogle::Apis::AndroidpublisherV3::OtherRecurringProduct

Details of a recurring external transaction product which doesn't belong to any other more specific category. Corresponds to the JSON property otherRecurringProduct



7119
7120
7121
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7119

def other_recurring_product
  @other_recurring_product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7126
7127
7128
7129
7130
7131
7132
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7126

def update!(**args)
  @external_subscription = args[:external_subscription] if args.key?(:external_subscription)
  @external_transaction_token = args[:external_transaction_token] if args.key?(:external_transaction_token)
  @initial_external_transaction_id = args[:initial_external_transaction_id] if args.key?(:initial_external_transaction_id)
  @migrated_transaction_program = args[:migrated_transaction_program] if args.key?(:migrated_transaction_program)
  @other_recurring_product = args[:other_recurring_product] if args.key?(:other_recurring_product)
end