Class: Google::Apis::AndroidpublisherV3::RefundDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details for a partial or full refund.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RefundDetails

Returns a new instance of RefundDetails.



7149
7150
7151
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#taxGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property tax



7142
7143
7144
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7142

def tax
  @tax
end

#totalGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property total



7147
7148
7149
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7147

def total
  @total
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7154
7155
7156
7157
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7154

def update!(**args)
  @tax = args[:tax] if args.key?(:tax)
  @total = args[:total] if args.key?(:total)
end