Class: Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for a base plan specific to a region.
Instance Attribute Summary collapse
-
#new_subscriber_availability ⇒ Boolean
(also: #new_subscriber_availability?)
Whether the base plan in the specified region is available for new subscribers.
-
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalBasePlanConfig
constructor
A new instance of RegionalBasePlanConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalBasePlanConfig
Returns a new instance of RegionalBasePlanConfig.
8665 8666 8667 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_subscriber_availability ⇒ Boolean Also known as: new_subscriber_availability?
Whether the base plan in the specified region is available for new subscribers.
Existing subscribers will not have their subscription canceled if this value
is set to false. If not specified, this will default to false.
Corresponds to the JSON property newSubscriberAvailability
8651 8652 8653 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8651 def new_subscriber_availability @new_subscriber_availability end |
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property price
8657 8658 8659 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8657 def price @price end |
#region_code ⇒ String
Required. Region code this configuration applies to, as defined by ISO 3166-2,
e.g. "US".
Corresponds to the JSON property regionCode
8663 8664 8665 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8663 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8670 8671 8672 8673 8674 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8670 def update!(**args) @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability) @price = args[:price] if args.key?(:price) @region_code = args[:region_code] if args.key?(:region_code) end |