Class: Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for a base plan specific to a region.
Instance Attribute Summary collapse
-
#new_subscriber_availability ⇒ Boolean
(also: #new_subscriber_availability?)
Whether the base plan in the specified region is available for new subscribers.
-
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalBasePlanConfig
constructor
A new instance of RegionalBasePlanConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalBasePlanConfig
Returns a new instance of RegionalBasePlanConfig.
7974 7975 7976 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_subscriber_availability ⇒ Boolean Also known as: new_subscriber_availability?
Whether the base plan in the specified region is available for new subscribers.
Existing subscribers will not have their subscription canceled if this value
is set to false. If not specified, this will default to false.
Corresponds to the JSON property newSubscriberAvailability
7960 7961 7962 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7960 def new_subscriber_availability @new_subscriber_availability end |
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property price
7966 7967 7968 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7966 def price @price end |
#region_code ⇒ String
Required. Region code this configuration applies to, as defined by ISO 3166-2,
e.g. "US".
Corresponds to the JSON property regionCode
7972 7973 7974 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7972 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7979 7980 7981 7982 7983 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7979 def update!(**args) @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability) @price = args[:price] if args.key?(:price) @region_code = args[:region_code] if args.key?(:region_code) end |