Class: Google::Apis::AndroidpublisherV3::RegionalBasePlanConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration for a base plan specific to a region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalBasePlanConfig

Returns a new instance of RegionalBasePlanConfig.



7303
7304
7305
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_subscriber_availabilityBoolean Also known as: new_subscriber_availability?

Whether the base plan in the specified region is available for new subscribers. Existing subscribers will not have their subscription canceled if this value is set to false. If not specified, this will default to false. Corresponds to the JSON property newSubscriberAvailability

Returns:

  • (Boolean)


7289
7290
7291
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7289

def new_subscriber_availability
  @new_subscriber_availability
end

#priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property price



7295
7296
7297
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7295

def price
  @price
end

#region_codeString

Required. Region code this configuration applies to, as defined by ISO 3166-2, e.g. "US". Corresponds to the JSON property regionCode

Returns:

  • (String)


7301
7302
7303
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7301

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7308
7309
7310
7311
7312
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7308

def update!(**args)
  @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability)
  @price = args[:price] if args.key?(:price)
  @region_code = args[:region_code] if args.key?(:region_code)
end