Class: Google::Apis::AndroidpublisherV3::RegionalPriceMigrationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration for migration of a legacy price cohort.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalPriceMigrationConfig

Returns a new instance of RegionalPriceMigrationConfig.



7340
7341
7342
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#oldest_allowed_price_version_timeString

Required. Subscribers in all legacy price cohorts before this time will be migrated to the current price. Subscribers in any newer price cohorts are unaffected. Affected subscribers will receive one or more notifications from Google Play about the price change. Price decreases occur at the subscriber's next billing date. Price increases occur at the subscriber's next billing date following a notification period that varies by region and price increase type. Corresponds to the JSON property oldestAllowedPriceVersionTime

Returns:

  • (String)


7327
7328
7329
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7327

def oldest_allowed_price_version_time
  @oldest_allowed_price_version_time
end

#price_increase_typeString

Optional. The requested type of price increase Corresponds to the JSON property priceIncreaseType

Returns:

  • (String)


7332
7333
7334
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7332

def price_increase_type
  @price_increase_type
end

#region_codeString

Required. Region code this configuration applies to, as defined by ISO 3166-2, e.g. "US". Corresponds to the JSON property regionCode

Returns:

  • (String)


7338
7339
7340
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7338

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7345
7346
7347
7348
7349
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7345

def update!(**args)
  @oldest_allowed_price_version_time = args[:oldest_allowed_price_version_time] if args.key?(:oldest_allowed_price_version_time)
  @price_increase_type = args[:price_increase_type] if args.key?(:price_increase_type)
  @region_code = args[:region_code] if args.key?(:region_code)
end