Class: Google::Apis::AndroidpublisherV3::RegionalPriceMigrationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalPriceMigrationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for migration of a legacy price cohort.
Instance Attribute Summary collapse
-
#oldest_allowed_price_version_time ⇒ String
Required.
-
#price_increase_type ⇒ String
Optional.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalPriceMigrationConfig
constructor
A new instance of RegionalPriceMigrationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalPriceMigrationConfig
Returns a new instance of RegionalPriceMigrationConfig.
7243 7244 7245 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#oldest_allowed_price_version_time ⇒ String
Required. Subscribers in all legacy price cohorts before this time will be
migrated to the current price. Subscribers in any newer price cohorts are
unaffected. Affected subscribers will receive one or more notifications from
Google Play about the price change. Price decreases occur at the subscriber's
next billing date. Price increases occur at the subscriber's next billing date
following a notification period that varies by region and price increase type.
Corresponds to the JSON property oldestAllowedPriceVersionTime
7230 7231 7232 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7230 def oldest_allowed_price_version_time @oldest_allowed_price_version_time end |
#price_increase_type ⇒ String
Optional. The requested type of price increase
Corresponds to the JSON property priceIncreaseType
7235 7236 7237 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7235 def price_increase_type @price_increase_type end |
#region_code ⇒ String
Required. Region code this configuration applies to, as defined by ISO 3166-2,
e.g. "US".
Corresponds to the JSON property regionCode
7241 7242 7243 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7241 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7248 7249 7250 7251 7252 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7248 def update!(**args) @oldest_allowed_price_version_time = args[:oldest_allowed_price_version_time] if args.key?(:oldest_allowed_price_version_time) @price_increase_type = args[:price_increase_type] if args.key?(:price_increase_type) @region_code = args[:region_code] if args.key?(:region_code) end |