Class: Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for a subscription offer in a single region.
Instance Attribute Summary collapse
-
#new_subscriber_availability ⇒ Boolean
(also: #new_subscriber_availability?)
Whether the subscription offer in the specified region is available for new subscribers.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalSubscriptionOfferConfig
constructor
A new instance of RegionalSubscriptionOfferConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalSubscriptionOfferConfig
Returns a new instance of RegionalSubscriptionOfferConfig.
8066 8067 8068 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_subscriber_availability ⇒ Boolean Also known as: new_subscriber_availability?
Whether the subscription offer in the specified region is available for new
subscribers. Existing subscribers will not have their subscription cancelled
if this value is set to false. If not specified, this will default to false.
Corresponds to the JSON property newSubscriberAvailability
8057 8058 8059 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8057 def new_subscriber_availability @new_subscriber_availability end |
#region_code ⇒ String
Required. Immutable. Region code this configuration applies to, as defined by
ISO 3166-2, e.g. "US".
Corresponds to the JSON property regionCode
8064 8065 8066 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8064 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8071 8072 8073 8074 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8071 def update!(**args) @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability) @region_code = args[:region_code] if args.key?(:region_code) end |