Class: Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration for a subscription offer in a single region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalSubscriptionOfferConfig

Returns a new instance of RegionalSubscriptionOfferConfig.



7298
7299
7300
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_subscriber_availabilityBoolean Also known as: new_subscriber_availability?

Whether the subscription offer in the specified region is available for new subscribers. Existing subscribers will not have their subscription cancelled if this value is set to false. If not specified, this will default to false. Corresponds to the JSON property newSubscriberAvailability

Returns:

  • (Boolean)


7289
7290
7291
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7289

def new_subscriber_availability
  @new_subscriber_availability
end

#region_codeString

Required. Immutable. Region code this configuration applies to, as defined by ISO 3166-2, e.g. "US". Corresponds to the JSON property regionCode

Returns:

  • (String)


7296
7297
7298
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7296

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7303
7304
7305
7306
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7303

def update!(**args)
  @new_subscriber_availability = args[:new_subscriber_availability] if args.key?(:new_subscriber_availability)
  @region_code = args[:region_code] if args.key?(:region_code)
end