Class: Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Configuration for a single phase of a subscription offer in a single region.
Instance Attribute Summary collapse
-
#absolute_discount ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#free ⇒ Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseFreePriceOverride
Represents the free price override configuration for a single phase of a subscription offer Corresponds to the JSON property
free. -
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#region_code ⇒ String
Required.
-
#relative_discount ⇒ Float
The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalSubscriptionOfferPhaseConfig
constructor
A new instance of RegionalSubscriptionOfferPhaseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalSubscriptionOfferPhaseConfig
Returns a new instance of RegionalSubscriptionOfferPhaseConfig.
8984 8985 8986 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#absolute_discount ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property absoluteDiscount
8954 8955 8956 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8954 def absolute_discount @absolute_discount end |
#free ⇒ Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseFreePriceOverride
Represents the free price override configuration for a single phase of a
subscription offer
Corresponds to the JSON property free
8960 8961 8962 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8960 def free @free end |
#price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property price
8965 8966 8967 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8965 def price @price end |
#region_code ⇒ String
Required. Immutable. The region to which this config applies.
Corresponds to the JSON property regionCode
8970 8971 8972 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8970 def region_code @region_code end |
#relative_discount ⇒ Float
The fraction of the base plan price prorated over the phase duration that the
user pays for this offer phase. For example, if the base plan price for this
region is $12 for a period of 1 year, then a 50% discount for a phase of a
duration of 3 months would correspond to a price of $1.50. The discount must
be specified as a fraction strictly larger than 0 and strictly smaller than 1.
The resulting price will be rounded to the nearest billable unit (e.g. cents
for USD). The relative discount is considered invalid if the discounted price
ends up being smaller than the minimum price allowed in this region.
Corresponds to the JSON property relativeDiscount
8982 8983 8984 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8982 def relative_discount @relative_discount end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8989 def update!(**args) @absolute_discount = args[:absolute_discount] if args.key?(:absolute_discount) @free = args[:free] if args.key?(:free) @price = args[:price] if args.key?(:price) @region_code = args[:region_code] if args.key?(:region_code) @relative_discount = args[:relative_discount] if args.key?(:relative_discount) end |