Class: Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration for a single phase of a subscription offer in a single region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalSubscriptionOfferPhaseConfig

Returns a new instance of RegionalSubscriptionOfferPhaseConfig.



7449
7450
7451
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_discountGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property absoluteDiscount



7419
7420
7421
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7419

def absolute_discount
  @absolute_discount
end

#freeGoogle::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseFreePriceOverride

Represents the free price override configuration for a single phase of a subscription offer Corresponds to the JSON property free



7425
7426
7427
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7425

def free
  @free
end

#priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property price



7430
7431
7432
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7430

def price
  @price
end

#region_codeString

Required. Immutable. The region to which this config applies. Corresponds to the JSON property regionCode

Returns:

  • (String)


7435
7436
7437
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7435

def region_code
  @region_code
end

#relative_discountFloat

The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase. For example, if the base plan price for this region is $12 for a period of 1 year, then a 50% discount for a phase of a duration of 3 months would correspond to a price of $1.50. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in this region. Corresponds to the JSON property relativeDiscount

Returns:

  • (Float)


7447
7448
7449
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7447

def relative_discount
  @relative_discount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7454
7455
7456
7457
7458
7459
7460
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7454

def update!(**args)
  @absolute_discount = args[:absolute_discount] if args.key?(:absolute_discount)
  @free = args[:free] if args.key?(:free)
  @price = args[:price] if args.key?(:price)
  @region_code = args[:region_code] if args.key?(:region_code)
  @relative_discount = args[:relative_discount] if args.key?(:relative_discount)
end