Class: Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Configuration for a single phase of a subscription offer in a single region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalSubscriptionOfferPhaseConfig

Returns a new instance of RegionalSubscriptionOfferPhaseConfig.



7443
7444
7445
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_discountGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property absoluteDiscount



7413
7414
7415
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7413

def absolute_discount
  @absolute_discount
end

#freeGoogle::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseFreePriceOverride

Represents the free price override configuration for a single phase of a subscription offer Corresponds to the JSON property free



7419
7420
7421
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7419

def free
  @free
end

#priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property price



7424
7425
7426
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7424

def price
  @price
end

#region_codeString

Required. Immutable. The region to which this config applies. Corresponds to the JSON property regionCode

Returns:

  • (String)


7429
7430
7431
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7429

def region_code
  @region_code
end

#relative_discountFloat

The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase. For example, if the base plan price for this region is $12 for a period of 1 year, then a 50% discount for a phase of a duration of 3 months would correspond to a price of $1.50. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in this region. Corresponds to the JSON property relativeDiscount

Returns:

  • (Float)


7441
7442
7443
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7441

def relative_discount
  @relative_discount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7448
7449
7450
7451
7452
7453
7454
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7448

def update!(**args)
  @absolute_discount = args[:absolute_discount] if args.key?(:absolute_discount)
  @free = args[:free] if args.key?(:free)
  @price = args[:price] if args.key?(:price)
  @region_code = args[:region_code] if args.key?(:region_code)
  @relative_discount = args[:relative_discount] if args.key?(:relative_discount)
end