Class: Google::Apis::AndroidpublisherV3::RegionalTaxConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalTaxConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about taxation in a given geographical region.
Instance Attribute Summary collapse
-
#eligible_for_streaming_service_tax_rate ⇒ Boolean
(also: #eligible_for_streaming_service_tax_rate?)
You must tell us if your app contains streaming products to correctly charge US state and local sales tax.
-
#region_code ⇒ String
Required.
-
#streaming_tax_type ⇒ String
To collect communications or amusement taxes in the United States, choose the appropriate tax category.
-
#tax_tier ⇒ String
Tax tier to specify reduced tax rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalTaxConfig
constructor
A new instance of RegionalTaxConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalTaxConfig
Returns a new instance of RegionalTaxConfig.
7509 7510 7511 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eligible_for_streaming_service_tax_rate ⇒ Boolean Also known as: eligible_for_streaming_service_tax_rate?
You must tell us if your app contains streaming products to correctly charge
US state and local sales tax. Field only supported in the United States.
Corresponds to the JSON property eligibleForStreamingServiceTaxRate
7485 7486 7487 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7485 def eligible_for_streaming_service_tax_rate @eligible_for_streaming_service_tax_rate end |
#region_code ⇒ String
Required. Region code this configuration applies to, as defined by ISO 3166-2,
e.g. "US".
Corresponds to the JSON property regionCode
7492 7493 7494 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7492 def region_code @region_code end |
#streaming_tax_type ⇒ String
To collect communications or amusement taxes in the United States, choose the
appropriate tax category. Learn more.
Corresponds to the JSON property streamingTaxType
7499 7500 7501 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7499 def streaming_tax_type @streaming_tax_type end |
#tax_tier ⇒ String
Tax tier to specify reduced tax rate. Developers who sell digital news,
magazines, newspapers, books, or audiobooks in various regions may be eligible
for reduced tax rates. Learn more.
Corresponds to the JSON property taxTier
7507 7508 7509 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7507 def tax_tier @tax_tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7514 7515 7516 7517 7518 7519 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7514 def update!(**args) @eligible_for_streaming_service_tax_rate = args[:eligible_for_streaming_service_tax_rate] if args.key?(:eligible_for_streaming_service_tax_rate) @region_code = args[:region_code] if args.key?(:region_code) @streaming_tax_type = args[:streaming_tax_type] if args.key?(:streaming_tax_type) @tax_tier = args[:tax_tier] if args.key?(:tax_tier) end |