Class: Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Specified details about taxation in a given geographical region.
Instance Attribute Summary collapse
-
#eligible_for_streaming_service_tax_rate ⇒ Boolean
(also: #eligible_for_streaming_service_tax_rate?)
You must tell us if your app contains streaming products to correctly charge US state and local sales tax.
-
#streaming_tax_type ⇒ String
To collect communications or amusement taxes in the United States, choose the appropriate tax category.
-
#tax_tier ⇒ String
Tax tier to specify reduced tax rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalTaxRateInfo
constructor
A new instance of RegionalTaxRateInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalTaxRateInfo
Returns a new instance of RegionalTaxRateInfo.
7445 7446 7447 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eligible_for_streaming_service_tax_rate ⇒ Boolean Also known as: eligible_for_streaming_service_tax_rate?
You must tell us if your app contains streaming products to correctly charge
US state and local sales tax. Field only supported in the United States.
Corresponds to the JSON property eligibleForStreamingServiceTaxRate
7427 7428 7429 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7427 def eligible_for_streaming_service_tax_rate @eligible_for_streaming_service_tax_rate end |
#streaming_tax_type ⇒ String
To collect communications or amusement taxes in the United States, choose the
appropriate tax category. Learn more.
Corresponds to the JSON property streamingTaxType
7435 7436 7437 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7435 def streaming_tax_type @streaming_tax_type end |
#tax_tier ⇒ String
Tax tier to specify reduced tax rate. Developers who sell digital news,
magazines, newspapers, books, or audiobooks in various regions may be eligible
for reduced tax rates. Learn more.
Corresponds to the JSON property taxTier
7443 7444 7445 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7443 def tax_tier @tax_tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7450 7451 7452 7453 7454 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7450 def update!(**args) @eligible_for_streaming_service_tax_rate = args[:eligible_for_streaming_service_tax_rate] if args.key?(:eligible_for_streaming_service_tax_rate) @streaming_tax_type = args[:streaming_tax_type] if args.key?(:streaming_tax_type) @tax_tier = args[:tax_tier] if args.key?(:tax_tier) end |