Class: Google::Apis::AndroidpublisherV3::RestrictedPaymentCountries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Countries where the purchase of this product is restricted to payment methods registered in the same country. If empty, no payment location restrictions are imposed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestrictedPaymentCountries

Returns a new instance of RestrictedPaymentCountries.



7705
7706
7707
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#region_codesArray<String>

Required. Region codes to impose payment restrictions on, as defined by ISO 3166-2, e.g. "US". Corresponds to the JSON property regionCodes

Returns:

  • (Array<String>)


7703
7704
7705
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7703

def region_codes
  @region_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7710
7711
7712
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7710

def update!(**args)
  @region_codes = args[:region_codes] if args.key?(:region_codes)
end