Class: Google::Apis::AndroidpublisherV3::ReviewReplyResult
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::ReviewReplyResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
The result of replying/updating a reply to review.
Instance Attribute Summary collapse
-
#last_edited ⇒ Google::Apis::AndroidpublisherV3::Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#reply_text ⇒ String
The reply text that was applied.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReviewReplyResult
constructor
A new instance of ReviewReplyResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReviewReplyResult
Returns a new instance of ReviewReplyResult.
9202 9203 9204 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_edited ⇒ Google::Apis::AndroidpublisherV3::Timestamp
A Timestamp represents a point in time independent of any time zone or local
calendar, encoded as a count of seconds and fractions of seconds at nanosecond
resolution. The count is relative to an epoch at UTC midnight on January 1,
1970.
Corresponds to the JSON property lastEdited
9195 9196 9197 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9195 def last_edited @last_edited end |
#reply_text ⇒ String
The reply text that was applied.
Corresponds to the JSON property replyText
9200 9201 9202 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9200 def reply_text @reply_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9207 9208 9209 9210 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9207 def update!(**args) @last_edited = args[:last_edited] if args.key?(:last_edited) @reply_text = args[:reply_text] if args.key?(:reply_text) end |