Class: Google::Apis::AndroidpublisherV3::ReviewReplyResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The result of replying/updating a reply to review.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReviewReplyResult

Returns a new instance of ReviewReplyResult.



7840
7841
7842
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_editedGoogle::Apis::AndroidpublisherV3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970. Corresponds to the JSON property lastEdited



7833
7834
7835
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7833

def last_edited
  @last_edited
end

#reply_textString

The reply text that was applied. Corresponds to the JSON property replyText

Returns:

  • (String)


7838
7839
7840
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7838

def reply_text
  @reply_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7845
7846
7847
7848
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7845

def update!(**args)
  @last_edited = args[:last_edited] if args.key?(:last_edited)
  @reply_text = args[:reply_text] if args.key?(:reply_text)
end