Class: Google::Apis::AndroidpublisherV3::ReviewsListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response listing reviews.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReviewsListResponse

Returns a new instance of ReviewsListResponse.



7802
7803
7804
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_infoGoogle::Apis::AndroidpublisherV3::PageInfo

Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. Corresponds to the JSON property pageInfo



7783
7784
7785
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7783

def page_info
  @page_info
end

#reviewsArray<Google::Apis::AndroidpublisherV3::Review>

List of reviews. Corresponds to the JSON property reviews



7788
7789
7790
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7788

def reviews
  @reviews
end

#token_paginationGoogle::Apis::AndroidpublisherV3::TokenPagination

Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page. Corresponds to the JSON property tokenPagination



7800
7801
7802
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7800

def token_pagination
  @token_pagination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7807
7808
7809
7810
7811
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7807

def update!(**args)
  @page_info = args[:page_info] if args.key?(:page_info)
  @reviews = args[:reviews] if args.key?(:reviews)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
end