Class: Google::Apis::AndroidpublisherV3::RevocationContext
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::RevocationContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Revocation context of the purchases.subscriptionsv2.revoke API.
Instance Attribute Summary collapse
-
#full_refund ⇒ Google::Apis::AndroidpublisherV3::RevocationContextFullRefund
Used to determine if the refund type in the RevocationContext is a full refund.
-
#item_based_refund ⇒ Google::Apis::AndroidpublisherV3::RevocationContextItemBasedRefund
Used to determine what specific item to revoke in a subscription with multiple items.
-
#prorated_refund ⇒ Google::Apis::AndroidpublisherV3::RevocationContextProratedRefund
Used to determine if the refund type in the RevocationContext is a prorated refund.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevocationContext
constructor
A new instance of RevocationContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevocationContext
Returns a new instance of RevocationContext.
9313 9314 9315 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_refund ⇒ Google::Apis::AndroidpublisherV3::RevocationContextFullRefund
Used to determine if the refund type in the RevocationContext is a full refund.
Corresponds to the JSON property fullRefund
9299 9300 9301 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9299 def full_refund @full_refund end |
#item_based_refund ⇒ Google::Apis::AndroidpublisherV3::RevocationContextItemBasedRefund
Used to determine what specific item to revoke in a subscription with multiple
items.
Corresponds to the JSON property itemBasedRefund
9305 9306 9307 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9305 def item_based_refund @item_based_refund end |
#prorated_refund ⇒ Google::Apis::AndroidpublisherV3::RevocationContextProratedRefund
Used to determine if the refund type in the RevocationContext is a prorated
refund.
Corresponds to the JSON property proratedRefund
9311 9312 9313 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9311 def prorated_refund @prorated_refund end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9318 9319 9320 9321 9322 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9318 def update!(**args) @full_refund = args[:full_refund] if args.key?(:full_refund) @item_based_refund = args[:item_based_refund] if args.key?(:item_based_refund) @prorated_refund = args[:prorated_refund] if args.key?(:prorated_refund) end |