Class: Google::Apis::AndroidpublisherV3::RevocationContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Revocation context of the purchases.subscriptionsv2.revoke API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevocationContext

Returns a new instance of RevocationContext.



8622
8623
8624
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_refundGoogle::Apis::AndroidpublisherV3::RevocationContextFullRefund

Used to determine if the refund type in the RevocationContext is a full refund. Corresponds to the JSON property fullRefund



8608
8609
8610
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8608

def full_refund
  @full_refund
end

#item_based_refundGoogle::Apis::AndroidpublisherV3::RevocationContextItemBasedRefund

Used to determine what specific item to revoke in a subscription with multiple items. Corresponds to the JSON property itemBasedRefund



8614
8615
8616
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8614

def item_based_refund
  @item_based_refund
end

#prorated_refundGoogle::Apis::AndroidpublisherV3::RevocationContextProratedRefund

Used to determine if the refund type in the RevocationContext is a prorated refund. Corresponds to the JSON property proratedRefund



8620
8621
8622
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8620

def prorated_refund
  @prorated_refund
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8627
8628
8629
8630
8631
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8627

def update!(**args)
  @full_refund = args[:full_refund] if args.key?(:full_refund)
  @item_based_refund = args[:item_based_refund] if args.key?(:item_based_refund)
  @prorated_refund = args[:prorated_refund] if args.key?(:prorated_refund)
end