Class: Google::Apis::AndroidpublisherV3::RevocationContextItemBasedRefund

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Used to determine what specific item to revoke in a subscription with multiple items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevocationContextItemBasedRefund

Returns a new instance of RevocationContextItemBasedRefund.



7910
7911
7912
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_idString

Required. If the subscription is a subscription with add-ons, the product id of the subscription item to revoke. Corresponds to the JSON property productId

Returns:

  • (String)


7908
7909
7910
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7908

def product_id
  @product_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7915
7916
7917
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7915

def update!(**args)
  @product_id = args[:product_id] if args.key?(:product_id)
end