Class: Google::Apis::AndroidpublisherV3::RevocationContextItemBasedRefund

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Used to determine what specific item to revoke in a subscription with multiple items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevocationContextItemBasedRefund

Returns a new instance of RevocationContextItemBasedRefund.



7833
7834
7835
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_idString

Required. If the subscription is a subscription with add-ons, the product id of the subscription item to revoke. Corresponds to the JSON property productId

Returns:

  • (String)


7831
7832
7833
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7831

def product_id
  @product_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7838
7839
7840
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7838

def update!(**args)
  @product_id = args[:product_id] if args.key?(:product_id)
end