Class: Google::Apis::AndroidpublisherV3::ScreenDensityTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Targeting based on screen density.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScreenDensityTargeting

Returns a new instance of ScreenDensityTargeting.



8063
8064
8065
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::AndroidpublisherV3::ScreenDensity>

Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits. Corresponds to the JSON property alternatives



8056
8057
8058
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8056

def alternatives
  @alternatives
end

#valueArray<Google::Apis::AndroidpublisherV3::ScreenDensity>

Value of a screen density. Corresponds to the JSON property value



8061
8062
8063
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8061

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8068
8069
8070
8071
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8068

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @value = args[:value] if args.key?(:value)
end