Class: Google::Apis::AndroidpublisherV3::ScreenDensityTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Targeting based on screen density.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScreenDensityTargeting

Returns a new instance of ScreenDensityTargeting.



7966
7967
7968
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::AndroidpublisherV3::ScreenDensity>

Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits. Corresponds to the JSON property alternatives



7959
7960
7961
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7959

def alternatives
  @alternatives
end

#valueArray<Google::Apis::AndroidpublisherV3::ScreenDensity>

Value of a screen density. Corresponds to the JSON property value



7964
7965
7966
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7964

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7971
7972
7973
7974
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 7971

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @value = args[:value] if args.key?(:value)
end