Class: Google::Apis::AndroidpublisherV3::SplitApkVariant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Variant is a group of APKs that covers a part of the device configuration space. APKs from multiple variants are never combined on one device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitApkVariant

Returns a new instance of SplitApkVariant.



9656
9657
9658
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apk_setArray<Google::Apis::AndroidpublisherV3::ApkSet>

Set of APKs, one set per module. Corresponds to the JSON property apkSet



9642
9643
9644
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9642

def apk_set
  @apk_set
end

#targetingGoogle::Apis::AndroidpublisherV3::VariantTargeting

Targeting on the level of variants. Corresponds to the JSON property targeting



9647
9648
9649
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9647

def targeting
  @targeting
end

#variant_numberFixnum

Number of the variant, starting at 0 (unless overridden). A device will receive APKs from the first variant that matches the device configuration, with higher variant numbers having priority over lower variant numbers. Corresponds to the JSON property variantNumber

Returns:

  • (Fixnum)


9654
9655
9656
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9654

def variant_number
  @variant_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9661
9662
9663
9664
9665
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9661

def update!(**args)
  @apk_set = args[:apk_set] if args.key?(:apk_set)
  @targeting = args[:targeting] if args.key?(:targeting)
  @variant_number = args[:variant_number] if args.key?(:variant_number)
end