Class: Google::Apis::AndroidpublisherV3::SplitApkVariant
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SplitApkVariant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Variant is a group of APKs that covers a part of the device configuration space. APKs from multiple variants are never combined on one device.
Instance Attribute Summary collapse
-
#apk_set ⇒ Array<Google::Apis::AndroidpublisherV3::ApkSet>
Set of APKs, one set per module.
-
#targeting ⇒ Google::Apis::AndroidpublisherV3::VariantTargeting
Targeting on the level of variants.
-
#variant_number ⇒ Fixnum
Number of the variant, starting at 0 (unless overridden).
Instance Method Summary collapse
-
#initialize(**args) ⇒ SplitApkVariant
constructor
A new instance of SplitApkVariant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SplitApkVariant
Returns a new instance of SplitApkVariant.
8249 8250 8251 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apk_set ⇒ Array<Google::Apis::AndroidpublisherV3::ApkSet>
Set of APKs, one set per module.
Corresponds to the JSON property apkSet
8235 8236 8237 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8235 def apk_set @apk_set end |
#targeting ⇒ Google::Apis::AndroidpublisherV3::VariantTargeting
Targeting on the level of variants.
Corresponds to the JSON property targeting
8240 8241 8242 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8240 def targeting @targeting end |
#variant_number ⇒ Fixnum
Number of the variant, starting at 0 (unless overridden). A device will
receive APKs from the first variant that matches the device configuration,
with higher variant numbers having priority over lower variant numbers.
Corresponds to the JSON property variantNumber
8247 8248 8249 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8247 def variant_number @variant_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8254 8255 8256 8257 8258 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8254 def update!(**args) @apk_set = args[:apk_set] if args.key?(:apk_set) @targeting = args[:targeting] if args.key?(:targeting) @variant_number = args[:variant_number] if args.key?(:variant_number) end |