Class: Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information associated with purchases made with 'Subscribe with Google'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscribeWithGoogleInfo

Returns a new instance of SubscribeWithGoogleInfo.



8980
8981
8982
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_addressString

The email address of the user when the subscription was purchased. Corresponds to the JSON property emailAddress

Returns:

  • (String)


8958
8959
8960
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8958

def email_address
  @email_address
end

#family_nameString

The family name of the user when the subscription was purchased. Corresponds to the JSON property familyName

Returns:

  • (String)


8963
8964
8965
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8963

def family_name
  @family_name
end

#given_nameString

The given name of the user when the subscription was purchased. Corresponds to the JSON property givenName

Returns:

  • (String)


8968
8969
8970
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8968

def given_name
  @given_name
end

#profile_idString

The Google profile id of the user when the subscription was purchased. Corresponds to the JSON property profileId

Returns:

  • (String)


8973
8974
8975
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8973

def profile_id
  @profile_id
end

#profile_nameString

The profile name of the user when the subscription was purchased. Corresponds to the JSON property profileName

Returns:

  • (String)


8978
8979
8980
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8978

def profile_name
  @profile_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8985
8986
8987
8988
8989
8990
8991
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8985

def update!(**args)
  @email_address = args[:email_address] if args.key?(:email_address)
  @family_name = args[:family_name] if args.key?(:family_name)
  @given_name = args[:given_name] if args.key?(:given_name)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
  @profile_name = args[:profile_name] if args.key?(:profile_name)
end