Class: Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Information associated with purchases made with 'Subscribe with Google'.
Instance Attribute Summary collapse
-
#email_address ⇒ String
The email address of the user when the subscription was purchased.
-
#family_name ⇒ String
The family name of the user when the subscription was purchased.
-
#given_name ⇒ String
The given name of the user when the subscription was purchased.
-
#profile_id ⇒ String
The Google profile id of the user when the subscription was purchased.
-
#profile_name ⇒ String
The profile name of the user when the subscription was purchased.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscribeWithGoogleInfo
constructor
A new instance of SubscribeWithGoogleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscribeWithGoogleInfo
Returns a new instance of SubscribeWithGoogleInfo.
8315 8316 8317 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email_address ⇒ String
The email address of the user when the subscription was purchased.
Corresponds to the JSON property emailAddress
8293 8294 8295 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8293 def email_address @email_address end |
#family_name ⇒ String
The family name of the user when the subscription was purchased.
Corresponds to the JSON property familyName
8298 8299 8300 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8298 def family_name @family_name end |
#given_name ⇒ String
The given name of the user when the subscription was purchased.
Corresponds to the JSON property givenName
8303 8304 8305 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8303 def given_name @given_name end |
#profile_id ⇒ String
The Google profile id of the user when the subscription was purchased.
Corresponds to the JSON property profileId
8308 8309 8310 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8308 def profile_id @profile_id end |
#profile_name ⇒ String
The profile name of the user when the subscription was purchased.
Corresponds to the JSON property profileName
8313 8314 8315 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8313 def profile_name @profile_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8320 8321 8322 8323 8324 8325 8326 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8320 def update!(**args) @email_address = args[:email_address] if args.key?(:email_address) @family_name = args[:family_name] if args.key?(:family_name) @given_name = args[:given_name] if args.key?(:given_name) @profile_id = args[:profile_id] if args.key?(:profile_id) @profile_name = args[:profile_name] if args.key?(:profile_name) end |