Class: Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Information associated with purchases made with 'Subscribe with Google'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscribeWithGoogleInfo

Returns a new instance of SubscribeWithGoogleInfo.



8232
8233
8234
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_addressString

The email address of the user when the subscription was purchased. Corresponds to the JSON property emailAddress

Returns:

  • (String)


8210
8211
8212
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8210

def email_address
  @email_address
end

#family_nameString

The family name of the user when the subscription was purchased. Corresponds to the JSON property familyName

Returns:

  • (String)


8215
8216
8217
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8215

def family_name
  @family_name
end

#given_nameString

The given name of the user when the subscription was purchased. Corresponds to the JSON property givenName

Returns:

  • (String)


8220
8221
8222
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8220

def given_name
  @given_name
end

#profile_idString

The Google profile id of the user when the subscription was purchased. Corresponds to the JSON property profileId

Returns:

  • (String)


8225
8226
8227
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8225

def profile_id
  @profile_id
end

#profile_nameString

The profile name of the user when the subscription was purchased. Corresponds to the JSON property profileName

Returns:

  • (String)


8230
8231
8232
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8230

def profile_name
  @profile_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8237
8238
8239
8240
8241
8242
8243
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8237

def update!(**args)
  @email_address = args[:email_address] if args.key?(:email_address)
  @family_name = args[:family_name] if args.key?(:family_name)
  @given_name = args[:given_name] if args.key?(:given_name)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
  @profile_name = args[:profile_name] if args.key?(:profile_name)
end