Class: Google::Apis::AndroidpublisherV3::Subscription
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Subscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single subscription for an app.
Instance Attribute Summary collapse
-
#archived ⇒ Boolean
(also: #archived?)
Output only.
-
#base_plans ⇒ Array<Google::Apis::AndroidpublisherV3::BasePlan>
The set of base plans for this subscription.
-
#listings ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionListing>
Required.
-
#package_name ⇒ String
Immutable.
-
#product_id ⇒ String
Immutable.
-
#restricted_payment_countries ⇒ Google::Apis::AndroidpublisherV3::RestrictedPaymentCountries
Countries where the purchase of this product is restricted to payment methods registered in the same country.
-
#tax_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
Details about taxation, Google Play policy, and legal compliance for subscription products.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subscription
constructor
A new instance of Subscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subscription
Returns a new instance of Subscription.
9778 9779 9780 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archived ⇒ Boolean Also known as: archived?
Output only. Deprecated: subscription archiving is not supported.
Corresponds to the JSON property archived
9737 9738 9739 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9737 def archived @archived end |
#base_plans ⇒ Array<Google::Apis::AndroidpublisherV3::BasePlan>
The set of base plans for this subscription. Represents the prices and
duration of the subscription if no other offers apply.
Corresponds to the JSON property basePlans
9744 9745 9746 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9744 def base_plans @base_plans end |
#listings ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionListing>
Required. List of localized listings for this subscription. Must contain at
least an entry for the default language of the parent app.
Corresponds to the JSON property listings
9750 9751 9752 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9750 def listings @listings end |
#package_name ⇒ String
Immutable. Package name of the parent app.
Corresponds to the JSON property packageName
9755 9756 9757 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9755 def package_name @package_name end |
#product_id ⇒ String
Immutable. Unique product ID of the product. Unique within the parent app.
Product IDs must be composed of lower-case letters (a-z), numbers (0-9),
underscores (_) and dots (.). It must start with a lower-case letter or number,
and be between 1 and 40 (inclusive) characters in length.
Corresponds to the JSON property productId
9763 9764 9765 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9763 def product_id @product_id end |
#restricted_payment_countries ⇒ Google::Apis::AndroidpublisherV3::RestrictedPaymentCountries
Countries where the purchase of this product is restricted to payment methods
registered in the same country. If empty, no payment location restrictions are
imposed.
Corresponds to the JSON property restrictedPaymentCountries
9770 9771 9772 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9770 def restricted_payment_countries @restricted_payment_countries end |
#tax_and_compliance_settings ⇒ Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
Details about taxation, Google Play policy, and legal compliance for
subscription products.
Corresponds to the JSON property taxAndComplianceSettings
9776 9777 9778 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9776 def tax_and_compliance_settings @tax_and_compliance_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9783 def update!(**args) @archived = args[:archived] if args.key?(:archived) @base_plans = args[:base_plans] if args.key?(:base_plans) @listings = args[:listings] if args.key?(:listings) @package_name = args[:package_name] if args.key?(:package_name) @product_id = args[:product_id] if args.key?(:product_id) @restricted_payment_countries = args[:restricted_payment_countries] if args.key?(:restricted_payment_countries) @tax_and_compliance_settings = args[:tax_and_compliance_settings] if args.key?(:tax_and_compliance_settings) end |