Class: Google::Apis::AndroidpublisherV3::SubscriptionDeferralInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionDeferralInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A SubscriptionDeferralInfo contains the data needed to defer a subscription purchase to a future expiry time.
Instance Attribute Summary collapse
-
#desired_expiry_time_millis ⇒ Fixnum
The desired next expiry time to assign to the subscription, in milliseconds since the Epoch.
-
#expected_expiry_time_millis ⇒ Fixnum
The expected expiry time for the subscription.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionDeferralInfo
constructor
A new instance of SubscriptionDeferralInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionDeferralInfo
Returns a new instance of SubscriptionDeferralInfo.
9076 9077 9078 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#desired_expiry_time_millis ⇒ Fixnum
The desired next expiry time to assign to the subscription, in milliseconds
since the Epoch. The given time must be later/greater than the current expiry
time for the subscription.
Corresponds to the JSON property desiredExpiryTimeMillis
9068 9069 9070 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9068 def desired_expiry_time_millis @desired_expiry_time_millis end |
#expected_expiry_time_millis ⇒ Fixnum
The expected expiry time for the subscription. If the current expiry time for
the subscription is not the value specified here, the deferral will not occur.
Corresponds to the JSON property expectedExpiryTimeMillis
9074 9075 9076 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9074 def expected_expiry_time_millis @expected_expiry_time_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9081 9082 9083 9084 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9081 def update!(**args) @desired_expiry_time_millis = args[:desired_expiry_time_millis] if args.key?(:desired_expiry_time_millis) @expected_expiry_time_millis = args[:expected_expiry_time_millis] if args.key?(:expected_expiry_time_millis) end |