Class: Google::Apis::AndroidpublisherV3::SubscriptionDeferralInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A SubscriptionDeferralInfo contains the data needed to defer a subscription purchase to a future expiry time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionDeferralInfo

Returns a new instance of SubscriptionDeferralInfo.



8377
8378
8379
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#desired_expiry_time_millisFixnum

The desired next expiry time to assign to the subscription, in milliseconds since the Epoch. The given time must be later/greater than the current expiry time for the subscription. Corresponds to the JSON property desiredExpiryTimeMillis

Returns:

  • (Fixnum)


8369
8370
8371
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8369

def desired_expiry_time_millis
  @desired_expiry_time_millis
end

#expected_expiry_time_millisFixnum

The expected expiry time for the subscription. If the current expiry time for the subscription is not the value specified here, the deferral will not occur. Corresponds to the JSON property expectedExpiryTimeMillis

Returns:

  • (Fixnum)


8375
8376
8377
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8375

def expected_expiry_time_millis
  @expected_expiry_time_millis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8382
8383
8384
8385
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8382

def update!(**args)
  @desired_expiry_time_millis = args[:desired_expiry_time_millis] if args.key?(:desired_expiry_time_millis)
  @expected_expiry_time_millis = args[:expected_expiry_time_millis] if args.key?(:expected_expiry_time_millis)
end