Class: Google::Apis::AndroidpublisherV3::SubscriptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionDetails

Returns a new instance of SubscriptionDetails.



9863
9864
9865
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

The base plan ID of the subscription. Corresponds to the JSON property basePlanId

Returns:

  • (String)


9830
9831
9832
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9830

def base_plan_id
  @base_plan_id
end

#offer_idString

The offer ID for the current subscription offer. Corresponds to the JSON property offerId

Returns:

  • (String)


9835
9836
9837
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9835

def offer_id
  @offer_id
end

#offer_phaseString

Deprecated: Use offer_phase_details instead. The pricing phase for the billing period funded by this order. Corresponds to the JSON property offerPhase

Returns:

  • (String)


9841
9842
9843
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9841

def offer_phase
  @offer_phase
end

#offer_phase_detailsGoogle::Apis::AndroidpublisherV3::OfferPhaseDetails

Details of a pricing phase for the entitlement period funded by this order. Corresponds to the JSON property offerPhaseDetails



9846
9847
9848
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9846

def offer_phase_details
  @offer_phase_details
end

#service_period_end_timeString

The end of the billing period funded by this order. This is a snapshot of the billing/service period end time at the moment the order was processed, and should be used only for accounting. To get the current end time of the subscription service period, use purchases.subscriptionsv2.get. Corresponds to the JSON property servicePeriodEndTime

Returns:

  • (String)


9854
9855
9856
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9854

def service_period_end_time
  @service_period_end_time
end

#service_period_start_timeString

The start of the billing period funded by this order. This is a snapshot of the billing/service period start time at the moment the order was processed, and should be used only for accounting. Corresponds to the JSON property servicePeriodStartTime

Returns:

  • (String)


9861
9862
9863
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9861

def service_period_start_time
  @service_period_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9868
9869
9870
9871
9872
9873
9874
9875
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9868

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_phase = args[:offer_phase] if args.key?(:offer_phase)
  @offer_phase_details = args[:offer_phase_details] if args.key?(:offer_phase_details)
  @service_period_end_time = args[:service_period_end_time] if args.key?(:service_period_end_time)
  @service_period_start_time = args[:service_period_start_time] if args.key?(:service_period_start_time)
end