Class: Google::Apis::AndroidpublisherV3::SubscriptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionDetails

Returns a new instance of SubscriptionDetails.



8491
8492
8493
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

The base plan ID of the subscription. Corresponds to the JSON property basePlanId

Returns:

  • (String)


8458
8459
8460
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8458

def base_plan_id
  @base_plan_id
end

#offer_idString

The offer ID for the current subscription offer. Corresponds to the JSON property offerId

Returns:

  • (String)


8463
8464
8465
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8463

def offer_id
  @offer_id
end

#offer_phaseString

Deprecated: Use offer_phase_details instead. The pricing phase for the billing period funded by this order. Corresponds to the JSON property offerPhase

Returns:

  • (String)


8469
8470
8471
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8469

def offer_phase
  @offer_phase
end

#offer_phase_detailsGoogle::Apis::AndroidpublisherV3::OfferPhaseDetails

Details of a pricing phase for the entitlement period funded by this order. Corresponds to the JSON property offerPhaseDetails



8474
8475
8476
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8474

def offer_phase_details
  @offer_phase_details
end

#service_period_end_timeString

The end of the billing period funded by this order. This is a snapshot of the billing/service period end time at the moment the order was processed, and should be used only for accounting. To get the current end time of the subscription service period, use purchases.subscriptionsv2.get. Corresponds to the JSON property servicePeriodEndTime

Returns:

  • (String)


8482
8483
8484
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8482

def service_period_end_time
  @service_period_end_time
end

#service_period_start_timeString

The start of the billing period funded by this order. This is a snapshot of the billing/service period start time at the moment the order was processed, and should be used only for accounting. Corresponds to the JSON property servicePeriodStartTime

Returns:

  • (String)


8489
8490
8491
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8489

def service_period_start_time
  @service_period_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8496
8497
8498
8499
8500
8501
8502
8503
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8496

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_phase = args[:offer_phase] if args.key?(:offer_phase)
  @offer_phase_details = args[:offer_phase_details] if args.key?(:offer_phase_details)
  @service_period_end_time = args[:service_period_end_time] if args.key?(:service_period_end_time)
  @service_period_start_time = args[:service_period_start_time] if args.key?(:service_period_start_time)
end