Class: Google::Apis::AndroidpublisherV3::SubscriptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details of a subscription purchase.
Instance Attribute Summary collapse
-
#base_plan_id ⇒ String
The base plan ID of the subscription.
-
#offer_id ⇒ String
The offer ID for the current subscription offer.
-
#offer_phase ⇒ String
Deprecated: Use offer_phase_details instead.
-
#offer_phase_details ⇒ Google::Apis::AndroidpublisherV3::OfferPhaseDetails
Details of a pricing phase for the entitlement period funded by this order.
-
#service_period_end_time ⇒ String
The end of the billing period funded by this order.
-
#service_period_start_time ⇒ String
The start of the billing period funded by this order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionDetails
constructor
A new instance of SubscriptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionDetails
Returns a new instance of SubscriptionDetails.
8485 8486 8487 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_plan_id ⇒ String
The base plan ID of the subscription.
Corresponds to the JSON property basePlanId
8452 8453 8454 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8452 def base_plan_id @base_plan_id end |
#offer_id ⇒ String
The offer ID for the current subscription offer.
Corresponds to the JSON property offerId
8457 8458 8459 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8457 def offer_id @offer_id end |
#offer_phase ⇒ String
Deprecated: Use offer_phase_details instead. The pricing phase for the billing
period funded by this order.
Corresponds to the JSON property offerPhase
8463 8464 8465 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8463 def offer_phase @offer_phase end |
#offer_phase_details ⇒ Google::Apis::AndroidpublisherV3::OfferPhaseDetails
Details of a pricing phase for the entitlement period funded by this order.
Corresponds to the JSON property offerPhaseDetails
8468 8469 8470 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8468 def offer_phase_details @offer_phase_details end |
#service_period_end_time ⇒ String
The end of the billing period funded by this order. This is a snapshot of the
billing/service period end time at the moment the order was processed, and
should be used only for accounting. To get the current end time of the
subscription service period, use purchases.subscriptionsv2.get.
Corresponds to the JSON property servicePeriodEndTime
8476 8477 8478 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8476 def service_period_end_time @service_period_end_time end |
#service_period_start_time ⇒ String
The start of the billing period funded by this order. This is a snapshot of
the billing/service period start time at the moment the order was processed,
and should be used only for accounting.
Corresponds to the JSON property servicePeriodStartTime
8483 8484 8485 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8483 def service_period_start_time @service_period_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8490 8491 8492 8493 8494 8495 8496 8497 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8490 def update!(**args) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_phase = args[:offer_phase] if args.key?(:offer_phase) @offer_phase_details = args[:offer_phase_details] if args.key?(:offer_phase_details) @service_period_end_time = args[:service_period_end_time] if args.key?(:service_period_end_time) @service_period_start_time = args[:service_period_start_time] if args.key?(:service_period_start_time) end |