Class: Google::Apis::AndroidpublisherV3::SubscriptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details of a subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionDetails

Returns a new instance of SubscriptionDetails.



8428
8429
8430
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

The base plan ID of the subscription. Corresponds to the JSON property basePlanId

Returns:

  • (String)


8395
8396
8397
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8395

def base_plan_id
  @base_plan_id
end

#offer_idString

The offer ID for the current subscription offer. Corresponds to the JSON property offerId

Returns:

  • (String)


8400
8401
8402
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8400

def offer_id
  @offer_id
end

#offer_phaseString

The pricing phase for the billing period funded by this order. Deprecated. Use offer_phase_details instead. Corresponds to the JSON property offerPhase

Returns:

  • (String)


8406
8407
8408
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8406

def offer_phase
  @offer_phase
end

#offer_phase_detailsGoogle::Apis::AndroidpublisherV3::OfferPhaseDetails

Details of a pricing phase for the entitlement period funded by this order. Corresponds to the JSON property offerPhaseDetails



8411
8412
8413
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8411

def offer_phase_details
  @offer_phase_details
end

#service_period_end_timeString

The end of the billing period funded by this order. This is a snapshot of the billing/service period end time at the moment the order was processed, and should be used only for accounting. To get the current end time of the subscription service period, use purchases.subscriptionsv2.get. Corresponds to the JSON property servicePeriodEndTime

Returns:

  • (String)


8419
8420
8421
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8419

def service_period_end_time
  @service_period_end_time
end

#service_period_start_timeString

The start of the billing period funded by this order. This is a snapshot of the billing/service period start time at the moment the order was processed, and should be used only for accounting. Corresponds to the JSON property servicePeriodStartTime

Returns:

  • (String)


8426
8427
8428
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8426

def service_period_start_time
  @service_period_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8433
8434
8435
8436
8437
8438
8439
8440
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8433

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_phase = args[:offer_phase] if args.key?(:offer_phase)
  @offer_phase_details = args[:offer_phase_details] if args.key?(:offer_phase_details)
  @service_period_end_time = args[:service_period_end_time] if args.key?(:service_period_end_time)
  @service_period_start_time = args[:service_period_start_time] if args.key?(:service_period_start_time)
end