Class: Google::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Price change related information of a subscription item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionItemPriceChangeDetails

Returns a new instance of SubscriptionItemPriceChangeDetails.



8533
8534
8535
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expected_new_price_charge_timeString

The renewal time at which the price change will become effective for the user. This is subject to change(to a future time) due to cases where the renewal time shifts like pause. This field is only populated if the price change has not taken effect. Corresponds to the JSON property expectedNewPriceChargeTime

Returns:

  • (String)


8516
8517
8518
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8516

def expected_new_price_charge_time
  @expected_new_price_charge_time
end

#new_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property newPrice



8521
8522
8523
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8521

def new_price
  @new_price
end

#price_change_modeString

Price change mode specifies how the subscription item price is changing. Corresponds to the JSON property priceChangeMode

Returns:

  • (String)


8526
8527
8528
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8526

def price_change_mode
  @price_change_mode
end

#price_change_stateString

State the price change is currently in. Corresponds to the JSON property priceChangeState

Returns:

  • (String)


8531
8532
8533
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8531

def price_change_state
  @price_change_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8538
8539
8540
8541
8542
8543
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8538

def update!(**args)
  @expected_new_price_charge_time = args[:expected_new_price_charge_time] if args.key?(:expected_new_price_charge_time)
  @new_price = args[:new_price] if args.key?(:new_price)
  @price_change_mode = args[:price_change_mode] if args.key?(:price_change_mode)
  @price_change_state = args[:price_change_state] if args.key?(:price_change_state)
end