Class: Google::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Price change related information of a subscription item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionItemPriceChangeDetails

Returns a new instance of SubscriptionItemPriceChangeDetails.



8470
8471
8472
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expected_new_price_charge_timeString

The renewal time at which the price change will become effective for the user. This is subject to change(to a future time) due to cases where the renewal time shifts like pause. This field is only populated if the price change has not taken effect. Corresponds to the JSON property expectedNewPriceChargeTime

Returns:

  • (String)


8453
8454
8455
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8453

def expected_new_price_charge_time
  @expected_new_price_charge_time
end

#new_priceGoogle::Apis::AndroidpublisherV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property newPrice



8458
8459
8460
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8458

def new_price
  @new_price
end

#price_change_modeString

Price change mode specifies how the subscription item price is changing. Corresponds to the JSON property priceChangeMode

Returns:

  • (String)


8463
8464
8465
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8463

def price_change_mode
  @price_change_mode
end

#price_change_stateString

State the price change is currently in. Corresponds to the JSON property priceChangeState

Returns:

  • (String)


8468
8469
8470
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8468

def price_change_state
  @price_change_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8475
8476
8477
8478
8479
8480
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8475

def update!(**args)
  @expected_new_price_charge_time = args[:expected_new_price_charge_time] if args.key?(:expected_new_price_charge_time)
  @new_price = args[:new_price] if args.key?(:new_price)
  @price_change_mode = args[:price_change_mode] if args.key?(:price_change_mode)
  @price_change_state = args[:price_change_state] if args.key?(:price_change_state)
end