Class: Google::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionItemPriceChangeDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Price change related information of a subscription item.
Instance Attribute Summary collapse
-
#expected_new_price_charge_time ⇒ String
The renewal time at which the price change will become effective for the user.
-
#new_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
-
#price_change_mode ⇒ String
Price change mode specifies how the subscription item price is changing.
-
#price_change_state ⇒ String
State the price change is currently in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionItemPriceChangeDetails
constructor
A new instance of SubscriptionItemPriceChangeDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionItemPriceChangeDetails
Returns a new instance of SubscriptionItemPriceChangeDetails.
8470 8471 8472 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expected_new_price_charge_time ⇒ String
The renewal time at which the price change will become effective for the user.
This is subject to change(to a future time) due to cases where the renewal
time shifts like pause. This field is only populated if the price change has
not taken effect.
Corresponds to the JSON property expectedNewPriceChargeTime
8453 8454 8455 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8453 def expected_new_price_charge_time @expected_new_price_charge_time end |
#new_price ⇒ Google::Apis::AndroidpublisherV3::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property newPrice
8458 8459 8460 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8458 def new_price @new_price end |
#price_change_mode ⇒ String
Price change mode specifies how the subscription item price is changing.
Corresponds to the JSON property priceChangeMode
8463 8464 8465 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8463 def price_change_mode @price_change_mode end |
#price_change_state ⇒ String
State the price change is currently in.
Corresponds to the JSON property priceChangeState
8468 8469 8470 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8468 def price_change_state @price_change_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8475 8476 8477 8478 8479 8480 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8475 def update!(**args) @expected_new_price_charge_time = args[:expected_new_price_charge_time] if args.key?(:expected_new_price_charge_time) @new_price = args[:new_price] if args.key?(:new_price) @price_change_mode = args[:price_change_mode] if args.key?(:price_change_mode) @price_change_state = args[:price_change_state] if args.key?(:price_change_state) end |