Class: Google::Apis::AndroidpublisherV3::SubscriptionListing
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionListing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
The consumer-visible metadata of a subscription.
Instance Attribute Summary collapse
-
#benefits ⇒ Array<String>
A list of benefits shown to the user on platforms such as the Play Store and in restoration flows in the language of this listing.
-
#description ⇒ String
The description of this subscription in the language of this listing.
-
#language_code ⇒ String
Required.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionListing
constructor
A new instance of SubscriptionListing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionListing
Returns a new instance of SubscriptionListing.
9946 9947 9948 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#benefits ⇒ Array<String>
A list of benefits shown to the user on platforms such as the Play Store and
in restoration flows in the language of this listing. Plain text. Ordered list
of at most four benefits.
Corresponds to the JSON property benefits
9927 9928 9929 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9927 def benefits @benefits end |
#description ⇒ String
The description of this subscription in the language of this listing. Maximum
length - 200 characters. Plain text.
Corresponds to the JSON property description
9933 9934 9935 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9933 def description @description end |
#language_code ⇒ String
Required. The language of this listing, as defined by BCP-47, e.g. "en-US".
Corresponds to the JSON property languageCode
9938 9939 9940 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9938 def language_code @language_code end |
#title ⇒ String
Required. The title of this subscription in the language of this listing.
Plain text.
Corresponds to the JSON property title
9944 9945 9946 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9944 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9951 9952 9953 9954 9955 9956 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9951 def update!(**args) @benefits = args[:benefits] if args.key?(:benefits) @description = args[:description] if args.key?(:description) @language_code = args[:language_code] if args.key?(:language_code) @title = args[:title] if args.key?(:title) end |