Class: Google::Apis::AndroidpublisherV3::SubscriptionListing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The consumer-visible metadata of a subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionListing

Returns a new instance of SubscriptionListing.



8574
8575
8576
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#benefitsArray<String>

A list of benefits shown to the user on platforms such as the Play Store and in restoration flows in the language of this listing. Plain text. Ordered list of at most four benefits. Corresponds to the JSON property benefits

Returns:

  • (Array<String>)


8555
8556
8557
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8555

def benefits
  @benefits
end

#descriptionString

The description of this subscription in the language of this listing. Maximum length - 200 characters. Plain text. Corresponds to the JSON property description

Returns:

  • (String)


8561
8562
8563
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8561

def description
  @description
end

#language_codeString

Required. The language of this listing, as defined by BCP-47, e.g. "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


8566
8567
8568
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8566

def language_code
  @language_code
end

#titleString

Required. The title of this subscription in the language of this listing. Plain text. Corresponds to the JSON property title

Returns:

  • (String)


8572
8573
8574
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8572

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8579
8580
8581
8582
8583
8584
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8579

def update!(**args)
  @benefits = args[:benefits] if args.key?(:benefits)
  @description = args[:description] if args.key?(:description)
  @language_code = args[:language_code] if args.key?(:language_code)
  @title = args[:title] if args.key?(:title)
end