Class: Google::Apis::AndroidpublisherV3::SubscriptionOffer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single, temporary offer

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionOffer

Returns a new instance of SubscriptionOffer.



9287
9288
9289
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_plan_idString

Required. Immutable. The ID of the base plan to which this offer is an extension. Corresponds to the JSON property basePlanId

Returns:

  • (String)


9231
9232
9233
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9231

def base_plan_id
  @base_plan_id
end

#offer_idString

Required. Immutable. Unique ID of this subscription offer. Must be unique within the base plan. Corresponds to the JSON property offerId

Returns:

  • (String)


9237
9238
9239
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9237

def offer_id
  @offer_id
end

#offer_tagsArray<Google::Apis::AndroidpublisherV3::OfferTag>

List of up to 20 custom tags specified for this offer, and returned to the app through the billing library. Corresponds to the JSON property offerTags



9243
9244
9245
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9243

def offer_tags
  @offer_tags
end

#other_regions_configGoogle::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig

Configuration for any new locations Play may launch in specified on a subscription offer. Corresponds to the JSON property otherRegionsConfig



9249
9250
9251
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9249

def other_regions_config
  @other_regions_config
end

#package_nameString

Required. Immutable. The package name of the app the parent subscription belongs to. Corresponds to the JSON property packageName

Returns:

  • (String)


9255
9256
9257
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9255

def package_name
  @package_name
end

#phasesArray<Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase>

Required. The phases of this subscription offer. Must contain at least one and at most two entries. Users will always receive all these phases in the specified order. Corresponds to the JSON property phases



9262
9263
9264
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9262

def phases
  @phases
end

#product_idString

Required. Immutable. The ID of the parent subscription this offer belongs to. Corresponds to the JSON property productId

Returns:

  • (String)


9267
9268
9269
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9267

def product_id
  @product_id
end

#regional_configsArray<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig>

Required. The region-specific configuration of this offer. Must contain at least one entry. Corresponds to the JSON property regionalConfigs



9273
9274
9275
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9273

def regional_configs
  @regional_configs
end

#stateString

Output only. The current state of this offer. Can be changed using Activate and Deactivate actions. NB: the base plan state supersedes this state, so an active offer may not be available if the base plan is not active. Corresponds to the JSON property state

Returns:

  • (String)


9280
9281
9282
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9280

def state
  @state
end

#targetingGoogle::Apis::AndroidpublisherV3::SubscriptionOfferTargeting

Defines the rule a user needs to satisfy to receive this offer. Corresponds to the JSON property targeting



9285
9286
9287
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9285

def targeting
  @targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9292

def update!(**args)
  @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @offer_tags = args[:offer_tags] if args.key?(:offer_tags)
  @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config)
  @package_name = args[:package_name] if args.key?(:package_name)
  @phases = args[:phases] if args.key?(:phases)
  @product_id = args[:product_id] if args.key?(:product_id)
  @regional_configs = args[:regional_configs] if args.key?(:regional_configs)
  @state = args[:state] if args.key?(:state)
  @targeting = args[:targeting] if args.key?(:targeting)
end