Class: Google::Apis::AndroidpublisherV3::SubscriptionOffer
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single, temporary offer
Instance Attribute Summary collapse
-
#base_plan_id ⇒ String
Required.
-
#offer_id ⇒ String
Required.
-
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
List of up to 20 custom tags specified for this offer, and returned to the app through the billing library.
-
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig
Configuration for any new locations Play may launch in specified on a subscription offer.
-
#package_name ⇒ String
Required.
-
#phases ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase>
Required.
-
#product_id ⇒ String
Required.
-
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig>
Required.
-
#state ⇒ String
Output only.
-
#targeting ⇒ Google::Apis::AndroidpublisherV3::SubscriptionOfferTargeting
Defines the rule a user needs to satisfy to receive this offer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionOffer
constructor
A new instance of SubscriptionOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionOffer
Returns a new instance of SubscriptionOffer.
8588 8589 8590 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_plan_id ⇒ String
Required. Immutable. The ID of the base plan to which this offer is an
extension.
Corresponds to the JSON property basePlanId
8532 8533 8534 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8532 def base_plan_id @base_plan_id end |
#offer_id ⇒ String
Required. Immutable. Unique ID of this subscription offer. Must be unique
within the base plan.
Corresponds to the JSON property offerId
8538 8539 8540 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8538 def offer_id @offer_id end |
#offer_tags ⇒ Array<Google::Apis::AndroidpublisherV3::OfferTag>
List of up to 20 custom tags specified for this offer, and returned to the app
through the billing library.
Corresponds to the JSON property offerTags
8544 8545 8546 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8544 def @offer_tags end |
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferConfig
Configuration for any new locations Play may launch in specified on a
subscription offer.
Corresponds to the JSON property otherRegionsConfig
8550 8551 8552 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8550 def other_regions_config @other_regions_config end |
#package_name ⇒ String
Required. Immutable. The package name of the app the parent subscription
belongs to.
Corresponds to the JSON property packageName
8556 8557 8558 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8556 def package_name @package_name end |
#phases ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase>
Required. The phases of this subscription offer. Must contain at least one and
at most two entries. Users will always receive all these phases in the
specified order.
Corresponds to the JSON property phases
8563 8564 8565 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8563 def phases @phases end |
#product_id ⇒ String
Required. Immutable. The ID of the parent subscription this offer belongs to.
Corresponds to the JSON property productId
8568 8569 8570 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8568 def product_id @product_id end |
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferConfig>
Required. The region-specific configuration of this offer. Must contain at
least one entry.
Corresponds to the JSON property regionalConfigs
8574 8575 8576 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8574 def regional_configs @regional_configs end |
#state ⇒ String
Output only. The current state of this offer. Can be changed using Activate
and Deactivate actions. NB: the base plan state supersedes this state, so an
active offer may not be available if the base plan is not active.
Corresponds to the JSON property state
8581 8582 8583 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8581 def state @state end |
#targeting ⇒ Google::Apis::AndroidpublisherV3::SubscriptionOfferTargeting
Defines the rule a user needs to satisfy to receive this offer.
Corresponds to the JSON property targeting
8586 8587 8588 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8586 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8593 def update!(**args) @base_plan_id = args[:base_plan_id] if args.key?(:base_plan_id) @offer_id = args[:offer_id] if args.key?(:offer_id) @offer_tags = args[:offer_tags] if args.key?(:offer_tags) @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config) @package_name = args[:package_name] if args.key?(:package_name) @phases = args[:phases] if args.key?(:phases) @product_id = args[:product_id] if args.key?(:product_id) @regional_configs = args[:regional_configs] if args.key?(:regional_configs) @state = args[:state] if args.key?(:state) @targeting = args[:targeting] if args.key?(:targeting) end |