Class: Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A single phase of a subscription offer.
Instance Attribute Summary collapse
-
#duration ⇒ String
Required.
-
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseConfig
Configuration for any new locations Play may launch in for a single offer phase.
-
#recurrence_count ⇒ Fixnum
Required.
-
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionOfferPhase
constructor
A new instance of SubscriptionOfferPhase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionOfferPhase
Returns a new instance of SubscriptionOfferPhase.
8693 8694 8695 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
Required. The duration of a single recurrence of this phase. Specified in ISO
8601 format.
Corresponds to the JSON property duration
8672 8673 8674 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8672 def duration @duration end |
#other_regions_config ⇒ Google::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseConfig
Configuration for any new locations Play may launch in for a single offer
phase.
Corresponds to the JSON property otherRegionsConfig
8678 8679 8680 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8678 def other_regions_config @other_regions_config end |
#recurrence_count ⇒ Fixnum
Required. The number of times this phase repeats. If this offer phase is not
free, each recurrence charges the user the price of this offer phase.
Corresponds to the JSON property recurrenceCount
8684 8685 8686 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8684 def recurrence_count @recurrence_count end |
#regional_configs ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig>
Required. The region-specific configuration of this offer phase. This list
must contain exactly one entry for each region for which the subscription
offer has a regional config.
Corresponds to the JSON property regionalConfigs
8691 8692 8693 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8691 def regional_configs @regional_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8698 8699 8700 8701 8702 8703 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8698 def update!(**args) @duration = args[:duration] if args.key?(:duration) @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config) @recurrence_count = args[:recurrence_count] if args.key?(:recurrence_count) @regional_configs = args[:regional_configs] if args.key?(:regional_configs) end |