Class: Google::Apis::AndroidpublisherV3::SubscriptionOfferPhase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A single phase of a subscription offer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionOfferPhase

Returns a new instance of SubscriptionOfferPhase.



8539
8540
8541
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Required. The duration of a single recurrence of this phase. Specified in ISO 8601 format. Corresponds to the JSON property duration

Returns:

  • (String)


8518
8519
8520
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8518

def duration
  @duration
end

#other_regions_configGoogle::Apis::AndroidpublisherV3::OtherRegionsSubscriptionOfferPhaseConfig

Configuration for any new locations Play may launch in for a single offer phase. Corresponds to the JSON property otherRegionsConfig



8524
8525
8526
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8524

def other_regions_config
  @other_regions_config
end

#recurrence_countFixnum

Required. The number of times this phase repeats. If this offer phase is not free, each recurrence charges the user the price of this offer phase. Corresponds to the JSON property recurrenceCount

Returns:

  • (Fixnum)


8530
8531
8532
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8530

def recurrence_count
  @recurrence_count
end

#regional_configsArray<Google::Apis::AndroidpublisherV3::RegionalSubscriptionOfferPhaseConfig>

Required. The region-specific configuration of this offer phase. This list must contain exactly one entry for each region for which the subscription offer has a regional config. Corresponds to the JSON property regionalConfigs



8537
8538
8539
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8537

def regional_configs
  @regional_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8544
8545
8546
8547
8548
8549
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8544

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @other_regions_config = args[:other_regions_config] if args.key?(:other_regions_config)
  @recurrence_count = args[:recurrence_count] if args.key?(:recurrence_count)
  @regional_configs = args[:regional_configs] if args.key?(:regional_configs)
end