Class: Google::Apis::AndroidpublisherV3::SubscriptionPriceChange
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionPriceChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Contains the price change information for a subscription that can be used to control the user journey for the price change in the app. This can be in the form of seeking confirmation from the user or tailoring the experience for a successful conversion.
Instance Attribute Summary collapse
-
#new_price ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e.
-
#state ⇒ Fixnum
The current state of the price change.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionPriceChange
constructor
A new instance of SubscriptionPriceChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionPriceChange
Returns a new instance of SubscriptionPriceChange.
8678 8679 8680 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_price ⇒ Google::Apis::AndroidpublisherV3::Price
Definition of a price, i.e. currency and units.
Corresponds to the JSON property newPrice
8665 8666 8667 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8665 def new_price @new_price end |
#state ⇒ Fixnum
The current state of the price change. Possible values are: 0. Outstanding:
State for a pending price change waiting for the user to agree. In this state,
you can optionally seek confirmation from the user using the In-App API. 1.
Accepted: State for an accepted price change that the subscription will renew
with unless it's canceled. The price change takes effect on a future date when
the subscription renews. Note that the change might not occur when the
subscription is renewed next.
Corresponds to the JSON property state
8676 8677 8678 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8676 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8683 8684 8685 8686 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8683 def update!(**args) @new_price = args[:new_price] if args.key?(:new_price) @state = args[:state] if args.key?(:state) end |