Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Item-level info for a subscription purchase.
Instance Attribute Summary collapse
-
#auto_renewing_plan ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingPlan
Information related to an auto renewing plan.
-
#deferred_item_removal ⇒ Google::Apis::AndroidpublisherV3::DeferredItemRemoval
Information related to deferred item replacement.
-
#deferred_item_replacement ⇒ Google::Apis::AndroidpublisherV3::DeferredItemReplacement
Information related to deferred item replacement.
-
#expiry_time ⇒ String
Time at which the subscription expired or will expire unless the access is extended (ex. renews).
-
#item_replacement ⇒ Google::Apis::AndroidpublisherV3::ItemReplacement
Details about a subscription line item that is being replaced.
-
#latest_successful_order_id ⇒ String
The order id of the latest successful order associated with this item.
-
#offer_details ⇒ Google::Apis::AndroidpublisherV3::OfferDetails
Offer details information related to a purchase line item.
-
#offer_phase ⇒ Google::Apis::AndroidpublisherV3::OfferPhase
Offer phase details.
-
#prepaid_plan ⇒ Google::Apis::AndroidpublisherV3::PrepaidPlan
Information related to a prepaid plan.
-
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
-
#signup_promotion ⇒ Google::Apis::AndroidpublisherV3::SignupPromotion
The promotion applied on this item when purchased.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionPurchaseLineItem
constructor
A new instance of SubscriptionPurchaseLineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionPurchaseLineItem
Returns a new instance of SubscriptionPurchaseLineItem.
9436 9437 9438 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renewing_plan ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingPlan
Information related to an auto renewing plan.
Corresponds to the JSON property autoRenewingPlan
9381 9382 9383 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9381 def auto_renewing_plan @auto_renewing_plan end |
#deferred_item_removal ⇒ Google::Apis::AndroidpublisherV3::DeferredItemRemoval
Information related to deferred item replacement.
Corresponds to the JSON property deferredItemRemoval
9386 9387 9388 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9386 def deferred_item_removal @deferred_item_removal end |
#deferred_item_replacement ⇒ Google::Apis::AndroidpublisherV3::DeferredItemReplacement
Information related to deferred item replacement.
Corresponds to the JSON property deferredItemReplacement
9391 9392 9393 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9391 def deferred_item_replacement @deferred_item_replacement end |
#expiry_time ⇒ String
Time at which the subscription expired or will expire unless the access is
extended (ex. renews).
Corresponds to the JSON property expiryTime
9397 9398 9399 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9397 def expiry_time @expiry_time end |
#item_replacement ⇒ Google::Apis::AndroidpublisherV3::ItemReplacement
Details about a subscription line item that is being replaced.
Corresponds to the JSON property itemReplacement
9402 9403 9404 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9402 def item_replacement @item_replacement end |
#latest_successful_order_id ⇒ String
The order id of the latest successful order associated with this item. Not
present if the item is not owned by the user yet (e.g. the item being deferred
replaced to).
Corresponds to the JSON property latestSuccessfulOrderId
9409 9410 9411 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9409 def latest_successful_order_id @latest_successful_order_id end |
#offer_details ⇒ Google::Apis::AndroidpublisherV3::OfferDetails
Offer details information related to a purchase line item.
Corresponds to the JSON property offerDetails
9414 9415 9416 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9414 def offer_details @offer_details end |
#offer_phase ⇒ Google::Apis::AndroidpublisherV3::OfferPhase
Offer phase details.
Corresponds to the JSON property offerPhase
9419 9420 9421 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9419 def offer_phase @offer_phase end |
#prepaid_plan ⇒ Google::Apis::AndroidpublisherV3::PrepaidPlan
Information related to a prepaid plan.
Corresponds to the JSON property prepaidPlan
9424 9425 9426 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9424 def prepaid_plan @prepaid_plan end |
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
Corresponds to the JSON property productId
9429 9430 9431 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9429 def product_id @product_id end |
#signup_promotion ⇒ Google::Apis::AndroidpublisherV3::SignupPromotion
The promotion applied on this item when purchased.
Corresponds to the JSON property signupPromotion
9434 9435 9436 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9434 def signup_promotion @signup_promotion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9441 def update!(**args) @auto_renewing_plan = args[:auto_renewing_plan] if args.key?(:auto_renewing_plan) @deferred_item_removal = args[:deferred_item_removal] if args.key?(:deferred_item_removal) @deferred_item_replacement = args[:deferred_item_replacement] if args.key?(:deferred_item_replacement) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @item_replacement = args[:item_replacement] if args.key?(:item_replacement) @latest_successful_order_id = args[:latest_successful_order_id] if args.key?(:latest_successful_order_id) @offer_details = args[:offer_details] if args.key?(:offer_details) @offer_phase = args[:offer_phase] if args.key?(:offer_phase) @prepaid_plan = args[:prepaid_plan] if args.key?(:prepaid_plan) @product_id = args[:product_id] if args.key?(:product_id) @signup_promotion = args[:signup_promotion] if args.key?(:signup_promotion) end |