Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Item-level info for a subscription purchase.
Instance Attribute Summary collapse
-
#auto_renewing_plan ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingPlan
Information related to an auto renewing plan.
-
#deferred_item_removal ⇒ Google::Apis::AndroidpublisherV3::DeferredItemRemoval
Information related to deferred item replacement.
-
#deferred_item_replacement ⇒ Google::Apis::AndroidpublisherV3::DeferredItemReplacement
Information related to deferred item replacement.
-
#expiry_time ⇒ String
Time at which the subscription expired or will expire unless the access is extended (ex. renews).
-
#item_replacement ⇒ Google::Apis::AndroidpublisherV3::ItemReplacement
Details about a subscription line item that is being replaced.
-
#latest_successful_order_id ⇒ String
The order id of the latest successful order associated with this item.
-
#offer_details ⇒ Google::Apis::AndroidpublisherV3::OfferDetails
Offer details information related to a purchase line item.
-
#offer_phase ⇒ Google::Apis::AndroidpublisherV3::OfferPhase
Offer phase details.
-
#prepaid_plan ⇒ Google::Apis::AndroidpublisherV3::PrepaidPlan
Information related to a prepaid plan.
-
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
-
#signup_promotion ⇒ Google::Apis::AndroidpublisherV3::SignupPromotion
The promotion applied on this item when purchased.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionPurchaseLineItem
constructor
A new instance of SubscriptionPurchaseLineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionPurchaseLineItem
Returns a new instance of SubscriptionPurchaseLineItem.
9075 9076 9077 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renewing_plan ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingPlan
Information related to an auto renewing plan.
Corresponds to the JSON property autoRenewingPlan
9020 9021 9022 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9020 def auto_renewing_plan @auto_renewing_plan end |
#deferred_item_removal ⇒ Google::Apis::AndroidpublisherV3::DeferredItemRemoval
Information related to deferred item replacement.
Corresponds to the JSON property deferredItemRemoval
9025 9026 9027 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9025 def deferred_item_removal @deferred_item_removal end |
#deferred_item_replacement ⇒ Google::Apis::AndroidpublisherV3::DeferredItemReplacement
Information related to deferred item replacement.
Corresponds to the JSON property deferredItemReplacement
9030 9031 9032 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9030 def deferred_item_replacement @deferred_item_replacement end |
#expiry_time ⇒ String
Time at which the subscription expired or will expire unless the access is
extended (ex. renews).
Corresponds to the JSON property expiryTime
9036 9037 9038 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9036 def expiry_time @expiry_time end |
#item_replacement ⇒ Google::Apis::AndroidpublisherV3::ItemReplacement
Details about a subscription line item that is being replaced.
Corresponds to the JSON property itemReplacement
9041 9042 9043 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9041 def item_replacement @item_replacement end |
#latest_successful_order_id ⇒ String
The order id of the latest successful order associated with this item. Not
present if the item is not owned by the user yet (e.g. the item being deferred
replaced to).
Corresponds to the JSON property latestSuccessfulOrderId
9048 9049 9050 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9048 def latest_successful_order_id @latest_successful_order_id end |
#offer_details ⇒ Google::Apis::AndroidpublisherV3::OfferDetails
Offer details information related to a purchase line item.
Corresponds to the JSON property offerDetails
9053 9054 9055 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9053 def offer_details @offer_details end |
#offer_phase ⇒ Google::Apis::AndroidpublisherV3::OfferPhase
Offer phase details.
Corresponds to the JSON property offerPhase
9058 9059 9060 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9058 def offer_phase @offer_phase end |
#prepaid_plan ⇒ Google::Apis::AndroidpublisherV3::PrepaidPlan
Information related to a prepaid plan.
Corresponds to the JSON property prepaidPlan
9063 9064 9065 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9063 def prepaid_plan @prepaid_plan end |
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
Corresponds to the JSON property productId
9068 9069 9070 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9068 def product_id @product_id end |
#signup_promotion ⇒ Google::Apis::AndroidpublisherV3::SignupPromotion
The promotion applied on this item when purchased.
Corresponds to the JSON property signupPromotion
9073 9074 9075 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9073 def signup_promotion @signup_promotion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9080 def update!(**args) @auto_renewing_plan = args[:auto_renewing_plan] if args.key?(:auto_renewing_plan) @deferred_item_removal = args[:deferred_item_removal] if args.key?(:deferred_item_removal) @deferred_item_replacement = args[:deferred_item_replacement] if args.key?(:deferred_item_replacement) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @item_replacement = args[:item_replacement] if args.key?(:item_replacement) @latest_successful_order_id = args[:latest_successful_order_id] if args.key?(:latest_successful_order_id) @offer_details = args[:offer_details] if args.key?(:offer_details) @offer_phase = args[:offer_phase] if args.key?(:offer_phase) @prepaid_plan = args[:prepaid_plan] if args.key?(:prepaid_plan) @product_id = args[:product_id] if args.key?(:product_id) @signup_promotion = args[:signup_promotion] if args.key?(:signup_promotion) end |