Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Item-level info for a subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionPurchaseLineItem

Returns a new instance of SubscriptionPurchaseLineItem.



9012
9013
9014
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewing_planGoogle::Apis::AndroidpublisherV3::AutoRenewingPlan

Information related to an auto renewing plan. Corresponds to the JSON property autoRenewingPlan



8957
8958
8959
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8957

def auto_renewing_plan
  @auto_renewing_plan
end

#deferred_item_removalGoogle::Apis::AndroidpublisherV3::DeferredItemRemoval

Information related to deferred item replacement. Corresponds to the JSON property deferredItemRemoval



8962
8963
8964
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8962

def deferred_item_removal
  @deferred_item_removal
end

#deferred_item_replacementGoogle::Apis::AndroidpublisherV3::DeferredItemReplacement

Information related to deferred item replacement. Corresponds to the JSON property deferredItemReplacement



8967
8968
8969
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8967

def deferred_item_replacement
  @deferred_item_replacement
end

#expiry_timeString

Time at which the subscription expired or will expire unless the access is extended (ex. renews). Corresponds to the JSON property expiryTime

Returns:

  • (String)


8973
8974
8975
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8973

def expiry_time
  @expiry_time
end

#item_replacementGoogle::Apis::AndroidpublisherV3::ItemReplacement

Details about a subscription line item that is being replaced. Corresponds to the JSON property itemReplacement



8978
8979
8980
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8978

def item_replacement
  @item_replacement
end

#latest_successful_order_idString

The order id of the latest successful order associated with this item. Not present if the item is not owned by the user yet (e.g. the item being deferred replaced to). Corresponds to the JSON property latestSuccessfulOrderId

Returns:

  • (String)


8985
8986
8987
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8985

def latest_successful_order_id
  @latest_successful_order_id
end

#offer_detailsGoogle::Apis::AndroidpublisherV3::OfferDetails

Offer details information related to a purchase line item. Corresponds to the JSON property offerDetails



8990
8991
8992
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8990

def offer_details
  @offer_details
end

#offer_phaseGoogle::Apis::AndroidpublisherV3::OfferPhase

Offer phase details. Corresponds to the JSON property offerPhase



8995
8996
8997
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8995

def offer_phase
  @offer_phase
end

#prepaid_planGoogle::Apis::AndroidpublisherV3::PrepaidPlan

Information related to a prepaid plan. Corresponds to the JSON property prepaidPlan



9000
9001
9002
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9000

def prepaid_plan
  @prepaid_plan
end

#product_idString

The purchased product ID (for example, 'monthly001'). Corresponds to the JSON property productId

Returns:

  • (String)


9005
9006
9007
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9005

def product_id
  @product_id
end

#signup_promotionGoogle::Apis::AndroidpublisherV3::SignupPromotion

The promotion applied on this item when purchased. Corresponds to the JSON property signupPromotion



9010
9011
9012
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9010

def 
  @signup_promotion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9017
9018
9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9017

def update!(**args)
  @auto_renewing_plan = args[:auto_renewing_plan] if args.key?(:auto_renewing_plan)
  @deferred_item_removal = args[:deferred_item_removal] if args.key?(:deferred_item_removal)
  @deferred_item_replacement = args[:deferred_item_replacement] if args.key?(:deferred_item_replacement)
  @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
  @item_replacement = args[:item_replacement] if args.key?(:item_replacement)
  @latest_successful_order_id = args[:latest_successful_order_id] if args.key?(:latest_successful_order_id)
  @offer_details = args[:offer_details] if args.key?(:offer_details)
  @offer_phase = args[:offer_phase] if args.key?(:offer_phase)
  @prepaid_plan = args[:prepaid_plan] if args.key?(:prepaid_plan)
  @product_id = args[:product_id] if args.key?(:product_id)
  @signup_promotion = args[:signup_promotion] if args.key?(:signup_promotion)
end