Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Item-level info for a subscription purchase.
Instance Attribute Summary collapse
-
#auto_renewing_plan ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingPlan
Information related to an auto renewing plan.
-
#deferred_item_removal ⇒ Google::Apis::AndroidpublisherV3::DeferredItemRemoval
Information related to deferred item replacement.
-
#deferred_item_replacement ⇒ Google::Apis::AndroidpublisherV3::DeferredItemReplacement
Information related to deferred item replacement.
-
#expiry_time ⇒ String
Time at which the subscription expired or will expire unless the access is extended (ex. renews).
-
#item_replacement ⇒ Google::Apis::AndroidpublisherV3::ItemReplacement
Details about a subscription line item that is being replaced.
-
#latest_successful_order_id ⇒ String
The order id of the latest successful order associated with this item.
-
#offer_details ⇒ Google::Apis::AndroidpublisherV3::OfferDetails
Offer details information related to a purchase line item.
-
#offer_phase ⇒ Google::Apis::AndroidpublisherV3::OfferPhase
Offer phase details.
-
#prepaid_plan ⇒ Google::Apis::AndroidpublisherV3::PrepaidPlan
Information related to a prepaid plan.
-
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
-
#signup_promotion ⇒ Google::Apis::AndroidpublisherV3::SignupPromotion
The promotion applied on this item when purchased.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionPurchaseLineItem
constructor
A new instance of SubscriptionPurchaseLineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionPurchaseLineItem
Returns a new instance of SubscriptionPurchaseLineItem.
8992 8993 8994 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renewing_plan ⇒ Google::Apis::AndroidpublisherV3::AutoRenewingPlan
Information related to an auto renewing plan.
Corresponds to the JSON property autoRenewingPlan
8937 8938 8939 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8937 def auto_renewing_plan @auto_renewing_plan end |
#deferred_item_removal ⇒ Google::Apis::AndroidpublisherV3::DeferredItemRemoval
Information related to deferred item replacement.
Corresponds to the JSON property deferredItemRemoval
8942 8943 8944 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8942 def deferred_item_removal @deferred_item_removal end |
#deferred_item_replacement ⇒ Google::Apis::AndroidpublisherV3::DeferredItemReplacement
Information related to deferred item replacement.
Corresponds to the JSON property deferredItemReplacement
8947 8948 8949 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8947 def deferred_item_replacement @deferred_item_replacement end |
#expiry_time ⇒ String
Time at which the subscription expired or will expire unless the access is
extended (ex. renews).
Corresponds to the JSON property expiryTime
8953 8954 8955 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8953 def expiry_time @expiry_time end |
#item_replacement ⇒ Google::Apis::AndroidpublisherV3::ItemReplacement
Details about a subscription line item that is being replaced.
Corresponds to the JSON property itemReplacement
8958 8959 8960 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8958 def item_replacement @item_replacement end |
#latest_successful_order_id ⇒ String
The order id of the latest successful order associated with this item. Not
present if the item is not owned by the user yet (e.g. the item being deferred
replaced to).
Corresponds to the JSON property latestSuccessfulOrderId
8965 8966 8967 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8965 def latest_successful_order_id @latest_successful_order_id end |
#offer_details ⇒ Google::Apis::AndroidpublisherV3::OfferDetails
Offer details information related to a purchase line item.
Corresponds to the JSON property offerDetails
8970 8971 8972 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8970 def offer_details @offer_details end |
#offer_phase ⇒ Google::Apis::AndroidpublisherV3::OfferPhase
Offer phase details.
Corresponds to the JSON property offerPhase
8975 8976 8977 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8975 def offer_phase @offer_phase end |
#prepaid_plan ⇒ Google::Apis::AndroidpublisherV3::PrepaidPlan
Information related to a prepaid plan.
Corresponds to the JSON property prepaidPlan
8980 8981 8982 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8980 def prepaid_plan @prepaid_plan end |
#product_id ⇒ String
The purchased product ID (for example, 'monthly001').
Corresponds to the JSON property productId
8985 8986 8987 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8985 def product_id @product_id end |
#signup_promotion ⇒ Google::Apis::AndroidpublisherV3::SignupPromotion
The promotion applied on this item when purchased.
Corresponds to the JSON property signupPromotion
8990 8991 8992 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8990 def signup_promotion @signup_promotion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 9009 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 8997 def update!(**args) @auto_renewing_plan = args[:auto_renewing_plan] if args.key?(:auto_renewing_plan) @deferred_item_removal = args[:deferred_item_removal] if args.key?(:deferred_item_removal) @deferred_item_replacement = args[:deferred_item_replacement] if args.key?(:deferred_item_replacement) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @item_replacement = args[:item_replacement] if args.key?(:item_replacement) @latest_successful_order_id = args[:latest_successful_order_id] if args.key?(:latest_successful_order_id) @offer_details = args[:offer_details] if args.key?(:offer_details) @offer_phase = args[:offer_phase] if args.key?(:offer_phase) @prepaid_plan = args[:prepaid_plan] if args.key?(:prepaid_plan) @product_id = args[:product_id] if args.key?(:product_id) @signup_promotion = args[:signup_promotion] if args.key?(:signup_promotion) end |