Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseV2
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionPurchaseV2
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Indicates the status of a user's subscription purchase.
Instance Attribute Summary collapse
-
#acknowledgement_state ⇒ String
The acknowledgement state of the subscription.
-
#canceled_state_context ⇒ Google::Apis::AndroidpublisherV3::CanceledStateContext
Information specific to a subscription in the SUBSCRIPTION_STATE_CANCELED or SUBSCRIPTION_STATE_EXPIRED state.
-
#etag ⇒ String
Entity tag representing the current state of the subscription.
-
#external_account_identifiers ⇒ Google::Apis::AndroidpublisherV3::ExternalAccountIdentifiers
User account identifier in the third-party service.
-
#in_grace_period_state_context ⇒ Google::Apis::AndroidpublisherV3::InGracePeriodStateContext
Additional context around subscriptions in IN_GRACE_PERIOD state.
-
#kind ⇒ String
This kind represents a SubscriptionPurchaseV2 object in the androidpublisher service.
-
#line_items ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem>
Item-level info for a subscription purchase.
-
#linked_purchase_token ⇒ String
The purchase token of the old subscription if this subscription is one of the following: * Re-signup of a canceled but non-lapsed subscription * Upgrade/ downgrade from a previous subscription.
-
#on_hold_state_context ⇒ Google::Apis::AndroidpublisherV3::OnHoldStateContext
Additional context around subscriptions in ON_HOLD state.
-
#out_of_app_purchase_context ⇒ Google::Apis::AndroidpublisherV3::OutOfAppPurchaseContext
Information specific to an out of app purchase.
-
#paused_state_context ⇒ Google::Apis::AndroidpublisherV3::PausedStateContext
Information specific to a subscription in paused state.
-
#region_code ⇒ String
ISO 3166-1 alpha-2 billing country/region code of the user at the time the subscription was granted.
-
#start_time ⇒ String
Time at which the subscription was granted.
-
#subscribe_with_google_info ⇒ Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo
Information associated with purchases made with 'Subscribe with Google'.
-
#subscription_state ⇒ String
The current state of the subscription.
-
#test_purchase ⇒ Google::Apis::AndroidpublisherV3::TestPurchase
Whether this subscription purchase is a test purchase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionPurchaseV2
constructor
A new instance of SubscriptionPurchaseV2.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionPurchaseV2
Returns a new instance of SubscriptionPurchaseV2.
10539 10540 10541 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acknowledgement_state ⇒ String
The acknowledgement state of the subscription.
Corresponds to the JSON property acknowledgementState
10451 10452 10453 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10451 def acknowledgement_state @acknowledgement_state end |
#canceled_state_context ⇒ Google::Apis::AndroidpublisherV3::CanceledStateContext
Information specific to a subscription in the SUBSCRIPTION_STATE_CANCELED or
SUBSCRIPTION_STATE_EXPIRED state.
Corresponds to the JSON property canceledStateContext
10457 10458 10459 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10457 def canceled_state_context @canceled_state_context end |
#etag ⇒ String
Entity tag representing the current state of the subscription. The developer
will provide this etag for subscription actions. This etag is always present
for auto-renewing and prepaid subscriptions.
Corresponds to the JSON property etag
10464 10465 10466 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10464 def etag @etag end |
#external_account_identifiers ⇒ Google::Apis::AndroidpublisherV3::ExternalAccountIdentifiers
User account identifier in the third-party service.
Corresponds to the JSON property externalAccountIdentifiers
10469 10470 10471 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10469 def external_account_identifiers @external_account_identifiers end |
#in_grace_period_state_context ⇒ Google::Apis::AndroidpublisherV3::InGracePeriodStateContext
Additional context around subscriptions in IN_GRACE_PERIOD state.
Corresponds to the JSON property inGracePeriodStateContext
10474 10475 10476 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10474 def in_grace_period_state_context @in_grace_period_state_context end |
#kind ⇒ String
This kind represents a SubscriptionPurchaseV2 object in the androidpublisher
service.
Corresponds to the JSON property kind
10480 10481 10482 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10480 def kind @kind end |
#line_items ⇒ Array<Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem>
Item-level info for a subscription purchase. The items in the same purchase
should be either all with AutoRenewingPlan or all with PrepaidPlan.
Corresponds to the JSON property lineItems
10486 10487 10488 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10486 def line_items @line_items end |
#linked_purchase_token ⇒ String
The purchase token of the old subscription if this subscription is one of the following: * Re-signup of a canceled but non-lapsed subscription * Upgrade/ downgrade from a previous subscription. * Convert from prepaid to auto renewing subscription. * Convert from an auto renewing subscription to prepaid.
- Topup a prepaid subscription.
Corresponds to the JSON property
linkedPurchaseToken
10495 10496 10497 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10495 def linked_purchase_token @linked_purchase_token end |
#on_hold_state_context ⇒ Google::Apis::AndroidpublisherV3::OnHoldStateContext
Additional context around subscriptions in ON_HOLD state.
Corresponds to the JSON property onHoldStateContext
10500 10501 10502 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10500 def on_hold_state_context @on_hold_state_context end |
#out_of_app_purchase_context ⇒ Google::Apis::AndroidpublisherV3::OutOfAppPurchaseContext
Information specific to an out of app purchase.
Corresponds to the JSON property outOfAppPurchaseContext
10505 10506 10507 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10505 def out_of_app_purchase_context @out_of_app_purchase_context end |
#paused_state_context ⇒ Google::Apis::AndroidpublisherV3::PausedStateContext
Information specific to a subscription in paused state.
Corresponds to the JSON property pausedStateContext
10510 10511 10512 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10510 def paused_state_context @paused_state_context end |
#region_code ⇒ String
ISO 3166-1 alpha-2 billing country/region code of the user at the time the
subscription was granted.
Corresponds to the JSON property regionCode
10516 10517 10518 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10516 def region_code @region_code end |
#start_time ⇒ String
Time at which the subscription was granted. Not set for pending subscriptions (
subscription was created but awaiting payment during signup).
Corresponds to the JSON property startTime
10522 10523 10524 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10522 def start_time @start_time end |
#subscribe_with_google_info ⇒ Google::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo
Information associated with purchases made with 'Subscribe with Google'.
Corresponds to the JSON property subscribeWithGoogleInfo
10527 10528 10529 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10527 def subscribe_with_google_info @subscribe_with_google_info end |
#subscription_state ⇒ String
The current state of the subscription.
Corresponds to the JSON property subscriptionState
10532 10533 10534 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10532 def subscription_state @subscription_state end |
#test_purchase ⇒ Google::Apis::AndroidpublisherV3::TestPurchase
Whether this subscription purchase is a test purchase.
Corresponds to the JSON property testPurchase
10537 10538 10539 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10537 def test_purchase @test_purchase end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10544 10545 10546 10547 10548 10549 10550 10551 10552 10553 10554 10555 10556 10557 10558 10559 10560 10561 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10544 def update!(**args) @acknowledgement_state = args[:acknowledgement_state] if args.key?(:acknowledgement_state) @canceled_state_context = args[:canceled_state_context] if args.key?(:canceled_state_context) @etag = args[:etag] if args.key?(:etag) @external_account_identifiers = args[:external_account_identifiers] if args.key?(:external_account_identifiers) @in_grace_period_state_context = args[:in_grace_period_state_context] if args.key?(:in_grace_period_state_context) @kind = args[:kind] if args.key?(:kind) @line_items = args[:line_items] if args.key?(:line_items) @linked_purchase_token = args[:linked_purchase_token] if args.key?(:linked_purchase_token) @on_hold_state_context = args[:on_hold_state_context] if args.key?(:on_hold_state_context) @out_of_app_purchase_context = args[:out_of_app_purchase_context] if args.key?(:out_of_app_purchase_context) @paused_state_context = args[:paused_state_context] if args.key?(:paused_state_context) @region_code = args[:region_code] if args.key?(:region_code) @start_time = args[:start_time] if args.key?(:start_time) @subscribe_with_google_info = args[:subscribe_with_google_info] if args.key?(:subscribe_with_google_info) @subscription_state = args[:subscription_state] if args.key?(:subscription_state) @test_purchase = args[:test_purchase] if args.key?(:test_purchase) end |