Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseV2

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Indicates the status of a user's subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionPurchaseV2

Returns a new instance of SubscriptionPurchaseV2.



9551
9552
9553
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acknowledgement_stateString

The acknowledgement state of the subscription. Corresponds to the JSON property acknowledgementState

Returns:

  • (String)


9463
9464
9465
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9463

def acknowledgement_state
  @acknowledgement_state
end

#canceled_state_contextGoogle::Apis::AndroidpublisherV3::CanceledStateContext

Information specific to a subscription in the SUBSCRIPTION_STATE_CANCELED or SUBSCRIPTION_STATE_EXPIRED state. Corresponds to the JSON property canceledStateContext



9469
9470
9471
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9469

def canceled_state_context
  @canceled_state_context
end

#etagString

Entity tag representing the current state of the subscription. The developer will provide this etag for subscription actions. This etag is always present for auto-renewing and prepaid subscriptions. Corresponds to the JSON property etag

Returns:

  • (String)


9476
9477
9478
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9476

def etag
  @etag
end

#external_account_identifiersGoogle::Apis::AndroidpublisherV3::ExternalAccountIdentifiers

User account identifier in the third-party service. Corresponds to the JSON property externalAccountIdentifiers



9481
9482
9483
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9481

def 
  @external_account_identifiers
end

#in_grace_period_state_contextGoogle::Apis::AndroidpublisherV3::InGracePeriodStateContext

Additional context around subscriptions in IN_GRACE_PERIOD state. Corresponds to the JSON property inGracePeriodStateContext



9486
9487
9488
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9486

def in_grace_period_state_context
  @in_grace_period_state_context
end

#kindString

This kind represents a SubscriptionPurchaseV2 object in the androidpublisher service. Corresponds to the JSON property kind

Returns:

  • (String)


9492
9493
9494
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9492

def kind
  @kind
end

#line_itemsArray<Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem>

Item-level info for a subscription purchase. The items in the same purchase should be either all with AutoRenewingPlan or all with PrepaidPlan. Corresponds to the JSON property lineItems



9498
9499
9500
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9498

def line_items
  @line_items
end

#linked_purchase_tokenString

The purchase token of the old subscription if this subscription is one of the following: * Re-signup of a canceled but non-lapsed subscription * Upgrade/ downgrade from a previous subscription. * Convert from prepaid to auto renewing subscription. * Convert from an auto renewing subscription to prepaid.

  • Topup a prepaid subscription. Corresponds to the JSON property linkedPurchaseToken

Returns:

  • (String)


9507
9508
9509
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9507

def linked_purchase_token
  @linked_purchase_token
end

#on_hold_state_contextGoogle::Apis::AndroidpublisherV3::OnHoldStateContext

Additional context around subscriptions in ON_HOLD state. Corresponds to the JSON property onHoldStateContext



9512
9513
9514
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9512

def on_hold_state_context
  @on_hold_state_context
end

#out_of_app_purchase_contextGoogle::Apis::AndroidpublisherV3::OutOfAppPurchaseContext

Information specific to an out of app purchase. Corresponds to the JSON property outOfAppPurchaseContext



9517
9518
9519
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9517

def out_of_app_purchase_context
  @out_of_app_purchase_context
end

#paused_state_contextGoogle::Apis::AndroidpublisherV3::PausedStateContext

Information specific to a subscription in paused state. Corresponds to the JSON property pausedStateContext



9522
9523
9524
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9522

def paused_state_context
  @paused_state_context
end

#region_codeString

ISO 3166-1 alpha-2 billing country/region code of the user at the time the subscription was granted. Corresponds to the JSON property regionCode

Returns:

  • (String)


9528
9529
9530
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9528

def region_code
  @region_code
end

#start_timeString

Time at which the subscription was granted. Not set for pending subscriptions ( subscription was created but awaiting payment during signup). Corresponds to the JSON property startTime

Returns:

  • (String)


9534
9535
9536
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9534

def start_time
  @start_time
end

#subscribe_with_google_infoGoogle::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo

Information associated with purchases made with 'Subscribe with Google'. Corresponds to the JSON property subscribeWithGoogleInfo



9539
9540
9541
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9539

def subscribe_with_google_info
  @subscribe_with_google_info
end

#subscription_stateString

The current state of the subscription. Corresponds to the JSON property subscriptionState

Returns:

  • (String)


9544
9545
9546
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9544

def subscription_state
  @subscription_state
end

#test_purchaseGoogle::Apis::AndroidpublisherV3::TestPurchase

Whether this subscription purchase is a test purchase. Corresponds to the JSON property testPurchase



9549
9550
9551
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9549

def test_purchase
  @test_purchase
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
9571
9572
9573
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9556

def update!(**args)
  @acknowledgement_state = args[:acknowledgement_state] if args.key?(:acknowledgement_state)
  @canceled_state_context = args[:canceled_state_context] if args.key?(:canceled_state_context)
  @etag = args[:etag] if args.key?(:etag)
  @external_account_identifiers = args[:external_account_identifiers] if args.key?(:external_account_identifiers)
  @in_grace_period_state_context = args[:in_grace_period_state_context] if args.key?(:in_grace_period_state_context)
  @kind = args[:kind] if args.key?(:kind)
  @line_items = args[:line_items] if args.key?(:line_items)
  @linked_purchase_token = args[:linked_purchase_token] if args.key?(:linked_purchase_token)
  @on_hold_state_context = args[:on_hold_state_context] if args.key?(:on_hold_state_context)
  @out_of_app_purchase_context = args[:out_of_app_purchase_context] if args.key?(:out_of_app_purchase_context)
  @paused_state_context = args[:paused_state_context] if args.key?(:paused_state_context)
  @region_code = args[:region_code] if args.key?(:region_code)
  @start_time = args[:start_time] if args.key?(:start_time)
  @subscribe_with_google_info = args[:subscribe_with_google_info] if args.key?(:subscribe_with_google_info)
  @subscription_state = args[:subscription_state] if args.key?(:subscription_state)
  @test_purchase = args[:test_purchase] if args.key?(:test_purchase)
end