Class: Google::Apis::AndroidpublisherV3::SubscriptionPurchaseV2

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Indicates the status of a user's subscription purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionPurchaseV2

Returns a new instance of SubscriptionPurchaseV2.



9107
9108
9109
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acknowledgement_stateString

The acknowledgement state of the subscription. Corresponds to the JSON property acknowledgementState

Returns:

  • (String)


9019
9020
9021
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9019

def acknowledgement_state
  @acknowledgement_state
end

#canceled_state_contextGoogle::Apis::AndroidpublisherV3::CanceledStateContext

Information specific to a subscription in the SUBSCRIPTION_STATE_CANCELED or SUBSCRIPTION_STATE_EXPIRED state. Corresponds to the JSON property canceledStateContext



9025
9026
9027
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9025

def canceled_state_context
  @canceled_state_context
end

#etagString

Entity tag representing the current state of the subscription. The developer will provide this etag for subscription actions. This etag is always present for auto-renewing and prepaid subscriptions. Corresponds to the JSON property etag

Returns:

  • (String)


9032
9033
9034
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9032

def etag
  @etag
end

#external_account_identifiersGoogle::Apis::AndroidpublisherV3::ExternalAccountIdentifiers

User account identifier in the third-party service. Corresponds to the JSON property externalAccountIdentifiers



9037
9038
9039
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9037

def 
  @external_account_identifiers
end

#kindString

This kind represents a SubscriptionPurchaseV2 object in the androidpublisher service. Corresponds to the JSON property kind

Returns:

  • (String)


9043
9044
9045
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9043

def kind
  @kind
end

#latest_order_idString

Deprecated: Use line_items.latest_successful_order_id instead. The order id of the latest order associated with the purchase of the subscription. For autoRenewing subscription, this is the order id of signup order if it is not renewed yet, or the last recurring order id (success, pending, or declined order). For prepaid subscription, this is the order id associated with the queried purchase token. Corresponds to the JSON property latestOrderId

Returns:

  • (String)


9053
9054
9055
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9053

def latest_order_id
  @latest_order_id
end

#line_itemsArray<Google::Apis::AndroidpublisherV3::SubscriptionPurchaseLineItem>

Item-level info for a subscription purchase. The items in the same purchase should be either all with AutoRenewingPlan or all with PrepaidPlan. Corresponds to the JSON property lineItems



9059
9060
9061
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9059

def line_items
  @line_items
end

#linked_purchase_tokenString

The purchase token of the old subscription if this subscription is one of the following: * Re-signup of a canceled but non-lapsed subscription * Upgrade/ downgrade from a previous subscription. * Convert from prepaid to auto renewing subscription. * Convert from an auto renewing subscription to prepaid.

  • Topup a prepaid subscription. Corresponds to the JSON property linkedPurchaseToken

Returns:

  • (String)


9068
9069
9070
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9068

def linked_purchase_token
  @linked_purchase_token
end

#out_of_app_purchase_contextGoogle::Apis::AndroidpublisherV3::OutOfAppPurchaseContext

Information specific to an out of app purchase. Corresponds to the JSON property outOfAppPurchaseContext



9073
9074
9075
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9073

def out_of_app_purchase_context
  @out_of_app_purchase_context
end

#paused_state_contextGoogle::Apis::AndroidpublisherV3::PausedStateContext

Information specific to a subscription in paused state. Corresponds to the JSON property pausedStateContext



9078
9079
9080
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9078

def paused_state_context
  @paused_state_context
end

#region_codeString

ISO 3166-1 alpha-2 billing country/region code of the user at the time the subscription was granted. Corresponds to the JSON property regionCode

Returns:

  • (String)


9084
9085
9086
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9084

def region_code
  @region_code
end

#start_timeString

Time at which the subscription was granted. Not set for pending subscriptions ( subscription was created but awaiting payment during signup). Corresponds to the JSON property startTime

Returns:

  • (String)


9090
9091
9092
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9090

def start_time
  @start_time
end

#subscribe_with_google_infoGoogle::Apis::AndroidpublisherV3::SubscribeWithGoogleInfo

Information associated with purchases made with 'Subscribe with Google'. Corresponds to the JSON property subscribeWithGoogleInfo



9095
9096
9097
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9095

def subscribe_with_google_info
  @subscribe_with_google_info
end

#subscription_stateString

The current state of the subscription. Corresponds to the JSON property subscriptionState

Returns:

  • (String)


9100
9101
9102
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9100

def subscription_state
  @subscription_state
end

#test_purchaseGoogle::Apis::AndroidpublisherV3::TestPurchase

Whether this subscription purchase is a test purchase. Corresponds to the JSON property testPurchase



9105
9106
9107
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9105

def test_purchase
  @test_purchase
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9112
9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
9128
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9112

def update!(**args)
  @acknowledgement_state = args[:acknowledgement_state] if args.key?(:acknowledgement_state)
  @canceled_state_context = args[:canceled_state_context] if args.key?(:canceled_state_context)
  @etag = args[:etag] if args.key?(:etag)
  @external_account_identifiers = args[:external_account_identifiers] if args.key?(:external_account_identifiers)
  @kind = args[:kind] if args.key?(:kind)
  @latest_order_id = args[:latest_order_id] if args.key?(:latest_order_id)
  @line_items = args[:line_items] if args.key?(:line_items)
  @linked_purchase_token = args[:linked_purchase_token] if args.key?(:linked_purchase_token)
  @out_of_app_purchase_context = args[:out_of_app_purchase_context] if args.key?(:out_of_app_purchase_context)
  @paused_state_context = args[:paused_state_context] if args.key?(:paused_state_context)
  @region_code = args[:region_code] if args.key?(:region_code)
  @start_time = args[:start_time] if args.key?(:start_time)
  @subscribe_with_google_info = args[:subscribe_with_google_info] if args.key?(:subscribe_with_google_info)
  @subscription_state = args[:subscription_state] if args.key?(:subscription_state)
  @test_purchase = args[:test_purchase] if args.key?(:test_purchase)
end