Class: Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about taxation, Google Play policy, and legal compliance for subscription products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings

Returns a new instance of SubscriptionTaxAndComplianceSettings.



10417
10418
10419
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eea_withdrawal_right_typeString

Digital content or service classification for products distributed to users in the European Economic Area (EEA). The withdrawal regime under EEA consumer laws depends on this classification. Refer to the Help Center article for more information. Corresponds to the JSON property eeaWithdrawalRightType

Returns:

  • (String)


10388
10389
10390
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10388

def eea_withdrawal_right_type
  @eea_withdrawal_right_type
end

#is_tokenized_digital_assetBoolean Also known as: is_tokenized_digital_asset?

Whether this subscription is declared as a product representing a tokenized digital asset. Corresponds to the JSON property isTokenizedDigitalAsset

Returns:

  • (Boolean)


10394
10395
10396
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10394

def is_tokenized_digital_asset
  @is_tokenized_digital_asset
end

#product_tax_category_codeString

Product tax category code to assign to the subscription. Product tax category determines the transaction tax rates applied to the subscription. Refer to the Help Center article for more information. Corresponds to the JSON property productTaxCategoryCode

Returns:

  • (String)


10403
10404
10405
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10403

def product_tax_category_code
  @product_tax_category_code
end

#regional_product_age_rating_infosArray<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>

Regional age rating information. Currently this field is only supported for region code US. Corresponds to the JSON property regionalProductAgeRatingInfos



10409
10410
10411
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10409

def regional_product_age_rating_infos
  @regional_product_age_rating_infos
end

#tax_rate_info_by_region_codeHash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>

A mapping from region code to tax rate details. The keys are region codes as defined by Unicode's "CLDR". Corresponds to the JSON property taxRateInfoByRegionCode



10415
10416
10417
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10415

def tax_rate_info_by_region_code
  @tax_rate_info_by_region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10422
10423
10424
10425
10426
10427
10428
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10422

def update!(**args)
  @eea_withdrawal_right_type = args[:eea_withdrawal_right_type] if args.key?(:eea_withdrawal_right_type)
  @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset)
  @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code)
  @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos)
  @tax_rate_info_by_region_code = args[:tax_rate_info_by_region_code] if args.key?(:tax_rate_info_by_region_code)
end