Class: Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about taxation, Google Play policy, and legal compliance for subscription products.
Instance Attribute Summary collapse
-
#eea_withdrawal_right_type ⇒ String
Digital content or service classification for products distributed to users in the European Economic Area (EEA).
-
#is_tokenized_digital_asset ⇒ Boolean
(also: #is_tokenized_digital_asset?)
Whether this subscription is declared as a product representing a tokenized digital asset.
-
#product_tax_category_code ⇒ String
Product tax category code to assign to the subscription.
-
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information.
-
#tax_rate_info_by_region_code ⇒ Hash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>
A mapping from region code to tax rate details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings
constructor
A new instance of SubscriptionTaxAndComplianceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings
Returns a new instance of SubscriptionTaxAndComplianceSettings.
9331 9332 9333 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eea_withdrawal_right_type ⇒ String
Digital content or service classification for products distributed to users in
the European Economic Area (EEA). The withdrawal regime under EEA consumer
laws depends on this classification. Refer to the Help Center article for more
information.
Corresponds to the JSON property eeaWithdrawalRightType
9302 9303 9304 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9302 def eea_withdrawal_right_type @eea_withdrawal_right_type end |
#is_tokenized_digital_asset ⇒ Boolean Also known as: is_tokenized_digital_asset?
Whether this subscription is declared as a product representing a tokenized
digital asset.
Corresponds to the JSON property isTokenizedDigitalAsset
9308 9309 9310 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9308 def is_tokenized_digital_asset @is_tokenized_digital_asset end |
#product_tax_category_code ⇒ String
Product tax category code to assign to the subscription. Product tax category
determines the transaction tax rates applied to the subscription. Refer to the
Help Center article for more information.
Corresponds to the JSON property productTaxCategoryCode
9317 9318 9319 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9317 def product_tax_category_code @product_tax_category_code end |
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information. Currently this field is only supported for
region code US.
Corresponds to the JSON property regionalProductAgeRatingInfos
9323 9324 9325 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9323 def @regional_product_age_rating_infos end |
#tax_rate_info_by_region_code ⇒ Hash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>
A mapping from region code to tax rate details. The keys are region codes as
defined by Unicode's "CLDR".
Corresponds to the JSON property taxRateInfoByRegionCode
9329 9330 9331 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9329 def tax_rate_info_by_region_code @tax_rate_info_by_region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9336 9337 9338 9339 9340 9341 9342 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9336 def update!(**args) @eea_withdrawal_right_type = args[:eea_withdrawal_right_type] if args.key?(:eea_withdrawal_right_type) @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset) @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code) @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos) @tax_rate_info_by_region_code = args[:tax_rate_info_by_region_code] if args.key?(:tax_rate_info_by_region_code) end |