Class: Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Details about taxation, Google Play policy, and legal compliance for subscription products.
Instance Attribute Summary collapse
-
#eea_withdrawal_right_type ⇒ String
Digital content or service classification for products distributed to users in the European Economic Area (EEA).
-
#is_tokenized_digital_asset ⇒ Boolean
(also: #is_tokenized_digital_asset?)
Whether this subscription is declared as a product representing a tokenized digital asset.
-
#product_tax_category_code ⇒ String
Product tax category code to assign to the subscription.
-
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information.
-
#tax_rate_info_by_region_code ⇒ Hash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>
A mapping from region code to tax rate details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings
constructor
A new instance of SubscriptionTaxAndComplianceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings
Returns a new instance of SubscriptionTaxAndComplianceSettings.
9236 9237 9238 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eea_withdrawal_right_type ⇒ String
Digital content or service classification for products distributed to users in
the European Economic Area (EEA). The withdrawal regime under EEA consumer
laws depends on this classification. Refer to the Help Center article for more
information.
Corresponds to the JSON property eeaWithdrawalRightType
9207 9208 9209 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9207 def eea_withdrawal_right_type @eea_withdrawal_right_type end |
#is_tokenized_digital_asset ⇒ Boolean Also known as: is_tokenized_digital_asset?
Whether this subscription is declared as a product representing a tokenized
digital asset.
Corresponds to the JSON property isTokenizedDigitalAsset
9213 9214 9215 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9213 def is_tokenized_digital_asset @is_tokenized_digital_asset end |
#product_tax_category_code ⇒ String
Product tax category code to assign to the subscription. Product tax category
determines the transaction tax rates applied to the subscription. Refer to the
Help Center article for more information.
Corresponds to the JSON property productTaxCategoryCode
9222 9223 9224 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9222 def product_tax_category_code @product_tax_category_code end |
#regional_product_age_rating_infos ⇒ Array<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>
Regional age rating information. Currently this field is only supported for
region code US.
Corresponds to the JSON property regionalProductAgeRatingInfos
9228 9229 9230 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9228 def @regional_product_age_rating_infos end |
#tax_rate_info_by_region_code ⇒ Hash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>
A mapping from region code to tax rate details. The keys are region codes as
defined by Unicode's "CLDR".
Corresponds to the JSON property taxRateInfoByRegionCode
9234 9235 9236 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9234 def tax_rate_info_by_region_code @tax_rate_info_by_region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9241 def update!(**args) @eea_withdrawal_right_type = args[:eea_withdrawal_right_type] if args.key?(:eea_withdrawal_right_type) @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset) @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code) @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos) @tax_rate_info_by_region_code = args[:tax_rate_info_by_region_code] if args.key?(:tax_rate_info_by_region_code) end |