Class: Google::Apis::AndroidpublisherV3::SubscriptionTaxAndComplianceSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Details about taxation, Google Play policy, and legal compliance for subscription products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionTaxAndComplianceSettings

Returns a new instance of SubscriptionTaxAndComplianceSettings.



9159
9160
9161
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eea_withdrawal_right_typeString

Digital content or service classification for products distributed to users in the European Economic Area (EEA). The withdrawal regime under EEA consumer laws depends on this classification. Refer to the Help Center article for more information. Corresponds to the JSON property eeaWithdrawalRightType

Returns:

  • (String)


9130
9131
9132
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9130

def eea_withdrawal_right_type
  @eea_withdrawal_right_type
end

#is_tokenized_digital_assetBoolean Also known as: is_tokenized_digital_asset?

Whether this subscription is declared as a product representing a tokenized digital asset. Corresponds to the JSON property isTokenizedDigitalAsset

Returns:

  • (Boolean)


9136
9137
9138
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9136

def is_tokenized_digital_asset
  @is_tokenized_digital_asset
end

#product_tax_category_codeString

Product tax category code to assign to the subscription. Product tax category determines the transaction tax rates applied to the subscription. Refer to the Help Center article for more information. Corresponds to the JSON property productTaxCategoryCode

Returns:

  • (String)


9145
9146
9147
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9145

def product_tax_category_code
  @product_tax_category_code
end

#regional_product_age_rating_infosArray<Google::Apis::AndroidpublisherV3::RegionalProductAgeRatingInfo>

Regional age rating information. Currently this field is only supported for region code US. Corresponds to the JSON property regionalProductAgeRatingInfos



9151
9152
9153
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9151

def regional_product_age_rating_infos
  @regional_product_age_rating_infos
end

#tax_rate_info_by_region_codeHash<String,Google::Apis::AndroidpublisherV3::RegionalTaxRateInfo>

A mapping from region code to tax rate details. The keys are region codes as defined by Unicode's "CLDR". Corresponds to the JSON property taxRateInfoByRegionCode



9157
9158
9159
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9157

def tax_rate_info_by_region_code
  @tax_rate_info_by_region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9164
9165
9166
9167
9168
9169
9170
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9164

def update!(**args)
  @eea_withdrawal_right_type = args[:eea_withdrawal_right_type] if args.key?(:eea_withdrawal_right_type)
  @is_tokenized_digital_asset = args[:is_tokenized_digital_asset] if args.key?(:is_tokenized_digital_asset)
  @product_tax_category_code = args[:product_tax_category_code] if args.key?(:product_tax_category_code)
  @regional_product_age_rating_infos = args[:regional_product_age_rating_infos] if args.key?(:regional_product_age_rating_infos)
  @tax_rate_info_by_region_code = args[:tax_rate_info_by_region_code] if args.key?(:tax_rate_info_by_region_code)
end