Class: Google::Apis::AndroidpublisherV3::Targeting
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Targeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Targeting details for a recovery action such as regions, android sdk levels, app versions etc.
Instance Attribute Summary collapse
-
#all_users ⇒ Google::Apis::AndroidpublisherV3::AllUsers
Object representation to describe all set of users.
-
#android_sdks ⇒ Google::Apis::AndroidpublisherV3::AndroidSdks
Android api level targeting data for app recovery action targeting.
-
#regions ⇒ Google::Apis::AndroidpublisherV3::Regions
Region targeting data for app recovery action targeting.
-
#version_list ⇒ Google::Apis::AndroidpublisherV3::AppVersionList
Data format for a list of app versions.
-
#version_range ⇒ Google::Apis::AndroidpublisherV3::AppVersionRange
Data format for a continuous range of app versions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Targeting
constructor
A new instance of Targeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Targeting
Returns a new instance of Targeting.
9484 9485 9486 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_users ⇒ Google::Apis::AndroidpublisherV3::AllUsers
Object representation to describe all set of users.
Corresponds to the JSON property allUsers
9462 9463 9464 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9462 def all_users @all_users end |
#android_sdks ⇒ Google::Apis::AndroidpublisherV3::AndroidSdks
Android api level targeting data for app recovery action targeting.
Corresponds to the JSON property androidSdks
9467 9468 9469 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9467 def android_sdks @android_sdks end |
#regions ⇒ Google::Apis::AndroidpublisherV3::Regions
Region targeting data for app recovery action targeting.
Corresponds to the JSON property regions
9472 9473 9474 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9472 def regions @regions end |
#version_list ⇒ Google::Apis::AndroidpublisherV3::AppVersionList
Data format for a list of app versions.
Corresponds to the JSON property versionList
9477 9478 9479 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9477 def version_list @version_list end |
#version_range ⇒ Google::Apis::AndroidpublisherV3::AppVersionRange
Data format for a continuous range of app versions.
Corresponds to the JSON property versionRange
9482 9483 9484 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9482 def version_range @version_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9489 def update!(**args) @all_users = args[:all_users] if args.key?(:all_users) @android_sdks = args[:android_sdks] if args.key?(:android_sdks) @regions = args[:regions] if args.key?(:regions) @version_list = args[:version_list] if args.key?(:version_list) @version_range = args[:version_range] if args.key?(:version_range) end |