Class: Google::Apis::AndroidpublisherV3::TargetingUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::TargetingUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Update type for targeting. Note it is always a subset Targeting.
Instance Attribute Summary collapse
-
#all_users ⇒ Google::Apis::AndroidpublisherV3::AllUsers
Object representation to describe all set of users.
-
#android_sdks ⇒ Google::Apis::AndroidpublisherV3::AndroidSdks
Android api level targeting data for app recovery action targeting.
-
#regions ⇒ Google::Apis::AndroidpublisherV3::Regions
Region targeting data for app recovery action targeting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetingUpdate
constructor
A new instance of TargetingUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetingUpdate
Returns a new instance of TargetingUpdate.
9967 9968 9969 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9967 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_users ⇒ Google::Apis::AndroidpublisherV3::AllUsers
Object representation to describe all set of users.
Corresponds to the JSON property allUsers
9955 9956 9957 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9955 def all_users @all_users end |
#android_sdks ⇒ Google::Apis::AndroidpublisherV3::AndroidSdks
Android api level targeting data for app recovery action targeting.
Corresponds to the JSON property androidSdks
9960 9961 9962 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9960 def android_sdks @android_sdks end |
#regions ⇒ Google::Apis::AndroidpublisherV3::Regions
Region targeting data for app recovery action targeting.
Corresponds to the JSON property regions
9965 9966 9967 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9965 def regions @regions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9972 9973 9974 9975 9976 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9972 def update!(**args) @all_users = args[:all_users] if args.key?(:all_users) @android_sdks = args[:android_sdks] if args.key?(:android_sdks) @regions = args[:regions] if args.key?(:regions) end |