Class: Google::Apis::AndroidpublisherV3::Testers

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

The testers of an app. The resource for TestersService. Note: while it is possible in the Play Console UI to add testers via email lists, email lists are not supported by this resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Testers

Returns a new instance of Testers.



9577
9578
9579
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_groupsArray<String>

All testing Google Groups, as email addresses. Corresponds to the JSON property googleGroups

Returns:

  • (Array<String>)


9575
9576
9577
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9575

def google_groups
  @google_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9582
9583
9584
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9582

def update!(**args)
  @google_groups = args[:google_groups] if args.key?(:google_groups)
end