Class: Google::Apis::AndroidpublisherV3::Timestamp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Timestamp

Returns a new instance of Timestamp.



10094
10095
10096
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Non-negative fractions of a second at nanosecond resolution. Must be from 0 to 999,999,999 inclusive. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


10087
10088
10089
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10087

def nanos
  @nanos
end

#secondsFixnum

Represents seconds of UTC time since Unix epoch. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


10092
10093
10094
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10092

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10099
10100
10101
10102
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10099

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end