Class: Google::Apis::AndroidpublisherV3::Timestamp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Timestamp

Returns a new instance of Timestamp.



9649
9650
9651
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Non-negative fractions of a second at nanosecond resolution. Must be from 0 to 999,999,999 inclusive. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


9642
9643
9644
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9642

def nanos
  @nanos
end

#secondsFixnum

Represents seconds of UTC time since Unix epoch. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


9647
9648
9649
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9647

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9654
9655
9656
9657
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9654

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end