Class: Google::Apis::AndroidpublisherV3::Timestamp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Timestamp

Returns a new instance of Timestamp.



9572
9573
9574
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Non-negative fractions of a second at nanosecond resolution. Must be from 0 to 999,999,999 inclusive. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


9565
9566
9567
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9565

def nanos
  @nanos
end

#secondsFixnum

Represents seconds of UTC time since Unix epoch. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


9570
9571
9572
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9570

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9577
9578
9579
9580
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9577

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end