Class: Google::Apis::AndroidpublisherV3::TokenPagination
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::TokenPagination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Tokens to pass to the standard list field 'page_token'.
-
#previous_page_token ⇒ String
Corresponds to the JSON property
previousPageToken.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TokenPagination
constructor
A new instance of TokenPagination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TokenPagination
Returns a new instance of TokenPagination.
9605 9606 9607 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Tokens to pass to the standard list field 'page_token'. Whenever available,
tokens are preferred over manipulating start_index.
Corresponds to the JSON property nextPageToken
9598 9599 9600 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9598 def next_page_token @next_page_token end |
#previous_page_token ⇒ String
Corresponds to the JSON property previousPageToken
9603 9604 9605 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9603 def previous_page_token @previous_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9610 9611 9612 9613 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9610 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @previous_page_token = args[:previous_page_token] if args.key?(:previous_page_token) end |