Class: Google::Apis::AndroidpublisherV3::TrackCountryAvailability
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::TrackCountryAvailability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Resource for per-track country availability information.
Instance Attribute Summary collapse
-
#countries ⇒ Array<Google::Apis::AndroidpublisherV3::TrackTargetedCountry>
A list of one or more countries where artifacts in this track are available.
-
#rest_of_world ⇒ Boolean
(also: #rest_of_world?)
Whether artifacts in this track are available to "rest of the world" countries.
-
#sync_with_production ⇒ Boolean
(also: #sync_with_production?)
Whether this track's availability is synced with the default production track.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrackCountryAvailability
constructor
A new instance of TrackCountryAvailability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrackCountryAvailability
Returns a new instance of TrackCountryAvailability.
9875 9876 9877 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#countries ⇒ Array<Google::Apis::AndroidpublisherV3::TrackTargetedCountry>
A list of one or more countries where artifacts in this track are available.
This list includes all countries that are targeted by the track, even if only
specific carriers are targeted in that country.
Corresponds to the JSON property countries
9857 9858 9859 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9857 def countries @countries end |
#rest_of_world ⇒ Boolean Also known as: rest_of_world?
Whether artifacts in this track are available to "rest of the world" countries.
Corresponds to the JSON property restOfWorld
9862 9863 9864 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9862 def rest_of_world @rest_of_world end |
#sync_with_production ⇒ Boolean Also known as: sync_with_production?
Whether this track's availability is synced with the default production track.
See https://support.google.com/googleplay/android-developer/answer/7550024 for
more information on syncing country availability with production. Note that if
this is true, the returned "countries" and "rest_of_world" fields will reflect
the values for the default production track.
Corresponds to the JSON property syncWithProduction
9872 9873 9874 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9872 def sync_with_production @sync_with_production end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9880 9881 9882 9883 9884 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9880 def update!(**args) @countries = args[:countries] if args.key?(:countries) @rest_of_world = args[:rest_of_world] if args.key?(:rest_of_world) @sync_with_production = args[:sync_with_production] if args.key?(:sync_with_production) end |