Class: Google::Apis::AndroidpublisherV3::TrackCountryAvailability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Resource for per-track country availability information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackCountryAvailability

Returns a new instance of TrackCountryAvailability.



9709
9710
9711
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countriesArray<Google::Apis::AndroidpublisherV3::TrackTargetedCountry>

A list of one or more countries where artifacts in this track are available. This list includes all countries that are targeted by the track, even if only specific carriers are targeted in that country. Corresponds to the JSON property countries



9691
9692
9693
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9691

def countries
  @countries
end

#rest_of_worldBoolean Also known as: rest_of_world?

Whether artifacts in this track are available to "rest of the world" countries. Corresponds to the JSON property restOfWorld

Returns:

  • (Boolean)


9696
9697
9698
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9696

def rest_of_world
  @rest_of_world
end

#sync_with_productionBoolean Also known as: sync_with_production?

Whether this track's availability is synced with the default production track. See https://support.google.com/googleplay/android-developer/answer/7550024 for more information on syncing country availability with production. Note that if this is true, the returned "countries" and "rest_of_world" fields will reflect the values for the default production track. Corresponds to the JSON property syncWithProduction

Returns:

  • (Boolean)


9706
9707
9708
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9706

def sync_with_production
  @sync_with_production
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9714
9715
9716
9717
9718
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9714

def update!(**args)
  @countries = args[:countries] if args.key?(:countries)
  @rest_of_world = args[:rest_of_world] if args.key?(:rest_of_world)
  @sync_with_production = args[:sync_with_production] if args.key?(:sync_with_production)
end