Class: Google::Apis::AndroidpublisherV3::TrackRelease

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A release within a track.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackRelease

Returns a new instance of TrackRelease.



9768
9769
9770
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_targetingGoogle::Apis::AndroidpublisherV3::CountryTargeting

Country targeting specification. Corresponds to the JSON property countryTargeting



9728
9729
9730
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9728

def country_targeting
  @country_targeting
end

#in_app_update_priorityFixnum

In-app update priority of the release. All newly added APKs in the release will be considered at this priority. Can take values in the range [0, 5], with 5 the highest priority. Defaults to 0. in_app_update_priority can not be updated once the release is rolled out. See https://developer.android.com/ guide/playcore/in-app-updates. Corresponds to the JSON property inAppUpdatePriority

Returns:

  • (Fixnum)


9737
9738
9739
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9737

def in_app_update_priority
  @in_app_update_priority
end

#nameString

The release name. Not required to be unique. If not set, the name is generated from the APK's version_name. If the release contains multiple APKs, the name is generated from the date. Corresponds to the JSON property name

Returns:

  • (String)


9744
9745
9746
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9744

def name
  @name
end

#release_notesArray<Google::Apis::AndroidpublisherV3::LocalizedText>

A description of what is new in this release. Corresponds to the JSON property releaseNotes



9749
9750
9751
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9749

def release_notes
  @release_notes
end

#statusString

The status of the release. Corresponds to the JSON property status

Returns:

  • (String)


9754
9755
9756
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9754

def status
  @status
end

#user_fractionFloat

Fraction of users who are eligible for a staged release. 0 < fraction < 1. Can only be set when status is "inProgress" or "halted". Corresponds to the JSON property userFraction

Returns:

  • (Float)


9760
9761
9762
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9760

def user_fraction
  @user_fraction
end

#version_codesArray<Fixnum>

Version codes of all APKs in the release. Must include version codes to retain from previous releases. Corresponds to the JSON property versionCodes

Returns:

  • (Array<Fixnum>)


9766
9767
9768
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9766

def version_codes
  @version_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9773
9774
9775
9776
9777
9778
9779
9780
9781
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9773

def update!(**args)
  @country_targeting = args[:country_targeting] if args.key?(:country_targeting)
  @in_app_update_priority = args[:in_app_update_priority] if args.key?(:in_app_update_priority)
  @name = args[:name] if args.key?(:name)
  @release_notes = args[:release_notes] if args.key?(:release_notes)
  @status = args[:status] if args.key?(:status)
  @user_fraction = args[:user_fraction] if args.key?(:user_fraction)
  @version_codes = args[:version_codes] if args.key?(:version_codes)
end