Class: Google::Apis::AndroidpublisherV3::TrackTargetedCountry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Representation of a single country where the contents of a track can be made available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackTargetedCountry

Returns a new instance of TrackTargetedCountry.



9891
9892
9893
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

The country that can be targeted, as a two-letter CLDR code. Corresponds to the JSON property countryCode

Returns:

  • (String)


9889
9890
9891
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9889

def country_code
  @country_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9896
9897
9898
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9896

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
end