Class: Google::Apis::AndroidpublisherV3::UpdateAppStoreHostedAppPublishStatusRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpdateAppStoreHostedAppPublishStatusRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request to update the publish status of an app store hosted app. The default state for any app with an update is PUBLISHED. It is not necessary to call this RPC explicitly to set an app to PUBLISHED.
Instance Attribute Summary collapse
-
#publish_state ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateAppStoreHostedAppPublishStatusRequest
constructor
A new instance of UpdateAppStoreHostedAppPublishStatusRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateAppStoreHostedAppPublishStatusRequest
Returns a new instance of UpdateAppStoreHostedAppPublishStatusRequest.
11098 11099 11100 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#publish_state ⇒ String
Required. The new publish state for the hosted app.
Corresponds to the JSON property publishState
11096 11097 11098 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11096 def publish_state @publish_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11103 11104 11105 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11103 def update!(**args) @publish_state = args[:publish_state] if args.key?(:publish_state) end |