Class: Google::Apis::AndroidpublisherV3::UpdateAppStoreHostedAppPublishStatusRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpdateAppStoreHostedAppPublishStatusRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request to update the publish status of an app store hosted app. The default state for any app with an update is PUBLISHED. It is not necessary to call this RPC explicitly to set an app to PUBLISHED.
Instance Attribute Summary collapse
-
#publish_state ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateAppStoreHostedAppPublishStatusRequest
constructor
A new instance of UpdateAppStoreHostedAppPublishStatusRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateAppStoreHostedAppPublishStatusRequest
Returns a new instance of UpdateAppStoreHostedAppPublishStatusRequest.
10362 10363 10364 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#publish_state ⇒ String
Required. The new publish state for the hosted app.
Corresponds to the JSON property publishState
10360 10361 10362 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10360 def publish_state @publish_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10367 10368 10369 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10367 def update!(**args) @publish_state = args[:publish_state] if args.key?(:publish_state) end |