Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductOfferRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpdateOneTimeProductOfferRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for UpdateOneTimeProductOffer.
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
Optional.
-
#latency_tolerance ⇒ String
Optional.
-
#one_time_product_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductOffer
A single offer for a one-time product.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateOneTimeProductOfferRequest
constructor
A new instance of UpdateOneTimeProductOfferRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateOneTimeProductOfferRequest
Returns a new instance of UpdateOneTimeProductOfferRequest.
10059 10060 10061 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
Optional. If set to true, and the offer with the given package_name,
product_id, purchase_option_id and offer_id doesn't exist, an offer will be
created. If a new offer is created, the update_mask is ignored.
Corresponds to the JSON property allowMissing
10035 10036 10037 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10035 def allow_missing @allow_missing end |
#latency_tolerance ⇒ String
Optional. The latency tolerance for the propagation of this offer update.
Defaults to latency-sensitive.
Corresponds to the JSON property latencyTolerance
10042 10043 10044 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10042 def latency_tolerance @latency_tolerance end |
#one_time_product_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductOffer
A single offer for a one-time product.
Corresponds to the JSON property oneTimeProductOffer
10047 10048 10049 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10047 def one_time_product_offer @one_time_product_offer end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
10052 10053 10054 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10052 def regions_version @regions_version end |
#update_mask ⇒ String
Required. The list of fields to be updated.
Corresponds to the JSON property updateMask
10057 10058 10059 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10057 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10064 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance) @one_time_product_offer = args[:one_time_product_offer] if args.key?(:one_time_product_offer) @regions_version = args[:regions_version] if args.key?(:regions_version) @update_mask = args[:update_mask] if args.key?(:update_mask) end |