Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductOfferRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpdateOneTimeProductOfferRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for UpdateOneTimeProductOffer.
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
Optional.
-
#latency_tolerance ⇒ String
Optional.
-
#one_time_product_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductOffer
A single offer for a one-time product.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateOneTimeProductOfferRequest
constructor
A new instance of UpdateOneTimeProductOfferRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateOneTimeProductOfferRequest
Returns a new instance of UpdateOneTimeProductOfferRequest.
9964 9965 9966 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
Optional. If set to true, and the offer with the given package_name,
product_id, purchase_option_id and offer_id doesn't exist, an offer will be
created. If a new offer is created, the update_mask is ignored.
Corresponds to the JSON property allowMissing
9940 9941 9942 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9940 def allow_missing @allow_missing end |
#latency_tolerance ⇒ String
Optional. The latency tolerance for the propagation of this offer update.
Defaults to latency-sensitive.
Corresponds to the JSON property latencyTolerance
9947 9948 9949 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9947 def latency_tolerance @latency_tolerance end |
#one_time_product_offer ⇒ Google::Apis::AndroidpublisherV3::OneTimeProductOffer
A single offer for a one-time product.
Corresponds to the JSON property oneTimeProductOffer
9952 9953 9954 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9952 def one_time_product_offer @one_time_product_offer end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
9957 9958 9959 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9957 def regions_version @regions_version end |
#update_mask ⇒ String
Required. The list of fields to be updated.
Corresponds to the JSON property updateMask
9962 9963 9964 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9962 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9969 9970 9971 9972 9973 9974 9975 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9969 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance) @one_time_product_offer = args[:one_time_product_offer] if args.key?(:one_time_product_offer) @regions_version = args[:regions_version] if args.key?(:regions_version) @update_mask = args[:update_mask] if args.key?(:update_mask) end |