Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductOfferRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for UpdateOneTimeProductOffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateOneTimeProductOfferRequest

Returns a new instance of UpdateOneTimeProductOfferRequest.



9887
9888
9889
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. If set to true, and the offer with the given package_name, product_id, purchase_option_id and offer_id doesn't exist, an offer will be created. If a new offer is created, the update_mask is ignored. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


9863
9864
9865
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9863

def allow_missing
  @allow_missing
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this offer update. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


9870
9871
9872
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9870

def latency_tolerance
  @latency_tolerance
end

#one_time_product_offerGoogle::Apis::AndroidpublisherV3::OneTimeProductOffer

A single offer for a one-time product. Corresponds to the JSON property oneTimeProductOffer



9875
9876
9877
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9875

def one_time_product_offer
  @one_time_product_offer
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



9880
9881
9882
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9880

def regions_version
  @regions_version
end

#update_maskString

Required. The list of fields to be updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


9885
9886
9887
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9885

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9892
9893
9894
9895
9896
9897
9898
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9892

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @one_time_product_offer = args[:one_time_product_offer] if args.key?(:one_time_product_offer)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end