Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for UpdateOneTimeProduct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateOneTimeProductRequest

Returns a new instance of UpdateOneTimeProductRequest.



10062
10063
10064
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. If set to true, and the one-time product with the given package_name and product_id doesn't exist, the one-time product will be created. If a new one-time product is created, update_mask is ignored. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


10038
10039
10040
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10038

def allow_missing
  @allow_missing
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this product upsert. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


10045
10046
10047
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10045

def latency_tolerance
  @latency_tolerance
end

#one_time_productGoogle::Apis::AndroidpublisherV3::OneTimeProduct

A single one-time product for an app. Corresponds to the JSON property oneTimeProduct



10050
10051
10052
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10050

def one_time_product
  @one_time_product
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



10055
10056
10057
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10055

def regions_version
  @regions_version
end

#update_maskString

Required. The list of fields to be updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


10060
10061
10062
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10060

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10067
10068
10069
10070
10071
10072
10073
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10067

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @one_time_product = args[:one_time_product] if args.key?(:one_time_product)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end