Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpdateOneTimeProductRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for UpdateOneTimeProduct.
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
Optional.
-
#latency_tolerance ⇒ String
Optional.
-
#one_time_product ⇒ Google::Apis::AndroidpublisherV3::OneTimeProduct
A single one-time product for an app.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateOneTimeProductRequest
constructor
A new instance of UpdateOneTimeProductRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateOneTimeProductRequest
Returns a new instance of UpdateOneTimeProductRequest.
10042 10043 10044 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
Optional. If set to true, and the one-time product with the given package_name
and product_id doesn't exist, the one-time product will be created. If a new
one-time product is created, update_mask is ignored.
Corresponds to the JSON property allowMissing
10018 10019 10020 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10018 def allow_missing @allow_missing end |
#latency_tolerance ⇒ String
Optional. The latency tolerance for the propagation of this product upsert.
Defaults to latency-sensitive.
Corresponds to the JSON property latencyTolerance
10025 10026 10027 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10025 def latency_tolerance @latency_tolerance end |
#one_time_product ⇒ Google::Apis::AndroidpublisherV3::OneTimeProduct
A single one-time product for an app.
Corresponds to the JSON property oneTimeProduct
10030 10031 10032 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10030 def one_time_product @one_time_product end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
10035 10036 10037 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10035 def regions_version @regions_version end |
#update_mask ⇒ String
Required. The list of fields to be updated.
Corresponds to the JSON property updateMask
10040 10041 10042 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10040 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10047 10048 10049 10050 10051 10052 10053 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10047 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance) @one_time_product = args[:one_time_product] if args.key?(:one_time_product) @regions_version = args[:regions_version] if args.key?(:regions_version) @update_mask = args[:update_mask] if args.key?(:update_mask) end |