Class: Google::Apis::AndroidpublisherV3::UpdateOneTimeProductRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Request message for UpdateOneTimeProduct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateOneTimeProductRequest

Returns a new instance of UpdateOneTimeProductRequest.



9965
9966
9967
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. If set to true, and the one-time product with the given package_name and product_id doesn't exist, the one-time product will be created. If a new one-time product is created, update_mask is ignored. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


9941
9942
9943
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9941

def allow_missing
  @allow_missing
end

#latency_toleranceString

Optional. The latency tolerance for the propagation of this product upsert. Defaults to latency-sensitive. Corresponds to the JSON property latencyTolerance

Returns:

  • (String)


9948
9949
9950
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9948

def latency_tolerance
  @latency_tolerance
end

#one_time_productGoogle::Apis::AndroidpublisherV3::OneTimeProduct

A single one-time product for an app. Corresponds to the JSON property oneTimeProduct



9953
9954
9955
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9953

def one_time_product
  @one_time_product
end

#regions_versionGoogle::Apis::AndroidpublisherV3::RegionsVersion

The version of the available regions being used for the specified resource. Corresponds to the JSON property regionsVersion



9958
9959
9960
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9958

def regions_version
  @regions_version
end

#update_maskString

Required. The list of fields to be updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


9963
9964
9965
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9963

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9970
9971
9972
9973
9974
9975
9976
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 9970

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance)
  @one_time_product = args[:one_time_product] if args.key?(:one_time_product)
  @regions_version = args[:regions_version] if args.key?(:regions_version)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end