Class: Google::Apis::AndroidpublisherV3::UpdateSubscriptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpdateSubscriptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Request message for UpdateSubscription.
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
Optional.
-
#latency_tolerance ⇒ String
Optional.
-
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
-
#subscription ⇒ Google::Apis::AndroidpublisherV3::Subscription
A single subscription for an app.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSubscriptionRequest
constructor
A new instance of UpdateSubscriptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateSubscriptionRequest
Returns a new instance of UpdateSubscriptionRequest.
10109 10110 10111 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
Optional. If set to true, and the subscription with the given package_name and
product_id doesn't exist, the subscription will be created. If a new
subscription is created, update_mask is ignored.
Corresponds to the JSON property allowMissing
10085 10086 10087 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10085 def allow_missing @allow_missing end |
#latency_tolerance ⇒ String
Optional. The latency tolerance for the propagation of this product update.
Defaults to latency-sensitive.
Corresponds to the JSON property latencyTolerance
10092 10093 10094 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10092 def latency_tolerance @latency_tolerance end |
#regions_version ⇒ Google::Apis::AndroidpublisherV3::RegionsVersion
The version of the available regions being used for the specified resource.
Corresponds to the JSON property regionsVersion
10097 10098 10099 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10097 def regions_version @regions_version end |
#subscription ⇒ Google::Apis::AndroidpublisherV3::Subscription
A single subscription for an app.
Corresponds to the JSON property subscription
10102 10103 10104 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10102 def subscription @subscription end |
#update_mask ⇒ String
Required. The list of fields to be updated.
Corresponds to the JSON property updateMask
10107 10108 10109 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10107 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10114 10115 10116 10117 10118 10119 10120 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10114 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @latency_tolerance = args[:latency_tolerance] if args.key?(:latency_tolerance) @regions_version = args[:regions_version] if args.key?(:regions_version) @subscription = args[:subscription] if args.key?(:subscription) @update_mask = args[:update_mask] if args.key?(:update_mask) end |