Class: Google::Apis::AndroidpublisherV3::UpgradeTargetingRule
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UpgradeTargetingRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Represents a targeting rule of the form: User currently has scope [with
billing period billing_period].
Instance Attribute Summary collapse
-
#billing_period_duration ⇒ String
The specific billing period duration, specified in ISO 8601 format, that a user must be currently subscribed to to be eligible for this rule.
-
#once_per_user ⇒ Boolean
(also: #once_per_user?)
Limit this offer to only once per user.
-
#scope ⇒ Google::Apis::AndroidpublisherV3::TargetingRuleScope
Defines the scope of subscriptions which a targeting rule can match to target offers to users based on past or current entitlement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeTargetingRule
constructor
A new instance of UpgradeTargetingRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeTargetingRule
Returns a new instance of UpgradeTargetingRule.
10760 10761 10762 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_period_duration ⇒ String
The specific billing period duration, specified in ISO 8601 format, that a
user must be currently subscribed to to be eligible for this rule. If not
specified, users subscribed to any billing period are matched.
Corresponds to the JSON property billingPeriodDuration
10745 10746 10747 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10745 def billing_period_duration @billing_period_duration end |
#once_per_user ⇒ Boolean Also known as: once_per_user?
Limit this offer to only once per user. If set to true, a user can never be
eligible for this offer again if they ever subscribed to this offer.
Corresponds to the JSON property oncePerUser
10751 10752 10753 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10751 def once_per_user @once_per_user end |
#scope ⇒ Google::Apis::AndroidpublisherV3::TargetingRuleScope
Defines the scope of subscriptions which a targeting rule can match to target
offers to users based on past or current entitlement.
Corresponds to the JSON property scope
10758 10759 10760 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10758 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10765 10766 10767 10768 10769 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10765 def update!(**args) @billing_period_duration = args[:billing_period_duration] if args.key?(:billing_period_duration) @once_per_user = args[:once_per_user] if args.key?(:once_per_user) @scope = args[:scope] if args.key?(:scope) end |