Class: Google::Apis::AndroidpublisherV3::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



11658
11659
11660
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_stateString

Output only. The state of the user's access to the Play Console. Corresponds to the JSON property accessState

Returns:

  • (String)


11617
11618
11619
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11617

def access_state
  @access_state
end

#developer_account_permissionsArray<String>

Permissions for the user which apply across the developer account. Corresponds to the JSON property developerAccountPermissions

Returns:

  • (Array<String>)


11622
11623
11624
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11622

def 
  @developer_account_permissions
end

#emailString

Immutable. The user's email address. Corresponds to the JSON property email

Returns:

  • (String)


11627
11628
11629
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11627

def email
  @email
end

#expiration_timeString

The time at which the user's access expires, if set. When setting this value, it must always be in the future. Corresponds to the JSON property expirationTime

Returns:

  • (String)


11633
11634
11635
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11633

def expiration_time
  @expiration_time
end

#grantsArray<Google::Apis::AndroidpublisherV3::Grant>

Output only. Per-app permissions for the user. Corresponds to the JSON property grants



11638
11639
11640
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11638

def grants
  @grants
end

#nameString

Required. Resource name for this user, following the pattern "developers/ developer/users/email". Corresponds to the JSON property name

Returns:

  • (String)


11644
11645
11646
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11644

def name
  @name
end

#partialBoolean Also known as: partial?

Output only. Whether there are more permissions for the user that are not represented here. This can happen if the caller does not have permission to manage all apps in the account. This is also true if this user is the account owner. If this field is true, it should be taken as a signal that this user cannot be fully managed via the API. That is, the API caller is not be able to manage all of the permissions this user holds, either because it doesn't know about them or because the user is the account owner. Corresponds to the JSON property partial

Returns:

  • (Boolean)


11655
11656
11657
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11655

def partial
  @partial
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11663
11664
11665
11666
11667
11668
11669
11670
11671
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11663

def update!(**args)
  @access_state = args[:access_state] if args.key?(:access_state)
  @developer_account_permissions = args[:developer_account_permissions] if args.key?(:developer_account_permissions)
  @email = args[:email] if args.key?(:email)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @grants = args[:grants] if args.key?(:grants)
  @name = args[:name] if args.key?(:name)
  @partial = args[:partial] if args.key?(:partial)
end