Class: Google::Apis::AndroidpublisherV3::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



10380
10381
10382
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_stateString

Output only. The state of the user's access to the Play Console. Corresponds to the JSON property accessState

Returns:

  • (String)


10339
10340
10341
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10339

def access_state
  @access_state
end

#developer_account_permissionsArray<String>

Permissions for the user which apply across the developer account. Corresponds to the JSON property developerAccountPermissions

Returns:

  • (Array<String>)


10344
10345
10346
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10344

def 
  @developer_account_permissions
end

#emailString

Immutable. The user's email address. Corresponds to the JSON property email

Returns:

  • (String)


10349
10350
10351
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10349

def email
  @email
end

#expiration_timeString

The time at which the user's access expires, if set. When setting this value, it must always be in the future. Corresponds to the JSON property expirationTime

Returns:

  • (String)


10355
10356
10357
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10355

def expiration_time
  @expiration_time
end

#grantsArray<Google::Apis::AndroidpublisherV3::Grant>

Output only. Per-app permissions for the user. Corresponds to the JSON property grants



10360
10361
10362
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10360

def grants
  @grants
end

#nameString

Required. Resource name for this user, following the pattern "developers/ developer/users/email". Corresponds to the JSON property name

Returns:

  • (String)


10366
10367
10368
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10366

def name
  @name
end

#partialBoolean Also known as: partial?

Output only. Whether there are more permissions for the user that are not represented here. This can happen if the caller does not have permission to manage all apps in the account. This is also true if this user is the account owner. If this field is true, it should be taken as a signal that this user cannot be fully managed via the API. That is, the API caller is not be able to manage all of the permissions this user holds, either because it doesn't know about them or because the user is the account owner. Corresponds to the JSON property partial

Returns:

  • (Boolean)


10377
10378
10379
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10377

def partial
  @partial
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10385
10386
10387
10388
10389
10390
10391
10392
10393
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10385

def update!(**args)
  @access_state = args[:access_state] if args.key?(:access_state)
  @developer_account_permissions = args[:developer_account_permissions] if args.key?(:developer_account_permissions)
  @email = args[:email] if args.key?(:email)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @grants = args[:grants] if args.key?(:grants)
  @name = args[:name] if args.key?(:name)
  @partial = args[:partial] if args.key?(:partial)
end