Class: Google::Apis::AndroidpublisherV3::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

A user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



10374
10375
10376
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_stateString

Output only. The state of the user's access to the Play Console. Corresponds to the JSON property accessState

Returns:

  • (String)


10333
10334
10335
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10333

def access_state
  @access_state
end

#developer_account_permissionsArray<String>

Permissions for the user which apply across the developer account. Corresponds to the JSON property developerAccountPermissions

Returns:

  • (Array<String>)


10338
10339
10340
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10338

def 
  @developer_account_permissions
end

#emailString

Immutable. The user's email address. Corresponds to the JSON property email

Returns:

  • (String)


10343
10344
10345
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10343

def email
  @email
end

#expiration_timeString

The time at which the user's access expires, if set. When setting this value, it must always be in the future. Corresponds to the JSON property expirationTime

Returns:

  • (String)


10349
10350
10351
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10349

def expiration_time
  @expiration_time
end

#grantsArray<Google::Apis::AndroidpublisherV3::Grant>

Output only. Per-app permissions for the user. Corresponds to the JSON property grants



10354
10355
10356
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10354

def grants
  @grants
end

#nameString

Required. Resource name for this user, following the pattern "developers/ developer/users/email". Corresponds to the JSON property name

Returns:

  • (String)


10360
10361
10362
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10360

def name
  @name
end

#partialBoolean Also known as: partial?

Output only. Whether there are more permissions for the user that are not represented here. This can happen if the caller does not have permission to manage all apps in the account. This is also true if this user is the account owner. If this field is true, it should be taken as a signal that this user cannot be fully managed via the API. That is, the API caller is not be able to manage all of the permissions this user holds, either because it doesn't know about them or because the user is the account owner. Corresponds to the JSON property partial

Returns:

  • (Boolean)


10371
10372
10373
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10371

def partial
  @partial
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10379
10380
10381
10382
10383
10384
10385
10386
10387
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10379

def update!(**args)
  @access_state = args[:access_state] if args.key?(:access_state)
  @developer_account_permissions = args[:developer_account_permissions] if args.key?(:developer_account_permissions)
  @email = args[:email] if args.key?(:email)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @grants = args[:grants] if args.key?(:grants)
  @name = args[:name] if args.key?(:name)
  @partial = args[:partial] if args.key?(:partial)
end