Class: Google::Apis::AndroidpublisherV3::User
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A user resource.
Instance Attribute Summary collapse
-
#access_state ⇒ String
Output only.
-
#developer_account_permissions ⇒ Array<String>
Permissions for the user which apply across the developer account.
-
#email ⇒ String
Immutable.
-
#expiration_time ⇒ String
The time at which the user's access expires, if set.
-
#grants ⇒ Array<Google::Apis::AndroidpublisherV3::Grant>
Output only.
-
#name ⇒ String
Required.
-
#partial ⇒ Boolean
(also: #partial?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
10305 10306 10307 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_state ⇒ String
Output only. The state of the user's access to the Play Console.
Corresponds to the JSON property accessState
10264 10265 10266 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10264 def access_state @access_state end |
#developer_account_permissions ⇒ Array<String>
Permissions for the user which apply across the developer account.
Corresponds to the JSON property developerAccountPermissions
10269 10270 10271 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10269 def @developer_account_permissions end |
#email ⇒ String
Immutable. The user's email address.
Corresponds to the JSON property email
10274 10275 10276 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10274 def email @email end |
#expiration_time ⇒ String
The time at which the user's access expires, if set. When setting this value,
it must always be in the future.
Corresponds to the JSON property expirationTime
10280 10281 10282 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10280 def expiration_time @expiration_time end |
#grants ⇒ Array<Google::Apis::AndroidpublisherV3::Grant>
Output only. Per-app permissions for the user.
Corresponds to the JSON property grants
10285 10286 10287 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10285 def grants @grants end |
#name ⇒ String
Required. Resource name for this user, following the pattern "developers/
developer/users/email".
Corresponds to the JSON property name
10291 10292 10293 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10291 def name @name end |
#partial ⇒ Boolean Also known as: partial?
Output only. Whether there are more permissions for the user that are not
represented here. This can happen if the caller does not have permission to
manage all apps in the account. This is also true if this user is the
account owner. If this field is true, it should be taken as a signal that
this user cannot be fully managed via the API. That is, the API caller is not
be able to manage all of the permissions this user holds, either because it
doesn't know about them or because the user is the account owner.
Corresponds to the JSON property partial
10302 10303 10304 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10302 def partial @partial end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10310 10311 10312 10313 10314 10315 10316 10317 10318 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10310 def update!(**args) @access_state = args[:access_state] if args.key?(:access_state) @developer_account_permissions = args[:developer_account_permissions] if args.key?(:developer_account_permissions) @email = args[:email] if args.key?(:email) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @grants = args[:grants] if args.key?(:grants) @name = args[:name] if args.key?(:name) @partial = args[:partial] if args.key?(:partial) end |