Class: Google::Apis::AndroidpublisherV3::User
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
A user resource.
Instance Attribute Summary collapse
-
#access_state ⇒ String
Output only.
-
#developer_account_permissions ⇒ Array<String>
Permissions for the user which apply across the developer account.
-
#email ⇒ String
Immutable.
-
#expiration_time ⇒ String
The time at which the user's access expires, if set.
-
#grants ⇒ Array<Google::Apis::AndroidpublisherV3::Grant>
Output only.
-
#name ⇒ String
Required.
-
#partial ⇒ Boolean
(also: #partial?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
10208 10209 10210 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_state ⇒ String
Output only. The state of the user's access to the Play Console.
Corresponds to the JSON property accessState
10167 10168 10169 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10167 def access_state @access_state end |
#developer_account_permissions ⇒ Array<String>
Permissions for the user which apply across the developer account.
Corresponds to the JSON property developerAccountPermissions
10172 10173 10174 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10172 def @developer_account_permissions end |
#email ⇒ String
Immutable. The user's email address.
Corresponds to the JSON property email
10177 10178 10179 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10177 def email @email end |
#expiration_time ⇒ String
The time at which the user's access expires, if set. When setting this value,
it must always be in the future.
Corresponds to the JSON property expirationTime
10183 10184 10185 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10183 def expiration_time @expiration_time end |
#grants ⇒ Array<Google::Apis::AndroidpublisherV3::Grant>
Output only. Per-app permissions for the user.
Corresponds to the JSON property grants
10188 10189 10190 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10188 def grants @grants end |
#name ⇒ String
Required. Resource name for this user, following the pattern "developers/
developer/users/email".
Corresponds to the JSON property name
10194 10195 10196 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10194 def name @name end |
#partial ⇒ Boolean Also known as: partial?
Output only. Whether there are more permissions for the user that are not
represented here. This can happen if the caller does not have permission to
manage all apps in the account. This is also true if this user is the
account owner. If this field is true, it should be taken as a signal that
this user cannot be fully managed via the API. That is, the API caller is not
be able to manage all of the permissions this user holds, either because it
doesn't know about them or because the user is the account owner.
Corresponds to the JSON property partial
10205 10206 10207 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10205 def partial @partial end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10213 10214 10215 10216 10217 10218 10219 10220 10221 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10213 def update!(**args) @access_state = args[:access_state] if args.key?(:access_state) @developer_account_permissions = args[:developer_account_permissions] if args.key?(:developer_account_permissions) @email = args[:email] if args.key?(:email) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @grants = args[:grants] if args.key?(:grants) @name = args[:name] if args.key?(:name) @partial = args[:partial] if args.key?(:partial) end |