Class: Google::Apis::AndroidpublisherV3::UserComment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

User entry from conversation between user and developer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserComment

Returns a new instance of UserComment.



11748
11749
11750
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_os_versionFixnum

Integer Android SDK version of the user's device at the time the review was written, e.g. 23 is Marshmallow. May be absent. Corresponds to the JSON property androidOsVersion

Returns:

  • (Fixnum)


11682
11683
11684
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11682

def android_os_version
  @android_os_version
end

#app_version_codeFixnum

Integer version code of the app as installed at the time the review was written. May be absent. Corresponds to the JSON property appVersionCode

Returns:

  • (Fixnum)


11688
11689
11690
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11688

def app_version_code
  @app_version_code
end

#app_version_nameString

String version name of the app as installed at the time the review was written. May be absent. Corresponds to the JSON property appVersionName

Returns:

  • (String)


11694
11695
11696
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11694

def app_version_name
  @app_version_name
end

#deviceString

Codename for the reviewer's device, e.g. klte, flounder. May be absent. Corresponds to the JSON property device

Returns:

  • (String)


11699
11700
11701
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11699

def device
  @device
end

#device_metadataGoogle::Apis::AndroidpublisherV3::DeviceMetadata

Characteristics of the user's device. Corresponds to the JSON property deviceMetadata



11704
11705
11706
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11704

def 
  @device_metadata
end

#last_modifiedGoogle::Apis::AndroidpublisherV3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970. Corresponds to the JSON property lastModified



11712
11713
11714
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11712

def last_modified
  @last_modified
end

#original_textString

Untranslated text of the review, where the review was translated. If the review was not translated this is left blank. Corresponds to the JSON property originalText

Returns:

  • (String)


11718
11719
11720
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11718

def original_text
  @original_text
end

#reviewer_languageString

Language code for the reviewer. This is taken from the device settings so is not guaranteed to match the language the review is written in. May be absent. Corresponds to the JSON property reviewerLanguage

Returns:

  • (String)


11724
11725
11726
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11724

def reviewer_language
  @reviewer_language
end

#star_ratingFixnum

The star rating associated with the review, from 1 to 5. Corresponds to the JSON property starRating

Returns:

  • (Fixnum)


11729
11730
11731
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11729

def star_rating
  @star_rating
end

#textString

The content of the comment, i.e. review body. In some cases users have been able to write a review with separate title and body; in those cases the title and body are concatenated and separated by a tab character. Corresponds to the JSON property text

Returns:

  • (String)


11736
11737
11738
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11736

def text
  @text
end

#thumbs_down_countFixnum

Number of users who have given this review a thumbs down. Corresponds to the JSON property thumbsDownCount

Returns:

  • (Fixnum)


11741
11742
11743
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11741

def thumbs_down_count
  @thumbs_down_count
end

#thumbs_up_countFixnum

Number of users who have given this review a thumbs up. Corresponds to the JSON property thumbsUpCount

Returns:

  • (Fixnum)


11746
11747
11748
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11746

def thumbs_up_count
  @thumbs_up_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11753
11754
11755
11756
11757
11758
11759
11760
11761
11762
11763
11764
11765
11766
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11753

def update!(**args)
  @android_os_version = args[:android_os_version] if args.key?(:android_os_version)
  @app_version_code = args[:app_version_code] if args.key?(:app_version_code)
  @app_version_name = args[:app_version_name] if args.key?(:app_version_name)
  @device = args[:device] if args.key?(:device)
  @device_metadata = args[:device_metadata] if args.key?(:device_metadata)
  @last_modified = args[:last_modified] if args.key?(:last_modified)
  @original_text = args[:original_text] if args.key?(:original_text)
  @reviewer_language = args[:reviewer_language] if args.key?(:reviewer_language)
  @star_rating = args[:star_rating] if args.key?(:star_rating)
  @text = args[:text] if args.key?(:text)
  @thumbs_down_count = args[:thumbs_down_count] if args.key?(:thumbs_down_count)
  @thumbs_up_count = args[:thumbs_up_count] if args.key?(:thumbs_up_count)
end