Class: Google::Apis::AndroidpublisherV3::UserComment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

User entry from conversation between user and developer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserComment

Returns a new instance of UserComment.



10464
10465
10466
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_os_versionFixnum

Integer Android SDK version of the user's device at the time the review was written, e.g. 23 is Marshmallow. May be absent. Corresponds to the JSON property androidOsVersion

Returns:

  • (Fixnum)


10398
10399
10400
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10398

def android_os_version
  @android_os_version
end

#app_version_codeFixnum

Integer version code of the app as installed at the time the review was written. May be absent. Corresponds to the JSON property appVersionCode

Returns:

  • (Fixnum)


10404
10405
10406
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10404

def app_version_code
  @app_version_code
end

#app_version_nameString

String version name of the app as installed at the time the review was written. May be absent. Corresponds to the JSON property appVersionName

Returns:

  • (String)


10410
10411
10412
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10410

def app_version_name
  @app_version_name
end

#deviceString

Codename for the reviewer's device, e.g. klte, flounder. May be absent. Corresponds to the JSON property device

Returns:

  • (String)


10415
10416
10417
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10415

def device
  @device
end

#device_metadataGoogle::Apis::AndroidpublisherV3::DeviceMetadata

Characteristics of the user's device. Corresponds to the JSON property deviceMetadata



10420
10421
10422
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10420

def 
  @device_metadata
end

#last_modifiedGoogle::Apis::AndroidpublisherV3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970. Corresponds to the JSON property lastModified



10428
10429
10430
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10428

def last_modified
  @last_modified
end

#original_textString

Untranslated text of the review, where the review was translated. If the review was not translated this is left blank. Corresponds to the JSON property originalText

Returns:

  • (String)


10434
10435
10436
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10434

def original_text
  @original_text
end

#reviewer_languageString

Language code for the reviewer. This is taken from the device settings so is not guaranteed to match the language the review is written in. May be absent. Corresponds to the JSON property reviewerLanguage

Returns:

  • (String)


10440
10441
10442
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10440

def reviewer_language
  @reviewer_language
end

#star_ratingFixnum

The star rating associated with the review, from 1 to 5. Corresponds to the JSON property starRating

Returns:

  • (Fixnum)


10445
10446
10447
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10445

def star_rating
  @star_rating
end

#textString

The content of the comment, i.e. review body. In some cases users have been able to write a review with separate title and body; in those cases the title and body are concatenated and separated by a tab character. Corresponds to the JSON property text

Returns:

  • (String)


10452
10453
10454
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10452

def text
  @text
end

#thumbs_down_countFixnum

Number of users who have given this review a thumbs down. Corresponds to the JSON property thumbsDownCount

Returns:

  • (Fixnum)


10457
10458
10459
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10457

def thumbs_down_count
  @thumbs_down_count
end

#thumbs_up_countFixnum

Number of users who have given this review a thumbs up. Corresponds to the JSON property thumbsUpCount

Returns:

  • (Fixnum)


10462
10463
10464
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10462

def thumbs_up_count
  @thumbs_up_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10469

def update!(**args)
  @android_os_version = args[:android_os_version] if args.key?(:android_os_version)
  @app_version_code = args[:app_version_code] if args.key?(:app_version_code)
  @app_version_name = args[:app_version_name] if args.key?(:app_version_name)
  @device = args[:device] if args.key?(:device)
  @device_metadata = args[:device_metadata] if args.key?(:device_metadata)
  @last_modified = args[:last_modified] if args.key?(:last_modified)
  @original_text = args[:original_text] if args.key?(:original_text)
  @reviewer_language = args[:reviewer_language] if args.key?(:reviewer_language)
  @star_rating = args[:star_rating] if args.key?(:star_rating)
  @text = args[:text] if args.key?(:text)
  @thumbs_down_count = args[:thumbs_down_count] if args.key?(:thumbs_down_count)
  @thumbs_up_count = args[:thumbs_up_count] if args.key?(:thumbs_up_count)
end