Class: Google::Apis::AndroidpublisherV3::UserComment
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UserComment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
User entry from conversation between user and developer.
Instance Attribute Summary collapse
-
#android_os_version ⇒ Fixnum
Integer Android SDK version of the user's device at the time the review was written, e.g.
-
#app_version_code ⇒ Fixnum
Integer version code of the app as installed at the time the review was written.
-
#app_version_name ⇒ String
String version name of the app as installed at the time the review was written.
-
#device ⇒ String
Codename for the reviewer's device, e.g.
-
#device_metadata ⇒ Google::Apis::AndroidpublisherV3::DeviceMetadata
Characteristics of the user's device.
-
#last_modified ⇒ Google::Apis::AndroidpublisherV3::Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#original_text ⇒ String
Untranslated text of the review, where the review was translated.
-
#reviewer_language ⇒ String
Language code for the reviewer.
-
#star_rating ⇒ Fixnum
The star rating associated with the review, from 1 to 5.
-
#text ⇒ String
The content of the comment, i.e.
-
#thumbs_down_count ⇒ Fixnum
Number of users who have given this review a thumbs down.
-
#thumbs_up_count ⇒ Fixnum
Number of users who have given this review a thumbs up.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserComment
constructor
A new instance of UserComment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserComment
Returns a new instance of UserComment.
10298 10299 10300 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_os_version ⇒ Fixnum
Integer Android SDK version of the user's device at the time the review was
written, e.g. 23 is Marshmallow. May be absent.
Corresponds to the JSON property androidOsVersion
10232 10233 10234 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10232 def android_os_version @android_os_version end |
#app_version_code ⇒ Fixnum
Integer version code of the app as installed at the time the review was
written. May be absent.
Corresponds to the JSON property appVersionCode
10238 10239 10240 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10238 def app_version_code @app_version_code end |
#app_version_name ⇒ String
String version name of the app as installed at the time the review was written.
May be absent.
Corresponds to the JSON property appVersionName
10244 10245 10246 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10244 def app_version_name @app_version_name end |
#device ⇒ String
Codename for the reviewer's device, e.g. klte, flounder. May be absent.
Corresponds to the JSON property device
10249 10250 10251 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10249 def device @device end |
#device_metadata ⇒ Google::Apis::AndroidpublisherV3::DeviceMetadata
Characteristics of the user's device.
Corresponds to the JSON property deviceMetadata
10254 10255 10256 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10254 def @device_metadata end |
#last_modified ⇒ Google::Apis::AndroidpublisherV3::Timestamp
A Timestamp represents a point in time independent of any time zone or local
calendar, encoded as a count of seconds and fractions of seconds at nanosecond
resolution. The count is relative to an epoch at UTC midnight on January 1,
1970.
Corresponds to the JSON property lastModified
10262 10263 10264 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10262 def last_modified @last_modified end |
#original_text ⇒ String
Untranslated text of the review, where the review was translated. If the
review was not translated this is left blank.
Corresponds to the JSON property originalText
10268 10269 10270 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10268 def original_text @original_text end |
#reviewer_language ⇒ String
Language code for the reviewer. This is taken from the device settings so is
not guaranteed to match the language the review is written in. May be absent.
Corresponds to the JSON property reviewerLanguage
10274 10275 10276 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10274 def reviewer_language @reviewer_language end |
#star_rating ⇒ Fixnum
The star rating associated with the review, from 1 to 5.
Corresponds to the JSON property starRating
10279 10280 10281 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10279 def @star_rating end |
#text ⇒ String
The content of the comment, i.e. review body. In some cases users have been
able to write a review with separate title and body; in those cases the title
and body are concatenated and separated by a tab character.
Corresponds to the JSON property text
10286 10287 10288 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10286 def text @text end |
#thumbs_down_count ⇒ Fixnum
Number of users who have given this review a thumbs down.
Corresponds to the JSON property thumbsDownCount
10291 10292 10293 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10291 def thumbs_down_count @thumbs_down_count end |
#thumbs_up_count ⇒ Fixnum
Number of users who have given this review a thumbs up.
Corresponds to the JSON property thumbsUpCount
10296 10297 10298 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10296 def thumbs_up_count @thumbs_up_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10303 def update!(**args) @android_os_version = args[:android_os_version] if args.key?(:android_os_version) @app_version_code = args[:app_version_code] if args.key?(:app_version_code) @app_version_name = args[:app_version_name] if args.key?(:app_version_name) @device = args[:device] if args.key?(:device) @device_metadata = args[:device_metadata] if args.key?(:device_metadata) @last_modified = args[:last_modified] if args.key?(:last_modified) @original_text = args[:original_text] if args.key?(:original_text) @reviewer_language = args[:reviewer_language] if args.key?(:reviewer_language) @star_rating = args[:star_rating] if args.key?(:star_rating) @text = args[:text] if args.key?(:text) @thumbs_down_count = args[:thumbs_down_count] if args.key?(:thumbs_down_count) @thumbs_up_count = args[:thumbs_up_count] if args.key?(:thumbs_up_count) end |