Class: Google::Apis::AndroidpublisherV3::UserInitiatedCancellation
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::UserInitiatedCancellation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
Information specific to cancellations initiated by users.
Instance Attribute Summary collapse
-
#cancel_survey_result ⇒ Google::Apis::AndroidpublisherV3::CancelSurveyResult
Result of the cancel survey when the subscription was canceled by the user.
-
#cancel_time ⇒ String
The time at which the subscription was canceled by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserInitiatedCancellation
constructor
A new instance of UserInitiatedCancellation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserInitiatedCancellation
Returns a new instance of UserInitiatedCancellation.
11102 11103 11104 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_survey_result ⇒ Google::Apis::AndroidpublisherV3::CancelSurveyResult
Result of the cancel survey when the subscription was canceled by the user.
Corresponds to the JSON property cancelSurveyResult
11093 11094 11095 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11093 def cancel_survey_result @cancel_survey_result end |
#cancel_time ⇒ String
The time at which the subscription was canceled by the user. The user might
still have access to the subscription after this time. Use line_items.
expiry_time to determine if a user still has access.
Corresponds to the JSON property cancelTime
11100 11101 11102 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11100 def cancel_time @cancel_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11107 11108 11109 11110 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11107 def update!(**args) @cancel_survey_result = args[:cancel_survey_result] if args.key?(:cancel_survey_result) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) end |