Class: Google::Apis::AndroidpublisherV3::UsesConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Represents all configurations marked as required by use of the uses- configuration manifest tag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsesConfiguration

Returns a new instance of UsesConfiguration.



11881
11882
11883
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_keyboard_typeString

The type of keyboard required. Corresponds to the JSON property requiredKeyboardType

Returns:

  • (String)


11857
11858
11859
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11857

def required_keyboard_type
  @required_keyboard_type
end

#required_navigation_typeString

The navigation device required. Corresponds to the JSON property requiredNavigationType

Returns:

  • (String)


11862
11863
11864
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11862

def required_navigation_type
  @required_navigation_type
end

#required_touchscreen_typeString

The type of touchscreen required. Corresponds to the JSON property requiredTouchscreenType

Returns:

  • (String)


11867
11868
11869
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11867

def required_touchscreen_type
  @required_touchscreen_type
end

#requires_five_way_navigationBoolean Also known as: requires_five_way_navigation?

Whether or not the application requires a five-way navigation control. Corresponds to the JSON property requiresFiveWayNavigation

Returns:

  • (Boolean)


11872
11873
11874
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11872

def requires_five_way_navigation
  @requires_five_way_navigation
end

#requires_hardware_keyboardBoolean Also known as: requires_hardware_keyboard?

Whether or not the application requires a hardware keyboard. Corresponds to the JSON property requiresHardwareKeyboard

Returns:

  • (Boolean)


11878
11879
11880
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11878

def requires_hardware_keyboard
  @requires_hardware_keyboard
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11886
11887
11888
11889
11890
11891
11892
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 11886

def update!(**args)
  @required_keyboard_type = args[:required_keyboard_type] if args.key?(:required_keyboard_type)
  @required_navigation_type = args[:required_navigation_type] if args.key?(:required_navigation_type)
  @required_touchscreen_type = args[:required_touchscreen_type] if args.key?(:required_touchscreen_type)
  @requires_five_way_navigation = args[:requires_five_way_navigation] if args.key?(:requires_five_way_navigation)
  @requires_hardware_keyboard = args[:requires_hardware_keyboard] if args.key?(:requires_hardware_keyboard)
end