Class: Google::Apis::AndroidpublisherV3::Variant
- Inherits:
-
Object
- Object
- Google::Apis::AndroidpublisherV3::Variant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb
Overview
APK that is suitable for inclusion in a system image. The resource of SystemApksService.
Instance Attribute Summary collapse
-
#device_spec ⇒ Google::Apis::AndroidpublisherV3::DeviceSpec
The device spec used to generate a system APK.
-
#options ⇒ Google::Apis::AndroidpublisherV3::SystemApkOptions
Options for system APKs.
-
#variant_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Variant
constructor
A new instance of Variant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Variant
Returns a new instance of Variant.
10629 10630 10631 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_spec ⇒ Google::Apis::AndroidpublisherV3::DeviceSpec
The device spec used to generate a system APK.
Corresponds to the JSON property deviceSpec
10617 10618 10619 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10617 def device_spec @device_spec end |
#options ⇒ Google::Apis::AndroidpublisherV3::SystemApkOptions
Options for system APKs.
Corresponds to the JSON property options
10622 10623 10624 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10622 def @options end |
#variant_id ⇒ Fixnum
Output only. The ID of a previously created system APK variant.
Corresponds to the JSON property variantId
10627 10628 10629 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10627 def variant_id @variant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10634 10635 10636 10637 10638 |
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10634 def update!(**args) @device_spec = args[:device_spec] if args.key?(:device_spec) @options = args[:options] if args.key?(:options) @variant_id = args[:variant_id] if args.key?(:variant_id) end |