Class: Google::Apis::AndroidpublisherV3::VoidedPurchasesListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response for the voidedpurchases.list API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VoidedPurchasesListResponse

Returns a new instance of VoidedPurchasesListResponse.



12133
12134
12135
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_infoGoogle::Apis::AndroidpublisherV3::PageInfo

Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. Corresponds to the JSON property pageInfo



12114
12115
12116
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12114

def page_info
  @page_info
end

#token_paginationGoogle::Apis::AndroidpublisherV3::TokenPagination

Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page. Corresponds to the JSON property tokenPagination



12126
12127
12128
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12126

def token_pagination
  @token_pagination
end

#voided_purchasesArray<Google::Apis::AndroidpublisherV3::VoidedPurchase>

Corresponds to the JSON property voidedPurchases



12131
12132
12133
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12131

def voided_purchases
  @voided_purchases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12138
12139
12140
12141
12142
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 12138

def update!(**args)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @voided_purchases = args[:voided_purchases] if args.key?(:voided_purchases)
end