Class: Google::Apis::AndroidpublisherV3::VoidedPurchasesListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidpublisher_v3/classes.rb,
lib/google/apis/androidpublisher_v3/representations.rb,
lib/google/apis/androidpublisher_v3/representations.rb

Overview

Response for the voidedpurchases.list API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VoidedPurchasesListResponse

Returns a new instance of VoidedPurchasesListResponse.



10784
10785
10786
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_infoGoogle::Apis::AndroidpublisherV3::PageInfo

Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. Corresponds to the JSON property pageInfo



10765
10766
10767
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10765

def page_info
  @page_info
end

#token_paginationGoogle::Apis::AndroidpublisherV3::TokenPagination

Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/ previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page. Corresponds to the JSON property tokenPagination



10777
10778
10779
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10777

def token_pagination
  @token_pagination
end

#voided_purchasesArray<Google::Apis::AndroidpublisherV3::VoidedPurchase>

Corresponds to the JSON property voidedPurchases



10782
10783
10784
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10782

def voided_purchases
  @voided_purchases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10789
10790
10791
10792
10793
# File 'lib/google/apis/androidpublisher_v3/classes.rb', line 10789

def update!(**args)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @voided_purchases = args[:voided_purchases] if args.key?(:voided_purchases)
end